@@ -25,6 +25,10 @@ import java.util.Map;
 import java.util.StringTokenizer;
 import java.util.Vector;
 
+import org.dogtagpki.server.ca.ICMSCRLExtension;
+import org.dogtagpki.server.ca.ICMSCRLExtensions;
+import org.dogtagpki.server.ca.ICRLIssuingPoint;
+import org.dogtagpki.server.ca.ICertificateAuthority;
 import org.mozilla.jss.netscape.security.extensions.AuthInfoAccessExtension;
 import org.mozilla.jss.netscape.security.x509.AuthorityKeyIdentifierExtension;
 import org.mozilla.jss.netscape.security.x509.CRLExtensions;
@@ -44,17 +48,12 @@ import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.EPropertyNotDefined;
 import com.netscape.certsrv.base.EPropertyNotFound;
 import com.netscape.certsrv.base.IConfigStore;
-import com.netscape.certsrv.ca.ICMSCRLExtension;
-import com.netscape.certsrv.ca.ICMSCRLExtensions;
-import com.netscape.certsrv.ca.ICRLIssuingPoint;
-import com.netscape.certsrv.ca.ICertificateAuthority;
 import com.netscape.certsrv.common.Constants;
 import com.netscape.certsrv.common.NameValuePairs;
-import com.netscape.certsrv.logging.ILogger;
 import com.netscape.cms.crl.CMSIssuingDistributionPointExtension;
-import com.netscape.cms.logging.Logger;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.apps.CMSEngine;
+import com.netscape.cmscore.apps.EngineConfig;
 
 public class CMSCRLExtensions implements ICMSCRLExtensions {
 
@@ -71,7 +70,7 @@ public class CMSCRLExtensions implements ICMSCRLExtensions {
     private ICRLIssuingPoint mCRLIssuingPoint = null;
 
     @SuppressWarnings("unused")
-    private IConfigStore mConfig;
+    private CRLIssuingPointConfig mConfig;
     private IConfigStore mCRLExtConfig = null;
 
     private Vector<String> mCRLExtensionNames = new Vector<String>();
@@ -88,8 +87,6 @@ public class CMSCRLExtensions implements ICMSCRLExtensions {
     private static final Hashtable<String, String> mDefaultCRLExtensionClassNames = new Hashtable<String, String>();
     private static final Hashtable<String, String> mDefaultCRLExtensionIDs = new Hashtable<String, String>();
 
-    private Logger systemLogger = Logger.getLogger(ILogger.EV_SYSTEM, ILogger.S_CA);
-
     static {
 
         /* Default CRL Extensions */
@@ -195,7 +192,7 @@ public class CMSCRLExtensions implements ICMSCRLExtensions {
     /**
      * Constructs a CRL extensions for CRL issuing point.
      */
-    public CMSCRLExtensions(ICRLIssuingPoint crlIssuingPoint, IConfigStore config) {
+    public CMSCRLExtensions(ICRLIssuingPoint crlIssuingPoint, CRLIssuingPointConfig config) {
         boolean modifiedConfig = false;
 
         CMSEngine engine = CMS.getCMSEngine();
@@ -203,7 +200,7 @@ public class CMSCRLExtensions implements ICMSCRLExtensions {
         mCRLExtConfig = config.getSubStore(PROP_EXTENSION);
         mCRLIssuingPoint = crlIssuingPoint;
 
-        IConfigStore mFileConfig = engine.getConfigStore();
+        EngineConfig mFileConfig = engine.getConfig();
 
         IConfigStore crlExtConfig = mFileConfig;
         StringTokenizer st = new StringTokenizer(mCRLExtConfig.getName(), ".");
@@ -236,7 +233,7 @@ public class CMSCRLExtensions implements ICMSCRLExtensions {
                 try {
                     mFileConfig.commit(true);
                 } catch (EBaseException e) {
-                    log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_CA_CRLEXTS_SAVE_CONF", e.toString()));
+                    logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_SAVE_CONF", e.toString()), e);
                 }
             }
         }
@@ -249,34 +246,35 @@ public class CMSCRLExtensions implements ICMSCRLExtensions {
             if (extConfig.getBoolean(PROP_ENABLE)) {
                 mEnabledCRLExtensions.addElement(extName);
             }
+
         } catch (EPropertyNotFound e) {
             extConfig.putBoolean(PROP_ENABLE, mDefaultEnabledCRLExtensions.contains(extName));
             modifiedConfig = true;
             if (mDefaultEnabledCRLExtensions.contains(extName)) {
                 mEnabledCRLExtensions.addElement(extName);
             }
-            log(ILogger.LL_FAILURE,
-                    CMS.getLogMessage("CMSCORE_CA_CRLEXTS_NO_ENABLE", extName,
-                            mDefaultEnabledCRLExtensions.contains(extName) ? "true" : "false"));
+            logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_NO_ENABLE", extName,
+                            mDefaultEnabledCRLExtensions.contains(extName) ? "true" : "false"), e);
+
         } catch (EPropertyNotDefined e) {
             extConfig.putBoolean(PROP_ENABLE, mDefaultEnabledCRLExtensions.contains(extName));
             modifiedConfig = true;
             if (mDefaultEnabledCRLExtensions.contains(extName)) {
                 mEnabledCRLExtensions.addElement(extName);
             }
-            log(ILogger.LL_FAILURE,
-                    CMS.getLogMessage("CMSCORE_CA_CRLEXTS_UNDEFINE_ENABLE", extName,
-                            mDefaultEnabledCRLExtensions.contains(extName) ? "true" : "false"));
+            logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_UNDEFINE_ENABLE", extName,
+                            mDefaultEnabledCRLExtensions.contains(extName) ? "true" : "false"), e);
+
         } catch (EBaseException e) {
             extConfig.putBoolean(PROP_ENABLE, mDefaultEnabledCRLExtensions.contains(extName));
             modifiedConfig = true;
             if (mDefaultEnabledCRLExtensions.contains(extName)) {
                 mEnabledCRLExtensions.addElement(extName);
             }
-            log(ILogger.LL_FAILURE,
-                    CMS.getLogMessage("CMSCORE_CA_CRLEXTS_INVALID_ENABLE", extName,
-                            mDefaultEnabledCRLExtensions.contains(extName) ? "true" : "false"));
+            logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_INVALID_ENABLE", extName,
+                            mDefaultEnabledCRLExtensions.contains(extName) ? "true" : "false"), e);
         }
+
         return modifiedConfig;
     }
 
@@ -287,34 +285,35 @@ public class CMSCRLExtensions implements ICMSCRLExtensions {
             if (extConfig.getBoolean(PROP_CRITICAL)) {
                 mCriticalCRLExtensions.addElement(extName);
             }
+
         } catch (EPropertyNotFound e) {
             extConfig.putBoolean(PROP_CRITICAL, mDefaultCriticalCRLExtensions.contains(extName));
             modifiedConfig = true;
             if (mDefaultCriticalCRLExtensions.contains(extName)) {
                 mCriticalCRLExtensions.addElement(extName);
             }
-            log(ILogger.LL_FAILURE,
-                    CMS.getLogMessage("CMSCORE_CA_CRLEXTS_NO_CRITICAL", extName,
-                            mDefaultEnabledCRLExtensions.contains(extName) ? "true" : "false"));
+            logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_NO_CRITICAL", extName,
+                            mDefaultEnabledCRLExtensions.contains(extName) ? "true" : "false"), e);
+
         } catch (EPropertyNotDefined e) {
             extConfig.putBoolean(PROP_CRITICAL, mDefaultCriticalCRLExtensions.contains(extName));
             modifiedConfig = true;
             if (mDefaultCriticalCRLExtensions.contains(extName)) {
                 mCriticalCRLExtensions.addElement(extName);
             }
-            log(ILogger.LL_FAILURE,
-                    CMS.getLogMessage("CMSCORE_CA_CRLEXTS_UNDEFINE_CRITICAL", extName,
-                            mDefaultEnabledCRLExtensions.contains(extName) ? "true" : "false"));
+            logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_UNDEFINE_CRITICAL", extName,
+                            mDefaultEnabledCRLExtensions.contains(extName) ? "true" : "false"), e);
+
         } catch (EBaseException e) {
             extConfig.putBoolean(PROP_CRITICAL, mDefaultCriticalCRLExtensions.contains(extName));
             modifiedConfig = true;
             if (mDefaultCriticalCRLExtensions.contains(extName)) {
                 mCriticalCRLExtensions.addElement(extName);
             }
-            log(ILogger.LL_FAILURE,
-                    CMS.getLogMessage("CMSCORE_CA_CRLEXTS_INVALID_CRITICAL", extName,
-                            mDefaultEnabledCRLExtensions.contains(extName) ? "true" : "false"));
+            logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_INVALID_CRITICAL", extName,
+                            mDefaultEnabledCRLExtensions.contains(extName) ? "true" : "false"), e);
         }
+
         return modifiedConfig;
     }
 
@@ -334,21 +333,23 @@ public class CMSCRLExtensions implements ICMSCRLExtensions {
                         extConfig.putString(PROP_TYPE, PROP_CRL_ENTRY_EXT);
                         modifiedConfig = true;
                         mCRLEntryExtensionNames.addElement(extName);
-                        log(ILogger.LL_FAILURE,
-                                CMS.getLogMessage("CMSCORE_CA_CRLEXTS_INVALID_EXT", extName, PROP_CRL_ENTRY_EXT));
+                        logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_INVALID_EXT", extName, PROP_CRL_ENTRY_EXT));
+
                     } else if (mDefaultCRLExtensionNames.contains(extName)) {
                         extConfig.putString(PROP_TYPE, PROP_CRL_EXT);
                         modifiedConfig = true;
                         mCRLExtensionNames.addElement(extName);
-                        log(ILogger.LL_FAILURE,
-                                CMS.getLogMessage("CMSCORE_CA_CRLEXTS_INVALID_EXT", extName, PROP_CRL_EXT));
+                        logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_INVALID_EXT", extName, PROP_CRL_EXT));
+
                     } else {
-                        log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_CA_CRLEXTS_INVALID_EXT", extName, ""));
+                        logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_INVALID_EXT", extName, ""));
                     }
                 }
+
             } else {
-                log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_CA_CRLEXTS_UNDEFINE_EXT", extName));
+                logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_UNDEFINE_EXT", extName));
             }
+
         } catch (EPropertyNotFound e) {
             if (mDefaultCRLEntryExtensionNames.contains(extName)) {
                 extConfig.putString(PROP_TYPE, PROP_CRL_ENTRY_EXT);
@@ -357,10 +358,12 @@ public class CMSCRLExtensions implements ICMSCRLExtensions {
                 extConfig.putString(PROP_TYPE, PROP_CRL_EXT);
                 modifiedConfig = true;
             }
-            log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_CA_CRLEXTS_MISSING_EXT", extName));
+            logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_MISSING_EXT", extName), e);
+
         } catch (EBaseException e) {
-            log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_CA_CRLEXTS_INVALID_EXT", extName, ""));
+            logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_INVALID_EXT", extName, ""), e);
         }
+
         return modifiedConfig;
     }
 
@@ -388,18 +391,18 @@ public class CMSCRLExtensions implements ICMSCRLExtensions {
                             }
                         }
                     }
+
                 } catch (ClassCastException e) {
-                    log(ILogger.LL_FAILURE,
-                            CMS.getLogMessage("CMSCORE_CA_CRLEXTS_INCORRECT_CLASS", extClass, e.toString()));
+                    logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_INCORRECT_CLASS", extClass, e.toString()), e);
+
                 } catch (ClassNotFoundException e) {
-                    log(ILogger.LL_FAILURE,
-                            CMS.getLogMessage("CMSCORE_CA_CRLEXTS_CLASS_NOT_FOUND", extClass, e.toString()));
+                    logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_CLASS_NOT_FOUND", extClass, e.toString()), e);
+
                 } catch (InstantiationException e) {
-                    log(ILogger.LL_FAILURE,
-                            CMS.getLogMessage("CMSCORE_CA_CRLEXTS_CLASS_NOT_INST", extClass, e.toString()));
+                    logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_CLASS_NOT_INST", extClass, e.toString()), e);
+
                 } catch (IllegalAccessException e) {
-                    log(ILogger.LL_FAILURE,
-                            CMS.getLogMessage("CMSCORE_CA_CRLEXTS_CLASS_NOT_ACCESS", extClass, e.toString()));
+                    logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_CLASS_NOT_ACCESS", extClass, e.toString()), e);
                 }
 
             } else {
@@ -408,23 +411,26 @@ public class CMSCRLExtensions implements ICMSCRLExtensions {
                     extConfig.putString(PROP_CLASS, extClass);
                     modifiedConfig = true;
                 }
-                log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_CA_CRLEXTS_CLASS_NOT_DEFINED", extName));
+                logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_CLASS_NOT_DEFINED", extName));
             }
+
         } catch (EPropertyNotFound e) {
             if (mDefaultCRLExtensionClassNames.containsKey(extName)) {
                 extClass = mDefaultCRLExtensionClassNames.get(extName);
                 extConfig.putString(PROP_CLASS, extClass);
                 modifiedConfig = true;
             }
-            log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_CA_CRLEXTS_CLASS_MISSING", extName));
+            logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_CLASS_MISSING", extName), e);
+
         } catch (EBaseException e) {
             if (mDefaultCRLExtensionClassNames.containsKey(extName)) {
                 extClass = mDefaultCRLExtensionClassNames.get(extName);
                 extConfig.putString(PROP_CLASS, extClass);
                 modifiedConfig = true;
             }
-            log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_CA_CRLEXTS_CLASS_INVALID", extName));
+            logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_CLASS_INVALID", extName), e);
         }
+
         return modifiedConfig;
     }
 
@@ -490,16 +496,21 @@ public class CMSCRLExtensions implements ICMSCRLExtensions {
                         }
                     }
                 }
+
             } catch (ClassCastException e) {
-                log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_CA_CRLEXTS_INCORRECT_CLASS", name, e.toString()));
+                logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_INCORRECT_CLASS", name, e.toString()), e);
+
             } catch (ClassNotFoundException e) {
-                log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_CA_CRLEXTS_CLASS_NOT_FOUND", name, e.toString()));
+                logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_CLASS_NOT_FOUND", name, e.toString()), e);
+
             } catch (InstantiationException e) {
-                log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_CA_CRLEXTS_CLASS_NOT_INST", name, e.toString()));
+                logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_CLASS_NOT_INST", name, e.toString()), e);
+
             } catch (IllegalAccessException e) {
-                log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_CA_CRLEXTS_CLASS_NOT_ACCESS", name, e.toString()));
+                logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_CLASS_NOT_ACCESS", name, e.toString()), e);
+
             } catch (IOException e) {
-                log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_CA_CRLEXTS_CLASS_ADD", name, e.toString()));
+                logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_CLASS_ADD", name, e.toString()), e);
             }
         }
     }
@@ -551,15 +562,15 @@ public class CMSCRLExtensions implements ICMSCRLExtensions {
                                 cmsCRLExt.getConfigParams(mCRLExtConfig.getSubStore(id), nvp);
                             }
                         }
+
                     } catch (ClassNotFoundException e) {
-                        log(ILogger.LL_FAILURE,
-                                CMS.getLogMessage("CMSCORE_CA_CRLEXTS_CLASS_NOT_FOUND", name, e.toString()));
+                        logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_CLASS_NOT_FOUND", name, e.toString()), e);
+
                     } catch (InstantiationException e) {
-                        log(ILogger.LL_FAILURE,
-                                CMS.getLogMessage("CMSCORE_CA_CRLEXTS_CLASS_NOT_INST", name, e.toString()));
+                        logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_CLASS_NOT_INST", name, e.toString()), e);
+
                     } catch (IllegalAccessException e) {
-                        log(ILogger.LL_FAILURE,
-                                CMS.getLogMessage("CMSCORE_CA_CRLEXTS_CLASS_NOT_ACCESS", name, e.toString()));
+                        logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_CLASS_NOT_ACCESS", name, e.toString()), e);
                     }
 
                     int i = name.lastIndexOf('.');
@@ -678,11 +689,13 @@ public class CMSCRLExtensions implements ICMSCRLExtensions {
                     IConfigStore crlsSubStore = CA.getConfigStore();
                     crlsSubStore = crlsSubStore.getSubStore(ICertificateAuthority.PROP_CRL_SUBSTORE);
                     crlsSubStore = crlsSubStore.getSubStore(ipId);
+
                     try {
                         crlsSubStore.putString(Constants.PR_CA_CERTS_ONLY, newValue);
                         crlsSubStore.commit(true);
+
                     } catch (EBaseException e) {
-                        log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_CA_CRLEXTS_SAVE_CONF", e.toString()));
+                        logger.warn(CMS.getLogMessage("CMSCORE_CA_CRLEXTS_SAVE_CONF", e.toString()), e);
                     }
                 }
             }
@@ -714,8 +727,4 @@ public class CMSCRLExtensions implements ICMSCRLExtensions {
 
         return null;
     }
-
-    private void log(int level, String msg) {
-        systemLogger.log(level, "CMSCRLExtension - " + msg);
-    }
 }
