@@ -22,13 +22,17 @@ import java.io.OutputStream;
 import java.math.BigInteger;
 import java.security.cert.X509Certificate;
 import java.util.Enumeration;
+import java.util.HashMap;
 import java.util.Locale;
+import java.util.Map;
 
 import javax.servlet.ServletConfig;
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
+import org.dogtagpki.server.authentication.IAuthManager;
+import org.dogtagpki.server.authorization.AuthzToken;
 import org.dogtagpki.server.ca.CAEngine;
 import org.mozilla.jss.asn1.ASN1Util;
 import org.mozilla.jss.asn1.INTEGER;
@@ -43,9 +47,7 @@ import org.mozilla.jss.pkix.cmc.LraPopWitness;
 import org.mozilla.jss.pkix.cmc.OtherInfo;
 import org.mozilla.jss.pkix.cmc.TaggedAttribute;
 
-import com.netscape.certsrv.authentication.IAuthManager;
 import com.netscape.certsrv.authentication.IAuthToken;
-import com.netscape.certsrv.authorization.AuthzToken;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.SessionContext;
 import com.netscape.certsrv.logging.AuditEvent;
@@ -60,23 +62,22 @@ import com.netscape.certsrv.profile.ECMCPopRequiredException;
 import com.netscape.certsrv.profile.EDeferException;
 import com.netscape.certsrv.profile.EProfileException;
 import com.netscape.certsrv.profile.ERejectException;
-import com.netscape.certsrv.profile.IEnrollProfile;
-import com.netscape.certsrv.profile.IProfile;
-import com.netscape.certsrv.profile.IProfileAuthenticator;
-import com.netscape.certsrv.profile.IProfileContext;
-import com.netscape.certsrv.profile.IProfileInput;
-import com.netscape.certsrv.profile.IProfileSubsystem;
 import com.netscape.certsrv.request.INotify;
 import com.netscape.certsrv.request.IRequest;
 import com.netscape.certsrv.request.RequestId;
 import com.netscape.certsrv.request.RequestStatus;
 import com.netscape.cms.logging.Logger;
 import com.netscape.cms.logging.SignedAuditLogger;
+import com.netscape.cms.profile.IProfileAuthenticator;
+import com.netscape.cms.profile.common.EnrollProfile;
+import com.netscape.cms.profile.common.ProfileInput;
+import com.netscape.cms.profile.common.Profile;
 import com.netscape.cms.servlet.common.AuthCredentials;
 import com.netscape.cms.servlet.common.CMCOutputTemplate;
 import com.netscape.cms.servlet.common.CMSRequest;
 import com.netscape.cms.servlet.common.CMSTemplate;
 import com.netscape.cmscore.apps.CMS;
+import com.netscape.cmscore.profile.ProfileSubsystem;
 
 /**
  * This servlet submits end-user request into the profile framework.
@@ -113,7 +114,7 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
         mRenderResult = false;
     }
 
-    private void setInputsIntoContext(HttpServletRequest request, IProfile profile, IProfileContext ctx) {
+    private void setInputsIntoContext(HttpServletRequest request, Profile profile, Map<String, String> ctx) {
         String method = "ProfileSubmitCMCServlet.setInputsIntoContext: ";
         // passing inputs into context
         Enumeration<String> inputIds = profile.getProfileInputIds();
@@ -121,7 +122,7 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
         if (inputIds != null) {
             while (inputIds.hasMoreElements()) {
                 String inputId = inputIds.nextElement();
-                IProfileInput profileInput = profile.getProfileInput(inputId);
+                ProfileInput profileInput = profile.getProfileInput(inputId);
                 Enumeration<String> inputNames = profileInput.getValueNames();
 
                 while (inputNames.hasMoreElements()) {
@@ -129,7 +130,7 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
 
                     if (request.getParameter(inputName) != null) {
                         logger.debug(method + "setting: " + inputName);
-                        ctx.set(inputName, request.getParameter(inputName));
+                        ctx.put(inputName, request.getParameter(inputName));
                     }
                 }
             }
@@ -138,7 +139,7 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
     }
 
     private void setCredentialsIntoContext(HttpServletRequest request, IProfileAuthenticator authenticator,
-            IProfileContext ctx) {
+            Map<String, String> ctx) {
         Enumeration<String> authIds = authenticator.getValueNames();
 
         if (authIds != null) {
@@ -146,7 +147,7 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
                 String authName = authIds.nextElement();
 
                 if (request.getParameter(authName) != null) {
-                    ctx.set(authName, request.getParameter(authName));
+                    ctx.put(authName, request.getParameter(authName));
                 }
             }
         }
@@ -220,14 +221,14 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
         return authToken;
     }
 
-    private void setInputsIntoRequest(HttpServletRequest request, IProfile
+    private void setInputsIntoRequest(HttpServletRequest request, Profile
             profile, IRequest req) {
         Enumeration<String> inputIds = profile.getProfileInputIds();
 
         if (inputIds != null) {
             while (inputIds.hasMoreElements()) {
                 String inputId = inputIds.nextElement();
-                IProfileInput profileInput = profile.getProfileInput(inputId);
+                ProfileInput profileInput = profile.getProfileInput(inputId);
                 Enumeration<String> inputNames = profileInput.getValueNames();
 
                 if (inputNames != null) {
@@ -319,13 +320,13 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
         logger.debug("ProfileSubmitCMCServlet: start serving");
 
         if (mProfileSubId == null || mProfileSubId.equals("")) {
-            mProfileSubId = IProfileSubsystem.ID;
+            mProfileSubId = ProfileSubsystem.ID;
         }
 
         logger.debug("ProfileSubmitCMCServlet: SubId=" + mProfileSubId);
 
         CAEngine engine = (CAEngine) CMS.getCMSEngine();
-        IProfileSubsystem ps = (IProfileSubsystem) engine.getSubsystem(mProfileSubId);
+        ProfileSubsystem ps = engine.getProfileSubsystem();
 
         if (ps == null) {
             logger.warn("ProfileSubmitCMCServlet: ProfileSubsystem not found");
@@ -349,7 +350,7 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
             profileId = mProfileId;
         }
 
-        IProfile profile = null;
+        Profile profile = null;
 
         try {
             logger.debug("ProfileSubmitCMCServlet: profileId " + profileId);
@@ -388,16 +389,16 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
             return;
         }
 
-        IProfileContext ctx = profile.createContext();
+        Map<String, String> ctx = new HashMap<>();
         if (requestB64 != null) {
-            ctx.set("cert_request_type", cert_request_type);
-            ctx.set("cert_request", Utils.normalizeString(requestB64));
+            ctx.put("cert_request_type", cert_request_type);
+            ctx.put("cert_request", Utils.normalizeString(requestB64));
         }
         // passing auths into context
         IProfileAuthenticator authenticator = null;
 
         try {
-            authenticator = profile.getAuthenticator();
+            authenticator = ps.getProfileAuthenticator(profile);
         } catch (EProfileException e) {
             // authenticator not installed correctly
         }
@@ -510,7 +511,7 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
             // unlikely to happen, but do this just in case
             logger.debug("ProfileSubmitCMCServlet: found existing CRED_CMC_SIGNING_CERT in ctx for CMCUserSignedAuth:" + tmpCertSerialS);
             logger.debug("ProfileSubmitCMCServlet: null it out");
-            ctx.set(IAuthManager.CRED_CMC_SIGNING_CERT, "");
+            ctx.put(IAuthManager.CRED_CMC_SIGNING_CERT, "");
         }
 
         String signingCertSerialS = null;
@@ -519,7 +520,7 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
         }
         if (signingCertSerialS != null) {
             logger.debug("ProfileSubmitCMCServlet: setting CRED_CMC_SIGNING_CERT in ctx for CMCUserSignedAuth");
-            ctx.set(IAuthManager.CRED_CMC_SIGNING_CERT, signingCertSerialS);
+            ctx.put(IAuthManager.CRED_CMC_SIGNING_CERT, signingCertSerialS);
         }
 
         String tmpSharedTokenAuthenticatedCertSubject = ctx.get(IAuthToken.TOKEN_SHARED_TOKEN_AUTHENTICATED_CERT_SUBJECT);
@@ -527,7 +528,7 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
             // unlikely to happen, but do this just in case
             logger.debug("ProfileSubmitCMCServlet: found existing TOKEN_SHARED_TOKEN_AUTHENTICATED_CERT_SUBJECT in ctx for CMCUserSignedAuth:" + tmpSharedTokenAuthenticatedCertSubject);
             logger.debug("ProfileSubmitCMCServlet: null it out");
-            ctx.set(IAuthToken.TOKEN_SHARED_TOKEN_AUTHENTICATED_CERT_SUBJECT, "");
+            ctx.put(IAuthToken.TOKEN_SHARED_TOKEN_AUTHENTICATED_CERT_SUBJECT, "");
         }
 
         String errorCode = null;
@@ -630,7 +631,7 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
         if (attr != null) {
             boolean verifyAllow = false; //disable RA by default
             try {
-                verifyAllow = engine.getConfigStore().getBoolean("cmc.lraPopWitness.verify.allow", false);
+                verifyAllow = engine.getConfig().getBoolean("cmc.lraPopWitness.verify.allow", false);
             } catch (EBaseException ee) {
             }
             logger.debug("ProfileSubmitCMCServlet: cmc.lraPopWitness.verify.allow is " + verifyAllow);
@@ -873,7 +874,7 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
                     profile.submit(authToken, reqs[k]);
                     reqs[k].setRequestStatus(RequestStatus.COMPLETE);
 
-                    X509CertImpl x509cert = reqs[k].getExtDataInCert(IEnrollProfile.REQUEST_ISSUED_CERT);
+                    X509CertImpl x509cert = reqs[k].getExtDataInCert(EnrollProfile.REQUEST_ISSUED_CERT);
 
                     if (x509cert != null) {
 
@@ -981,7 +982,7 @@ public class ProfileSubmitCMCServlet extends ProfileServlet {
                     reqs[0].setRequestStatus(RequestStatus.COMPLETE);
                     //profile.getRequestQueue().markAsServiced(provedReq);
 
-                    X509CertImpl x509cert = reqs[0].getExtDataInCert(IEnrollProfile.REQUEST_ISSUED_CERT);
+                    X509CertImpl x509cert = reqs[0].getExtDataInCert(EnrollProfile.REQUEST_ISSUED_CERT);
 
                     if (x509cert != null) {
 
