@@ -17,13 +17,12 @@ import org.dogtagpki.server.rest.PKIExceptionMapper;
 import org.dogtagpki.server.rest.SecurityDomainService;
 import org.dogtagpki.server.rest.SelfTestService;
 import org.dogtagpki.server.rest.SessionContextInterceptor;
-import org.dogtagpki.server.rest.SystemCertService;
 import org.dogtagpki.server.rest.UserService;
 
 import com.netscape.certsrv.base.EBaseException;
-import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.apps.CMSEngine;
+import com.netscape.cmscore.apps.EngineConfig;
 
 public class CAApplication extends Application {
 
@@ -61,7 +60,7 @@ public class CAApplication extends Application {
         classes.add(UserService.class);
 
         // system certs
-        classes.add(SystemCertService.class);
+        classes.add(CASystemCertService.class);
 
         // kra connector
         classes.add(KRAConnectorService.class);
@@ -74,12 +73,12 @@ public class CAApplication extends Application {
 
         // security domain
         CMSEngine engine = CMS.getCMSEngine();
-        IConfigStore cs = engine.getConfigStore();
+        EngineConfig cs = engine.getConfig();
 
         // check server state
         int state;
         try {
-            state = cs.getInteger("cs.state");
+            state = cs.getState();
         } catch (EBaseException e) {
             logger.error("CAApplication: " + e.getMessage(), e);
             throw new RuntimeException(e);
