@@ -27,6 +27,8 @@ import java.util.List;
 import javax.ws.rs.PathParam;
 import javax.ws.rs.core.Response;
 
+import org.dogtagpki.server.ca.CAEngine;
+import org.dogtagpki.server.ca.ICertificateAuthority;
 import org.jboss.resteasy.plugins.providers.atom.Link;
 import org.mozilla.jss.netscape.security.x509.X500Name;
 
@@ -46,7 +48,6 @@ import com.netscape.certsrv.ca.CADisabledException;
 import com.netscape.certsrv.ca.CAMissingCertException;
 import com.netscape.certsrv.ca.CAMissingKeyException;
 import com.netscape.certsrv.ca.CANotFoundException;
-import com.netscape.certsrv.ca.ICertificateAuthority;
 import com.netscape.certsrv.cert.CertEnrollmentRequest;
 import com.netscape.certsrv.cert.CertRequestInfo;
 import com.netscape.certsrv.cert.CertRequestInfos;
@@ -55,8 +56,6 @@ import com.netscape.certsrv.cert.CertReviewResponse;
 import com.netscape.certsrv.profile.EDeferException;
 import com.netscape.certsrv.profile.EProfileException;
 import com.netscape.certsrv.profile.ERejectException;
-import com.netscape.certsrv.profile.IProfile;
-import com.netscape.certsrv.profile.IProfileSubsystem;
 import com.netscape.certsrv.profile.ProfileAttribute;
 import com.netscape.certsrv.profile.ProfileDataInfo;
 import com.netscape.certsrv.profile.ProfileDataInfos;
@@ -64,10 +63,11 @@ import com.netscape.certsrv.profile.ProfileInput;
 import com.netscape.certsrv.property.EPropertyException;
 import com.netscape.certsrv.request.RequestId;
 import com.netscape.certsrv.request.RequestNotFoundException;
+import com.netscape.cms.profile.common.Profile;
 import com.netscape.cms.servlet.base.PKIService;
-import com.netscape.cms.servlet.cert.CertRequestDAO;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.apps.CMSEngine;
+import com.netscape.cmscore.profile.ProfileSubsystem;
 import com.netscape.cmsutil.ldap.LDAPUtil;
 
 /**
@@ -88,8 +88,11 @@ public class CertRequestService extends PKIService implements CertRequestResourc
      */
     @Override
     public Response getRequestInfo(RequestId id) {
+
+        logger.info("Retrieving certificate request " + id);
+
         if (id == null) {
-            String message = "Unable to get cert request info: Missing request ID";
+            String message = "Unable to get certificate request info: Missing request ID";
             logger.error(message);
             throw new BadRequestException(message);
         }
@@ -113,6 +116,9 @@ public class CertRequestService extends PKIService implements CertRequestResourc
 
     @Override
     public Response enrollCert(CertEnrollmentRequest data, String aidString, String adnString) {
+
+        logger.info("Receiving certificate request");
+
         if (data == null) {
             String message = "Unable to create enrollment request: Missing input data";
             logger.error(message);
@@ -123,8 +129,9 @@ public class CertRequestService extends PKIService implements CertRequestResourc
             throw new BadRequestException("Cannot provide both issuer-id and issuer-dn");
 
         CMSEngine engine = CMS.getCMSEngine();
-        AuthorityID aid = null;
         ICertificateAuthority ca = (ICertificateAuthority) engine.getSubsystem(ICertificateAuthority.ID);
+
+        AuthorityID aid = null;
         if (aidString != null) {
             try {
                 aid = new AuthorityID(aidString);
@@ -135,6 +142,7 @@ public class CertRequestService extends PKIService implements CertRequestResourc
             if (ca == null)
                 throw new ResourceNotFoundException("CA not found: " + aidString);
         }
+
         if (adnString != null) {
             X500Name adn = null;
             try {
@@ -147,6 +155,7 @@ public class CertRequestService extends PKIService implements CertRequestResourc
                 throw new ResourceNotFoundException("CA not found: " + adnString);
             aid = ca.getAuthorityID();
         }
+
         if (!ca.getAuthorityEnabled())
             throw new ConflictingOperationException("CA not enabled: " + aid.toString());
 
@@ -194,42 +203,63 @@ public class CertRequestService extends PKIService implements CertRequestResourc
 
     @Override
     public Response approveRequest(RequestId id, CertReviewResponse data) {
+
+        logger.info("Approving certificate request " + id);
+
         changeRequestState(id, data, "approve");
         return createNoContentResponse();
     }
 
     @Override
     public Response rejectRequest(RequestId id, CertReviewResponse data) {
+
+        logger.info("Rejecting certificate request " + id);
+
         changeRequestState(id, data, "reject");
         return createNoContentResponse();
     }
 
     @Override
     public Response cancelRequest(RequestId id, CertReviewResponse data) {
+
+        logger.info("Canceling certificate request " + id);
+
         changeRequestState(id, data, "cancel");
         return createNoContentResponse();
     }
 
     @Override
     public Response updateRequest(RequestId id, CertReviewResponse data) {
+
+        logger.info("Updating certificate request " + id);
+
         changeRequestState(id, data, "update");
         return createNoContentResponse();
     }
 
     @Override
     public Response validateRequest(RequestId id, CertReviewResponse data) {
+
+        logger.info("Validating certificate request " + id);
+
         changeRequestState(id, data, "validate");
         return createNoContentResponse();
     }
 
     @Override
     public Response unassignRequest(RequestId id, CertReviewResponse data) {
+
+        logger.info("Unassigning certificate request " + id);
+
         changeRequestState(id, data, "unassign");
         return createNoContentResponse();
     }
 
     @Override
     public Response assignRequest(RequestId id, CertReviewResponse data) {
+
+        logger.info("Assigning certificate request " + id);
+
         changeRequestState(id, data, "assign");
         return createNoContentResponse();
     }
@@ -301,6 +331,9 @@ public class CertRequestService extends PKIService implements CertRequestResourc
 
     @Override
     public Response reviewRequest(@PathParam("id") RequestId id) {
+
+        logger.info("Reviewing certificate request " + id);
+
         if (id == null) {
             String message = "Unable to review cert request: Missing request ID";
             logger.error(message);
@@ -386,15 +419,16 @@ public class CertRequestService extends PKIService implements CertRequestResourc
             throw new BadRequestException(message);
         }
 
-        CMSEngine engine = CMS.getCMSEngine();
-        IProfileSubsystem ps = (IProfileSubsystem) engine.getSubsystem(IProfileSubsystem.ID);
+        CAEngine engine = (CAEngine) CMS.getCMSEngine();
+        ProfileSubsystem ps = engine.getProfileSubsystem();
+
         if (ps == null) {
             String message = "Unable to get enrollment template: Profile Service not available";
             logger.error(message);
             throw new PKIException(message);
         }
 
-        IProfile profile = null;
+        Profile profile = null;
         try {
             profile = ps.getProfile(profileId);
             if (profile == null) {
@@ -446,8 +480,8 @@ public class CertRequestService extends PKIService implements CertRequestResourc
         start = start == null ? DEFAULT_START : start;
         size = size == null ? DEFAULT_PAGESIZE : size;
 
-        CMSEngine engine = CMS.getCMSEngine();
-        IProfileSubsystem ps = (IProfileSubsystem) engine.getSubsystem(IProfileSubsystem.ID);
+        CAEngine engine = (CAEngine) CMS.getCMSEngine();
+        ProfileSubsystem ps = engine.getProfileSubsystem();
 
         if (ps == null) {
             throw new PKIException("Profile subsystem unavailable.");
