@@ -38,6 +38,7 @@ import javax.ws.rs.core.UriInfo;
 
 import org.apache.catalina.realm.GenericPrincipal;
 import org.apache.commons.lang.StringUtils;
+import org.dogtagpki.server.ca.CAEngine;
 import org.jboss.resteasy.plugins.providers.atom.Link;
 
 import com.netscape.certsrv.base.BadRequestException;
@@ -52,15 +53,10 @@ import com.netscape.certsrv.common.ScopeDef;
 import com.netscape.certsrv.logging.AuditEvent;
 import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.profile.EProfileException;
-import com.netscape.certsrv.profile.IProfile;
-import com.netscape.certsrv.profile.IProfileEx;
-import com.netscape.certsrv.profile.IProfileInput;
-import com.netscape.certsrv.profile.IProfileOutput;
-import com.netscape.certsrv.profile.IProfilePolicy;
-import com.netscape.certsrv.profile.IProfileSubsystem;
 import com.netscape.certsrv.profile.PolicyConstraint;
 import com.netscape.certsrv.profile.PolicyConstraintValue;
 import com.netscape.certsrv.profile.PolicyDefault;
+import com.netscape.certsrv.profile.ProfileAttribute;
 import com.netscape.certsrv.profile.ProfileData;
 import com.netscape.certsrv.profile.ProfileDataInfo;
 import com.netscape.certsrv.profile.ProfileDataInfos;
@@ -70,16 +66,19 @@ import com.netscape.certsrv.profile.ProfileOutput;
 import com.netscape.certsrv.profile.ProfileParameter;
 import com.netscape.certsrv.profile.ProfilePolicy;
 import com.netscape.certsrv.profile.ProfileResource;
+import com.netscape.certsrv.property.Descriptor;
 import com.netscape.certsrv.property.EPropertyException;
 import com.netscape.certsrv.registry.IPluginInfo;
-import com.netscape.certsrv.registry.IPluginRegistry;
+import com.netscape.cms.profile.common.CAEnrollProfile;
+import com.netscape.cms.profile.common.Profile;
 import com.netscape.cms.servlet.base.SubsystemService;
 import com.netscape.cms.servlet.profile.PolicyConstraintFactory;
 import com.netscape.cms.servlet.profile.PolicyDefaultFactory;
 import com.netscape.cmscore.apps.CMS;
-import com.netscape.cmscore.apps.CMSEngine;
 import com.netscape.cmscore.base.PropConfigStore;
 import com.netscape.cmscore.base.SimpleProperties;
+import com.netscape.cmscore.profile.ProfileSubsystem;
+import com.netscape.cmscore.registry.PluginRegistry;
 
 /**
  * @author alee
@@ -89,9 +88,14 @@ public class ProfileService extends SubsystemService implements ProfileResource
 
     public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(ProfileService.class);
 
-    CMSEngine engine = CMS.getCMSEngine();
-    private IProfileSubsystem ps = (IProfileSubsystem) engine.getSubsystem(IProfileSubsystem.ID);
-    private IPluginRegistry registry = (IPluginRegistry) engine.getSubsystem(IPluginRegistry.ID);
+    private PluginRegistry registry;
+    private ProfileSubsystem ps;
+
+    public ProfileService() {
+        CAEngine engine = (CAEngine) CMS.getCMSEngine();
+        registry = engine.getPluginRegistry();
+        ps = engine.getProfileSubsystem();
+    }
 
     @Override
     public Response listProfiles(Integer start, Integer size) {
@@ -154,7 +158,7 @@ public class ProfileService extends SubsystemService implements ProfileResource
         return createOKResponse(infos);
     }
 
-    private IProfile getProfile(String profileId) throws ProfileNotFoundException {
+    private Profile getProfile(String profileId) throws ProfileNotFoundException {
         boolean visibleOnly = true;
 
         if (profileId == null) {
@@ -177,7 +181,7 @@ public class ProfileService extends SubsystemService implements ProfileResource
                     visibleOnly = false;
         }
 
-        IProfile profile;
+        Profile profile;
         try {
             profile = ps.getProfile(profileId);
         } catch (EProfileException e) {
@@ -214,20 +218,19 @@ public class ProfileService extends SubsystemService implements ProfileResource
     }
 
     @Override
-    public Response retrieveProfileRaw(String profileId)
-            throws ProfileNotFoundException {
-        IProfile profile = getProfile(profileId);
+    public Response retrieveProfileRaw(String profileId) throws Exception {
+        Profile profile = getProfile(profileId);
         ByteArrayOutputStream data = new ByteArrayOutputStream();
         // add profileId and classId "virtual" properties
         profile.getConfigStore().put("profileId", profileId);
         profile.getConfigStore().put("classId", ps.getProfileClassId(profileId));
-        profile.getConfigStore().save(data, null);
+        profile.getConfigStore().store(data);
         return createOKResponse(data.toByteArray());
     }
 
 
     public ProfileData createProfileData(String profileId) throws EBaseException {
-        IProfile profile = getProfile(profileId);
+        Profile profile = getProfile(profileId);
 
         ProfileData data = new ProfileData();
 
@@ -290,8 +293,8 @@ public class ProfileService extends SubsystemService implements ProfileResource
         return data;
     }
 
-    public ProfilePolicy createProfilePolicy(IProfile profile, String setId, String policyId) throws EBaseException {
-        IProfilePolicy policy = profile.getProfilePolicy(setId, policyId);
+    public ProfilePolicy createProfilePolicy(Profile profile, String setId, String policyId) throws EBaseException {
+        com.netscape.cms.profile.common.ProfilePolicy policy = profile.getProfilePolicy(setId, policyId);
         IConfigStore policyStore = profile.getConfigStore().getSubStore(
                 "policyset." + setId + "." + policy.getId());
 
@@ -304,39 +307,66 @@ public class ProfileService extends SubsystemService implements ProfileResource
         return p;
     }
 
-    public static ProfileInput createProfileInput(IProfile profile, String inputId, Locale locale) throws EBaseException {
-        IProfileInput profileInput = profile.getProfileInput(inputId);
+    public static ProfileInput createProfileInput(Profile profile, String inputId, Locale locale) throws EBaseException {
+        com.netscape.cms.profile.common.ProfileInput profileInput = profile.getProfileInput(inputId);
         if (profileInput == null)
             return null;
 
         IConfigStore inputStore = profile.getConfigStore().getSubStore("input");
+        String name = profileInput.getName(locale);
         String classId = inputStore.getString(inputId + ".class_id");
 
-        return new ProfileInput(profileInput, inputId, classId, locale);
+        ProfileInput input = new ProfileInput(inputId, name, classId);
+
+        Enumeration<String> attrNames = profileInput.getValueNames();
+        while (attrNames.hasMoreElements()) {
+            String attrName = attrNames.nextElement();
+
+            Descriptor descriptor = (Descriptor) profileInput.getValueDescriptor(locale, attrName);
+
+            ProfileAttribute attr = new ProfileAttribute(attrName, null, descriptor);
+            input.addAttribute(attr);
+        }
+
+        return input;
     }
 
-    public static ProfileOutput createProfileOutput(IProfile profile, String outputId, Locale locale) throws EBaseException {
-        IProfileOutput profileOutput = profile.getProfileOutput(outputId);
+    public static ProfileOutput createProfileOutput(Profile profile, String outputId, Locale locale) throws EBaseException {
+        com.netscape.cms.profile.common.ProfileOutput profileOutput = profile.getProfileOutput(outputId);
         if (profileOutput == null)
             return null;
 
         IConfigStore outputStore = profile.getConfigStore().getSubStore("output");
+        String name = profileOutput.getName(locale);
         String classId = outputStore.getString(outputId + ".class_id");
 
-        return new ProfileOutput(profileOutput, outputId, classId, locale);
+        ProfileOutput output = new ProfileOutput(outputId, name, classId);
+
+        Enumeration<String> attrNames = profileOutput.getValueNames();
+        while (attrNames.hasMoreElements()) {
+            String attrName = attrNames.nextElement();
+
+            Descriptor descriptor = (Descriptor) profileOutput.getValueDescriptor(locale, attrName);
+
+            ProfileAttribute attr = new ProfileAttribute(attrName, null, descriptor);
+            output.addAttribute(attr);
+        }
+
+        return output;
     }
 
     public static ProfileDataInfo createProfileDataInfo(String profileId, boolean visibleOnly, UriInfo uriInfo,
             Locale locale) throws EBaseException {
 
-        CMSEngine engine = CMS.getCMSEngine();
-        IProfileSubsystem ps = (IProfileSubsystem) engine.getSubsystem(IProfileSubsystem.ID);
+        CAEngine engine = (CAEngine) CMS.getCMSEngine();
+        ProfileSubsystem ps = engine.getProfileSubsystem();
+
         if (profileId == null) {
             throw new EBaseException("Error creating ProfileDataInfo.");
         }
         ProfileDataInfo ret = null;
 
-        IProfile profile = null;
+        Profile profile = null;
 
         profile = ps.getProfile(profileId);
         if (profile == null) {
@@ -363,7 +393,7 @@ public class ProfileService extends SubsystemService implements ProfileResource
     }
 
     @Override
-    public Response modifyProfileState(String profileId, String action) {
+    public Response modifyProfileState(String profileId, String action) throws Exception {
         if (profileId == null) {
             logger.error("modifyProfileState: invalid request. profileId is null");
             throw new BadRequestException("Unable to modify profile state: Invalid Profile Id");
@@ -380,7 +410,7 @@ public class ProfileService extends SubsystemService implements ProfileResource
         }
 
         try {
-            IProfile profile = ps.getProfile(profileId);
+            Profile profile = ps.getProfile(profileId);
             if (profile == null) {
                 logger.error("Trying to modify profile: " + profileId + ".  Profile not found.");
                 throw new ProfileNotFoundException(profileId);
@@ -443,7 +473,7 @@ public class ProfileService extends SubsystemService implements ProfileResource
     }
 
     @Override
-    public Response createProfile(ProfileData data) {
+    public Response createProfile(ProfileData data) throws Exception {
         if (data == null) {
             logger.error("createProfile: profile data is null");
             throw new BadRequestException("Unable to create profile: Invalid profile data.");
@@ -454,7 +484,7 @@ public class ProfileService extends SubsystemService implements ProfileResource
             throw new PKIException("Error creating profile.  Profile Service not available");
         }
 
-        IProfile profile = null;
+        Profile profile = null;
         String profileId = data.getId();
         Map<String, String> auditParams = new LinkedHashMap<String, String>();
         try {
@@ -476,10 +506,10 @@ public class ProfileService extends SubsystemService implements ProfileResource
             profile.setVisible(data.isVisible());
             ps.commitProfile(profileId);
 
-            if (profile instanceof IProfileEx) {
+            if (profile instanceof CAEnrollProfile) {
                 // populates profile specific plugins such as
                 // policies, inputs and outputs with defaults
-                ((IProfileEx) profile).populate();
+                ((CAEnrollProfile) profile).populate();
             }
 
             auditProfileChange(
@@ -511,45 +541,60 @@ public class ProfileService extends SubsystemService implements ProfileResource
 
     @Override
     public Response createProfileRaw(byte[] data) {
+
         if (data == null) {
-            logger.error("createProfileRaw: profile data is null");
-            throw new BadRequestException("Unable to create profile: Invalid profile data.");
+            String message = "Unable to create profile: Missing profile data";
+            logger.error(message);
+            throw new BadRequestException(message);
         }
 
         if (ps == null) {
-            logger.error("createProfile: ps is null");
-            throw new PKIException("Error creating profile.  Profile Service not available");
+            String message = "Unable to create profile: Profile service not available";
+            logger.error(message);
+            throw new PKIException(message);
         }
 
+        logger.info("ProfileService: Creating profile from raw data");
+
         Map<String, String> auditParams = new LinkedHashMap<String, String>();
-        String profileId = null;
-        String classId = null;
+        String profileId;
+        String classId;
+
         SimpleProperties properties = new SimpleProperties();
         try {
             // load data and read profileId and classId
             properties.load(new ByteArrayInputStream(data));
-            profileId = properties.getProperty("profileId");
-            classId = properties.getProperty("classId");
+            profileId = properties.remove("profileId");
+            classId = properties.remove("classId");
+
         } catch (IOException e) {
-            throw new BadRequestException("Could not parse raw profile data.");
+            String message = "Unable to create profile: " + e.getMessage();
+            logger.error(message, e);
+            throw new BadRequestException(message, e);
         }
+
         if (profileId == null) {
-            throw new BadRequestException("Profile data did not contain profileId attribute.");
+            String message = "Unable to create profile: Missing profile ID";
+            logger.error(message);
+            throw new BadRequestException(message);
         }
+
         if (classId == null) {
-            throw new BadRequestException("Profile data did not contain classId attribute.");
+            String message = "Unable to create profile: Missing class ID";
+            logger.error(message);
+            throw new BadRequestException(message);
         }
-        properties.remove("profileId");
-        properties.remove("classId");
 
         try {
             ByteArrayOutputStream out = new ByteArrayOutputStream();
             properties.store(out, null);
             data = out.toByteArray();  // original data sans profileId, classId
 
-            IProfile profile = ps.getProfile(profileId);
+            Profile profile = ps.getProfile(profileId);
             if (profile != null) {
-                throw new ConflictingOperationException("Profile already exists");
+                String message = "Unable to create profile: Profile already exists";
+                logger.error(message);
+                throw new ConflictingOperationException(message);
             }
 
             auditParams.put("class_id", classId);
@@ -558,20 +603,26 @@ public class ProfileService extends SubsystemService implements ProfileResource
             String className = info.getClassName();
 
             // create temporary profile to verify profile configuration
-            IProfile tempProfile;
+            Profile tempProfile;
             try {
-                tempProfile = (IProfile) Class.forName(className).newInstance();
+                tempProfile = (Profile) Class.forName(className).newInstance();
             } catch (Exception e) {
-                throw new PKIException(
-                    "Error instantiating profile class: " + className);
+                String message = "Unable to create profile: " + e.getMessage();
+                logger.error(message, e);
+                throw new PKIException(message, e);
             }
+
             tempProfile.setId(profileId);
+
             try {
-                PropConfigStore tempConfig = new PropConfigStore(null);
+                PropConfigStore tempConfig = new PropConfigStore();
                 tempConfig.load(new ByteArrayInputStream(data));
                 tempProfile.init(ps, tempConfig);
+
             } catch (Exception e) {
-                throw new BadRequestException("Invalid profile data", e);
+                String message = "Unable to create profile: " + e.getMessage();
+                logger.error(message, e);
+                throw new BadRequestException(message, e);
             }
 
             // no error thrown, proceed with profile creation
@@ -588,8 +639,11 @@ public class ProfileService extends SubsystemService implements ProfileResource
                     auditParams);
 
             return createCreatedResponse(data, uriInfo.getAbsolutePath());
+
         } catch (EBaseException | IOException e) {
-            logger.error("createProfile: error in creating profile: " + e.getMessage(), e);
+
+            String message = "Unable to create profile: " + e.getMessage();
+            logger.error(message, e);
 
             auditProfileChange(
                     ScopeDef.SC_PROFILE_RULES,
@@ -598,12 +652,12 @@ public class ProfileService extends SubsystemService implements ProfileResource
                     ILogger.FAILURE,
                     auditParams);
 
-            throw new PKIException("Error in creating profile", e);
+            throw new PKIException(message, e);
         }
     }
 
     @Override
-    public Response modifyProfile(String profileId, ProfileData data) {
+    public Response modifyProfile(String profileId, ProfileData data) throws Exception {
         if (profileId == null) {
             logger.error("modifyProfile: invalid request. profileId is null");
             throw new BadRequestException("Unable to modify profile: Invalid Profile Id");
@@ -619,7 +673,7 @@ public class ProfileService extends SubsystemService implements ProfileResource
             throw new PKIException("Error modifying profile.  Profile Service not available");
         }
 
-        IProfile profile = null;
+        Profile profile = null;
         try {
             profile = ps.getProfile(profileId);
             if (profile == null) {
@@ -639,7 +693,7 @@ public class ProfileService extends SubsystemService implements ProfileResource
     }
 
     @Override
-    public Response modifyProfileRaw(String profileId, byte[] data) {
+    public Response modifyProfileRaw(String profileId, byte[] data) throws Exception {
         if (profileId == null) {
             logger.error("modifyProfile: invalid request. profileId is null");
             throw new BadRequestException("Unable to modify profile: Invalid Profile Id");
@@ -669,7 +723,7 @@ public class ProfileService extends SubsystemService implements ProfileResource
         properties.remove("classId");
 
         try {
-            IProfile profile = ps.getProfile(profileId);
+            Profile profile = ps.getProfile(profileId);
             if (profile == null) {
                 throw new ProfileNotFoundException(profileId);
             }
@@ -682,16 +736,16 @@ public class ProfileService extends SubsystemService implements ProfileResource
             String classId = ps.getProfileClassId(profileId);
             String className =
                 registry.getPluginInfo("profile", classId).getClassName();
-            IProfile tempProfile;
+            Profile tempProfile;
             try {
-                tempProfile = (IProfile) Class.forName(className).newInstance();
+                tempProfile = (Profile) Class.forName(className).newInstance();
             } catch (Exception e) {
                 throw new PKIException(
                     "Error instantiating profile class: " + className);
             }
             tempProfile.setId(profileId);
             try {
-                PropConfigStore tempConfig = new PropConfigStore(null);
+                PropConfigStore tempConfig = new PropConfigStore();
                 tempConfig.load(new ByteArrayInputStream(data));
                 tempProfile.init(ps, tempConfig);
             } catch (Exception e) {
@@ -711,7 +765,7 @@ public class ProfileService extends SubsystemService implements ProfileResource
         }
     }
 
-    private void changeProfileData(ProfileData data, IProfile profile) {
+    private void changeProfileData(ProfileData data, Profile profile) throws Exception {
         String profileId = data.getId();
         if (profile == null) {
             logger.error("changeProfileData - profile is null");
@@ -798,7 +852,7 @@ public class ProfileService extends SubsystemService implements ProfileResource
         return false;
     }
 
-    private void populateProfilePolicies(ProfileData data, IProfile profile) throws EBaseException {
+    private void populateProfilePolicies(ProfileData data, Profile profile) throws EBaseException {
         // get list of changes for auditing
         List<String> auditAdd = new ArrayList<String>();
         List<String> auditModify = new ArrayList<String>();
@@ -843,7 +897,7 @@ public class ProfileService extends SubsystemService implements ProfileResource
                     PolicyConstraint con = policy.getConstraint();
 
                     // create policy using defaults for PolicyDefault and PolicyConstraint
-                    IProfilePolicy p = profile.createProfilePolicy(setId, policy.getId(),
+                    com.netscape.cms.profile.common.ProfilePolicy p = profile.createProfilePolicy(setId, policy.getId(),
                             def.getClassId(), con.getClassId());
 
                     // change specific elements to match incoming data for PolicyDefault
@@ -923,7 +977,7 @@ public class ProfileService extends SubsystemService implements ProfileResource
         }
     }
 
-    private void populateProfileOutputs(ProfileData data, IProfile profile) throws EBaseException {
+    private void populateProfileOutputs(ProfileData data, Profile profile) throws EBaseException {
         // get list of changes for auditing
         List<String> auditAdd = new ArrayList<String>();
         List<String> auditModify = new ArrayList<String>();
@@ -1014,7 +1068,7 @@ public class ProfileService extends SubsystemService implements ProfileResource
         }
     }
 
-    private void populateProfileInputs(ProfileData data, IProfile profile) throws EBaseException {
+    private void populateProfileInputs(ProfileData data, Profile profile) throws EBaseException {
         // get list of changes for auditing
         List<String> auditAdd = new ArrayList<String>();
         List<String> auditModify = new ArrayList<String>();
@@ -1118,7 +1172,7 @@ public class ProfileService extends SubsystemService implements ProfileResource
         }
 
         try {
-            IProfile profile = ps.getProfile(profileId);
+            Profile profile = ps.getProfile(profileId);
             if (profile == null) {
                 logger.error("Trying to delete profile: " + profileId + ".  Profile already deleted.");
                 throw new ProfileNotFoundException(profileId);
