@@ -172,6 +172,8 @@ public class ConfigurationTest {
                 if (!token.isLoggedIn()) {
                     token.initPassword(password, password);
                 }
+            } finally {
+                password.clear();
             }
         } catch (Exception e) {
             System.out.println("Exception in logging into token:" + e.toString());
@@ -229,7 +231,6 @@ public class ConfigurationTest {
         data.setPin(pin);
         data.setSecurityDomainType(ConfigurationRequest.NEW_DOMAIN);
         data.setClone("false");
-        data.setHierarchy("root");
 
         // create system certs
         List<SystemCertData> systemCerts = new ArrayList<SystemCertData>();
@@ -284,13 +285,7 @@ public class ConfigurationTest {
         data.setPin(pin);
 
         data.setSecurityDomainType(ConfigurationRequest.EXISTING_DOMAIN);
-        data.setSecurityDomainUri("https://" + host + ":9225");
-        data.setSecurityDomainUser("admin");
-        data.setSecurityDomainPassword("redhat123");
-
         data.setClone("false");
-        data.setHierarchy("join");
-
         data.setIssuingCA("https://" + host + ":9224");
 
         // create system certs
@@ -346,10 +341,7 @@ public class ConfigurationTest {
         data.setPin(pin);
 
         data.setSecurityDomainType(ConfigurationRequest.NEW_DOMAIN);
-
         data.setClone("false");
-        data.setHierarchy("join");
-
         data.setIssuingCA("External CA");
 
         // create system certs
@@ -405,10 +397,7 @@ public class ConfigurationTest {
         data.setPin(pin);
 
         data.setSecurityDomainType(ConfigurationRequest.NEW_DOMAIN);
-
         data.setClone("false");
-        data.setHierarchy("join");
-
         data.setIssuingCA("External CA");
 
         // create system certs
@@ -471,14 +460,7 @@ public class ConfigurationTest {
         ConfigurationRequest data = new ConfigurationRequest();
         data.setPin(pin);
         data.setSecurityDomainType(ConfigurationRequest.EXISTING_DOMAIN);
-        data.setSecurityDomainUri("https://" + host + ":9225");
-        data.setSecurityDomainUser("admin");
-        data.setSecurityDomainPassword("redhat123");
-
         data.setClone("true");
-        data.setCloneUri("https://" + host + ":9224" );
-
-        data.setHierarchy("root");
 
         // create system certs
         List<SystemCertData> systemCerts = new ArrayList<SystemCertData>();
@@ -500,12 +482,7 @@ public class ConfigurationTest {
         data.setPin(pin);
 
         data.setSecurityDomainType(ConfigurationRequest.EXISTING_DOMAIN);
-        data.setSecurityDomainUri("https://" + host + ":9225");
-        data.setSecurityDomainUser("admin");
-        data.setSecurityDomainPassword("redhat123");
-
         data.setClone("false");
-
         data.setIssuingCA("https://" + host + ":9224");
 
         // create system certs
@@ -561,12 +538,7 @@ public class ConfigurationTest {
         data.setPin(pin);
 
         data.setSecurityDomainType(ConfigurationRequest.EXISTING_DOMAIN);
-        data.setSecurityDomainUri("https://" + host + ":9225");
-        data.setSecurityDomainUser("admin");
-        data.setSecurityDomainPassword("redhat123");
-
         data.setClone("false");
-
         data.setIssuingCA("https://" + host + ":9224");
 
         // create system certs
@@ -614,12 +586,7 @@ public class ConfigurationTest {
         data.setPin(pin);
 
         data.setSecurityDomainType(ConfigurationRequest.EXISTING_DOMAIN);
-        data.setSecurityDomainUri("https://" + host + ":9225");
-        data.setSecurityDomainUser("admin");
-        data.setSecurityDomainPassword("redhat123");
-
         data.setClone("false");
-
         data.setIssuingCA("https://" + host + ":9224");
 
         // create system certs
