@@ -620,13 +620,23 @@ class CertClient(object):
 
     def __init__(self, connection):
         """ Constructor """
+
         self.connection = connection
-        self.headers = {'Content-type': 'application/json',
-                        'Accept': 'application/json'}
+
         self.cert_url = '/rest/certs'
         self.agent_cert_url = '/rest/agent/certs'
         self.cert_requests_url = '/rest/certrequests'
         self.agent_cert_requests_url = '/rest/agent/certrequests'
+
+        if connection.subsystem is None:
+            self.cert_url = '/ca' + self.cert_url
+            self.agent_cert_url = '/ca' + self.agent_cert_url
+            self.cert_requests_url = '/ca' + self.cert_requests_url
+            self.agent_cert_requests_url = '/ca' + self.agent_cert_requests_url
+
+        self.headers = {'Content-type': 'application/json',
+                        'Accept': 'application/json'}
+
         self.enrollment_templates = {}
 
     @pki.handle_exceptions()
@@ -1060,7 +1070,7 @@ encoder.NOTYPES['ProfileParameter'] = profile.ProfileParameter
 
 def main():
     # Create a PKIConnection object that stores the details of the CA.
-    connection = client.PKIConnection('https', 'localhost', '8443', 'ca')
+    connection = client.PKIConnection('https', 'localhost', '8443')
 
     # The pem file used for authentication. Created from a p12 file using the
     # command -
