@@ -110,11 +110,9 @@ class PKCS12ImportCLI(pki.cli.CLI):
                 overwrite = True
 
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
                 logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--debug':
-                self.set_debug(True)
                 logging.getLogger().setLevel(logging.DEBUG)
 
             elif o == '--help':
@@ -122,7 +120,7 @@ class PKCS12ImportCLI(pki.cli.CLI):
                 sys.exit()
 
             else:
-                logger.error('option %s not recognized', o)
+                logger.error('Invalid option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
@@ -142,7 +140,7 @@ class PKCS12ImportCLI(pki.cli.CLI):
         # using certutil in order to preserve the nickname stored in
         # the PKCS #12 file.
 
-        logger.info('Getting certificate infos in PKCS #12 file')
+        logger.info('Certificates in PKCS #12 file:')
 
         certs = []
 
@@ -164,12 +162,12 @@ class PKCS12ImportCLI(pki.cli.CLI):
                 if password_file:
                     cmd.extend(['--pkcs12-password-file', password_file])
 
-                if self.verbose:
-                    cmd.extend(['--verbose'])
-
-                if self.debug:
+                if logger.isEnabledFor(logging.DEBUG):
                     cmd.extend(['--debug'])
 
+                elif logger.isEnabledFor(logging.INFO):
+                    cmd.extend(['--verbose'])
+
                 main_cli.execute_java(cmd, stdout=f)
 
             # parse results
@@ -186,7 +184,9 @@ class PKCS12ImportCLI(pki.cli.CLI):
 
                     match = re.match(r'  Friendly Name: (.*)$', line)
                     if match:
-                        cert_info['nickname'] = match.group(1)
+                        nickname = match.group(1)
+                        cert_info['nickname'] = nickname
+                        logger.info('- %s', nickname)
                         continue
 
                     match = re.match(r'  Trust Flags: (.*)$', line)
@@ -205,7 +205,7 @@ class PKCS12ImportCLI(pki.cli.CLI):
         # import CA certificates if requested
         if import_ca_certs:
 
-            logger.info('Importing CA certificates')
+            logger.info('Importing CA certificates:')
 
             tmpdir = tempfile.mkdtemp()
 
@@ -226,17 +226,16 @@ class PKCS12ImportCLI(pki.cli.CLI):
 
                     cert_id = cert_info['id']
                     nickname = cert_info['nickname']
+                    logger.info('- %s', nickname)
 
-                    cert = nssdb.get_cert(
-                        nickname=nickname)
+                    cert = nssdb.get_cert(nickname=nickname)
 
                     if cert:
                         if not overwrite:
-                            logger.warning('cert %s already exists', nickname)
+                            logger.warning('Certificate already exists: %s', nickname)
                             continue
 
-                        nssdb.remove_cert(
-                            nickname=nickname)
+                        nssdb.remove_cert(nickname=nickname)
 
                     if 'trust_flags' in cert_info:
                         trust_flags = cert_info['trust_flags']
@@ -261,12 +260,12 @@ class PKCS12ImportCLI(pki.cli.CLI):
 
                     cmd.extend(['--cert-id', cert_id])
 
-                    if self.verbose:
-                        cmd.extend(['--verbose'])
-
-                    if self.debug:
+                    if logger.isEnabledFor(logging.DEBUG):
                         cmd.extend(['--debug'])
 
+                    elif logger.isEnabledFor(logging.INFO):
+                        cmd.extend(['-v'])
+
                     main_cli.execute_java(cmd)
 
                     logger.info('Importing %s', nickname)
@@ -282,7 +281,7 @@ class PKCS12ImportCLI(pki.cli.CLI):
         # import user certificates if requested
         if import_user_certs:
 
-            logger.info('Importing user certificates')
+            logger.info('Importing user certificates:')
 
             nicknames = []
             for cert_info in certs:
@@ -292,6 +291,8 @@ class PKCS12ImportCLI(pki.cli.CLI):
                     continue
 
                 nickname = cert_info['nickname']
+                logger.info('- %s', nickname)
+
                 if nickname not in nicknames:
                     nicknames.append(nickname)
 
@@ -312,15 +313,13 @@ class PKCS12ImportCLI(pki.cli.CLI):
             if overwrite:
                 cmd.extend(['--overwrite'])
 
-            if self.verbose:
-                cmd.extend(['--verbose'])
-
-            if self.debug:
+            if logger.isEnabledFor(logging.DEBUG):
                 cmd.extend(['--debug'])
 
+            elif logger.isEnabledFor(logging.INFO):
+                cmd.extend(['-v'])
+
             cmd.extend(nicknames)
 
             with open(os.devnull, 'w') as f:
                 main_cli.execute_java(cmd, stdout=f)
-
-        self.print_message('Import complete')
