@@ -204,6 +204,7 @@ class NSSDatabase(object):
             self.password_file = password_file
 
         else:
+            # no password or password file provided
             self.password_file = None
 
         if internal_password:
@@ -221,18 +222,35 @@ class NSSDatabase(object):
 
         self.passwords = passwords
 
-    def create(self):
+    def create(self, enable_trust_policy=False):
 
         cmd = [
             'certutil',
             '-N',
-            '-d', self.directory,
-            '-f', self.internal_password_file
+            '-d', self.directory
         ]
 
+        if self.internal_password_file:
+            cmd.extend(['-f', self.internal_password_file])
+        else:
+            cmd.extend(['--empty-password'])
+
         logger.debug('Command: %s', ' '.join(cmd))
         subprocess.check_call(cmd)
 
+        if enable_trust_policy and not self.module_exists('p11-kit-trust'):
+            self.add_module('p11-kit-trust', '/usr/share/pki/lib/p11-kit-trust.so')
+
+    def exists(self):
+
+        if os.path.exists(os.path.join(self.directory, 'cert9.db')):
+            return True
+
+        if os.path.exists(os.path.join(self.directory, 'cert8.db')):
+            return True
+
+        return False
+
     def close(self):
         shutil.rmtree(self.tmpdir)
 
@@ -295,6 +313,9 @@ class NSSDatabase(object):
         return dest_dbtype == 'sql' and self.get_dbtype() == 'dbm'
 
     def convert_db(self):
+        '''
+        See https://fedoraproject.org/wiki/Changes/NSSDefaultFileFormatSql
+        '''
         dbtype = self.get_dbtype()
         if dbtype is None:
             raise ValueError(
@@ -309,17 +330,18 @@ class NSSDatabase(object):
             "Convert NSSDB %s from DBM to SQL format", self.directory
         )
 
-        basecmd = [
+        cmd = [
             'certutil',
-            '-d', 'sql:{}'.format(self.directory),
-            '-f', self.password_file,
-        ]
-        # See https://fedoraproject.org/wiki/Changes/NSSDefaultFileFormatSql
-        cmd = basecmd + [
             '-N',
-            '-@', self.password_file
+            '-d', 'sql:{}'.format(self.directory)
         ]
 
+        if self.password_file:
+            cmd.extend([
+                '-f', self.password_file,
+                '-@', self.password_file
+            ])
+
         logger.debug('Command: %s', ' '.join(map(str, cmd)))
         subprocess.check_call(cmd)
 
@@ -339,16 +361,25 @@ class NSSDatabase(object):
         if selinux is not None and selinux.is_selinux_enabled():
             selinux.restorecon(self.directory, recursive=True)
 
-        # list certs to verify DB
         if self.get_dbtype() != 'sql':
             raise RuntimeError(
-                "Migration of NSS database {} was not successfull.".format(
+                "Migration of NSS database {} was not successful.".format(
                     self.directory
                 )
             )
 
+        # list certs to verify DB
+        cmd = [
+            'certutil',
+            '-L',
+            '-d', 'sql:{}'.format(self.directory)
+        ]
+
+        if self.password_file:
+            cmd.extend(['-f', self.password_file])
+
         with open(os.devnull, 'wb') as f:
-            subprocess.check_call(basecmd + ['-L'], stdout=f)
+            subprocess.check_call(cmd, stdout=f)
 
         for oldname, _ in migration:  # pylint: disable=unused-variable
             oldname = os.path.join(self.directory, oldname)
@@ -356,6 +387,65 @@ class NSSDatabase(object):
 
         logger.info("Migration successful")
 
+    def module_exists(self, name):
+
+        logger.info('Checking module %s', name)
+
+        cmd = [
+            'modutil',
+            '-dbdir', self.directory,
+            '-rawlist'
+        ]
+
+        logger.debug('Command: %s', ' '.join(cmd))
+
+        result = subprocess.run(cmd, stdout=subprocess.PIPE, check=True)
+        output = result.stdout.decode('utf-8')
+
+        pattern = re.compile(r' name="%s"' % name)
+
+        for line in output.splitlines():
+
+            logger.info('Output: %s', line)
+
+            if pattern.search(line):
+                logger.info('Module %s found', name)
+                return True
+
+        logger.info('Module %s not found', name)
+        return False
+
+    def add_module(self, name, library):
+
+        logger.info('Adding module %s (%s)', name, library)
+
+        cmd = [
+            'modutil',
+            '-dbdir', self.directory,
+            '-nocertdb',
+            '-add', name,
+            '-libfile', library,
+            '-force'
+        ]
+
+        logger.debug('Command: %s', ' '.join(cmd))
+
+        # modutil will generate the following question:
+
+        # WARNING: Manually adding a module while p11-kit is enabled could cause
+        # duplicate module registration in your security database. It is suggested
+        # to configure the module through p11-kit configuration file instead.
+        #
+        # Type 'q <enter>' to abort, or <enter> to continue:
+
+        # respond with <enter>
+
+        subprocess.run(
+            cmd,
+            input='\n'.encode('utf-8'),
+            stdout=subprocess.DEVNULL,
+            check=True)
+
     def add_cert(self, nickname, cert_file, token=None, trust_attributes=None):
 
         tmpdir = tempfile.mkdtemp()
@@ -372,13 +462,18 @@ class NSSDatabase(object):
                     '-A',
                     '-d', self.directory,
                     '-h', token,
-                    '-P', token,
-                    '-f', password_file,
+                    '-P', token
+                ]
+
+                if password_file:
+                    cmd.extend(['-f', password_file])
+
+                cmd.extend([
                     '-n', nickname,
                     '-a',
                     '-i', cert_file,
                     '-t', ''
-                ]
+                ])
 
                 logger.debug('Command: %s', ' '.join(map(str, cmd)))
                 rc = subprocess.call(cmd)
@@ -395,13 +490,18 @@ class NSSDatabase(object):
                 cmd = [
                     'certutil',
                     '-A',
-                    '-d', self.directory,
-                    '-f', self.internal_password_file,
+                    '-d', self.directory
+                ]
+
+                if self.internal_password_file:
+                    cmd.extend(['-f', self.internal_password_file])
+
+                cmd.extend([
                     '-n', nickname,
                     '-a',
                     '-i', cert_file,
                     '-t', trust_attributes
-                ]
+                ])
 
                 logger.debug('Command: %s', ' '.join(map(str, cmd)))
                 subprocess.check_call(cmd)
@@ -425,10 +525,12 @@ class NSSDatabase(object):
 
         cmd = [
             'pki',
-            '-d', self.directory,
-            '-C', self.internal_password_file
+            '-d', self.directory
         ]
 
+        if self.internal_password_file:
+            cmd.extend(['-C', self.internal_password_file])
+
         cmd.extend([
             'client-cert-import',
             '--ca-cert', cert_file
@@ -450,8 +552,10 @@ class NSSDatabase(object):
         if self.token:
             cmd.extend(['-h', self.token])
 
+        if self.password_file:
+            cmd.extend(['-f', self.password_file])
+
         cmd.extend([
-            '-f', self.password_file,
             '-n', nickname,
             '-t', trust_attributes
         ])
@@ -459,7 +563,16 @@ class NSSDatabase(object):
         logger.debug('Command: %s', ' '.join(map(str, cmd)))
         subprocess.check_call(cmd)
 
-    def create_noise(self, noise_file, size=2048):
+    def create_noise(self, noise_file, size=2048, key_type='rsa'):
+        # Under EC keys, key_size parameter is actually the name of a curve.
+        # This curve maps to a specific size, but EC keys require less entropy
+        # to generate than RSA keys. We can either maintain a mapping of
+        # curve name -> key size (and note that the openssl rand command takes
+        # the number of bytes, not the number of bits), or we can hard-code
+        # some safe value. We choose the latter.
+        if key_type.lower() in ('ec', 'ecc'):
+            size = 1024
+
         cmd = [
             'openssl',
             'rand',
@@ -576,7 +689,7 @@ class NSSDatabase(object):
                 if noise_file is None:
                     noise_file = os.path.join(tmpdir, 'noise')
                     size = key_size if key_size else 2048
-                    self.create_noise(noise_file=noise_file, size=size)
+                    self.create_noise(noise_file=noise_file, size=size, key_type=key_type)
                 key_args.extend(['-z', noise_file])
 
             cmd.extend(key_args)
@@ -587,8 +700,10 @@ class NSSDatabase(object):
             if token:
                 cmd.extend(['-h', token])
 
+            if password_file:
+                cmd.extend(['-f', password_file])
+
             cmd.extend([
-                '-f', password_file,
                 '-s', subject_dn,
                 '-o', binary_request_file,
             ])
@@ -674,8 +789,9 @@ class NSSDatabase(object):
             rc = p.wait()
 
             if rc:
-                raise Exception(
-                    'Failed to generate certificate request. RC: %d' % rc)
+                msg = "Failed to generate certificate request. Return code: %d\n"
+                msg += "Command: %s"
+                raise Exception(msg % (rc, cmd))
 
             # encode binary request in base-64
             b64_request_file = os.path.join(tmpdir, 'request.b64')
@@ -722,11 +838,13 @@ class NSSDatabase(object):
 
         cmd = [
             'certutil',
-            '-d', self.directory,
-            '-f', password_file,
             '-G',
+            '-d', self.directory
         ]
 
+        if password_file:
+            cmd.extend(['-f', password_file])
+
         token = self.get_effective_token(token)
         if token:
             cmd.extend(['-h', token])
@@ -739,7 +857,7 @@ class NSSDatabase(object):
             fd, noise_file = tempfile.mkstemp()
             os.close(fd)
             size = key_size if key_size else 2048
-            self.create_noise(noise_file=noise_file, size=size)
+            self.create_noise(noise_file=noise_file, size=size, key_type=key_type)
         cmd.extend(['-z', noise_file])
 
         try:
@@ -758,11 +876,13 @@ class NSSDatabase(object):
         """
         cmd = [
             'certutil',
-            '-d', self.directory,
-            '-f', password_file,
             '-K',
+            '-d', self.directory
         ]
 
+        if password_file:
+            cmd.extend(['-f', password_file])
+
         token = self.get_effective_token(token)
         if token:
             cmd.extend(['-h', token])
@@ -801,8 +921,10 @@ class NSSDatabase(object):
         if self.token:
             cmd.extend(['-h', self.token])
 
+        if self.password_file:
+            cmd.extend(['-f', self.password_file])
+
         cmd.extend([
-            '-f', self.password_file,
             '-a',
             '-i', request_file,
             '-o', cert_file,
@@ -1053,10 +1175,10 @@ class NSSDatabase(object):
                 cmd.extend(['-h', token])
                 fullname = token + ':' + fullname
 
-            cmd.extend([
-                '-f', password_file,
-                '-n', fullname
-            ])
+            if password_file:
+                cmd.extend(['-f', password_file])
+
+            cmd.extend(['-n', fullname])
 
             if output_format_option:
                 cmd.extend([output_format_option])
@@ -1134,8 +1256,7 @@ class NSSDatabase(object):
                     append=False,
                     include_trust_flags=True,
                     include_key=True,
-                    include_chain=True,
-                    debug=False):
+                    include_chain=True):
 
         tmpdir = tempfile.mkdtemp()
 
@@ -1154,10 +1275,12 @@ class NSSDatabase(object):
 
             cmd = [
                 'pki',
-                '-d', self.directory,
-                '-C', self.password_file
+                '-d', self.directory
             ]
 
+            if self.password_file:
+                cmd.extend(['-C', self.password_file])
+
             if self.token:
                 cmd.extend(['--token', self.token])
                 full_name = self.token + ':' + nickname
@@ -1192,7 +1315,7 @@ class NSSDatabase(object):
             if not include_chain:
                 cmd.extend(['--no-chain'])
 
-            if debug:
+            if logger.isEnabledFor(logging.DEBUG):
                 cmd.extend(['--debug'])
 
             cmd.extend([full_name])
@@ -1226,10 +1349,10 @@ class NSSDatabase(object):
             if token:
                 cmd.extend(['-h', token])
 
-            cmd.extend([
-                '-f', password_file,
-                '-n', nickname
-            ])
+            if password_file:
+                cmd.extend(['-f', password_file])
+
+            cmd.extend(['-n', nickname])
 
             logger.debug('Command: %s', ' '.join(map(str, cmd)))
             subprocess.check_call(cmd)
@@ -1380,10 +1503,12 @@ class NSSDatabase(object):
 
             cmd = [
                 'pki',
-                '-d', self.directory,
-                '-C', self.password_file
+                '-d', self.directory
             ]
 
+            if self.password_file:
+                cmd.extend(['-C', self.password_file])
+
             if self.token:
                 cmd.extend(['--token', self.token])
 
@@ -1417,8 +1542,7 @@ class NSSDatabase(object):
                       append=False,
                       include_trust_flags=True,
                       include_key=True,
-                      include_chain=True,
-                      debug=False):
+                      include_chain=True):
 
         tmpdir = tempfile.mkdtemp()
 
@@ -1437,10 +1561,12 @@ class NSSDatabase(object):
 
             cmd = [
                 'pki',
-                '-d', self.directory,
-                '-C', self.password_file
+                '-d', self.directory
             ]
 
+            if self.password_file:
+                cmd.extend(['-C', self.password_file])
+
             if self.token:
                 cmd.extend(['--token', self.token])
 
@@ -1469,7 +1595,7 @@ class NSSDatabase(object):
             if not include_chain:
                 cmd.extend(['--no-chain'])
 
-            if debug:
+            if logger.isEnabledFor(logging.DEBUG):
                 cmd.extend(['--debug'])
 
             if nicknames:
@@ -1488,23 +1614,45 @@ class NSSDatabase(object):
 
         """
         args = []
+        is_ec = key_type and key_type.lower() in ('ec', 'ecc')
 
         if key_type:
-            if key_type.lower() == 'ecc':
-                key_type = 'ec'
-            args.extend(['-k', key_type])
+            # The -k parameter is either a key type or an identifer of a key
+            # to reuse. Make sure to handle ec correctly: the type should be
+            # "ec" not "ecc".
+            if is_ec:
+                args.extend(['-k', 'ec'])
+            else:
+                args.extend(['-k', key_type])
 
-        if key_type.lower() == 'ec':
+        if is_ec:
             # This is fix for Bugzilla 1544843
             args.extend([
                 '--keyOpFlagsOn', 'sign',
                 '--keyOpFlagsOff', 'derive',
             ])
 
-        if key_size:
-            args.extend(['-g', str(key_size)])
+            # When we want to generate a new EC key, we have to know the curve
+            # we want to use. This is either passed via the curve parameter or
+            # via the key_size parameter. If neither is specified, we have a
+            # problem. If both are specified and differ, we're confused. The
+            # reason is because the curve determines the size of the key;
+            # after that you don't have a choice.
+            if not curve and not key_size:
+                msg = "Must specify the curve to use when generating an "
+                msg += "elliptic curve key."
+                raise ValueError(msg)
+            if curve and key_size and curve != key_size:
+                msg = "Specified both curve (%s) and key size (%s) when "
+                msg += "generating an elliptic curve key, but they differ."
+                raise ValueError(msg % (curve, key_size))
 
-        if curve:
-            args.extend(['-q', curve])
+            if curve:
+                args.extend(['-q', str(curve)])
+            else:
+                args.extend(['-q', str(key_size)])
+        else:
+            if key_size:
+                args.extend(['-g', str(key_size)])
 
         return args
