@@ -23,7 +23,6 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
 import java.io.PrintStream;
-import java.lang.reflect.InvocationTargetException;
 import java.net.InetAddress;
 import java.net.InetSocketAddress;
 import java.net.Socket;
@@ -90,7 +89,7 @@ import com.netscape.certsrv.base.PKIException;
 
 public class PKIConnection {
 
-    boolean verbose;
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(PKIConnection.class);
 
     ClientConfig config;
 
@@ -132,11 +131,16 @@ public class PKIConnection {
 
                 requestCounter++;
 
-                if (verbose) {
-                    System.out.println("HTTP request: "+request.getRequestLine());
-                    for (Header header : request.getAllHeaders()) {
-                        System.out.println("  "+header.getName()+": "+header.getValue());
+                logger.info("HTTP request: " + request.getRequestLine());
+                for (Header header : request.getAllHeaders()) {
+                    String name = header.getName();
+                    String value = header.getValue();
+
+                    if ("Authorization".equalsIgnoreCase(name)) {
+                        value = "********";
                     }
+
+                    logger.info("  " + name + ": " + value);
                 }
 
                 if (output != null) {
@@ -160,11 +164,9 @@ public class PKIConnection {
 
                 responseCounter++;
 
-                if (verbose) {
-                    System.out.println("HTTP response: "+response.getStatusLine());
-                    for (Header header : response.getAllHeaders()) {
-                        System.out.println("  "+header.getName()+": "+header.getValue());
-                    }
+                logger.info("HTTP response: " + response.getStatusLine());
+                for (Header header : response.getAllHeaders()) {
+                    logger.info("  " + header.getName() + ": " + header.getValue());
                 }
 
                 if (output != null) {
@@ -182,7 +184,7 @@ public class PKIConnection {
                 HttpUriRequest uriRequest = super.getRedirect(request, response, context);
 
                 URI uri = uriRequest.getURI();
-                if (verbose) System.out.println("HTTP redirect: "+uri);
+                logger.info("HTTP redirect: "+uri);
 
                 // Redirect the original request to the new URI.
                 RequestWrapper wrapper;
@@ -212,15 +214,6 @@ public class PKIConnection {
         resteasyClient.register(PKIRESTProvider.class);
     }
 
-    public boolean isVerbose() {
-        return verbose;
-    }
-
-    public void setVerbose(boolean verbose) {
-        this.verbose = verbose;
-
-    }
-
     public void setCallback(SSLCertificateApprovalCallback callback) {
         this.callback = callback;
     }
@@ -353,7 +346,7 @@ public class PKIConnection {
 
             String certNickname = config.getCertNickname();
             if (certNickname != null) {
-                if (verbose) System.out.println("Client certificate: "+certNickname);
+                logger.info("Client certificate: "+certNickname);
                 socket.setClientCertNickname(certNickname);
             }
 
@@ -368,8 +361,8 @@ public class PKIConnection {
                     int intDescription = event.getDescription();
                     SSLAlertDescription description = SSLAlertDescription.valueOf(intDescription);
 
-                    if (level == SSLAlertLevel.FATAL || verbose) {
-                        System.err.println(level + ": SSL alert received: " + description);
+                    if (level == SSLAlertLevel.FATAL || logger.isInfoEnabled()) {
+                        logger.error(level + ": SSL alert received: " + description);
                     }
                 }
 
@@ -382,8 +375,8 @@ public class PKIConnection {
                     int intDescription = event.getDescription();
                     SSLAlertDescription description = SSLAlertDescription.valueOf(intDescription);
 
-                    if (level == SSLAlertLevel.FATAL || verbose) {
-                        System.err.println(level + ": SSL alert sent: " + description);
+                    if (level == SSLAlertLevel.FATAL || logger.isInfoEnabled()) {
+                        logger.error(level + ": SSL alert sent: " + description);
                     }
                 }
 
@@ -428,7 +421,7 @@ public class PKIConnection {
         return builder.build();
     }
 
-    public <T> T getEntity(Response response, Class<T> clazz) {
+    public <T> T getEntity(Response response, Class<T> clazz) throws Exception {
         try {
             Family family = response.getStatusInfo().getFamily();
             if (!family.equals(Family.CLIENT_ERROR) && !family.equals(Family.SERVER_ERROR)) {
@@ -443,7 +436,7 @@ public class PKIConnection {
         }
     }
 
-    public <T> T getEntity(Response response, GenericType<T> clazz) {
+    public <T> T getEntity(Response response, GenericType<T> clazz) throws Exception {
         try {
             Family family = response.getStatusInfo().getFamily();
             if (!family.equals(Family.CLIENT_ERROR) && !family.equals(Family.SERVER_ERROR)) {
@@ -458,33 +451,28 @@ public class PKIConnection {
         }
     }
 
-    private void handleErrorResponse(Response response) {
+    private void handleErrorResponse(Response response) throws Exception {
+
         StatusType status = response.getStatusInfo();
         MediaType contentType = response.getMediaType();
 
-        if (!MediaType.APPLICATION_XML_TYPE.equals(contentType)
-                && !MediaType.APPLICATION_JSON_TYPE.equals(contentType))
+        PKIException.Data data;
+        if (MediaType.APPLICATION_XML_TYPE.isCompatible(contentType)) {
+            data = response.readEntity(PKIException.Data.class);
+            logger.debug("XML response:\n" + data.toXML());
+
+        } else if (MediaType.APPLICATION_JSON_TYPE.isCompatible(contentType)) {
+            data = response.readEntity(PKIException.Data.class);
+            logger.debug("JSON response:\n" + data.toJSON());
+
+        } else {
             throw new PKIException(status.getStatusCode(), status.getReasonPhrase());
-
-        PKIException.Data data = response.readEntity(PKIException.Data.class);
-
-        Class<?> exceptionClass;
-        try {
-            exceptionClass = Class.forName(data.getClassName());
-        } catch (ClassNotFoundException e) {
-            throw new PKIException(e.getMessage(), e);
         }
 
-        try {
-            throw (PKIException) exceptionClass.getConstructor(PKIException.Data.class).newInstance(data);
-        } catch (InstantiationException
-                | IllegalAccessException
-                | IllegalArgumentException
-                | InvocationTargetException
-                | NoSuchMethodException
-                | SecurityException e) {
-            throw new PKIException(e.getMessage(), e);
-        }
+        String className = data.getClassName();
+        Class<?> exceptionClass = Class.forName(data.getClassName());
+
+        throw (PKIException) exceptionClass.getConstructor(PKIException.Data.class).newInstance(data);
     }
 
     public Response get(String path) throws Exception {
