@@ -33,6 +33,7 @@ import org.mozilla.jss.crypto.EncryptionAlgorithm;
 import org.mozilla.jss.crypto.KeyWrapAlgorithm;
 import org.mozilla.jss.crypto.SymmetricKey;
 import org.mozilla.jss.crypto.X509Certificate;
+import org.mozilla.jss.netscape.security.util.Utils;
 
 import com.netscape.certsrv.base.ResourceMessage;
 import com.netscape.certsrv.client.Client;
@@ -41,7 +42,6 @@ import com.netscape.certsrv.dbs.keydb.KeyId;
 import com.netscape.certsrv.request.RequestId;
 import com.netscape.certsrv.util.CryptoProvider;
 import com.netscape.cmsutil.crypto.CryptoUtil;
-import org.mozilla.jss.netscape.security.util.Utils;
 
 /**
  * @author Endi S. Dewata
@@ -49,6 +49,8 @@ import org.mozilla.jss.netscape.security.util.Utils;
  */
 public class KeyClient extends Client {
 
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(KeyClient.class);
+
     public KeyResource keyClient;
     public KeyRequestResource keyRequestClient;
     public KRAInfoResource kraInfoClient;
@@ -123,14 +125,14 @@ public class KeyClient extends Client {
      * @return a KeyInfoCollection object.
      */
     public KeyInfoCollection listKeys(String clientKeyID, String status, Integer maxSize, Integer maxTime,
-            Integer start, Integer size, String realm) {
+            Integer start, Integer size, String realm) throws Exception {
         Response response = keyClient.listKeys(clientKeyID, status, maxSize, maxTime, start, size, realm);
         return client.getEntity(response, KeyInfoCollection.class);
     }
 
     /* for backward compatibility */
     public KeyInfoCollection listKeys(String clientKeyID, String status, Integer maxSize, Integer maxTime,
-            Integer start, Integer size) {
+            Integer start, Integer size) throws Exception {
         Response response = keyClient.listKeys(clientKeyID, status, maxSize, maxTime, start, size, null);
         return client.getEntity(response, KeyInfoCollection.class);
     }
@@ -143,7 +145,7 @@ public class KeyClient extends Client {
      * @param realm   -- Authz Realm
      * @return a KeyRequestCollection object.
      */
-    public KeyRequestInfoCollection listRequests(String requestState, String requestType, String realm) {
+    public KeyRequestInfoCollection listRequests(String requestState, String requestType, String realm) throws Exception {
         return listRequests(
                 requestState,
                 requestType,
@@ -156,7 +158,7 @@ public class KeyClient extends Client {
     }
 
     /* method for backwards compatibility */
-    public KeyRequestInfoCollection listRequests(String requestState, String requestType) {
+    public KeyRequestInfoCollection listRequests(String requestState, String requestType) throws Exception {
         return listRequests(
                 requestState,
                 requestType,
@@ -189,7 +191,7 @@ public class KeyClient extends Client {
             Integer pageSize,
             Integer maxResults,
             Integer maxTime,
-            String realm) {
+            String realm) throws Exception {
         Response response = keyRequestClient.listRequests(
                 requestState,
                 requestType,
@@ -208,7 +210,7 @@ public class KeyClient extends Client {
      * @param id -- A Request Id object
      * @return the KeyRequestInfo object for a specific request.
      */
-    public KeyRequestInfo getRequestInfo(RequestId id) {
+    public KeyRequestInfo getRequestInfo(RequestId id) throws Exception {
         if (id == null) {
             throw new IllegalArgumentException("Request Id must be specified.");
         }
@@ -222,7 +224,7 @@ public class KeyClient extends Client {
      * @param id -- key id for secret
      * @return the KeyInfo object for a specific request.
      */
-    public KeyInfo getKeyInfo(KeyId id) {
+    public KeyInfo getKeyInfo(KeyId id) throws Exception {
         if (id == null) {
             throw new IllegalArgumentException("Key Id must be specified.");
         }
@@ -235,7 +237,7 @@ public class KeyClient extends Client {
      *
      * @param clientKeyID -- Client Key Identifier
      */
-    public KeyInfo getActiveKeyInfo(String clientKeyID) {
+    public KeyInfo getActiveKeyInfo(String clientKeyID) throws Exception {
         if (clientKeyID == null) {
             throw new IllegalArgumentException("Client Key Id must be specified.");
         }
@@ -249,7 +251,7 @@ public class KeyClient extends Client {
      * @param id -- key id for secret
      * @param status -- Status to be set for the key
      */
-    public void modifyKeyStatus(KeyId id, String status) {
+    public void modifyKeyStatus(KeyId id, String status) throws Exception {
         if (id == null || status == null) {
             throw new IllegalArgumentException("Key Id and status must be specified.");
         }
@@ -266,7 +268,7 @@ public class KeyClient extends Client {
      *
      * @param id -- Id of the request
      */
-    public void approveRequest(RequestId id) {
+    public void approveRequest(RequestId id) throws Exception {
         if (id == null) {
             throw new IllegalArgumentException("Request Id must be specified.");
         }
@@ -279,7 +281,7 @@ public class KeyClient extends Client {
      *
      * @param id -- Id of the request
      */
-    public void rejectRequest(RequestId id) {
+    public void rejectRequest(RequestId id) throws Exception {
         if (id == null) {
             throw new IllegalArgumentException("Request Id must be specified.");
         }
@@ -292,7 +294,7 @@ public class KeyClient extends Client {
      *
      * @param id -- Id of the request
      */
-    public void cancelRequest(RequestId id) {
+    public void cancelRequest(RequestId id) throws Exception {
         if (id == null) {
             throw new IllegalArgumentException("Request Id must be specified.");
         }
@@ -307,10 +309,14 @@ public class KeyClient extends Client {
      * @param data -- A KeyArchivalRequest/KeyRecoveryRequest/SymKeyGenerationRequest object
      * @return A KeyRequestResponse object
      */
-    private KeyRequestResponse submitRequest(ResourceMessage request) {
+    private KeyRequestResponse submitRequest(ResourceMessage request) throws Exception {
+
         if (request == null) {
             throw new IllegalArgumentException("A Request object must be specified.");
         }
+
+        logger.info("Submitting " + request.getClassName() + " to KRA");
+
         Response response = keyRequestClient.submitRequest(request);
         return client.getEntity(response, KeyRequestResponse.class);
     }
@@ -333,7 +339,7 @@ public class KeyClient extends Client {
      * @return A KeyRequestResponse object containing information about the key request and the key.
      */
     public KeyRequestResponse recoverKey(KeyId keyId, byte[] sessionWrappedPassphrase, byte[] transWrappedSessionKey,
-            byte[] nonceData, String b64Certificate) {
+            byte[] nonceData, String b64Certificate) throws Exception {
         // create recovery request
         if (keyId == null) {
             throw new IllegalArgumentException("KeyId nust be specified.");
@@ -341,14 +347,14 @@ public class KeyClient extends Client {
         KeyRecoveryRequest data = new KeyRecoveryRequest();
         data.setKeyId(keyId);
         if (sessionWrappedPassphrase != null) {
-            data.setSessionWrappedPassphrase(Utils.base64encode(sessionWrappedPassphrase, true));
+            data.setSessionWrappedPassphrase(Utils.base64encode(sessionWrappedPassphrase, false));
         }
         if (transWrappedSessionKey != null) {
-            data.setTransWrappedSessionKey(Utils.base64encode(transWrappedSessionKey, true));
+            data.setTransWrappedSessionKey(Utils.base64encode(transWrappedSessionKey, false));
         }
 
         if (nonceData != null) {
-            data.setNonceData(Utils.base64encode(nonceData, true));
+            data.setNonceData(Utils.base64encode(nonceData, false));
         }
         if (b64Certificate != null) {
             data.setCertificate(b64Certificate);
@@ -365,12 +371,20 @@ public class KeyClient extends Client {
      *            request and a wrapping mechanism.
      * @return A Key object containing the wrapped secret.
      */
-    public Key retrieveKeyData(KeyRecoveryRequest data) {
+    public KeyData retrieveKeyData(KeyRecoveryRequest data) throws Exception {
+
         if (data == null) {
             throw new IllegalArgumentException("A KeyRecoveryRequest object must be specified");
         }
+
+        logger.info("Submitting key retrieval request to KRA");
+
         Response response = keyClient.retrieveKey(data);
-        return new Key(client.getEntity(response, KeyData.class));
+        return client.getEntity(response, KeyData.class);
+    }
+
+    public SymmetricKey generateSessionKey() throws Exception {
+        return crypto.generateSessionKey(encryptAlgorithm);
     }
 
     /**
@@ -391,16 +405,19 @@ public class KeyClient extends Client {
      *             CertificateEncodingException, InvalidKeyException, InvalidAlgorithmParameterException,
      *             BadPaddingException, IllegalBlockSizeException
      */
-    public Key retrieveKey(KeyId keyId) throws Exception {
+    public KeyData retrieveKey(KeyId keyId, SymmetricKey sessionKey) throws Exception {
+
+        logger.info("Retrieving key " + keyId + " with session key");
+
         if (keyId == null) {
             throw new IllegalArgumentException("KeyId must be specified.");
         }
-        SymmetricKey sessionKey = crypto.generateSessionKey(encryptAlgorithm);
+
+        logger.info("Wrapping session key with transport certificate");
+
         byte[] transWrappedSessionKey = crypto.wrapSymmetricKey(sessionKey, transportCert.getPublicKey());
 
-        Key data = retrieveKey(keyId, transWrappedSessionKey);
-        processKeyData(data, sessionKey);
-        return data;
+        return retrieveKey(keyId, transWrappedSessionKey);
     }
 
     public void processKeyData(Key data, SymmetricKey sessionKey) throws Exception {
@@ -446,22 +463,21 @@ public class KeyClient extends Client {
         data.setData(bytes);
     }
 
-    public Key retrieveKeyByRequest(RequestId requestId) throws Exception {
+    public KeyData retrieveKeyByRequest(RequestId requestId, SymmetricKey sessionKey) throws Exception {
+
         if (requestId == null) {
             throw new IllegalArgumentException("RequestId must be specified.");
         }
-        SymmetricKey sessionKey = crypto.generateSessionKey(encryptAlgorithm);
+
         byte[] transWrappedSessionKey = crypto.wrapSymmetricKey(sessionKey, transportCert.getPublicKey());
 
         KeyRecoveryRequest recoveryRequest = new KeyRecoveryRequest();
         recoveryRequest.setRequestId(requestId);
-        recoveryRequest.setTransWrappedSessionKey(Utils.base64encode(transWrappedSessionKey, true));
+        recoveryRequest.setTransWrappedSessionKey(Utils.base64encode(transWrappedSessionKey, false));
         recoveryRequest.setPayloadEncryptionOID(getEncryptAlgorithmOID());
         recoveryRequest.setPayloadWrappingName(wrapAlgorithm.toString());
 
-        Key data = retrieveKeyData(recoveryRequest);
-        processKeyData(data, sessionKey);
-        return data;
+        return retrieveKeyData(recoveryRequest);
     }
 
     /**
@@ -483,20 +499,23 @@ public class KeyClient extends Client {
      *             CertificateEncodingException, InvalidKeyException, InvalidAlgorithmParameterException,
      *             BadPaddingException, IllegalBlockSizeException
      */
-    public Key retrieveKey(KeyId keyId, byte[] transWrappedSessionKey) throws Exception {
+    public KeyData retrieveKey(KeyId keyId, byte[] transWrappedSessionKey) throws Exception {
+
+        logger.info("Retrieving key " + keyId + " with session key wrapped by transport certificate");
 
         if (keyId == null) {
             throw new IllegalArgumentException("KeyId must be specified.");
         }
+
         if (transWrappedSessionKey == null) {
             throw new IllegalArgumentException("A transport cert wrapped session key cannot be null.");
         }
 
         KeyRecoveryRequest recoveryRequest = new KeyRecoveryRequest();
         recoveryRequest.setKeyId(keyId);
-        recoveryRequest.setTransWrappedSessionKey(Utils.base64encode(transWrappedSessionKey, true));
+        recoveryRequest.setTransWrappedSessionKey(Utils.base64encode(transWrappedSessionKey, false));
         recoveryRequest.setPayloadEncryptionOID(getEncryptAlgorithmOID());
-        recoveryRequest.setPayloadWrappingName(wrapAlgorithm.toString());
+        recoveryRequest.setPayloadWrappingName(getWrapAlgorithmName());
 
         return retrieveKeyData(recoveryRequest);
     }
@@ -520,14 +539,14 @@ public class KeyClient extends Client {
      *             CertificateEncodingException, InvalidKeyException, InvalidAlgorithmParameterException,
      *             BadPaddingException, IllegalBlockSizeException
      */
-    public Key retrieveKeyByPassphrase(KeyId keyId, String passphrase) throws Exception {
+    public KeyData retrieveKeyByPassphrase(KeyId keyId, String passphrase) throws Exception {
         if (keyId == null) {
             throw new IllegalArgumentException("KeyId must be specified.");
         }
         if (passphrase == null) {
             throw new IllegalArgumentException("Passphrase must be specified.");
         }
-        SymmetricKey sessionKey = crypto.generateSessionKey(encryptAlgorithm);
+        SymmetricKey sessionKey = generateSessionKey();
         byte[] transWrappedSessionKey = crypto.wrapSymmetricKey(sessionKey, transportCert.getPublicKey());
         byte[] nonceData = CryptoUtil.getNonceData(encryptAlgorithm.getIVLength());
 
@@ -546,7 +565,7 @@ public class KeyClient extends Client {
             throw new IllegalArgumentException("Passphrase must be specified.");
         }
 
-        SymmetricKey sessionKey = crypto.generateSessionKey(encryptAlgorithm);
+        SymmetricKey sessionKey = generateSessionKey();
         byte[] transWrappedSessionKey = crypto.wrapSymmetricKey(sessionKey, transportCert.getPublicKey());
         byte[] nonceData = CryptoUtil.getNonceData(encryptAlgorithm.getIVLength());
 
@@ -556,13 +575,13 @@ public class KeyClient extends Client {
 
         KeyRecoveryRequest data = new KeyRecoveryRequest();
         data.setRequestId(requestId);
-        data.setTransWrappedSessionKey(Utils.base64encode(transWrappedSessionKey, true));
-        data.setSessionWrappedPassphrase(Utils.base64encode(sessionWrappedPassphrase, true));
-        data.setNonceData(Utils.base64encode(nonceData, true));
+        data.setTransWrappedSessionKey(Utils.base64encode(transWrappedSessionKey, false));
+        data.setSessionWrappedPassphrase(Utils.base64encode(sessionWrappedPassphrase, false));
+        data.setNonceData(Utils.base64encode(nonceData, false));
         data.setPayloadEncryptionOID(getEncryptAlgorithmOID());
         data.setPayloadWrappingName(wrapAlgorithm.toString());
 
-        return retrieveKeyData(data);
+        return new Key(retrieveKeyData(data));
     }
 
     /**
@@ -583,7 +602,7 @@ public class KeyClient extends Client {
      *             CertificateEncodingException, InvalidKeyException, InvalidAlgorithmParameterException,
      *             BadPaddingException, IllegalBlockSizeException
      */
-    public Key retrieveKeyUsingWrappedPassphrase(KeyId keyId, byte[] transWrappedSessionKey,
+    public KeyData retrieveKeyUsingWrappedPassphrase(KeyId keyId, byte[] transWrappedSessionKey,
             byte[] sessionWrappedPassphrase, byte[] nonceData) throws Exception {
 
         if (keyId == null) {
@@ -612,13 +631,13 @@ public class KeyClient extends Client {
         data.setPayloadWrappingName(wrapAlgorithm.toString());
 
         if (transWrappedSessionKey != null) {
-            data.setTransWrappedSessionKey(Utils.base64encode(transWrappedSessionKey, true));
+            data.setTransWrappedSessionKey(Utils.base64encode(transWrappedSessionKey, false));
         }
         if (sessionWrappedPassphrase != null) {
-            data.setSessionWrappedPassphrase(Utils.base64encode(sessionWrappedPassphrase, true));
+            data.setSessionWrappedPassphrase(Utils.base64encode(sessionWrappedPassphrase, false));
         }
         if (nonceData != null) {
-            data.setNonceData(Utils.base64encode(nonceData, true));
+            data.setNonceData(Utils.base64encode(nonceData, false));
         }
 
         // Just return the KeyData as the wrappedPrivateData contains the key wrapped by the passphrase
@@ -638,7 +657,7 @@ public class KeyClient extends Client {
      * @param passphrase -- A passphrase for the pkcs12 file.
      * @return A Key object with the wrapped secret
      */
-    public Key retrieveKeyByPKCS12(KeyId keyId, String certificate, String passphrase) {
+    public KeyData retrieveKeyByPKCS12(KeyId keyId, String certificate, String passphrase) throws Exception {
         if (keyId == null || certificate == null || passphrase == null) {
             throw new IllegalArgumentException("KeyId, certificate and passphrase must be specified.");
         }
@@ -674,7 +693,7 @@ public class KeyClient extends Client {
         String algorithmOID = getEncryptAlgorithmOID();
 
         byte[] nonceData = CryptoUtil.getNonceData(encryptAlgorithm.getIVLength());
-        SymmetricKey sessionKey = crypto.generateSessionKey(encryptAlgorithm);
+        SymmetricKey sessionKey = generateSessionKey();
         byte[] transWrappedSessionKey = crypto.wrapSymmetricKey(sessionKey, transportCert.getPublicKey());
 
         byte[] encryptedData = crypto.encryptSecret(
@@ -683,7 +702,7 @@ public class KeyClient extends Client {
                 sessionKey,
                 encryptAlgorithm);
 
-        return archiveEncryptedData(clientKeyId, KeyRequestResource.PASS_PHRASE_TYPE, null, 0, algorithmOID,
+        return archiveEncryptedData(clientKeyId, KeyRequestResource.PASS_PHRASE_TYPE, null, null, algorithmOID,
                 nonceData, encryptedData, transWrappedSessionKey, realm);
     }
 
@@ -703,6 +722,10 @@ public class KeyClient extends Client {
         return algorithmOID;
     }
 
+    public String getWrapAlgorithmName() {
+        return wrapAlgorithm.toString();
+    }
+
     /**
      * Archive a symmetric key on the DRM.
      *
@@ -720,7 +743,7 @@ public class KeyClient extends Client {
      *             BadPaddingException, IllegalBlockSizeException
      */
     public KeyRequestResponse archiveSymmetricKey(String clientKeyId, SymmetricKey secret, String keyAlgorithm,
-            int keySize, String realm) throws Exception {
+            Integer keySize, String realm) throws Exception {
 
         String algorithmOID = getEncryptAlgorithmOID();
 
@@ -729,7 +752,7 @@ public class KeyClient extends Client {
             nonceData = CryptoUtil.getNonceData(wrapIVLength);
         }
 
-        SymmetricKey sessionKey = crypto.generateSessionKey(encryptAlgorithm);
+        SymmetricKey sessionKey = generateSessionKey();
         byte[] encryptedData = crypto.wrapWithSessionKey(secret, sessionKey, nonceData, wrapAlgorithm);
         byte[] transWrappedSessionKey = crypto.wrapSymmetricKey(sessionKey, transportCert.getPublicKey());
 
@@ -740,7 +763,7 @@ public class KeyClient extends Client {
     /* old method signature for backwards compatibility */
     @Deprecated
     public KeyRequestResponse archiveSymmetricKey(String clientKeyId, SymmetricKey secret, String keyAlgorithm,
-            int keySize) throws Exception {
+            Integer keySize) throws Exception {
         return archiveSymmetricKey(clientKeyId, secret, keyAlgorithm,keySize, null);
     }
 
@@ -763,34 +786,44 @@ public class KeyClient extends Client {
      * @param realm -- authorization realm
      * @return A KeyRequestResponse object with information about the request.
      */
-    public KeyRequestResponse archiveEncryptedData(String clientKeyId, String dataType, String keyAlgorithm,
-            int keySize, String algorithmOID, byte[] nonceData, byte[] encryptedData,
-            byte[] transWrappedSessionKey, String realm) {
+    public KeyRequestResponse archiveEncryptedData(
+            String clientKeyId,
+            String dataType,
+            String keyAlgorithm,
+            Integer keySize,
+            String algorithmOID,
+            byte[] nonceData,
+            byte[] encryptedData,
+            byte[] transWrappedSessionKey,
+            String realm) throws Exception {
+
+        logger.info("Archiving encrypted data");
 
         if (clientKeyId == null || dataType == null) {
             throw new IllegalArgumentException("Client key id and data type must be specified.");
         }
+
         if (dataType == KeyRequestResource.SYMMETRIC_KEY_TYPE) {
             if (keyAlgorithm == null || keySize < 0) {
                 throw new IllegalArgumentException(
                         "Key algorithm and key size must be specified for a symmetric key type request.");
             }
         }
+
         if (encryptedData == null || transWrappedSessionKey == null || algorithmOID == null
                 || nonceData == null) {
             throw new IllegalArgumentException("All data and wrapping parameters must be specified.");
         }
-        KeyArchivalRequest data = new KeyArchivalRequest();
 
+        KeyArchivalRequest data = new KeyArchivalRequest();
         data.setDataType(dataType);
         data.setKeyAlgorithm(keyAlgorithm);
         data.setKeySize(keySize);
         data.setClientKeyId(clientKeyId);
         data.setAlgorithmOID(algorithmOID);
-        data.setSymmetricAlgorithmParams(Utils.base64encode(nonceData, true));
-        String req1 = Utils.base64encode(encryptedData, true);
-        data.setWrappedPrivateData(req1);
-        data.setTransWrappedSessionKey(Utils.base64encode(transWrappedSessionKey, true));
+        data.setSymmetricAlgorithmParams(Utils.base64encode(nonceData, false));
+        data.setWrappedPrivateData(Utils.base64encode(encryptedData, false));
+        data.setTransWrappedSessionKey(Utils.base64encode(transWrappedSessionKey, false));
         data.setRealm(realm);
 
         return submitRequest(data);
@@ -799,8 +832,8 @@ public class KeyClient extends Client {
     /* old signature for backwards compatibility */
     @Deprecated
     public KeyRequestResponse archiveEncryptedData(String clientKeyId, String dataType, String keyAlgorithm,
-            int keySize, String algorithmOID, byte[] nonceData, byte[] encryptedData,
-            byte[] transWrappedSessionKey) {
+            Integer keySize, String algorithmOID, byte[] nonceData, byte[] encryptedData,
+            byte[] transWrappedSessionKey) throws Exception {
         return archiveEncryptedData(clientKeyId, dataType, keyAlgorithm, keySize, algorithmOID, nonceData,
                 encryptedData, transWrappedSessionKey, null);
     }
@@ -819,7 +852,7 @@ public class KeyClient extends Client {
      * @throws Exception
      */
     public KeyRequestResponse archivePKIOptions(String clientKeyId, String dataType, String keyAlgorithm, int keySize,
-            byte[] pkiArchiveOptions, String realm) {
+            byte[] pkiArchiveOptions, String realm) throws Exception {
 
         if (clientKeyId == null || dataType == null) {
             throw new IllegalArgumentException("Client key id and data type must be specified.");
@@ -841,7 +874,7 @@ public class KeyClient extends Client {
         data.setKeyAlgorithm(keyAlgorithm);
         data.setKeySize(keySize);
 
-        String options = Utils.base64encode(pkiArchiveOptions, true);
+        String options = Utils.base64encode(pkiArchiveOptions, false);
         data.setPKIArchiveOptions(options);
         data.setRealm(realm);
 
@@ -851,7 +884,7 @@ public class KeyClient extends Client {
     /* old method signature for backwards compatibility */
     @Deprecated
     public KeyRequestResponse archivePKIOptions(String clientKeyId, String dataType, String keyAlgorithm, int keySize,
-            byte[] pkiArchiveOptions) {
+            byte[] pkiArchiveOptions) throws Exception {
         return archivePKIOptions(clientKeyId, dataType, keyAlgorithm, keySize, pkiArchiveOptions, null);
     }
 
@@ -869,7 +902,7 @@ public class KeyClient extends Client {
      *         object that describes the URL for the request and generated key.
      */
     public KeyRequestResponse generateSymmetricKey(String clientKeyId, String keyAlgorithm, int keySize,
-            List<String> usages, String transWrappedSessionKey, String realm) {
+            List<String> usages, String transWrappedSessionKey, String realm) throws Exception {
         if (clientKeyId == null) {
             throw new IllegalArgumentException("Client Key Identifier must be specified.");
         }
@@ -897,7 +930,7 @@ public class KeyClient extends Client {
     /* old method signature for backwards compatibility */
     @Deprecated
     public KeyRequestResponse generateSymmetricKey(String clientKeyId, String keyAlgorithm, int keySize,
-            List<String> usages, String transWrappedSessionKey) {
+            List<String> usages, String transWrappedSessionKey) throws Exception {
         return generateSymmetricKey(clientKeyId, keyAlgorithm, keySize, usages, transWrappedSessionKey, null);
     }
 
@@ -913,7 +946,7 @@ public class KeyClient extends Client {
      * @param realm  -- authorization realm
      */
     public KeyRequestResponse generateAsymmetricKey(String clientKeyId, String keyAlgorithm, int keySize,
-            List<String> usages, byte[] transWrappedSessionKey, String realm) {
+            List<String> usages, byte[] transWrappedSessionKey, String realm) throws Exception {
 
         if (clientKeyId == null) {
             throw new IllegalArgumentException("Client Key Identifier must be specified.");
@@ -957,7 +990,7 @@ public class KeyClient extends Client {
         data.setKeyAlgorithm(keyAlgorithm);
         data.setKeySize(keySize);
         data.setUsages(usages);
-        data.setTransWrappedSessionKey(Utils.base64encode(transWrappedSessionKey, true));
+        data.setTransWrappedSessionKey(Utils.base64encode(transWrappedSessionKey, false));
         data.setRealm(realm);
 
         return submitRequest(data);
@@ -966,7 +999,7 @@ public class KeyClient extends Client {
     /* old method signature for backwards compatibility */
     @Deprecated
     public KeyRequestResponse generateAsymmetricKey(String clientKeyId, String keyAlgorithm, int keySize,
-            List<String> usages, byte[] transWrappedSessionKey) {
+            List<String> usages, byte[] transWrappedSessionKey) throws Exception {
         return generateAsymmetricKey(clientKeyId, keyAlgorithm, keySize, usages, transWrappedSessionKey, null);
     }
 }
