@@ -40,54 +40,53 @@ public class ProfileClient extends Client {
         profileClient = createProxy(ProfileResource.class);
     }
 
-    public ProfileData retrieveProfile(String id) {
+    public ProfileData retrieveProfile(String id) throws Exception {
         Response response = profileClient.retrieveProfile(id);
         return client.getEntity(response, ProfileData.class);
     }
 
-    public byte[] retrieveProfileRaw(String id) {
+    public byte[] retrieveProfileRaw(String id) throws Exception {
         Response response = profileClient.retrieveProfileRaw(id);
         return client.getEntity(response, byte[].class);
     }
 
-    public ProfileDataInfos listProfiles(Integer start, Integer size) {
+    public ProfileDataInfos listProfiles(Integer start, Integer size) throws Exception {
         Response response =  profileClient.listProfiles(start, size);
         return client.getEntity(response, ProfileDataInfos.class);
     }
 
-    public void enableProfile(String id) {
+    public void enableProfile(String id) throws Exception {
         Response response = profileClient.modifyProfileState(id, "enable");
         client.getEntity(response, Void.class);
     }
 
-    public void disableProfile(String id) {
+    public void disableProfile(String id) throws Exception {
         Response response = profileClient.modifyProfileState(id, "disable");
         client.getEntity(response, Void.class);
     }
 
-    public ProfileData createProfile(ProfileData data) {
+    public ProfileData createProfile(ProfileData data) throws Exception {
         Response response = profileClient.createProfile(data);
         return client.getEntity(response, ProfileData.class);
     }
 
-    public byte[] createProfileRaw(byte[] properties) {
+    public byte[] createProfileRaw(byte[] properties) throws Exception {
         Response response =
             profileClient.createProfileRaw(properties);
         return client.getEntity(response, byte[].class);
     }
 
-    public ProfileData modifyProfile(ProfileData data) {
+    public ProfileData modifyProfile(ProfileData data) throws Exception {
         Response response = profileClient.modifyProfile(data.getId(), data);
         return client.getEntity(response, ProfileData.class);
     }
 
-    public byte[] modifyProfileRaw(String profileId, byte[] properties) {
-        Response response =
-            profileClient.modifyProfileRaw(profileId, properties);
+    public byte[] modifyProfileRaw(String profileId, byte[] properties) throws Exception {
+        Response response = profileClient.modifyProfileRaw(profileId, properties);
         return client.getEntity(response, byte[].class);
     }
 
-    public void deleteProfile(String id) {
+    public void deleteProfile(String id) throws Exception {
         Response response = profileClient.deleteProfile(id);
         client.getEntity(response, Void.class);
     }
