@@ -2,7 +2,6 @@ package com.netscape.certsrv.system;
 
 import java.net.URISyntaxException;
 
-import javax.ws.rs.NotFoundException;
 import javax.ws.rs.core.Response;
 
 import com.netscape.certsrv.base.ResourceNotFoundException;
@@ -24,17 +23,17 @@ public class TPSConnectorClient extends Client {
     }
 
     public TPSConnectorCollection findConnectors(
-            String host, String port, Integer start, Integer size) {
+            String host, String port, Integer start, Integer size) throws Exception {
         Response response = tpsConnectorClient.findConnectors(host, port, start, size);
         return client.getEntity(response, TPSConnectorCollection.class);
     }
 
-    public TPSConnectorData getConnector(String id) {
+    public TPSConnectorData getConnector(String id) throws Exception {
         Response response = tpsConnectorClient.getConnector(id);
         return client.getEntity(response, TPSConnectorData.class);
     }
 
-    public TPSConnectorData getConnector(String host, String port) throws NotFoundException {
+    public TPSConnectorData getConnector(String host, String port) throws Exception {
         TPSConnectorCollection connectors = findConnectors(host, port, null, null);
         if (connectors.getTotal() < 1) {
             throw new ResourceNotFoundException("Connector not found: " + host + ":" + port);
@@ -42,42 +41,42 @@ public class TPSConnectorClient extends Client {
         return connectors.getEntries().iterator().next();
     }
 
-    public TPSConnectorData createConnector(String tpsHost, String tpsPort) {
+    public TPSConnectorData createConnector(String tpsHost, String tpsPort) throws Exception {
         Response response = tpsConnectorClient.createConnector(tpsHost, tpsPort);
         return client.getEntity(response, TPSConnectorData.class);
     }
 
-    public TPSConnectorData modifyConnector(String id, TPSConnectorData data) {
+    public TPSConnectorData modifyConnector(String id, TPSConnectorData data) throws Exception {
         Response response = tpsConnectorClient.modifyConnector(id, data);
         return client.getEntity(response, TPSConnectorData.class);
     }
 
-    public void deleteConnector(String id) {
+    public void deleteConnector(String id) throws Exception {
         Response response = tpsConnectorClient.deleteConnector(id);
         client.getEntity(response, Void.class);
     }
 
-    public KeyData createSharedSecret(String id) {
+    public KeyData createSharedSecret(String id) throws Exception {
         Response response = tpsConnectorClient.createSharedSecret(id);
         return client.getEntity(response, KeyData.class);
     }
 
-    public KeyData replaceSharedSecret(String id) {
+    public KeyData replaceSharedSecret(String id) throws Exception {
         Response response = tpsConnectorClient.replaceSharedSecret(id);
         return client.getEntity(response, KeyData.class);
     };
 
-    public void deleteSharedSecret(String id) {
+    public void deleteSharedSecret(String id) throws Exception {
         Response response = tpsConnectorClient.deleteSharedSecret(id);
         client.getEntity(response, Void.class);
     }
 
-    public KeyData getSharedSecret(String id) {
+    public KeyData getSharedSecret(String id) throws Exception {
         Response response = tpsConnectorClient.getSharedSecret(id);
         return client.getEntity(response, KeyData.class);
     }
 
-    public void deleteConnector(String host, String port) {
+    public void deleteConnector(String host, String port) throws Exception {
         Response response = tpsConnectorClient.deleteConnector(host, port);
         client.getEntity(response, Void.class);
     }
