@@ -19,6 +19,7 @@ package com.netscape.admin.certsrv;
 
 import java.awt.BorderLayout;
 import java.awt.Color;
+import java.awt.Component;
 import java.awt.Dimension;
 import java.awt.GridBagConstraints;
 import java.awt.GridBagLayout;
@@ -110,7 +111,7 @@ public class CMSAdminUtil {
     public static final int NO_OPTION = JOptionPane.NO_OPTION;
     public static final int CANCEL_OPTION = JOptionPane.CANCEL_OPTION;
 
-    private static Hashtable mPackageImages = new Hashtable();  //image container
+    private static Hashtable<String, RemoteImage> mPackageImages = new Hashtable<>();  //image container
     private static final ResourceSet mHelpResource =
       new ResourceSet("com.netscape.admin.certsrv.certsrv-help");
     public static final ResourceSet mResource =
@@ -132,7 +133,7 @@ public class CMSAdminUtil {
      */
     public static RemoteImage getImage( String name ) {
         String imageDir = CMSAdminResources.DEFAULT_IMAGE_DIRECTORY;
-		RemoteImage i = (RemoteImage) mPackageImages.get( name );
+		RemoteImage i = mPackageImages.get( name );
 		if ( i != null )
 			return i;
         i = getSystemImage( imageDir + "/" + name );
@@ -143,7 +144,7 @@ public class CMSAdminUtil {
 
     public static RemoteImage getThemeImage( String name ) {
         String imageDir = CMSAdminResources.DEFAULT_THEME_IMAGE_DIRECTORY;
-		RemoteImage i = (RemoteImage) mPackageImages.get( name );
+		RemoteImage i = mPackageImages.get( name );
 		if ( i != null )
 			return i;
         i = getSystemImage( imageDir + "/" + name );
@@ -160,12 +161,12 @@ public class CMSAdminUtil {
      */
     public static void resetGBC(GridBagConstraints gbc)
 	{
-      		gbc.gridx      = gbc.RELATIVE;
-      		gbc.gridy      = gbc.RELATIVE;
+      		gbc.gridx      = GridBagConstraints.RELATIVE;
+      		gbc.gridy      = GridBagConstraints.RELATIVE;
       		gbc.gridwidth  = 1;
       		gbc.gridheight = 1;
-      		gbc.fill       = gbc.HORIZONTAL;
-      		gbc.anchor     = gbc.CENTER;
+      		gbc.fill       = GridBagConstraints.HORIZONTAL;
+      		gbc.anchor     = GridBagConstraints.CENTER;
       		gbc.ipadx      = 0;
       		gbc.ipady      = 0;
       		gbc.weightx    = 0.0;
@@ -194,16 +195,16 @@ public class CMSAdminUtil {
       JComponent comp2, GridBagConstraints gbc) {
         double weighty = gbc.weighty;
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHEAST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.NORTHEAST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weighty = weighty;
         panel.add(comp1, gbc);
 
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weighty = weighty;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         panel.add(comp2, gbc);
     }
 
@@ -211,22 +212,22 @@ public class CMSAdminUtil {
       JComponent comp2, JComponent comp3, GridBagConstraints gbc) {
         double weighty = gbc.weighty;
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHEAST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.NORTHEAST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weighty = weighty;
         panel.add(comp1, gbc);
 
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weighty = weighty;
         panel.add(comp2, gbc);
 
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weighty = weighty;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         panel.add(comp3, gbc);
     }
 
@@ -235,28 +236,28 @@ public class CMSAdminUtil {
       GridBagConstraints gbc) {
         double weighty = gbc.weighty;
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHEAST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.NORTHEAST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weighty = weighty;
         panel.add(comp1, gbc);
 
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weighty = weighty;
         panel.add(comp2, gbc);
 
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weighty = weighty;
         panel.add(comp3, gbc);
 
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTHWEST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.NORTHWEST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weighty = weighty;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         panel.add(comp4, gbc);
     }
 
@@ -266,19 +267,19 @@ public class CMSAdminUtil {
      */
     public static void addEntryField(JPanel panel, JComponent label,
       JComponent field, GridBagConstraints gbc) {
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
         gbc.gridx = 0;
-        gbc.anchor = gbc.EAST;
+        gbc.anchor = GridBagConstraints.EAST;
         gbc.insets = new Insets(COMPONENT_SPACE,DIFFERENT_COMPONENT_SPACE,0,0);
         panel.add( label, gbc );
 
         gbc.gridx++;
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,
       		                            0,DIFFERENT_COMPONENT_SPACE);
         panel.add( field, gbc );
@@ -290,27 +291,27 @@ public class CMSAdminUtil {
      */
     public static void addEntryField(JPanel panel, JComponent field1,
       JComponent field2, JComponent field3, GridBagConstraints gbc) {
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
         gbc.gridx = 0;
-        gbc.anchor = gbc.EAST;
+        gbc.anchor = GridBagConstraints.EAST;
         gbc.insets = new Insets(COMPONENT_SPACE,DIFFERENT_COMPONENT_SPACE,0,0);
         panel.add( field1, gbc );
 
         gbc.gridx++;
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
         gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,0,0);
         panel.add(field2, gbc);
 
         gbc.gridx++;
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,
       		                            0,DIFFERENT_COMPONENT_SPACE);
         panel.add( field3, gbc );
@@ -322,35 +323,35 @@ public class CMSAdminUtil {
      */
     public static void addEntryField(JPanel panel, JComponent field1,
       JComponent field2, JComponent field3, JComponent field4, GridBagConstraints gbc) {
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
         gbc.gridx = 0;
-        gbc.anchor = gbc.EAST;
+        gbc.anchor = GridBagConstraints.EAST;
         gbc.insets = new Insets(COMPONENT_SPACE,DIFFERENT_COMPONENT_SPACE,0,0);
         panel.add( field1, gbc );
 
         gbc.gridx++;
-        gbc.anchor = gbc.EAST;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.anchor = GridBagConstraints.EAST;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         gbc.weightx = 0.5;
         gbc.gridwidth = 1;
         gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,0,0);
         panel.add(field2, gbc);
 
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
         gbc.gridx++;
-        gbc.anchor = gbc.EAST;
+        gbc.anchor = GridBagConstraints.EAST;
         gbc.insets = new Insets(COMPONENT_SPACE,DIFFERENT_COMPONENT_SPACE,0,0);
         panel.add( field3, gbc );
 
         gbc.gridx++;
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         gbc.weightx = 0.5;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,
       		                            0,DIFFERENT_COMPONENT_SPACE);
         panel.add( field4, gbc );
@@ -363,43 +364,43 @@ public class CMSAdminUtil {
     public static void addEntryField(JPanel panel, JComponent field1,
       JComponent field2, JComponent field3, JComponent field4,
       JComponent field5, GridBagConstraints gbc) {
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
         gbc.gridx = 0;
-        gbc.anchor = gbc.EAST;
+        gbc.anchor = GridBagConstraints.EAST;
         gbc.insets = new Insets(COMPONENT_SPACE,DIFFERENT_COMPONENT_SPACE,0,0);
         panel.add( field1, gbc );
 
         gbc.gridx++;
-        gbc.anchor = gbc.EAST;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.anchor = GridBagConstraints.EAST;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         //gbc.weightx = 0.5;
         gbc.gridwidth = 1;
         gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,0,0);
         panel.add(field2, gbc);
 
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
         gbc.gridx++;
-        gbc.anchor = gbc.EAST;
+        gbc.anchor = GridBagConstraints.EAST;
         gbc.insets = new Insets(COMPONENT_SPACE,DIFFERENT_COMPONENT_SPACE,0,0);
         panel.add( field3, gbc );
 
         gbc.gridx++;
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         //gbc.weightx = 0.5;
         gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,
                                             0,DIFFERENT_COMPONENT_SPACE);
         panel.add( field4, gbc );
 
         gbc.gridx++;
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,
                                             0,DIFFERENT_COMPONENT_SPACE);
         panel.add( field5, gbc );
@@ -412,51 +413,51 @@ public class CMSAdminUtil {
     public static void addEntryField(JPanel panel, JComponent field1,
       JComponent field2, JComponent field3, JComponent field4,
       JComponent field5, JComponent field6, GridBagConstraints gbc) {
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
         gbc.gridx = 0;
-        gbc.anchor = gbc.EAST;
+        gbc.anchor = GridBagConstraints.EAST;
         gbc.insets = new Insets(COMPONENT_SPACE,DIFFERENT_COMPONENT_SPACE,0,0);
         panel.add( field1, gbc );
 
         gbc.gridx++;
-        gbc.anchor = gbc.EAST;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.anchor = GridBagConstraints.EAST;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         //gbc.weightx = 0.5;
         gbc.gridwidth = 1;
         gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,0,0);
         panel.add(field2, gbc);
 
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
         gbc.gridx++;
-        gbc.anchor = gbc.EAST;
+        gbc.anchor = GridBagConstraints.EAST;
         gbc.insets = new Insets(COMPONENT_SPACE,DIFFERENT_COMPONENT_SPACE,0,0);
         panel.add( field3, gbc );
 
         gbc.gridx++;
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         //gbc.weightx = 0.5;
         gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,
                                             0,DIFFERENT_COMPONENT_SPACE);
         panel.add(field4, gbc);
 
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
         gbc.gridx++;
-        gbc.anchor = gbc.EAST;
+        gbc.anchor = GridBagConstraints.EAST;
         gbc.insets = new Insets(COMPONENT_SPACE,DIFFERENT_COMPONENT_SPACE,0,0);
         panel.add( field5, gbc );
 
         gbc.gridx++;
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,
                                             0,DIFFERENT_COMPONENT_SPACE);
         panel.add( field6, gbc );
@@ -568,10 +569,10 @@ public class CMSAdminUtil {
      * @table JTable object
      */
     public static int getTotalColumnWidth( JTable table ) {
-		Enumeration en = table.getColumnModel().getColumns();
+		Enumeration<TableColumn> en = table.getColumnModel().getColumns();
 		int width = 0;
 		while( en.hasMoreElements() ) {
-			TableColumn col = (TableColumn)en.nextElement();
+			TableColumn col = en.nextElement();
 			width += col.getWidth();
 		}
 		return width - 200;
@@ -877,9 +878,9 @@ public class CMSAdminUtil {
      * Factory Method to create a list box mode specified with specific
      * visible row count. Special cell renderer is used to display each cell.
      */
-    public static JList makeJList(DefaultListModel listModel, int visibleCount) {
-        JList listbox = new JList(listModel);
-        listbox.setCellRenderer(new AttrCellRenderer());
+    public static <E> JList<E> makeJList(DefaultListModel<E> listModel, int visibleCount) {
+        JList<E> listbox = new JList<E>(listModel);
+        listbox.setCellRenderer(new AttrCellRenderer<E>());
         listbox.setSelectionModel(new DefaultListSelectionModel());
         listbox.setVisibleRowCount(visibleCount);
         if(listModel.size()!=0)
@@ -1002,16 +1003,16 @@ public class CMSAdminUtil {
 		JPanel buttonPanel = new JPanel();
 		GridBagConstraints gbc = new GridBagConstraints();
 		buttonPanel.setLayout(new GridBagLayout());
-		gbc.fill = gbc.HORIZONTAL;
+		gbc.fill = GridBagConstraints.HORIZONTAL;
 		gbc.weightx = 1.0;
 		gbc.weighty = 0.0;
 		gbc.gridwidth = 1;
 		buttonPanel.add( Box.createGlue(), gbc );
-		gbc.fill = gbc.NONE;
+		gbc.fill = GridBagConstraints.NONE;
 		gbc.weightx = 0;
 		for( int i = 0; i < buttons.length; i++ ) {
 			if ( i == buttons.length-1 ) {
-				gbc.gridwidth = gbc.REMAINDER;
+				gbc.gridwidth = GridBagConstraints.REMAINDER;
 				if (isHelp)
 				    buttonPanel.add( Box.createHorizontalStrut(HELP_BUTTON_OFFSET));
 				else
@@ -1055,14 +1056,14 @@ public class CMSAdminUtil {
 		GridBagConstraints gbc = new GridBagConstraints();
 		buttonPanel.setLayout(new GridBagLayout());
 		resetGBC(gbc);
-		gbc.fill = gbc.NONE;
-		gbc.gridwidth = gbc.REMAINDER;
+		gbc.fill = GridBagConstraints.NONE;
+		gbc.gridwidth = GridBagConstraints.REMAINDER;
 		gbc.weightx = 1.0;
 		gbc.insets = new Insets(0, DIFFERENT_COMPONENT_SPACE, 0,0);
 
 		for( int i = 0; i < buttons.length; i++ ) {
 			if ( i == buttons.length-1 )
-				gbc.gridheight = gbc.REMAINDER;
+				gbc.gridheight = GridBagConstraints.REMAINDER;
 			buttonPanel.add( buttons[i], gbc );
 			gbc.insets = new Insets(COMPONENT_SPACE, DIFFERENT_COMPONENT_SPACE,
       		                            0, 0);
@@ -1076,7 +1077,7 @@ public class CMSAdminUtil {
 
     //===== COMBOBOX CREATION =======================
 
-    public static JComboBox makeJComboBox(ResourceBundle resource,
+    public static JComboBox<String> makeJComboBox(ResourceBundle resource,
                                        String panelName,
                                        String keyword)
     {
@@ -1085,7 +1086,7 @@ public class CMSAdminUtil {
             value = resource.getString(panelName+"_COMBOBOX_"+keyword+"_DEFAULT");
         } catch (MissingResourceException e) {
         }
-        JComboBox jcb = new JComboBox();
+        JComboBox<String> jcb = new JComboBox<>();
         String val = null;
         int ii = 0;
         do {
@@ -1295,7 +1296,7 @@ public class CMSAdminUtil {
         return num;
     }
 
-    public static Object createTableCell(String syntax, String syntaxVal, String v) {
+    public static Component createTableCell(String syntax, String syntaxVal, String v) {
         if (syntax.equalsIgnoreCase("string") ||
           syntax.equalsIgnoreCase("integer")) {
             if (v == null) {
@@ -1319,7 +1320,7 @@ public class CMSAdminUtil {
                 }
 
                 CMSAdminUtil.bubbleSort(item);
-                JComboBox b = new JComboBox(item);
+                JComboBox<String> b = new JComboBox<>(item);
 
                 if (v != null && v.length() > 0)
                     b.setSelectedItem(v);
@@ -1329,7 +1330,7 @@ public class CMSAdminUtil {
             }
         } else if (syntax.equalsIgnoreCase("boolean")) {
             String[] item = {"true", "false"};
-            JComboBox b = new JComboBox(item);
+            JComboBox<String> b = new JComboBox<>(item);
             if (v != null && v.equalsIgnoreCase("true")) {
                 b.setSelectedIndex(0);
             } else {
