@@ -204,8 +204,7 @@ public class Console implements CommClient {
                 // has an incorrect layout for some of the buttons. Create
                 // and discard an instance.
                 if (!_isWindows) {
-                    Object o = new JFileChooser();
-                    o = null;
+                    new JFileChooser();
                 }
             }
             FontFactory.initializeLFFonts(); // load default customized fonts for login/splash
@@ -378,7 +377,7 @@ public class Console implements CommClient {
     private String serverIDtoDN(String id) {
 
         LDAPConnection ldc = _info.getLDAPConnection();
-        Vector instances = new Vector();
+        Vector<String> instances = new Vector<>();
 
         try {
             LDAPSearchResults res = ldc.search(
@@ -397,7 +396,7 @@ public class Console implements CommClient {
                 System.exit(0);
             }
             else if (instances.size() == 1) {
-                id = (String) instances.elementAt(0);
+                id = instances.elementAt(0);
             }
             else {
 
@@ -435,7 +434,7 @@ public class Console implements CommClient {
                         break;
                     }
                 }
-                id = (String) instances.elementAt(idx);
+                id = instances.elementAt(idx);
             }
         }
         catch (Exception e) {
@@ -485,7 +484,7 @@ public class Console implements CommClient {
             }
             _info.setCurrentDN(host);
 
-            Class c = ClassLoaderUtil.getClass(_info, className);
+            Class<?> c = ClassLoaderUtil.getClass(_info, className);
             if (c == null) {
                 Debug.println(
                         "ERROR Console.constructor: could not get class " +
@@ -494,12 +493,12 @@ public class Console implements CommClient {
                     }
 
             try {
-                Hashtable topologyplugin =
+                Hashtable<String, ITopologyPlugin> topologyplugin =
                         TopologyInitializer.getTopologyPluginFromDS( _info);
-                Enumeration ePlugins = topologyplugin.elements();
+                Enumeration<ITopologyPlugin> ePlugins = topologyplugin.elements();
                 while (ePlugins.hasMoreElements()) {
                     ITopologyPlugin plugin =
-                            (ITopologyPlugin) ePlugins.nextElement();
+                            ePlugins.nextElement();
                     ResourceObject resObj =
                             plugin.getResourceObjectByID(host);
                     if (resObj != null) {
@@ -543,7 +542,7 @@ public class Console implements CommClient {
     }
 
     public Console(String adminURL, String localAdminURL, String language, String host, String uid, String passwd) {
-		Vector recentURLs = new Vector();
+		Vector<String> recentURLs = new Vector<>();
 		String lastUsedURL;
         common_init(language);
         String userid = uid;
@@ -673,9 +672,9 @@ public class Console implements CommClient {
 
 					String recentlyUsedURL;
 					int count = 1;
-					Enumeration urlEnum = recentURLs.elements();
+					Enumeration<String> urlEnum = recentURLs.elements();
 					while (urlEnum.hasMoreElements()) {
-						recentlyUsedURL = (String)urlEnum.nextElement();
+						recentlyUsedURL = urlEnum.nextElement();
 						if(!recentlyUsedURL.equals(adminURL))
 							_preferences.set(PREFERENCE_URL+Integer.toString(count++), recentlyUsedURL);
 					}
@@ -749,14 +748,8 @@ public class Console implements CommClient {
         LDAPConnection ldc = _info.getLDAPConnection();
 
         if (ldc != null) {
-            String sName;
-            String sValue;
-            int iFirstQuote;
-            int iSecondQuote;
-            int iThirdQuote;
-            int iFourthQuote;
             LDAPAttribute attribute;
-            Enumeration eAttributes;
+            Enumeration<String> eAttributes;
             String ldapLocation = "";
             LDAPEntry entry;
             LDAPSearchResults result;
@@ -773,11 +766,11 @@ public class Console implements CommClient {
                             LDAPUtil.getLDAPAttributeLocale());
 
                     if (attribute != null) {
-                        Vector vUserObjectClasses = new Vector();
+                        Vector<String> vUserObjectClasses = new Vector<>();
                         eAttributes = attribute.getStringValues();
                         while (eAttributes.hasMoreElements()) {
                             String sUserObjectClass =
-                                    (String) eAttributes.nextElement();
+                                    eAttributes.nextElement();
                             vUserObjectClasses.addElement(
                                     sUserObjectClass);
                         }
@@ -792,7 +785,7 @@ public class Console implements CommClient {
             }
             if (ResourceEditor.getNewObjectClasses().get(
                     ResourceEditor.KEY_NEW_USER_OBJECTCLASSES) == null) {
-                Vector vObject = new Vector();
+                Vector<String> vObject = new Vector<>();
                 vObject.addElement("top");
                 vObject.addElement("person");
                 vObject.addElement("organizationalPerson");
@@ -811,11 +804,11 @@ public class Console implements CommClient {
                             LDAPUtil.getLDAPAttributeLocale());
 
                     if (attribute != null) {
-                        Vector vGroupObjectClasses = new Vector();
+                        Vector<String> vGroupObjectClasses = new Vector<>();
                         eAttributes = attribute.getStringValues();
                         while (eAttributes.hasMoreElements()) {
                             String sGroupObjectClass =
-                                    (String) eAttributes.nextElement();
+                                    eAttributes.nextElement();
                             vGroupObjectClasses.addElement(
                                     sGroupObjectClass);
                         }
@@ -830,7 +823,7 @@ public class Console implements CommClient {
             }
             if (ResourceEditor.getNewObjectClasses().get(
                     ResourceEditor.KEY_NEW_GROUP_OBJECTCLASSES) == null) {
-                Vector vObject = new Vector();
+                Vector<String> vObject = new Vector<>();
                 vObject.addElement("top");
                 vObject.addElement("groupofuniquenames");
                 ResourceEditor.getNewObjectClasses().put(
@@ -847,11 +840,11 @@ public class Console implements CommClient {
                             LDAPUtil.getLDAPAttributeLocale());
 
                     if (attribute != null) {
-                        Vector vOUObjectClasses = new Vector();
+                        Vector<String> vOUObjectClasses = new Vector<>();
                         eAttributes = attribute.getStringValues();
                         while (eAttributes.hasMoreElements()) {
                             String sOUObjectClass =
-                                    (String) eAttributes.nextElement();
+                                    eAttributes.nextElement();
                             vOUObjectClasses.addElement(sOUObjectClass);
                         }
 
@@ -865,7 +858,7 @@ public class Console implements CommClient {
             }
             if (ResourceEditor.getNewObjectClasses().get(
                     ResourceEditor.KEY_NEW_OU_OBJECTCLASSES) == null) {
-                Vector vObject = new Vector();
+                Vector<String> vObject = new Vector<>();
                 vObject.addElement("top");
                 vObject.addElement("organizationalunit");
                 ResourceEditor.getNewObjectClasses().put(
@@ -881,8 +874,8 @@ public class Console implements CommClient {
                 result = ldc.search(ldapLocation,
                         LDAPConnection.SCOPE_ONE, "(Objectclass=nsAdminResourceEditorExtension)",
                         null, false, cons);
-                Hashtable hResourceEditorExtension = new Hashtable();
-                Hashtable deleteResourceEditorExtension = new Hashtable();
+                Hashtable<String, Vector<Class<?>>> hResourceEditorExtension = new Hashtable<>();
+                Hashtable<String, Vector<Class<?>>> deleteResourceEditorExtension = new Hashtable<>();
 
                 if (result != null) {
                     while (result.hasMoreElements()) {
@@ -896,10 +889,10 @@ public class Console implements CommClient {
 
                         attribute = ExtensionEntry.getAttribute("cn",
                                 LDAPUtil.getLDAPAttributeLocale());
-                        Enumeration eValues = attribute.getStringValues();
+                        Enumeration<String> eValues = attribute.getStringValues();
                         String sCN = "";
                         while (eValues.hasMoreElements()) {
-                            sCN = (String) eValues.nextElement(); // Take the first CN
+                            sCN = eValues.nextElement(); // Take the first CN
                             break;
                         }
 
@@ -908,11 +901,11 @@ public class Console implements CommClient {
                                 LDAPUtil.getLDAPAttributeLocale());
                         if (attribute != null) {
                             eValues = attribute.getStringValues();
-                            Vector vClass = new Vector();
+                            Vector<Class<?>> vClass = new Vector<>();
                             while (eValues.hasMoreElements()) {
                                 String sJarClassName =
-                                        (String) eValues.nextElement();
-                                Class c = ClassLoaderUtil.getClass(
+                                        eValues.nextElement();
+                                Class<?> c = ClassLoaderUtil.getClass(
                                         _info, sJarClassName);
 
                                 if (c != null) {
@@ -927,13 +920,12 @@ public class Console implements CommClient {
                                 ExtensionEntry.getAttribute("nsDeleteClassname",
                                 LDAPUtil.getLDAPAttributeLocale());
                         if (attribute != null) {
-                            Enumeration deleteClasses =
+                            Enumeration<String> deleteClasses =
                                     attribute.getStringValues();
-                            Vector deleteClassesVector = new Vector();
+                            Vector<Class<?>> deleteClassesVector = new Vector<>();
                             while (deleteClasses.hasMoreElements()) {
-                                String jarClassname = (String)
-                                        deleteClasses.nextElement();
-                                Class c = ClassLoaderUtil.getClass(
+                                String jarClassname = deleteClasses.nextElement();
+                                Class<?> c = ClassLoaderUtil.getClass(
                                         _info, jarClassname);
                                 if (c != null) {
                                     deleteClassesVector.addElement(c);
@@ -1015,8 +1007,8 @@ public class Console implements CommClient {
       *
       * @return hashtable which contain all the resource editor plugin.
       */
-    private Hashtable buildAccountPluginHashtable() {
-        Hashtable HTAccountPlugin = new Hashtable();
+    private Hashtable<String, Vector<String>> buildAccountPluginHashtable() {
+        Hashtable<String, Vector<String>> HTAccountPlugin = new Hashtable<>();
         try {
             LDAPConnection ldc = _info.getLDAPConnection();
             String sExtension = "cn=ResourceEditorExtension, "+
@@ -1035,12 +1027,12 @@ public class Console implements CommClient {
                         continue;
                     }
                     LDAPAttributeSet entryAttrs = entry.getAttributeSet();
-                    Enumeration attrsInSet = entryAttrs.getAttributes();
+                    Enumeration<LDAPAttribute> attrsInSet = entryAttrs.getAttributes();
                     String sName = "";
-                    Vector vJavaClass = new Vector();
+                    Vector<String> vJavaClass = new Vector<>();
                     while (attrsInSet.hasMoreElements()) {
                         LDAPAttribute nextAttr =
-                                (LDAPAttribute) attrsInSet.nextElement();
+                                attrsInSet.nextElement();
                         if (nextAttr.getName().equalsIgnoreCase("cn")) {
                             sName = LDAPUtil.flatting(
                                     nextAttr.getStringValues());
@@ -1106,14 +1098,14 @@ public class Console implements CommClient {
             return false;
         }
 
-        Hashtable ht = new Hashtable();
+        Hashtable<String, String> ht = new Hashtable<>();
 
         boolean successfulAuth = invoke_task(url, user, pw, ht);
 
         String param;
 
         // DT 6/29/98 Check Password Expiration data
-        if ((param = (String)(ht.get("NW_PASSWD_EXPIRING"))) != null) {
+        if ((param = ht.get("NW_PASSWD_EXPIRING")) != null) {
             int secondsToExpiration = Integer.parseInt(param);
 
             if (secondsToExpiration == 0) {
@@ -1144,7 +1136,7 @@ public class Console implements CommClient {
         if (!successfulAuth)
             return false;
 
-        if ((param = (String)(ht.get("UserDN"))) != null)
+        if ((param = ht.get("UserDN")) != null)
             info.setAuthenticationDN(param);
         else {
             Debug.println("Console:authenticate_user():UserDN not found");
@@ -1178,7 +1170,7 @@ public class Console implements CommClient {
             return false;
         }
 
-        return invoke_task(url, user, pw, new Hashtable());
+        return invoke_task(url, user, pw, new Hashtable<String, String>());
     }
 
     /**
@@ -1192,7 +1184,7 @@ public class Console implements CommClient {
       */
 
     private synchronized final boolean invoke_task(URL url,
-            String user, String pw, Hashtable ht) {
+            String user, String pw, Hashtable<String, String> ht) {
         HttpManager h = new HttpManager();
 
         InputStream is;
@@ -1201,7 +1193,7 @@ public class Console implements CommClient {
 
         try {
             h.get(url, this, r = new Response(user, pw),
-                    h.FORCE_BASIC_AUTH);
+                    HttpManager.FORCE_BASIC_AUTH);
         } catch (Exception ioe) {
             String _url;
             try {
@@ -1268,7 +1260,7 @@ public class Console implements CommClient {
         } catch (Exception e2) {
         }
 
-        String status = (String)(ht.get("NMC_Status"));
+        String status = ht.get("NMC_Status");
 
         if ((status == null) || (Integer.parseInt(status) != 0)) {
             Debug.println("Console:invoke_task():invocation failed");
@@ -1288,33 +1280,33 @@ public class Console implements CommClient {
     private final int LDAPinitialization(ConsoleInfo info) {
         // Set DS information;
 
-        Hashtable ht = _info.getAuthenticationValues();
+        Hashtable<String, String> ht = _info.getAuthenticationValues();
 
         String param;
 
         // set up configuration data base information
 
-        if ((param = (String)(ht.get("SIE"))) != null)
+        if ((param = (ht.get("SIE"))) != null)
             _adminServerSIE = param;
         else
             Debug.println("Console:authenticate_user():SIE not found");
 
-        if ((param = (String)(ht.get("ldapHost"))) != null)
+        if ((param = (ht.get("ldapHost"))) != null)
             info.setHost(param);
         else
             Debug.println("Console:authenticate_user():ldapHost not found");
 
-        if ((param = (String)(ht.get("ldapPort"))) != null)
+        if ((param = (ht.get("ldapPort"))) != null)
             info.setPort(Integer.parseInt(param));
         else
             Debug.println("Console:authenticate_user():ldapPort not found");
 
-        if ((param = (String)(ht.get("ldapBaseDN"))) != null)
+        if ((param = (ht.get("ldapBaseDN"))) != null)
             info.setBaseDN(param);
         else
             Debug.println("Console:authenticate_user():ldapBaseDN not found");
 
-        param = (String)(ht.get("ldapSecurity"));
+        param = (ht.get("ldapSecurity"));
         boolean fLdapSecurity = false;
         if ((param != null) && (param.equals("on"))) {
             info.put("ldapSecurity","on");
@@ -1395,7 +1387,7 @@ public class Console implements CommClient {
 
         // set up user data base information
         // If config DS is unaccessable when authenticate CGI is called, the CGI returns ? for UserDirectory
-        if ((param = (String)(ht.get("UserDirectory"))) != null &&
+        if ((param = (ht.get("UserDirectory"))) != null &&
                 !param.equals("?")) {
             // this caused I18n problem - param=param.toLowerCase();
             LDAPConnection ldc = null;
@@ -1646,7 +1638,7 @@ public class Console implements CommClient {
             if (Debug.getTraceLevel() == 9) {
                 try {
                     Properties props = System.getProperties();
-                    for (Enumeration e = props.keys();
+                    for (Enumeration<Object> e = props.keys();
                             e.hasMoreElements();) {
                         String key = (String) e.nextElement();
                         String val = (String) props.get(key);
