@@ -17,16 +17,51 @@
 // --- END COPYRIGHT BLOCK ---
 package com.netscape.admin.certsrv.config;
 
-import com.netscape.admin.certsrv.*;
-import com.netscape.admin.certsrv.connection.*;
-import javax.swing.*;
-import javax.swing.text.*;
-import java.awt.event.*;
-import java.awt.*;
-import java.util.*;
+import java.awt.BorderLayout;
+import java.awt.Component;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
+import java.awt.Insets;
+import java.awt.event.ActionEvent;
+import java.awt.event.ActionListener;
+import java.awt.event.FocusEvent;
+import java.awt.event.FocusListener;
+import java.awt.event.MouseEvent;
+import java.awt.event.MouseListener;
+import java.util.Enumeration;
+import java.util.Hashtable;
+import java.util.ResourceBundle;
+import java.util.StringTokenizer;
+import java.util.Vector;
 
-import com.netscape.management.client.util.*;
-import com.netscape.certsrv.common.*;
+import javax.swing.JButton;
+import javax.swing.JCheckBox;
+import javax.swing.JComboBox;
+import javax.swing.JComponent;
+import javax.swing.JDialog;
+import javax.swing.JFrame;
+import javax.swing.JLabel;
+import javax.swing.JPanel;
+import javax.swing.JPasswordField;
+import javax.swing.JScrollPane;
+import javax.swing.JTable;
+import javax.swing.JTextArea;
+import javax.swing.JTextField;
+import javax.swing.text.AttributeSet;
+import javax.swing.text.BadLocationException;
+import javax.swing.text.Document;
+import javax.swing.text.PlainDocument;
+
+import com.netscape.admin.certsrv.CMSAdminResources;
+import com.netscape.admin.certsrv.CMSAdminUtil;
+import com.netscape.admin.certsrv.CMSBaseResourceModel;
+import com.netscape.admin.certsrv.EAdminException;
+import com.netscape.admin.certsrv.connection.AdminConnection;
+import com.netscape.certsrv.common.Constants;
+import com.netscape.certsrv.common.NameValuePairs;
+import com.netscape.certsrv.common.ScopeDef;
+import com.netscape.management.client.util.Debug;
+import com.netscape.management.client.util.JButtonFactory;
 
 /**
  * Plugin Parameter Configuration Dialog
@@ -255,10 +290,10 @@ public class CMSBaseConfigDialog extends JDialog
 				CMSAdminUtil.resetGBC(gbc);
 
 				gbc.gridwidth = 1;
-				gbc.fill = gbc.NONE;
+				gbc.fill = GridBagConstraints.NONE;
 				gbc.weightx = 0.2;
 				gbc.gridwidth = 1;
-				gbc.anchor = gbc.EAST;
+				gbc.anchor = GridBagConstraints.EAST;
 				gbc.insets = new Insets(
 					CMSAdminUtil.COMPONENT_SPACE, // top
 					0,  // left
@@ -267,16 +302,8 @@ public class CMSBaseConfigDialog extends JDialog
 				p.add(l,gbc);
 
 
-				/* if there was no text extendedplugininfo for this parameter
-				 * just make it a text box
-				 */
-				if (epi == null) {
-					comp = new JTextField(stringvalue);
-				}
-				else  {
-					epi.setValue(stringvalue);
-					comp = epi.makeComponent(this);
-				}
+				epi.setValue(stringvalue);
+				comp = epi.makeComponent(this);
 
 				/* this lets us get an event when this component
 				 * is clicked on, so we can update the help text
@@ -284,9 +311,9 @@ public class CMSBaseConfigDialog extends JDialog
 				comp.addFocusListener(this);
 
 				gbc.weightx = 0.7;
-				gbc.fill = gbc.HORIZONTAL;
-				gbc.gridwidth = gbc.RELATIVE;
-				gbc.anchor = gbc.WEST;
+				gbc.fill = GridBagConstraints.HORIZONTAL;
+				gbc.gridwidth = GridBagConstraints.RELATIVE;
+				gbc.anchor = GridBagConstraints.WEST;
 				gbc.insets = new Insets(
 						CMSAdminUtil.COMPONENT_SPACE, //top
 						0,              			  //left
@@ -299,9 +326,9 @@ public class CMSBaseConfigDialog extends JDialog
 				 */
 				JLabel j = new JLabel("");
 				gbc.weightx = 0.1;
-				gbc.fill = gbc.HORIZONTAL;
-				gbc.gridwidth = gbc.REMAINDER;
-				gbc.anchor = gbc.WEST;
+				gbc.fill = GridBagConstraints.HORIZONTAL;
+				gbc.gridwidth = GridBagConstraints.REMAINDER;
+				gbc.anchor = GridBagConstraints.WEST;
 				gbc.insets = new Insets(
 						CMSAdminUtil.COMPONENT_SPACE,  //top
 						0,  //left
@@ -468,10 +495,10 @@ public class CMSBaseConfigDialog extends JDialog
 			}
 
 			Debug.println(4,"User pressed okay on instance config dialog");
-			Enumeration e = mEPIs.keys();
+			Enumeration<String> e = mEPIs.keys();
 			NameValuePairs nvp = new NameValuePairs();
 			while (e.hasMoreElements()) {
-				String paramName = (String)e.nextElement();
+				String paramName = e.nextElement();
 				ExtendedPluginInfo epi = mEPIs.get(paramName);
 				String value = epi.getComponentStateAsString();
 				if (epi.getType() == ExtendedPluginInfo.TYPE_PASSWORD) {
@@ -544,9 +571,9 @@ public class CMSBaseConfigDialog extends JDialog
 		 * and the help text */
         JPanel content = makeContentPane();
         CMSAdminUtil.resetGBC(gbc);
-		gbc.anchor = gbc.NORTH;
-		gbc.fill = gbc.BOTH;
-		gbc.gridwidth = gbc.REMAINDER;
+		gbc.anchor = GridBagConstraints.NORTH;
+		gbc.fill = GridBagConstraints.BOTH;
+		gbc.gridwidth = GridBagConstraints.REMAINDER;
 		gbc.weightx = 1.0;
 		gbc.weighty = 1.0;
         gb.setConstraints(content, gbc);
@@ -556,9 +583,9 @@ public class CMSBaseConfigDialog extends JDialog
 		/* Action panel. This is where we put the OK, Cancel, Help buttons */
 		JPanel action = makeActionPane();
         CMSAdminUtil.resetGBC(gbc);
-		gbc.anchor = gbc.NORTH;
-		gbc.gridwidth = gbc.REMAINDER;
-		gbc.gridheight = gbc.REMAINDER;
+		gbc.anchor = GridBagConstraints.NORTH;
+		gbc.gridwidth = GridBagConstraints.REMAINDER;
+		gbc.gridheight = GridBagConstraints.REMAINDER;
 		gbc.weightx = 1.0;
         gb.setConstraints(action, gbc);
 		center.add(action);
@@ -604,18 +631,18 @@ public class CMSBaseConfigDialog extends JDialog
         mPluginLabel.setVisible(false);
         mPluginName = new JTextField();
 
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
 		gbc.gridwidth = 1;
-        gbc.anchor = gbc.EAST;
+        gbc.anchor = GridBagConstraints.EAST;
         gbc.insets = new Insets(CMSAdminUtil.COMPONENT_SPACE,
                                  CMSAdminUtil.COMPONENT_SPACE,0,0);
         mListPanel.add(mRulenameCaption, gbc);
 
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         gbc.weightx = 1.0;
-		gbc.gridwidth = gbc.REMAINDER;
+		gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(CMSAdminUtil.COMPONENT_SPACE,
                                  CMSAdminUtil.COMPONENT_SPACE,
       		                     0,CMSAdminUtil.COMPONENT_SPACE);
@@ -628,18 +655,18 @@ public class CMSBaseConfigDialog extends JDialog
          "IMPLNAME", null);
 		mImplnameCaption.addMouseListener(this);
 
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
-        gbc.anchor = gbc.EAST;
+        gbc.anchor = GridBagConstraints.EAST;
         gbc.insets = new Insets(CMSAdminUtil.COMPONENT_SPACE,
                                  CMSAdminUtil.COMPONENT_SPACE,0,0);
         mListPanel.add( mImplnameCaption, gbc );
 
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         mImplName = new JLabel();
         mListPanel.add( mImplName, gbc );
 
@@ -650,9 +677,9 @@ public class CMSBaseConfigDialog extends JDialog
 		mScrollPane.setBorder(CMSAdminUtil.makeEtchedBorder());
 
 		CMSAdminUtil.resetGBC(gbc);
-		gbc.fill = gbc.BOTH;
-        gbc.anchor = gbc.WEST;
-        gbc.gridwidth = gbc.REMAINDER;
+		gbc.fill = GridBagConstraints.BOTH;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.weightx = 1.0;
         gbc.weighty = 1.0;
         gb.setConstraints(mScrollPane, gbc);
@@ -670,9 +697,9 @@ public class CMSBaseConfigDialog extends JDialog
         GridBagConstraints gbc2 = new GridBagConstraints();
 
 		CMSAdminUtil.resetGBC(gbc2);
-		gbc2.fill = gbc.BOTH;
-        gbc2.anchor = gbc.WEST;
-        gbc2.gridwidth = gbc.REMAINDER;
+		gbc2.fill = GridBagConstraints.BOTH;
+        gbc2.anchor = GridBagConstraints.WEST;
+        gbc2.gridwidth = GridBagConstraints.REMAINDER;
         gbc2.weightx = 1.0;
         gbc2.weighty = 1.0;
         gb2.setConstraints(mHelpLabel, gbc2);
@@ -680,9 +707,9 @@ public class CMSBaseConfigDialog extends JDialog
 		mHelpPanel.add(mHelpLabel);
 
 		CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.SOUTH;
-        gbc.gridwidth = gbc.REMAINDER;
-        gbc.gridheight = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.SOUTH;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
+        gbc.gridheight = GridBagConstraints.REMAINDER;
         gbc.weightx = 1.0;
         gbc.weighty = 0.0;
         gb.setConstraints(mHelpPanel, gbc);
@@ -694,7 +721,7 @@ public class CMSBaseConfigDialog extends JDialog
 }
 
 
-class ExtendedPluginInfoSet extends Hashtable {
+class ExtendedPluginInfoSet extends Hashtable<String, ExtendedPluginInfo> {
 
 	/**
 	 * Add a value for this config parameter.
@@ -767,7 +794,7 @@ class ExtendedPluginInfoSet extends Hashtable {
 	}
 
 	public ExtendedPluginInfo get(String param) {
-		return (ExtendedPluginInfo)super.get(param);
+		return super.get(param);
 	}
 
 }
@@ -808,12 +835,12 @@ implements ExtendedPluginInfoComponent
 
 }
 
-class ExtendedPluginInfoComboBox extends JComboBox
+class ExtendedPluginInfoComboBox extends JComboBox<String>
 implements ExtendedPluginInfoComponent
 {
 	private ExtendedPluginInfo mEpi;
 
-	public ExtendedPluginInfoComboBox(ExtendedPluginInfo epi, Vector v)
+	public ExtendedPluginInfoComboBox(ExtendedPluginInfo epi, Vector<String> v)
 	{
 		super(v);
 		mEpi = epi;
@@ -941,7 +968,7 @@ class ExtendedPluginInfo {
 
 	private String mValue = null;
 
-	private Vector mChoices = null;
+	private Vector<String> mChoices = null;
 
 	private String mHelpText = null;
 
@@ -972,7 +999,7 @@ class ExtendedPluginInfo {
 				type.indexOf(')')
 				);
 			StringTokenizer tokenizer = new StringTokenizer(choices,",",false);
-			mChoices = new Vector();
+			mChoices = new Vector<>();
 			String prefix = null;
 			while (tokenizer.hasMoreElements()) {
 				String c = (String)tokenizer.nextElement();
@@ -996,7 +1023,7 @@ class ExtendedPluginInfo {
 		}
 	}
 
-	public Vector getChoices() {
+	public Vector<String> getChoices() {
 		return mChoices;
 	}
 
@@ -1063,7 +1090,7 @@ class ExtendedPluginInfo {
 				break;
 
 			case ExtendedPluginInfo.TYPE_CHOICE:
-				JComboBox cb = new ExtendedPluginInfoComboBox(this,getChoices());
+				JComboBox<String> cb = new ExtendedPluginInfoComboBox(this,getChoices());
 				cb.setSelectedItem(getValue());
 				((ExtendedPluginInfoComboBox)cb).addActionListener(al);
 				component = cb;
