@@ -17,18 +17,42 @@
 // --- END COPYRIGHT BLOCK ---
 package com.netscape.admin.certsrv.config;
 
-import com.netscape.admin.certsrv.*;
-import com.netscape.management.client.console.*;
-import com.netscape.admin.certsrv.connection.*;
-import com.netscape.certsrv.common.*;
-import java.awt.*;
-import java.util.*;
-import javax.swing.*;
-import java.awt.event.*;
-import javax.swing.border.*;
-import com.netscape.management.client.util.*;
-import com.netscape.admin.certsrv.keycert.*;
-import com.netscape.admin.certsrv.managecert.*;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
+import java.awt.Insets;
+import java.awt.event.ActionEvent;
+import java.awt.event.ItemEvent;
+import java.util.Enumeration;
+import java.util.Hashtable;
+import java.util.MissingResourceException;
+import java.util.StringTokenizer;
+import java.util.Vector;
+
+import javax.swing.BorderFactory;
+import javax.swing.JButton;
+import javax.swing.JComboBox;
+import javax.swing.JComponent;
+import javax.swing.JFrame;
+import javax.swing.JLabel;
+import javax.swing.JOptionPane;
+import javax.swing.JPanel;
+import javax.swing.border.CompoundBorder;
+import javax.swing.border.EmptyBorder;
+
+import com.netscape.admin.certsrv.CMSAdminResources;
+import com.netscape.admin.certsrv.CMSAdminUtil;
+import com.netscape.admin.certsrv.CMSServerInfo;
+import com.netscape.admin.certsrv.EAdminException;
+import com.netscape.admin.certsrv.connection.AdminConnection;
+import com.netscape.admin.certsrv.keycert.CertSetupWizard;
+import com.netscape.admin.certsrv.keycert.CertSetupWizardInfo;
+import com.netscape.admin.certsrv.managecert.ManageCertDialog;
+import com.netscape.certsrv.common.Constants;
+import com.netscape.certsrv.common.DestDef;
+import com.netscape.certsrv.common.NameValuePairs;
+import com.netscape.certsrv.common.ScopeDef;
+import com.netscape.management.client.console.ConsoleInfo;
+import com.netscape.management.client.util.Debug;
 
 /**
  * Encryption panel used for setup server encryption options.
@@ -49,14 +73,14 @@ public class CMSEncryptionPanel extends CMSBaseTab  {
     private CMSServerInfo mServerInfo;
     private AdminConnection mConnection;
     private JPanel mEncryptPane;
-    private JComboBox mSelection, mTokenList, mCertList;
-    private Hashtable mCertMapping;         //maps the function list items to tags
+    private JComboBox<String> mSelection, mTokenList, mCertList;
+    private Hashtable<String, CipherEntryData> mCertMapping;         //maps the function list items to tags
     private String mSelectedItem, mSelectedToken, mSelectedCert;
     private JButton mWizard, mCipherPref, mSetup;
-    private Hashtable mTokenCertList;        //container for tokens and certs (Vector)
+    private Hashtable<String, Vector<String>> mTokenCertList;        //container for tokens and certs (Vector)
     private boolean mIsDomestic = false;
     private boolean mHasFortezza =  false;
-    private Vector mCipherPrefStore;
+    private Vector<String> mCipherPrefStore;
     private CMSCipherPreferenceDialog mCipherDialog;
     private boolean updateFlag = false;
     private boolean mSelectionIgnore = false;
@@ -74,9 +98,9 @@ public class CMSEncryptionPanel extends CMSBaseTab  {
         mConsoleInfo = parent.getResourceModel().getConsoleInfo();
         mServerInfo = parent.getResourceModel().getServerInfo();
         mConnection = mServerInfo.getAdmin();
-        mCertMapping = new Hashtable();
-        mTokenCertList = new Hashtable();
-        mCipherPrefStore = new Vector();
+        mCertMapping = new Hashtable<>();
+        mTokenCertList = new Hashtable<>();
+        mCipherPrefStore = new Vector<>();
         mHelpToken = HELPINDEX;
     }
 
@@ -108,7 +132,7 @@ public class CMSEncryptionPanel extends CMSBaseTab  {
 
         //add selection combobox
         JLabel label1 = makeJLabel("SELECT");
-        mSelection = new JComboBox();
+        mSelection = new JComboBox<>();
         updateCertSelection();                  //dynamically generate this list
         addTopEntryField(top, label1, mSelection, gbc);
         if (mSelection.getItemCount()>0) {
@@ -125,8 +149,8 @@ public class CMSEncryptionPanel extends CMSBaseTab  {
         //mEncryptPane = new InnerEncryptionPane(mConsoleInfo);
         //mEncryptPane.addEncryptionPaneListener(this);
         CMSAdminUtil.resetGBC(gbc);
-        gbc.anchor = gbc.NORTH;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.anchor = GridBagConstraints.NORTH;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         //gbc.gridheight = gbc.REMAINDER;
         gbc.weightx = 1.0;
         //gbc.weighty = 1.0;
@@ -136,7 +160,7 @@ public class CMSEncryptionPanel extends CMSBaseTab  {
         top.add(mEncryptPane);
 
         CMSAdminUtil.resetGBC(gbc);
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.weightx = 1.0;
         gb.setConstraints(top, gbc);
         mCenterPanel.add(top);
@@ -145,7 +169,7 @@ public class CMSEncryptionPanel extends CMSBaseTab  {
         mCipherPref = makeJButton("CIPHERPREF");
         mSetup = makeJButton("SETUP");
         CMSAdminUtil.resetGBC(gbc);
-        gbc.gridheight = gbc.REMAINDER;
+        gbc.gridheight = GridBagConstraints.REMAINDER;
         gbc.weighty = 1.0;
         //addButtonEntryField(mCenterPanel, mSetup, mWizard, mCipherPref, gbc);
         addButtonEntryField(mCenterPanel, mSetup, mWizard, gbc);
@@ -177,9 +201,9 @@ public class CMSEncryptionPanel extends CMSBaseTab  {
 
         //construct NVP parameters
         NameValuePairs nvp = new NameValuePairs();
-        for (Enumeration e = mCertMapping.keys() ; e.hasMoreElements() ;) {
+        for (Enumeration<String> e = mCertMapping.keys() ; e.hasMoreElements() ;) {
             CipherEntryData data =
-                (CipherEntryData)mCertMapping.get(e.nextElement());
+                mCertMapping.get(e.nextElement());
             nvp.put(data.getTagName(), data.getTokenName() + "," + data.getCertName());
         }
 
@@ -287,8 +311,8 @@ public class CMSEncryptionPanel extends CMSBaseTab  {
             //Save the cipher settings
             StringBuffer buf = new StringBuffer();
 
-            if (mCipherDialog.isSSLEnabled(mCipherDialog.SSL2)) {
-                String[] v2 = mCipherDialog.getSSLPreference(mCipherDialog.SSL2);
+            if (mCipherDialog.isSSLEnabled(CMSCipherPreferenceDialog.SSL2)) {
+                String[] v2 = mCipherDialog.getSSLPreference(CMSCipherPreferenceDialog.SSL2);
                 for (int i=0; i< v2.length; i++) {
                     if (mCipherDialog.isCipherEnabled(v2[i])) {
                         if (buf.length()>0)
@@ -298,8 +322,8 @@ public class CMSEncryptionPanel extends CMSBaseTab  {
                 }
             }
 
-            if (mCipherDialog.isSSLEnabled(mCipherDialog.SSL3)) {
-                String[] v3 = mCipherDialog.getSSLPreference(mCipherDialog.SSL3);
+            if (mCipherDialog.isSSLEnabled(CMSCipherPreferenceDialog.SSL3)) {
+                String[] v3 = mCipherDialog.getSSLPreference(CMSCipherPreferenceDialog.SSL3);
                 for (int i=0; i< v3.length; i++) {
                     if (mCipherDialog.isCipherEnabled(v3[i])) {
                         if (buf.length()>0)
@@ -322,7 +346,7 @@ public class CMSEncryptionPanel extends CMSBaseTab  {
     public void itemStateChanged(ItemEvent e){
 
         if (e.getSource().equals(mSelection)) {
-            if (e.getStateChange() == e.SELECTED) {
+            if (e.getStateChange() == ItemEvent.SELECTED) {
                 if (!mSelectionIgnore) {
                     updateFlag = true;
                     saveChanges(mSelectedItem);
@@ -332,7 +356,7 @@ public class CMSEncryptionPanel extends CMSBaseTab  {
                 }
             }
         } else if (e.getSource().equals(mTokenList)) {
-            if ( (!updateFlag) && (e.getStateChange() == e.SELECTED) ){
+            if ( (!updateFlag) && (e.getStateChange() == ItemEvent.SELECTED) ){
                 Debug.println("Token Selected");
                 setDirtyFlag();
                 updateFlag = true;
@@ -340,7 +364,7 @@ public class CMSEncryptionPanel extends CMSBaseTab  {
                 updateFlag = false;
             }
         } else if (e.getSource().equals(mCertList)) {
-            if ( (!updateFlag) && (e.getStateChange() == e.SELECTED) ){
+            if ( (!updateFlag) && (e.getStateChange() == ItemEvent.SELECTED) ){
                 Debug.println("Cert Selected");
                 saveChanges(mSelectedItem);
                 setupComboSelection();
@@ -356,10 +380,10 @@ public class CMSEncryptionPanel extends CMSBaseTab  {
 
     //save the mappings if changes made
     private void saveChanges(String entry) {
-        if ( (!mSelectedToken.equals((String)mTokenList.getSelectedItem())) ||
-             (!mSelectedCert.equals((String)mCertList.getSelectedItem())) ) {
+        if ( (!mSelectedToken.equals(mTokenList.getSelectedItem())) ||
+             (!mSelectedCert.equals(mCertList.getSelectedItem())) ) {
 
-            CipherEntryData data = (CipherEntryData) mCertMapping.get(entry);
+            CipherEntryData data = mCertMapping.get(entry);
             data.setData((String)mTokenList.getSelectedItem(),
                          (String)mCertList.getSelectedItem());
         }
@@ -376,15 +400,15 @@ public class CMSEncryptionPanel extends CMSBaseTab  {
     //setup the cipher dialog
     private void setupCipherDialog(CMSCipherPreferenceDialog dialog) {
         Debug.println("setupCipherDialog");
-        dialog.setSSLEnabled(dialog.SSL3,true);
+        dialog.setSSLEnabled(CMSCipherPreferenceDialog.SSL3,true);
 
         //set selected/unselected ciphers
-        String[] v2 = dialog.getSSLPreference(dialog.SSL2);
+        String[] v2 = dialog.getSSLPreference(CMSCipherPreferenceDialog.SSL2);
 
         if (v2.length <= 0)
-            dialog.setSSLEnabled(dialog.SSL2,false);
+            dialog.setSSLEnabled(CMSCipherPreferenceDialog.SSL2,false);
         else
-            dialog.setSSLEnabled(dialog.SSL2,true);
+            dialog.setSSLEnabled(CMSCipherPreferenceDialog.SSL2,true);
 
         for (int i=0; i< v2.length; i++) {
             if (mCipherPrefStore.contains(v2[i])) {
@@ -395,11 +419,11 @@ public class CMSEncryptionPanel extends CMSBaseTab  {
                 dialog.setCipherEnabled(v2[i], false);
             }
         }
-        String[] v3 = dialog.getSSLPreference(dialog.SSL3);
+        String[] v3 = dialog.getSSLPreference(CMSCipherPreferenceDialog.SSL3);
         if (v3.length <= 0)
-            dialog.setSSLEnabled(dialog.SSL3,false);
+            dialog.setSSLEnabled(CMSCipherPreferenceDialog.SSL3,false);
         else
-            dialog.setSSLEnabled(dialog.SSL3,true);
+            dialog.setSSLEnabled(CMSCipherPreferenceDialog.SSL3,true);
 
         for (int i=0; i< v3.length; i++) {
             if (mCipherPrefStore.contains(v3[i])) {
@@ -447,9 +471,9 @@ public class CMSEncryptionPanel extends CMSBaseTab  {
         //setup the cipher entry data - loop through table and retrieve
         //the current mappings
         mSelectionIgnore = true;
-        for (Enumeration e = mCertMapping.keys() ; e.hasMoreElements() ;) {
-            String name = (String) e.nextElement();
-            CipherEntryData data = (CipherEntryData)mCertMapping.get(name);
+        for (Enumeration<String> e = mCertMapping.keys() ; e.hasMoreElements() ;) {
+            String name = e.nextElement();
+            CipherEntryData data = mCertMapping.get(name);
             String value = response.get(data.getTagName());
             if ( (value != null) && (!value.trim().equals("")) ) {
                 StringTokenizer tokenizer = new StringTokenizer(value, ",");
@@ -479,7 +503,7 @@ public class CMSEncryptionPanel extends CMSBaseTab  {
 
                 //get the certificate associated with this token
                 String certList = response.get(Constants.PR_TOKEN_PREFIX + token);
-                Vector certVector = new Vector();
+                Vector<String> certVector = new Vector<>();
                 if ( (certList != null) && (!certList.trim().equals("")) ) {
                     StringTokenizer tokenizer2 = new StringTokenizer(certList, ",");
                     while (tokenizer2.hasMoreTokens()) {
@@ -501,7 +525,7 @@ public class CMSEncryptionPanel extends CMSBaseTab  {
         String newToken = (String) mTokenList.getSelectedItem();
         mSelectedToken = newToken;
         mCertList.removeAllItems();
-        Vector list = (Vector) mTokenCertList.get(newToken);
+        Vector<String> list = mTokenCertList.get(newToken);
         for (int i=0; i< list.size(); i++)
             mCertList.addItem(list.elementAt(i));
     }
@@ -509,7 +533,7 @@ public class CMSEncryptionPanel extends CMSBaseTab  {
     //setup combobox selection
     private void setupComboSelection() {
         //get current function selection
-        CipherEntryData data = (CipherEntryData) mCertMapping.get(mSelection.getSelectedItem());
+        CipherEntryData data = mCertMapping.get(mSelection.getSelectedItem());
 
         //select correct token from the token list
         String oldToken = (String) mTokenList.getSelectedItem();
@@ -528,7 +552,7 @@ public class CMSEncryptionPanel extends CMSBaseTab  {
     private void setupCertCombo() {
         String newToken = (String) mTokenList.getSelectedItem();
         mCertList.removeAllItems();
-        Vector list = (Vector) mTokenCertList.get(newToken);
+        Vector<String> list = mTokenCertList.get(newToken);
         for (int i=0; i< list.size(); i++)
             mCertList.addItem(list.elementAt(i));
     }
@@ -550,9 +574,9 @@ public class CMSEncryptionPanel extends CMSBaseTab  {
                             0)));
 
         //add components
-        mTokenList = new JComboBox();
+        mTokenList = new JComboBox<>();
         mTokenList.addItemListener(this);
-        mCertList = new JComboBox();
+        mCertList = new JComboBox<>();
         mCertList.addItemListener(this);
         JLabel label1 = makeJLabel("TOKEN");
         JLabel label2 = makeJLabel("CERTIFICATE");
@@ -566,7 +590,7 @@ public class CMSEncryptionPanel extends CMSBaseTab  {
      */
     private void updateCertSelection() {
         //get installed subsystem
-        Vector v = mServerInfo.getInstalledSubsystems();
+        Vector<String> v = mServerInfo.getInstalledSubsystems();
 
         //add default system certificate list
         String certs;
@@ -586,7 +610,7 @@ public class CMSEncryptionPanel extends CMSBaseTab  {
 
         //create additional subsystem certificate list
         for (int i=0; i< v.size(); i++) {
-            String name = (String)v.elementAt(i);
+            String name = v.elementAt(i);
             try {
                 String certlist = mResource.getString(PANEL_NAME+"_"+name+"_CERTS");
                     if (!certlist.trim().equals("")) {
@@ -618,54 +642,31 @@ public class CMSEncryptionPanel extends CMSBaseTab  {
 
     private static void addTopEntryField(JPanel panel, JComponent label,
       JComponent field, GridBagConstraints gbc) {
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
         gbc.gridx = 0;
-        gbc.anchor = gbc.EAST;
+        gbc.anchor = GridBagConstraints.EAST;
         gbc.insets = new Insets(COMPONENT_SPACE,DIFFERENT_COMPONENT_SPACE,0,0);
         panel.add( label, gbc );
 
         gbc.gridx++;
-        gbc.anchor = gbc.WEST;
-        gbc.fill = gbc.HORIZONTAL;
+        gbc.anchor = GridBagConstraints.WEST;
+        gbc.fill = GridBagConstraints.HORIZONTAL;
         gbc.weightx = 1.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,
                                         0,DIFFERENT_COMPONENT_SPACE);
         panel.add( field, gbc );
     }
 
-   private static void addButtonEntryField(JPanel panel,
-      JComponent field, GridBagConstraints gbc) {
-        gbc.fill = gbc.NONE;
-        gbc.weightx = 0.0;
-        gbc.gridwidth = 1;
-        gbc.gridx = 0;
-        gbc.anchor = gbc.NORTHEAST;
-        gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,0,0);
-        //gbc.insets = new Insets(DIFFERENT_COMPONENT_SPACE,DIFFERENT_COMPONENT_SPACE,0,0);
-        panel.add(new JLabel(""));
-
-        gbc.gridx++;
-        gbc.anchor = gbc.NORTHEAST;
-        gbc.fill = gbc.NONE;
-        gbc.weightx = 0.0;
-        gbc.gridwidth = gbc.REMAINDER;
-        //gbc.insets = new Insets(DIFFERENT_COMPONENT_SPACE,DIFFERENT_COMPONENT_SPACE,
-         //                               0,DIFFERENT_COMPONENT_SPACE);
-        gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,
-                                        0,COMPONENT_SPACE);
-        panel.add( field, gbc );
-    }
-
     private static void addButtonEntryField(JPanel panel, JComponent label,
       JComponent field, GridBagConstraints gbc) {
-        gbc.fill = gbc.NONE;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
         gbc.gridwidth = 1;
         gbc.gridx = 0;
-        gbc.anchor = gbc.NORTHEAST;
+        gbc.anchor = GridBagConstraints.NORTHEAST;
         //gbc.insets = new Insets(DIFFERENT_COMPONENT_SPACE,DIFFERENT_COMPONENT_SPACE,0,0);
         gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,0,0);
         panel.add(new JLabel(""));
@@ -675,10 +676,10 @@ public class CMSEncryptionPanel extends CMSBaseTab  {
         panel.add( label, gbc );
 
         gbc.gridx++;
-        gbc.anchor = gbc.NORTHEAST;
-        gbc.fill = gbc.NONE;
+        gbc.anchor = GridBagConstraints.NORTHEAST;
+        gbc.fill = GridBagConstraints.NONE;
         gbc.weightx = 0.0;
-        gbc.gridwidth = gbc.REMAINDER;
+        gbc.gridwidth = GridBagConstraints.REMAINDER;
         //gbc.insets = new Insets(DIFFERENT_COMPONENT_SPACE,DIFFERENT_COMPONENT_SPACE,
                                         //0,DIFFERENT_COMPONENT_SPACE);
         gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,
@@ -686,44 +687,6 @@ public class CMSEncryptionPanel extends CMSBaseTab  {
         panel.add( field, gbc );
     }
 
-    private static void addButtonEntryField(JPanel panel, JComponent label,
-      JComponent field, JComponent field1, GridBagConstraints gbc) {
-        gbc.fill = gbc.NONE;
-        gbc.weightx = 0.0;
-        gbc.gridwidth = 1;
-        gbc.gridx = 0;
-        gbc.anchor = gbc.NORTHEAST;
-        //gbc.insets = new Insets(DIFFERENT_COMPONENT_SPACE,DIFFERENT_COMPONENT_SPACE,0,0);
-        gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,0,0);
-        panel.add(new JLabel(""));
-
-        gbc.gridx++;
-        gbc.weightx = 1.0;
-        panel.add( label, gbc );
-
-        gbc.gridx++;
-        gbc.anchor = gbc.NORTHEAST;
-        gbc.fill = gbc.NONE;
-        gbc.weightx = 0.0;
-        //gbc.gridwidth = gbc.REMAINDER;
-        //gbc.insets = new Insets(DIFFERENT_COMPONENT_SPACE,DIFFERENT_COMPONENT_SPACE,
-         //                               0,DIFFERENT_COMPONENT_SPACE);
-        gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,
-                                        0,COMPONENT_SPACE);
-        panel.add( field, gbc );
-
-        gbc.gridx++;
-        gbc.anchor = gbc.NORTHEAST;
-        gbc.fill = gbc.NONE;
-        gbc.weightx = 0.0;
-        gbc.gridwidth = gbc.REMAINDER;
-        //gbc.insets = new Insets(DIFFERENT_COMPONENT_SPACE,DIFFERENT_COMPONENT_SPACE,
-         //                               0,DIFFERENT_COMPONENT_SPACE);
-        gbc.insets = new Insets(COMPONENT_SPACE,COMPONENT_SPACE,
-                                        0,COMPONENT_SPACE);
-        panel.add( field1, gbc );
-    }
-
     /*==========================================================
      * SEND STUFF TO SERVER
      *==========================================================*/
@@ -740,8 +703,8 @@ public class CMSEncryptionPanel extends CMSBaseTab  {
         nvp.put(Constants.PR_TOKEN_LIST, "");
 
         //create installed certificate list data request
-        for (Enumeration e = mCertMapping.elements(); e.hasMoreElements() ;) {
-            CipherEntryData data = (CipherEntryData)e.nextElement();
+        for (Enumeration<CipherEntryData> e = mCertMapping.elements(); e.hasMoreElements() ;) {
+            CipherEntryData data = e.nextElement();
             nvp.put(data.getTagName(), "");
         }
 
