@@ -43,8 +43,6 @@ public class CMSImportCert extends CGITask {
     /*==========================================================
      * variables
      *==========================================================*/
-    private static final String PREFIX = "CGITASK";
-	private String mCgiTask = null; // CGI task to call
     private InstallWizardInfo mWizardInfo;
 	private String mPolicyMsg = null;
 
