@@ -33,17 +33,16 @@ import org.mozilla.jss.asn1.UTF8String;
 import org.mozilla.jss.asn1.UniversalString;
 import org.mozilla.jss.crypto.CryptoToken;
 import org.mozilla.jss.crypto.PrivateKey;
-import org.mozilla.jss.pkix.primitive.AVA;
-import org.mozilla.jss.pkix.primitive.Name;
-import org.mozilla.jss.util.Password;
-
-import com.netscape.cmsutil.crypto.CryptoUtil;
-
 import org.mozilla.jss.netscape.security.pkcs.PKCS10;
 import org.mozilla.jss.netscape.security.x509.Extensions;
 import org.mozilla.jss.netscape.security.x509.KeyIdentifier;
 import org.mozilla.jss.netscape.security.x509.SubjectKeyIdentifierExtension;
 import org.mozilla.jss.netscape.security.x509.X500Name;
+import org.mozilla.jss.pkix.primitive.AVA;
+import org.mozilla.jss.pkix.primitive.Name;
+import org.mozilla.jss.util.Password;
+
+import com.netscape.cmsutil.crypto.CryptoUtil;
 
 /**
  * Generates an ECC or RSA key pair in the security database, constructs a
@@ -185,7 +184,7 @@ public class PKCS10Client {
             }
         }
 
-        if (password == null || ofilename == null || subjectName == null) {
+        if (ofilename == null || subjectName == null) {
             System.out.println("PKCS10Client: Illegal input parameters.");
             printUsage();
             System.exit(1);
@@ -216,17 +215,17 @@ public class PKCS10Client {
                 System.out.println("PKCS10Client: Debug: thread token set.");
             }
 
+            if (password != null) {
+                Password pass = new Password(password.toCharArray());
 
-            Password pass = new Password(password.toCharArray());
-
-            try {
-                token.login(pass);
-                if(verbose) {
-                    System.out.println("PKCS10Client: token "+ tokenName + " logged in...");
+                try {
+                    token.login(pass);
+                    if (verbose) {
+                        System.out.println("PKCS10Client: token "+ tokenName + " logged in...");
+                    }
+                } finally {
+                    pass.clear();
                 }
-            } catch (Exception e) {
-                System.out.println("PKCS10Client: login Exception: " + e.toString());
-                System.exit(1);
             }
 
             KeyPair pair = null;
@@ -343,7 +342,7 @@ public class PKCS10Client {
 
 
         } catch (Exception e) {
-            System.out.println("PKCS10Client: Exception caught: "+e.toString());
+            System.out.println("PKCS10Client: Exception caught: " + e);
             System.exit(1);
         }
     }
