@@ -1,14 +1,13 @@
 package com.netscape.cmstools.authority;
 
-import java.util.Arrays;
-
 import org.apache.commons.cli.CommandLine;
-import org.dogtagpki.cli.CLI;
+import org.dogtagpki.cli.CommandCLI;
 
 import com.netscape.certsrv.authority.AuthorityClient;
 import com.netscape.certsrv.authority.AuthorityData;
+import com.netscape.cmstools.cli.MainCLI;
 
-public class AuthorityEnableCLI extends CLI {
+public class AuthorityEnableCLI extends CommandCLI {
 
     public AuthorityCLI authorityCLI;
 
@@ -21,14 +20,7 @@ public class AuthorityEnableCLI extends CLI {
         formatter.printHelp(getFullName() + " <ID>", options);
     }
 
-    public void execute(String[] args) throws Exception {
-        // Always check for "--help" prior to parsing
-        if (Arrays.asList(args).contains("--help")) {
-            printHelp();
-            return;
-        }
-
-        CommandLine cmd = parser.parse(options, args);
+    public void execute(CommandLine cmd) throws Exception {
 
         String[] cmdArgs = cmd.getArgs();
 
@@ -36,11 +28,14 @@ public class AuthorityEnableCLI extends CLI {
             throw new Exception("No ID specified.");
         }
 
+        MainCLI mainCLI = (MainCLI) getRoot();
+        mainCLI.init();
+
         AuthorityData data = new AuthorityData(
             null, null, cmdArgs[0], null, null, null, true, null, null);
+
         AuthorityClient authorityClient = authorityCLI.getAuthorityClient();
         data = authorityClient.modifyCA(data);
         AuthorityCLI.printAuthorityData(data);
     }
-
 }
