@@ -20,11 +20,10 @@ package com.netscape.cmstools.ca;
 
 import java.io.FileWriter;
 import java.io.PrintWriter;
-import java.util.Arrays;
 
 import org.apache.commons.cli.CommandLine;
 import org.apache.commons.cli.Option;
-import org.dogtagpki.cli.CLI;
+import org.dogtagpki.cli.CommandCLI;
 
 import com.netscape.certsrv.ca.CACertClient;
 import com.netscape.certsrv.cert.CertData;
@@ -34,15 +33,15 @@ import com.netscape.cmstools.cli.MainCLI;
 /**
  * @author Endi S. Dewata
  */
-public class CACertShowCLI extends CLI {
+public class CACertShowCLI extends CommandCLI {
+
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(CACertShowCLI.class);
 
     public CACertCLI certCLI;
 
     public CACertShowCLI(CACertCLI certCLI) {
         super("show", "Show certificate", certCLI);
         this.certCLI = certCLI;
-
-        createOptions();
     }
 
     public void printHelp() {
@@ -50,22 +49,15 @@ public class CACertShowCLI extends CLI {
     }
 
     public void createOptions() {
-        Option option = new Option(null, "output", true, "Output file");
+        Option option = new Option(null, "output", true, "DEPRECATED: Output file");
         option.setArgName("file");
         options.addOption(option);
 
         options.addOption(null, "pretty", false, "Pretty print");
-        options.addOption(null, "encoded", false, "Base-64 encoded");
+        options.addOption(null, "encoded", false, "DEPRECATED: Base-64 encoded");
     }
 
-    public void execute(String[] args) throws Exception {
-        // Always check for "--help" prior to parsing
-        if (Arrays.asList(args).contains("--help")) {
-            printHelp();
-            return;
-        }
-
-        CommandLine cmd = parser.parse(options, args);
+    public void execute(CommandLine cmd) throws Exception {
 
         String[] cmdArgs = cmd.getArgs();
 
@@ -73,12 +65,24 @@ public class CACertShowCLI extends CLI {
             throw new Exception("Missing Serial Number.");
         }
 
+        CertId certID = new CertId(cmdArgs[0]);
+
         boolean showPrettyPrint = cmd.hasOption("pretty");
         boolean showEncoded = cmd.hasOption("encoded");
 
-        CertId certID = new CertId(cmdArgs[0]);
+        if (showEncoded) {
+            logger.warn("The --encoded option has been deprecated. Use pki ca-cert-export instead.");
+        }
+
         String file = cmd.getOptionValue("output");
 
+        if (file != null) {
+            logger.warn("The --output option has been deprecated. Use pki ca-cert-export instead.");
+        }
+
+        MainCLI mainCLI = (MainCLI) getRoot();
+        mainCLI.init();
+
         CACertClient certClient = certCLI.getCertClient();
         CertData certData = certClient.getCert(certID);
 
@@ -90,8 +94,6 @@ public class CACertShowCLI extends CLI {
             }
         }
 
-        MainCLI.printMessage("Certificate \"" + certID.toHexString() + "\"");
-
         CACertCLI.printCertData(certData, showPrettyPrint, showEncoded);
     }
 }
