@@ -24,8 +24,12 @@ import java.util.List;
 
 import org.apache.commons.cli.CommandLine;
 import org.apache.commons.cli.Option;
-import org.dogtagpki.cli.CLI;
 import org.dogtagpki.cli.CLIException;
+import org.dogtagpki.cli.CommandCLI;
+import org.mozilla.jss.netscape.security.util.Cert;
+import org.mozilla.jss.netscape.security.x509.X500Name;
+import org.mozilla.jss.netscape.security.x509.X509CertImpl;
+import org.mozilla.jss.netscape.security.x509.X509Key;
 
 import com.netscape.certsrv.authority.AuthorityClient;
 import com.netscape.certsrv.authority.AuthorityData;
@@ -35,6 +39,7 @@ import com.netscape.certsrv.cert.CertData;
 import com.netscape.certsrv.client.ClientConfig;
 import com.netscape.certsrv.client.PKIClient;
 import com.netscape.certsrv.dbs.certdb.CertId;
+import com.netscape.cmstools.cli.MainCLI;
 import com.netscape.cmsutil.ocsp.BasicOCSPResponse;
 import com.netscape.cmsutil.ocsp.CertStatus;
 import com.netscape.cmsutil.ocsp.GoodInfo;
@@ -45,24 +50,19 @@ import com.netscape.cmsutil.ocsp.ResponseData;
 import com.netscape.cmsutil.ocsp.RevokedInfo;
 import com.netscape.cmsutil.ocsp.SingleResponse;
 import com.netscape.cmsutil.ocsp.UnknownInfo;
-import org.mozilla.jss.netscape.security.util.Cert;
-
-import org.mozilla.jss.netscape.security.x509.X500Name;
-import org.mozilla.jss.netscape.security.x509.X509CertImpl;
-import org.mozilla.jss.netscape.security.x509.X509Key;
 
 /**
  * @author Endi S. Dewata
  */
-public class CACertStatusCLI extends CLI {
+public class CACertStatusCLI extends CommandCLI {
+
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(CACertStatusCLI.class);
 
     public CACertCLI certCLI;
 
     public CACertStatusCLI(CACertCLI certCLI) {
         super("status", "Check certificate status", certCLI);
         this.certCLI = certCLI;
-
-        createOptions();
     }
 
     public void printHelp() {
@@ -73,28 +73,21 @@ public class CACertStatusCLI extends CLI {
         Option option = new Option(null, "ocsp", true, "OCSP URL");
         option.setArgName("URL");
         options.addOption(option);
-
-        options.addOption("v", "verbose", false, "Run in verbose mode.");
-        options.addOption(null, "help", false, "Show help message.");
     }
 
-    public void execute(String[] args) throws Exception {
-
-        CommandLine cmd = parser.parse(options, args);
+    public void execute(CommandLine cmd) throws Exception {
 
         String[] cmdArgs = cmd.getArgs();
 
-        if (cmd.hasOption("help")) {
-            printHelp();
-            return;
-        }
-
         if (cmdArgs.length < 1) {
             throw new Exception("Missing certificate serial number.");
         }
 
         CertId certID = new CertId(cmdArgs[0]);
 
+        MainCLI mainCLI = (MainCLI) getRoot();
+        mainCLI.init();
+
         PKIClient client = getClient();
         CAClient caClient = new CAClient(client);
         CACertClient certClient = new CACertClient(caClient);
@@ -104,7 +97,6 @@ public class CACertStatusCLI extends CLI {
         String ocspURL = cmd.getOptionValue("ocsp", config.getServerURL() + "/ca/ocsp");
 
         OCSPProcessor processor = new OCSPProcessor();
-        processor.setVerbose(verbose);
         processor.setURL(ocspURL);
 
         // get certificate data
