@@ -30,7 +30,6 @@ import java.net.URL;
 import java.net.UnknownHostException;
 import java.nio.file.Files;
 import java.nio.file.Paths;
-import java.util.Arrays;
 import java.util.Collection;
 import java.util.HashSet;
 import java.util.LinkedHashMap;
@@ -47,6 +46,9 @@ import org.dogtagpki.cli.CLI;
 import org.dogtagpki.cli.CLIException;
 import org.dogtagpki.common.Info;
 import org.dogtagpki.common.InfoClient;
+import org.dogtagpki.nss.NSSDatabase;
+import org.dogtagpki.util.logging.PKILogger;
+import org.dogtagpki.util.logging.PKILogger.Level;
 import org.mozilla.jss.CryptoManager;
 import org.mozilla.jss.NotInitializedException;
 import org.mozilla.jss.crypto.CryptoToken;
@@ -66,6 +68,7 @@ import com.netscape.cmstools.client.ClientCLI;
 import com.netscape.cmstools.group.ProxyGroupCLI;
 import com.netscape.cmstools.key.ProxyKeyCLI;
 import com.netscape.cmstools.kra.KRACLI;
+import com.netscape.cmstools.nss.NSSCLI;
 import com.netscape.cmstools.ocsp.OCSPCLI;
 import com.netscape.cmstools.pkcs11.PKCS11CLI;
 import com.netscape.cmstools.pkcs12.PKCS12CLI;
@@ -81,19 +84,6 @@ import com.netscape.cmsutil.crypto.CryptoUtil;
  */
 public class MainCLI extends CLI {
 
-    /**
-     * These commands should not be executed after CryptoManager.initialize()
-     * since they may modify the NSS database or execute external commands
-     * using the same NSS database.
-     */
-    public final static Collection<String> RESTRICTED_COMMANDS = Arrays.asList(
-            "client-init",
-            "client-cert-import",
-            "client-cert-mod",
-            "client-cert-request",
-            "client-cert-show"
-    );
-
     public ClientConfig config = new ClientConfig();
 
     public Collection<Integer> rejectedCertStatuses = new HashSet<Integer>();
@@ -104,12 +94,17 @@ public class MainCLI extends CLI {
 
     String output;
 
+    boolean initialized;
+
     public MainCLI() throws Exception {
         super("pki", "PKI command-line interface");
 
         addModule(new HelpCLI(this));
 
         addModule(new ClientCLI(this));
+        addModule(new NSSCLI(this));
+
+        addModule(new InfoCLI(this));
 
         addModule(new ProxyCertCLI(this));
         addModule(new ProxyGroupCLI(this));
@@ -130,6 +125,10 @@ public class MainCLI extends CLI {
         createOptions();
     }
 
+    public File getNSSDatabase() {
+        return certDatabase;
+    }
+
     public String getFullModuleName(String moduleName) {
         return moduleName;
     }
@@ -158,7 +157,7 @@ public class MainCLI extends CLI {
         option.setArgName("uri");
         options.addOption(option);
 
-        option = new Option("P", true, "Protocol (default: http)");
+        option = new Option("P", true, "Protocol (default: https)");
         option.setArgName("protocol");
         options.addOption(option);
 
@@ -166,7 +165,7 @@ public class MainCLI extends CLI {
         option.setArgName("hostname");
         options.addOption(option);
 
-        option = new Option("p", true, "Port (default: 8080)");
+        option = new Option("p", true, "Port (default: 8443)");
         option.setArgName("port");
         options.addOption(option);
 
@@ -230,6 +229,7 @@ public class MainCLI extends CLI {
         options.addOption(option);
 
         options.addOption("v", "verbose", false, "Run in verbose mode.");
+        options.addOption(null, "debug", false, "Run in debug mode.");
         options.addOption(null, "help", false, "Show help message.");
         options.addOption(null, "version", false, "Show version number.");
     }
@@ -326,27 +326,33 @@ public class MainCLI extends CLI {
 
     public void parseOptions(CommandLine cmd) throws Exception {
 
-        verbose = cmd.hasOption("v");
+        if (cmd.hasOption("debug")) {
+            PKILogger.setLevel(PKILogger.Level.DEBUG);
+
+        } else if (cmd.hasOption("verbose")) {
+            PKILogger.setLevel(Level.INFO);
+        }
+
         output = cmd.getOptionValue("output");
 
         String url = cmd.getOptionValue("U");
 
-        String protocol = cmd.getOptionValue("P", "http");
+        String protocol = cmd.getOptionValue("P", "https");
         String hostname = cmd.getOptionValue("h", InetAddress.getLocalHost().getCanonicalHostName());
-        String port = cmd.getOptionValue("p", "8080");
+        String port = cmd.getOptionValue("p", "8443");
         String subsystem = cmd.getOptionValue("t");
 
         if (url == null)
             url = protocol + "://" + hostname + ":" + port;
 
         if (subsystem != null) {
-            System.err.println("WARNING: The -t option has been deprecated. Use pki " + subsystem + " command instead.");
+            logger.warn("The -t option has been deprecated. Use pki " + subsystem + " command instead.");
             url = url + "/" + subsystem;
         }
 
         config.setServerURL(url);
 
-        if (verbose) System.out.println("Server URL: " + url);
+        logger.info("Server URL: " + url);
 
         String nssDatabase = cmd.getOptionValue("d");
         String nssPassword = cmd.getOptionValue("c");
@@ -401,12 +407,12 @@ public class MainCLI extends CLI {
             config.setNSSPassword(nssPassword);
 
         } else if (nssPasswordFile != null) {
-            if (verbose) System.out.println("Loading NSS password from " + nssPasswordFile);
+            logger.info("Loading NSS password from " + nssPasswordFile);
             nssPassword = loadPassword(nssPasswordFile);
             config.setNSSPassword(nssPassword);
 
         } else if (nssPasswordConfig != null) {
-            if (verbose) System.out.println("Loading NSS password configuration from " + nssPasswordConfig);
+            logger.info("Loading NSS password configuration from " + nssPasswordConfig);
             Map<String, String> nssPasswords = loadPasswordConfig(nssPasswordConfig);
             config.setNSSPasswords(nssPasswords);
         }
@@ -415,7 +421,7 @@ public class MainCLI extends CLI {
         config.setUsername(username);
 
         if (passwordFile != null) {
-            if (verbose) System.out.println("Loading user password from " + passwordFile);
+            logger.info("Loading user password from " + passwordFile);
             password = loadPassword(passwordFile);
 
         } else if (username != null && password == null) {
@@ -435,11 +441,11 @@ public class MainCLI extends CLI {
         ignoreBanner = cmd.hasOption("ignore-banner");
 
         this.certDatabase = new File(config.getNSSDatabase());
-        if (verbose) System.out.println("NSS database: " + this.certDatabase.getAbsolutePath());
+        logger.info("NSS database: " + this.certDatabase.getAbsolutePath());
 
         String messageFormat = cmd.getOptionValue("message-format");
         config.setMessageFormat(messageFormat);
-        if (verbose) System.out.println("Message format: " + messageFormat);
+        logger.info("Message format: " + messageFormat);
     }
 
     public ClientConfig getConfig() {
@@ -465,28 +471,18 @@ public class MainCLI extends CLI {
 
     public void init() throws Exception {
 
-        // Create NSS database if it doesn't exist
-        if (!certDatabase.exists()) {
-
-            if (verbose) System.out.println("Creating NSS database");
-
-            certDatabase.mkdirs();
-
-            String[] commands = {
-                    "/usr/bin/certutil", "-N",
-                    "-d", certDatabase.getAbsolutePath(),
-                    "--empty-password"
-            };
-
-            try {
-                runExternal(commands);
-            } catch (Exception e) {
-                throw new Exception("Unable to create NSS database", e);
-            }
+        if (initialized) {
+            return;
         }
 
-        // Main program should initialize NSS
-        if (verbose) System.out.println("Initializing NSS");
+        NSSDatabase nssdb = new NSSDatabase(certDatabase);
+
+        if (!nssdb.exists()) {
+            // Create a default NSS database without password
+            nssdb.create();
+        }
+
+        logger.info("Initializing NSS");
         CryptoManager.initialize(certDatabase.getAbsolutePath());
 
         CryptoManager manager;
@@ -504,7 +500,7 @@ public class MainCLI extends CLI {
             String tokenName = config.getTokenName();
             tokenName = tokenName == null ? CryptoUtil.INTERNAL_TOKEN_NAME : tokenName;
 
-            if (verbose) System.out.println("Logging into " + tokenName + " token");
+            logger.info("Logging into " + tokenName + " token");
 
             CryptoToken token = CryptoUtil.getKeyStorageToken(tokenName);
             Password password = new Password(config.getNSSPassword().toCharArray());
@@ -526,7 +522,7 @@ public class MainCLI extends CLI {
 
             for (String tokenName : passwords.keySet()) {
 
-                if (verbose) System.out.println("Logging into " + tokenName + " token");
+                logger.info("Logging into " + tokenName + " token");
 
                 CryptoToken token = CryptoUtil.getKeyStorageToken(tokenName);
                 Password password = new Password(passwords.get(tokenName).toCharArray());
@@ -546,7 +542,7 @@ public class MainCLI extends CLI {
 
         String tokenName = config.getTokenName();
         tokenName = tokenName == null ? CryptoUtil.INTERNAL_TOKEN_NAME : tokenName;
-        if (verbose) System.out.println("Using " + tokenName + " token");
+        logger.info("Using " + tokenName + " token");
 
         CryptoToken token = CryptoUtil.getKeyStorageToken(tokenName);
         manager.setThreadToken(token);
@@ -580,19 +576,17 @@ public class MainCLI extends CLI {
 
         String ciphers = System.getenv("SSL_CIPHERS");
         CryptoUtil.setSSLCiphers(ciphers);
+
+        initialized = true;
     }
 
     public PKIClient getClient() throws Exception {
 
         if (client != null) return client;
 
-        if (verbose) {
-            System.out.println("Initializing PKIClient");
-        }
+        logger.info("Initializing PKIClient");
 
         client = new PKIClient(config, null);
-        client.setVerbose(verbose);
-
         client.setRejectedCertStatuses(rejectedCertStatuses);
         client.setIgnoredCertStatuses(ignoredCertStatuses);
 
@@ -648,20 +642,14 @@ public class MainCLI extends CLI {
 
         parseOptions(cmd);
 
-        if (verbose) {
-            System.out.print("Command:");
+        if (logger.isInfoEnabled()) {
+            StringBuilder sb = new StringBuilder("Command:");
             for (String arg : cmdArgs) {
-                if (arg.contains(" ")) arg = "\""+arg+"\"";
-                System.out.print(" "+arg);
+                if (arg.contains(" ")) arg = "\"" + arg + "\"";
+                sb.append(" ");
+                sb.append(arg);
             }
-            System.out.println();
-        }
-
-        // Do not call CryptoManager.initialize() on some commands
-        // because otherwise the database will be locked.
-        String command = cmdArgs[0];
-        if (!RESTRICTED_COMMANDS.contains(command)) {
-            init();
+            logger.info(sb.toString());
         }
 
         super.execute(cmdArgs);
@@ -675,14 +663,14 @@ public class MainCLI extends CLI {
 
     public static void handleException(Throwable t) {
 
-        if (verbose) {
+        if (logger.isInfoEnabled()) {
             t.printStackTrace(System.err);
 
         } else if (t.getClass() == Exception.class) {
             // display a generic error
-            System.err.println("Error: " + t.getMessage());
+            System.err.println("ERROR: " + t.getMessage());
 
-        } else if (t.getClass() == UnrecognizedOptionException.class) {
+        } else if (t instanceof UnrecognizedOptionException) {
             // display only the error message
             System.err.println(t.getMessage());
 
@@ -705,7 +693,7 @@ public class MainCLI extends CLI {
         } catch (CLIException e) {
             String message = e.getMessage();
             if (message != null) {
-                System.err.println(message);
+                System.err.println("ERROR: " + message);
             }
             System.exit(e.getCode());
 
