@@ -30,8 +30,12 @@ import com.netscape.certsrv.client.SubsystemClient;
  */
 public class SubsystemCLI extends CLI {
 
-    public SubsystemCLI(String name, String description, CLI parent) {
-        super(name, description, parent);
+    public MainCLI mainCLI;
+
+    public SubsystemCLI(String name, String description, MainCLI mainCLI) {
+        super(name, description, mainCLI);
+
+        this.mainCLI = mainCLI;
     }
 
     public String getFullName() {
@@ -60,6 +64,9 @@ public class SubsystemCLI extends CLI {
 
     public void execute(String[] args) throws Exception {
 
+        MainCLI mainCLI = (MainCLI) getRoot();
+        mainCLI.init();
+
         // login if username or nickname is specified
         ClientConfig config = getConfig();
         if (config.getUsername() != null || config.getCertNickname() != null) {
