@@ -18,10 +18,8 @@
 
 package com.netscape.cmstools.client;
 
-import java.util.Arrays;
-
 import org.apache.commons.cli.CommandLine;
-import org.dogtagpki.cli.CLI;
+import org.dogtagpki.cli.CommandCLI;
 import org.mozilla.jss.CryptoManager;
 import org.mozilla.jss.crypto.X509Certificate;
 
@@ -30,15 +28,15 @@ import com.netscape.cmstools.cli.MainCLI;
 /**
  * @author Endi S. Dewata
  */
-public class ClientCertFindCLI extends CLI {
+public class ClientCertFindCLI extends CommandCLI {
+
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(ClientCertFindCLI.class);
 
     public ClientCLI clientCLI;
 
     public ClientCertFindCLI(ClientCLI clientCLI) {
         super("cert-find", "Find certificates in NSS database", clientCLI);
         this.clientCLI = clientCLI;
-
-        createOptions();
     }
 
     public void printHelp() {
@@ -49,14 +47,7 @@ public class ClientCertFindCLI extends CLI {
         options.addOption(null, "ca", false, "Find CA certificates only");
     }
 
-    public void execute(String[] args) throws Exception {
-        // Always check for "--help" prior to parsing
-        if (Arrays.asList(args).contains("--help")) {
-            printHelp();
-            return;
-        }
-
-        CommandLine cmd = parser.parse(options, args);
+    public void execute(CommandLine cmd) throws Exception {
 
         String[] cmdArgs = cmd.getArgs();
 
@@ -64,6 +55,9 @@ public class ClientCertFindCLI extends CLI {
             throw new Exception("Too many arguments specified.");
         }
 
+        MainCLI mainCLI = (MainCLI) getRoot();
+        mainCLI.init();
+
         CryptoManager manager = CryptoManager.getInstance();
 
         X509Certificate[] certs;
