@@ -18,10 +18,8 @@
 
 package com.netscape.cmstools.group;
 
-import java.util.Arrays;
-
 import org.apache.commons.cli.CommandLine;
-import org.dogtagpki.cli.CLI;
+import org.dogtagpki.cli.CommandCLI;
 
 import com.netscape.certsrv.group.GroupClient;
 import com.netscape.certsrv.group.GroupMemberData;
@@ -30,7 +28,9 @@ import com.netscape.cmstools.cli.MainCLI;
 /**
  * @author Endi S. Dewata
  */
-public class GroupMemberAddCLI extends CLI {
+public class GroupMemberAddCLI extends CommandCLI {
+
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(GroupMemberAddCLI.class);
 
     public GroupMemberCLI groupMemberCLI;
 
@@ -43,14 +43,7 @@ public class GroupMemberAddCLI extends CLI {
         formatter.printHelp(getFullName() + " <Group ID> <Member ID> [OPTIONS...]", options);
     }
 
-    public void execute(String[] args) throws Exception {
-        // Always check for "--help" prior to parsing
-        if (Arrays.asList(args).contains("--help")) {
-            printHelp();
-            return;
-        }
-
-        CommandLine cmd = parser.parse(options, args);
+    public void execute(CommandLine cmd) throws Exception {
 
         String[] cmdArgs = cmd.getArgs();
 
@@ -61,6 +54,9 @@ public class GroupMemberAddCLI extends CLI {
         String groupID = cmdArgs[0];
         String memberID = cmdArgs[1];
 
+        MainCLI mainCLI = (MainCLI) getRoot();
+        mainCLI.init();
+
         GroupClient groupClient = groupMemberCLI.getGroupClient();
         GroupMemberData groupMemberData = groupClient.addGroupMember(groupID, memberID);
 
