@@ -18,11 +18,9 @@
 
 package com.netscape.cmstools.group;
 
-import java.util.Arrays;
-
 import org.apache.commons.cli.CommandLine;
 import org.apache.commons.cli.Option;
-import org.dogtagpki.cli.CLI;
+import org.dogtagpki.cli.CommandCLI;
 
 import com.netscape.certsrv.group.GroupClient;
 import com.netscape.certsrv.group.GroupData;
@@ -31,15 +29,15 @@ import com.netscape.cmstools.cli.MainCLI;
 /**
  * @author Endi S. Dewata
  */
-public class GroupModifyCLI extends CLI {
+public class GroupModifyCLI extends CommandCLI {
+
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(GroupModifyCLI.class);
 
     public GroupCLI groupCLI;
 
     public GroupModifyCLI(GroupCLI groupCLI) {
         super("mod", "Modify group", groupCLI);
         this.groupCLI = groupCLI;
-
-        createOptions();
     }
 
     public void printHelp() {
@@ -52,14 +50,7 @@ public class GroupModifyCLI extends CLI {
         options.addOption(option);
     }
 
-    public void execute(String[] args) throws Exception {
-        // Always check for "--help" prior to parsing
-        if (Arrays.asList(args).contains("--help")) {
-            printHelp();
-            return;
-        }
-
-        CommandLine cmd = parser.parse(options, args);
+    public void execute(CommandLine cmd) throws Exception {
 
         String[] cmdArgs = cmd.getArgs();
 
@@ -73,6 +64,9 @@ public class GroupModifyCLI extends CLI {
         groupData.setID(groupID);
         groupData.setDescription(cmd.getOptionValue("description"));
 
+        MainCLI mainCLI = (MainCLI) getRoot();
+        mainCLI.init();
+
         GroupClient groupClient = groupCLI.getGroupClient();
         groupData = groupClient.modifyGroup(groupID, groupData);
 
