@@ -1,34 +1,29 @@
 package com.netscape.cmstools.kra;
 
-import java.io.FileInputStream;
-import java.io.FileNotFoundException;
+import java.nio.charset.StandardCharsets;
 import java.nio.file.Files;
 import java.nio.file.Path;
 import java.nio.file.Paths;
-import java.util.Arrays;
-
-import javax.xml.bind.JAXBContext;
-import javax.xml.bind.JAXBException;
-import javax.xml.bind.Unmarshaller;
 
 import org.apache.commons.cli.CommandLine;
 import org.apache.commons.cli.Option;
-import org.dogtagpki.cli.CLI;
+import org.dogtagpki.cli.CommandCLI;
+import org.mozilla.jss.netscape.security.util.Utils;
 
 import com.netscape.certsrv.key.KeyArchivalRequest;
 import com.netscape.certsrv.key.KeyClient;
 import com.netscape.certsrv.key.KeyRequestResponse;
 import com.netscape.cmstools.cli.MainCLI;
-import org.mozilla.jss.netscape.security.util.Utils;
 
-public class KRAKeyArchiveCLI extends CLI {
+public class KRAKeyArchiveCLI extends CommandCLI {
+
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(KRAKeyArchiveCLI.class);
+
     public KRAKeyCLI keyCLI;
 
     public KRAKeyArchiveCLI(KRAKeyCLI keyCLI) {
         super("archive", "Archive a secret in the DRM.", keyCLI);
         this.keyCLI = keyCLI;
-
-        createOptions();
     }
 
     public void printHelp() {
@@ -48,6 +43,10 @@ public class KRAKeyArchiveCLI extends CLI {
         option.setArgName("Passphrase");
         options.addOption(option);
 
+        option = new Option(null, "input-format", true, "Input format: xml (default), json");
+        option.setArgName("format");
+        options.addOption(option);
+
         option = new Option(null, "input", true,
                 "Location of the request file.\nUsed for archiving already encrypted data.");
         option.setArgName("Input file path");
@@ -60,16 +59,13 @@ public class KRAKeyArchiveCLI extends CLI {
         option = new Option(null, "transport", true, "Transport certificate nickname.");
         option.setArgName("Nickname");
         options.addOption(option);
+
+        option = new Option(null, "output-format", true, "Output format: none (default), json");
+        option.setArgName("format");
+        options.addOption(option);
     }
 
-    public void execute(String[] args) throws Exception {
-        // Always check for "--help" prior to parsing
-        if (Arrays.asList(args).contains("--help")) {
-            printHelp();
-            return;
-        }
-
-        CommandLine cmd = parser.parse(options, args);
+    public void execute(CommandLine cmd) throws Exception {
 
         String[] cmdArgs = cmd.getArgs();
 
@@ -81,8 +77,13 @@ public class KRAKeyArchiveCLI extends CLI {
         String passphrase = cmd.getOptionValue("passphrase");
         String clientKeyId = cmd.getOptionValue("clientKeyID");
         String realm = cmd.getOptionValue("realm");
+        String inputFormat = cmd.getOptionValue("input-format", "xml");
         String requestFile = cmd.getOptionValue("input");
         String transportNickname = cmd.getOptionValue("transport");
+        String outputFormat = cmd.getOptionValue("output-format", "none");
+
+        MainCLI mainCLI = (MainCLI) getRoot();
+        mainCLI.init();
 
         KeyRequestResponse response = null;
         KeyClient keyClient = keyCLI.getKeyClient(transportNickname);
@@ -110,37 +111,57 @@ public class KRAKeyArchiveCLI extends CLI {
 
         } else if (requestFile != null) {
             // Case where the request file is used. For pre-encrypted data.
-            try {
-                JAXBContext context = JAXBContext.newInstance(KeyArchivalRequest.class);
-                Unmarshaller unmarshaller = context.createUnmarshaller();
-                FileInputStream fis = new FileInputStream(requestFile);
-                KeyArchivalRequest req = (KeyArchivalRequest) unmarshaller.unmarshal(fis);
+            KeyArchivalRequest req;
 
-                if (req.getPKIArchiveOptions() != null) {
-                    response = keyClient.archivePKIOptions(req.getClientKeyId(), req.getDataType(),
-                            req.getKeyAlgorithm(), req.getKeySize(), Utils.base64decode(req.getPKIArchiveOptions()),
-                            req.getRealm());
-                } else {
-                    response = keyClient.archiveEncryptedData(req.getClientKeyId(), req.getDataType(),
-                            req.getKeyAlgorithm(), req.getKeySize(), req.getAlgorithmOID(),
-                            Utils.base64decode(req.getSymmetricAlgorithmParams()),
-                            Utils.base64decode(req.getWrappedPrivateData()),
-                            Utils.base64decode(req.getTransWrappedSessionKey()),
-                            req.getRealm());
-                }
+            Path path = Paths.get(requestFile);
+            String input = new String(Files.readAllBytes(path), StandardCharsets.UTF_8);
 
-            } catch (JAXBException e) {
-                throw new Exception("Cannot parse the request file.", e);
+            if ("xml".equalsIgnoreCase(inputFormat)) {
+                req = KeyArchivalRequest.fromXML(input);
+                logger.info("Request: " + req.toXML());
 
-            } catch (FileNotFoundException e) {
-                throw new Exception("Cannot locate file at path: " + requestFile, e);
+            } else if ("json".equalsIgnoreCase(inputFormat)) {
+                req = KeyArchivalRequest.fromJSON(input);
+                logger.info("Request: " + req.toJSON());
+
+            } else {
+                throw new Exception("Unsupported input format: " + inputFormat);
+            }
+
+            if (req.getPKIArchiveOptions() != null) {
+                response = keyClient.archivePKIOptions(
+                        req.getClientKeyId(),
+                        req.getDataType(),
+                        req.getKeyAlgorithm(),
+                        req.getKeySize(),
+                        Utils.base64decode(req.getPKIArchiveOptions()),
+                        req.getRealm());
+            } else {
+                response = keyClient.archiveEncryptedData(
+                        req.getClientKeyId(),
+                        req.getDataType(),
+                        req.getKeyAlgorithm(),
+                        req.getKeySize(),
+                        req.getAlgorithmOID(),
+                        Utils.base64decode(req.getSymmetricAlgorithmParams()),
+                        Utils.base64decode(req.getWrappedPrivateData()),
+                        Utils.base64decode(req.getTransWrappedSessionKey()),
+                        req.getRealm());
             }
 
         } else {
             throw new Exception("Missing input data, passphrase, or request.");
         }
 
-        MainCLI.printMessage("Archival request details");
-        KRAKeyCLI.printKeyRequestInfo(response.getRequestInfo());
+        if (outputFormat.equalsIgnoreCase("json")) {
+            System.out.println(response.toJSON());
+
+        } else if (outputFormat.equalsIgnoreCase("none")) {
+            MainCLI.printMessage("Archival request details");
+            KRAKeyCLI.printKeyRequestInfo(response.getRequestInfo());
+
+        } else {
+            throw new Exception("Unsupported output format: " + outputFormat);
+        }
     }
 }
