@@ -18,12 +18,11 @@
 
 package com.netscape.cmstools.kra;
 
-import java.util.Arrays;
 import java.util.Collection;
 
 import org.apache.commons.cli.CommandLine;
 import org.apache.commons.cli.Option;
-import org.dogtagpki.cli.CLI;
+import org.dogtagpki.cli.CommandCLI;
 
 import com.netscape.certsrv.key.KeyClient;
 import com.netscape.certsrv.key.KeyInfo;
@@ -33,15 +32,15 @@ import com.netscape.cmstools.cli.MainCLI;
 /**
  * @author Endi S. Dewata
  */
-public class KRAKeyFindCLI extends CLI {
+public class KRAKeyFindCLI extends CommandCLI {
+
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(KRAKeyFindCLI.class);
 
     public KRAKeyCLI keyCLI;
 
     public KRAKeyFindCLI(KRAKeyCLI keyCLI) {
         super("find", "Find keys", keyCLI);
         this.keyCLI = keyCLI;
-
-        createOptions();
     }
 
     public void printHelp() {
@@ -53,7 +52,7 @@ public class KRAKeyFindCLI extends CLI {
         option.setArgName("client key ID");
         options.addOption(option);
 
-        option = new Option(null, "status", true, "Status");
+        option = new Option(null, "status", true, "Status: active, inactive");
         option.setArgName("status");
         options.addOption(option);
 
@@ -76,16 +75,13 @@ public class KRAKeyFindCLI extends CLI {
         option = new Option(null, "realm", true, "Realm");
         option.setArgName("realm");
         options.addOption(option);
+
+        option = new Option(null, "output-format", true, "Output format: text (default), json");
+        option.setArgName("format");
+        options.addOption(option);
     }
 
-    public void execute(String[] args) throws Exception {
-        // Always check for "--help" prior to parsing
-        if (Arrays.asList(args).contains("--help")) {
-            printHelp();
-            return;
-        }
-
-        CommandLine cmd = parser.parse(options, args);
+    public void execute(CommandLine cmd) throws Exception {
 
         String[] cmdArgs = cmd.getArgs();
 
@@ -96,6 +92,7 @@ public class KRAKeyFindCLI extends CLI {
         String clientKeyID = cmd.getOptionValue("clientKeyID");
         String status = cmd.getOptionValue("status");
         String realm = cmd.getOptionValue("realm");
+        String outputFormat = cmd.getOptionValue("output-format", "text");
 
         String s = cmd.getOptionValue("maxResults");
         Integer maxResults = s == null ? null : Integer.valueOf(s);
@@ -109,26 +106,37 @@ public class KRAKeyFindCLI extends CLI {
         s = cmd.getOptionValue("size");
         Integer size = s == null ? null : Integer.valueOf(s);
 
+        MainCLI mainCLI = (MainCLI) getRoot();
+        mainCLI.init();
+
         KeyClient keyClient = keyCLI.getKeyClient();
         KeyInfoCollection keys = keyClient.listKeys(clientKeyID, status, maxResults, maxTime, start, size, realm);
 
-        Collection<KeyInfo> entries = keys.getEntries();
+        if ("json".equalsIgnoreCase(outputFormat)) {
+            System.out.println(keys.toJSON());
 
-        MainCLI.printMessage(entries.size() + " key(s) matched");
+        } else if ("text".equalsIgnoreCase(outputFormat)) {
+            Collection<KeyInfo> entries = keys.getEntries();
 
-        boolean first = true;
+            MainCLI.printMessage(entries.size() + " key(s) matched");
 
-        for (KeyInfo info : entries) {
+            boolean first = true;
 
-            if (first) {
-                first = false;
-            } else {
-                System.out.println();
+            for (KeyInfo info : entries) {
+
+                if (first) {
+                    first = false;
+                } else {
+                    System.out.println();
+                }
+
+                KRAKeyCLI.printKeyInfo(info);
             }
 
-            KRAKeyCLI.printKeyInfo(info);
-        }
+            MainCLI.printMessage("Number of entries returned " + entries.size());
 
-        MainCLI.printMessage("Number of entries returned " + entries.size());
+        } else {
+            throw new Exception("Unsupported format: " + outputFormat);
+        }
     }
 }
