@@ -5,21 +5,22 @@ import java.util.List;
 
 import org.apache.commons.cli.CommandLine;
 import org.apache.commons.cli.Option;
-import org.dogtagpki.cli.CLI;
+import org.dogtagpki.cli.CommandCLI;
 
 import com.netscape.certsrv.key.KeyClient;
 import com.netscape.certsrv.key.KeyRequestResource;
 import com.netscape.certsrv.key.KeyRequestResponse;
 import com.netscape.cmstools.cli.MainCLI;
 
-public class KRAKeyGenerateCLI extends CLI {
+public class KRAKeyGenerateCLI extends CommandCLI {
+
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(KRAKeyGenerateCLI.class);
+
     public KRAKeyCLI keyCLI;
 
     public KRAKeyGenerateCLI(KRAKeyCLI keyCLI) {
         super("generate", "Generate key", keyCLI);
         this.keyCLI = keyCLI;
-
-        createOptions();
     }
 
     public void printHelp() {
@@ -30,7 +31,6 @@ public class KRAKeyGenerateCLI extends CLI {
         Option option = new Option(null, "key-algorithm", true,
                 "Algorithm to be used to create a key.\nValid values: AES, DES, DES3, RC2, RC4, DESede, RSA, DSA");
         option.setArgName("algorithm");
-        option.setRequired(true);
         options.addOption(option);
 
         option = new Option(
@@ -58,14 +58,7 @@ public class KRAKeyGenerateCLI extends CLI {
         options.addOption(option);
     }
 
-    public void execute(String[] args) throws Exception {
-        // Always check for "--help" prior to parsing
-        if (Arrays.asList(args).contains("--help")) {
-            printHelp();
-            return;
-        }
-
-        CommandLine cmd = parser.parse(options, args);
+    public void execute(CommandLine cmd) throws Exception {
 
         String[] cmdArgs = cmd.getArgs();
 
@@ -78,6 +71,10 @@ public class KRAKeyGenerateCLI extends CLI {
         String keySize = cmd.getOptionValue("key-size");
         String realm = cmd.getOptionValue("realm");
 
+        if (keyAlgorithm == null) {
+            throw new Exception("Missing key algorithm");
+        }
+
         if (keySize == null) {
             switch (keyAlgorithm) {
             case KeyRequestResource.DES3_ALGORITHM:
@@ -104,12 +101,16 @@ public class KRAKeyGenerateCLI extends CLI {
         } catch (NumberFormatException e) {
             throw new Exception("Key size must be an integer.", e);
         }
+
         List<String> usages = null;
         String givenUsages = cmd.getOptionValue("usages");
         if (givenUsages != null) {
             usages = Arrays.asList(givenUsages.split(","));
         }
 
+        MainCLI mainCLI = (MainCLI) getRoot();
+        mainCLI.init();
+
         KeyClient keyClient = keyCLI.getKeyClient();
 
         KeyRequestResponse response = null;
@@ -131,6 +132,7 @@ public class KRAKeyGenerateCLI extends CLI {
         default:
             throw new Exception("Algorithm not supported.");
         }
+
         MainCLI.printMessage("Key generation request info");
         KRAKeyCLI.printKeyRequestInfo(response.getRequestInfo());
     }
