@@ -1,24 +1,23 @@
 package com.netscape.cmstools.kra;
 
-import java.util.Arrays;
-
 import org.apache.commons.cli.CommandLine;
 import org.apache.commons.cli.Option;
-import org.dogtagpki.cli.CLI;
+import org.dogtagpki.cli.CommandCLI;
 
 import com.netscape.certsrv.key.KeyClient;
 import com.netscape.certsrv.key.KeyRequestInfo;
 import com.netscape.certsrv.request.RequestId;
 import com.netscape.cmstools.cli.MainCLI;
 
-public class KRAKeyRequestReviewCLI extends CLI {
+public class KRAKeyRequestReviewCLI extends CommandCLI {
+
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(KRAKeyRequestReviewCLI.class);
+
     public KRAKeyCLI keyCLI;
 
     public KRAKeyRequestReviewCLI(KRAKeyCLI keyCLI) {
         super("request-review", "Review key request", keyCLI);
         this.keyCLI = keyCLI;
-
-        createOptions();
     }
 
     public void printHelp() {
@@ -29,18 +28,10 @@ public class KRAKeyRequestReviewCLI extends CLI {
         Option option = new Option(null, "action", true,
                 "Action to be performed on the request.\nValid values: approve, reject, cancel.");
         option.setArgName("Action to perform");
-        option.setRequired(true);
         options.addOption(option);
     }
 
-    public void execute(String[] args) throws Exception {
-        // Always check for "--help" prior to parsing
-        if (Arrays.asList(args).contains("--help")) {
-            printHelp();
-            return;
-        }
-
-        CommandLine cmd = parser.parse(options, args);
+    public void execute(CommandLine cmd) throws Exception {
 
         String[] cmdArgs = cmd.getArgs();
 
@@ -49,9 +40,18 @@ public class KRAKeyRequestReviewCLI extends CLI {
         }
 
         RequestId reqId = new RequestId(cmdArgs[0]);
+
+        MainCLI mainCLI = (MainCLI) getRoot();
+        mainCLI.init();
+
         KeyClient keyClient = keyCLI.getKeyClient();
 
         String action = cmd.getOptionValue("action");
+
+        if (action == null) {
+            throw new Exception("Missing action");
+        }
+
         switch (action.toLowerCase()) {
         case "approve":
             keyClient.approveRequest(reqId);
