@@ -24,16 +24,21 @@ import org.jboss.resteasy.plugins.providers.atom.Link;
 import com.netscape.certsrv.client.PKIClient;
 import com.netscape.certsrv.logging.ActivityClient;
 import com.netscape.certsrv.logging.ActivityData;
+import com.netscape.cmstools.tps.TPSCLI;
 
 /**
  * @author Endi S. Dewata
  */
 public class ActivityCLI extends CLI {
 
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(ActivityCLI.class);
+
+    public TPSCLI tpsCLI;
     public ActivityClient activityClient;
 
-    public ActivityCLI(CLI parent) {
-        super("activity", "Activity management commands", parent);
+    public ActivityCLI(TPSCLI tpsCLI) {
+        super("activity", "Activity management commands", tpsCLI);
+        this.tpsCLI = tpsCLI;
 
         addModule(new ActivityFindCLI(this));
         addModule(new ActivityShowCLI(this));
@@ -63,8 +68,6 @@ public class ActivityCLI extends CLI {
         }
 
         Link link = activity.getLink();
-        if (verbose && link != null) {
-            System.out.println("  Link: " + link.getHref());
-        }
+        logger.info("Link: " + (link == null ? null : link.getHref()));
     }
 }
