@@ -22,49 +22,30 @@ import java.security.KeyStore;
 import java.security.cert.Certificate;
 
 import org.apache.commons.cli.CommandLine;
-import org.dogtagpki.cli.CLI;
-import org.dogtagpki.util.logging.PKILogger;
+import org.dogtagpki.cli.CommandCLI;
 import org.mozilla.jss.crypto.CryptoToken;
 import org.mozilla.jss.provider.java.security.JSSLoadStoreParameter;
 
+import com.netscape.cmstools.cli.MainCLI;
 import com.netscape.cmsutil.crypto.CryptoUtil;
 
 /**
  * @author Endi S. Dewata
  */
-public class PKCS11CertRemoveCLI extends CLI {
+public class PKCS11CertRemoveCLI extends CommandCLI {
 
-    public PKCS11CertRemoveCLI(PKCS11CertCLI parent) {
-        super("del", "Remove PKCS #11 certificate", parent);
+    public PKCS11CertCLI certCLI;
 
-        createOptions();
+    public PKCS11CertRemoveCLI(PKCS11CertCLI certCLI) {
+        super("del", "Remove PKCS #11 certificate", certCLI);
+        this.certCLI = certCLI;
     }
 
     public void printHelp() {
         formatter.printHelp(getFullName() + " [OPTIONS...] <Cert ID>", options);
     }
 
-    public void createOptions() {
-        options.addOption("v", "verbose", false, "Run in verbose mode.");
-        options.addOption(null, "debug", false, "Run in debug mode.");
-        options.addOption(null, "help", false, "Show help message.");
-    }
-
-    public void execute(String[] args) throws Exception {
-
-        CommandLine cmd = parser.parse(options, args);
-
-        if (cmd.hasOption("help")) {
-            printHelp();
-            return;
-        }
-
-        if (cmd.hasOption("verbose")) {
-            PKILogger.setLevel(PKILogger.Level.INFO);
-
-        } else if (cmd.hasOption("debug")) {
-            PKILogger.setLevel(PKILogger.Level.DEBUG);
-        }
+    public void execute(CommandLine cmd) throws Exception {
 
         String[] cmdArgs = cmd.getArgs();
 
@@ -74,6 +55,9 @@ public class PKCS11CertRemoveCLI extends CLI {
 
         String alias = cmdArgs[0];
 
+        MainCLI mainCLI = (MainCLI) getRoot();
+        mainCLI.init();
+
         String tokenName = getConfig().getTokenName();
         CryptoToken token = CryptoUtil.getKeyStorageToken(tokenName);
 
