@@ -23,49 +23,33 @@ import java.security.KeyStore;
 import java.util.Enumeration;
 
 import org.apache.commons.cli.CommandLine;
-import org.dogtagpki.cli.CLI;
-import org.dogtagpki.util.logging.PKILogger;
+import org.dogtagpki.cli.CommandCLI;
 import org.mozilla.jss.crypto.CryptoToken;
 import org.mozilla.jss.provider.java.security.JSSLoadStoreParameter;
 
+import com.netscape.cmstools.cli.MainCLI;
 import com.netscape.cmsutil.crypto.CryptoUtil;
 
 /**
  * @author Endi S. Dewata
  */
-public class PKCS11KeyFindCLI extends CLI {
+public class PKCS11KeyFindCLI extends CommandCLI {
 
-    public PKCS11KeyFindCLI(PKCS11KeyCLI parent) {
-        super("find", "Find PKCS #11 keys", parent);
+    public PKCS11KeyCLI keyCLI;
 
-        createOptions();
+    public PKCS11KeyFindCLI(PKCS11KeyCLI keyCLI) {
+        super("find", "Find PKCS #11 keys", keyCLI);
+        this.keyCLI = keyCLI;
     }
 
     public void printHelp() {
         formatter.printHelp(getFullName() + " [OPTIONS...]", options);
     }
 
-    public void createOptions() {
-        options.addOption("v", "verbose", false, "Run in verbose mode.");
-        options.addOption(null, "debug", false, "Run in debug mode.");
-        options.addOption(null, "help", false, "Show help message.");
-    }
+    public void execute(CommandLine cmd) throws Exception {
 
-    public void execute(String[] args) throws Exception {
-
-        CommandLine cmd = parser.parse(options, args);
-
-        if (cmd.hasOption("help")) {
-            printHelp();
-            return;
-        }
-
-        if (cmd.hasOption("verbose")) {
-            PKILogger.setLevel(PKILogger.Level.INFO);
-
-        } else if (cmd.hasOption("debug")) {
-            PKILogger.setLevel(PKILogger.Level.DEBUG);
-        }
+        MainCLI mainCLI = (MainCLI) getRoot();
+        mainCLI.init();
 
         String tokenName = getConfig().getTokenName();
         CryptoToken token = CryptoUtil.getKeyStorageToken(tokenName);
