@@ -27,8 +27,11 @@ import com.netscape.cmstools.cli.MainCLI;
  */
 public class PKCS12CLI extends CLI {
 
-    public PKCS12CLI(CLI parent) {
-        super("pkcs12", "PKCS #12 utilities", parent);
+    public MainCLI mainCLI;
+
+    public PKCS12CLI(MainCLI mainCLI) {
+        super("pkcs12", "PKCS #12 utilities", mainCLI);
+        this.mainCLI = mainCLI;
 
         addModule(new PKCS12CertCLI(this));
         addModule(new PKCS12ExportCLI(this));
