@@ -24,26 +24,25 @@ import java.io.FileReader;
 
 import org.apache.commons.cli.CommandLine;
 import org.apache.commons.cli.Option;
-import org.dogtagpki.cli.CLI;
-import org.dogtagpki.util.logging.PKILogger;
+import org.dogtagpki.cli.CommandCLI;
+import org.mozilla.jss.netscape.security.pkcs.PKCS12;
+import org.mozilla.jss.netscape.security.pkcs.PKCS12Util;
 import org.mozilla.jss.util.Password;
 
 import com.netscape.cmstools.cli.MainCLI;
 
-import org.mozilla.jss.netscape.security.pkcs.PKCS12;
-import org.mozilla.jss.netscape.security.pkcs.PKCS12Util;
-
 /**
  * @author Endi S. Dewata
  * @deprecated Replaced by PKCS12CertImportCLI.
  */
 @Deprecated
-public class PKCS12CertAddCLI extends CLI {
+public class PKCS12CertAddCLI extends CommandCLI {
+
+    public PKCS12CertCLI certCLI;
 
     public PKCS12CertAddCLI(PKCS12CertCLI certCLI) {
         super("add", "Add certificate into PKCS #12 file", certCLI);
-
-        createOptions();
+        this.certCLI = certCLI;
     }
 
     public void printHelp() {
@@ -67,30 +66,12 @@ public class PKCS12CertAddCLI extends CLI {
         options.addOption(null, "no-trust-flags", false, "Do not include trust flags");
         options.addOption(null, "no-key", false, "Do not include private key");
         options.addOption(null, "no-chain", false, "Do not include certificate chain");
-
-        options.addOption("v", "verbose", false, "Run in verbose mode.");
-        options.addOption(null, "debug", false, "Run in debug mode.");
-        options.addOption(null, "help", false, "Show help message.");
     }
 
-    public void execute(String[] args) throws Exception {
+    public void execute(CommandLine cmd) throws Exception {
 
         System.err.println("WARNING: pki pkcs12-cert-add has been deprecated. Use pki pkcs12-cert-import instead.");
 
-        CommandLine cmd = parser.parse(options, args);
-
-        if (cmd.hasOption("help")) {
-            printHelp();
-            return;
-        }
-
-        if (cmd.hasOption("verbose")) {
-            PKILogger.setLevel(PKILogger.Level.INFO);
-
-        } else if (cmd.hasOption("debug")) {
-            PKILogger.setLevel(PKILogger.Level.DEBUG);
-        }
-
         String[] cmdArgs = cmd.getArgs();
 
         if (cmdArgs.length == 0) {
@@ -121,13 +102,16 @@ public class PKCS12CertAddCLI extends CLI {
             throw new Exception("Missing PKCS #12 password.");
         }
 
-        Password password = new Password(passwordString.toCharArray());
-
         boolean newFile = cmd.hasOption("new-file");
         boolean includeTrustFlags = !cmd.hasOption("no-trust-flags");
         boolean includeKey = !cmd.hasOption("no-key");
         boolean includeChain = !cmd.hasOption("no-chain");
 
+        MainCLI mainCLI = (MainCLI) getRoot();
+        mainCLI.init();
+
+        Password password = new Password(passwordString.toCharArray());
+
         try {
             PKCS12Util util = new PKCS12Util();
             util.setTrustFlagsEnabled(includeTrustFlags);
