@@ -24,24 +24,23 @@ import java.io.FileReader;
 import org.apache.commons.cli.CommandLine;
 import org.apache.commons.cli.Option;
 import org.apache.commons.codec.binary.Hex;
-import org.dogtagpki.cli.CLI;
-import org.dogtagpki.util.logging.PKILogger;
+import org.dogtagpki.cli.CommandCLI;
+import org.mozilla.jss.netscape.security.pkcs.PKCS12;
+import org.mozilla.jss.netscape.security.pkcs.PKCS12Util;
 import org.mozilla.jss.util.Password;
 
 import com.netscape.cmstools.cli.MainCLI;
 
-import org.mozilla.jss.netscape.security.pkcs.PKCS12;
-import org.mozilla.jss.netscape.security.pkcs.PKCS12Util;
-
 /**
  * @author Endi S. Dewata
  */
-public class PKCS12KeyRemoveCLI extends CLI {
+public class PKCS12KeyRemoveCLI extends CommandCLI {
 
-    public PKCS12KeyRemoveCLI(PKCS12KeyCLI certCLI) {
-        super("del", "Remove key from PKCS #12 file", certCLI);
+    public PKCS12KeyCLI keyCLI;
 
-        createOptions();
+    public PKCS12KeyRemoveCLI(PKCS12KeyCLI keyCLI) {
+        super("del", "Remove key from PKCS #12 file", keyCLI);
+        this.keyCLI = keyCLI;
     }
 
     public void printHelp() {
@@ -60,27 +59,9 @@ public class PKCS12KeyRemoveCLI extends CLI {
         option = new Option(null, "pkcs12-password-file", true, "PKCS #12 password file");
         option.setArgName("path");
         options.addOption(option);
-
-        options.addOption("v", "verbose", false, "Run in verbose mode.");
-        options.addOption(null, "debug", false, "Run in debug mode.");
-        options.addOption(null, "help", false, "Show help message.");
     }
 
-    public void execute(String[] args) throws Exception {
-
-        CommandLine cmd = parser.parse(options, args);
-
-        if (cmd.hasOption("help")) {
-            printHelp();
-            return;
-        }
-
-        if (cmd.hasOption("verbose")) {
-            PKILogger.setLevel(PKILogger.Level.INFO);
-
-        } else if (cmd.hasOption("debug")) {
-            PKILogger.setLevel(PKILogger.Level.DEBUG);
-        }
+    public void execute(CommandLine cmd) throws Exception {
 
         String[] cmdArgs = cmd.getArgs();
 
@@ -112,6 +93,9 @@ public class PKCS12KeyRemoveCLI extends CLI {
             throw new Exception("Missing PKCS #12 password.");
         }
 
+        MainCLI mainCLI = (MainCLI) getRoot();
+        mainCLI.init();
+
         Password password = new Password(passwordString.toCharArray());
 
         try {
