@@ -18,11 +18,9 @@
 
 package com.netscape.cmstools.selftests;
 
-import java.util.Arrays;
-
 import org.apache.commons.cli.CommandLine;
 import org.apache.commons.lang.StringUtils;
-import org.dogtagpki.cli.CLI;
+import org.dogtagpki.cli.CommandCLI;
 
 import com.netscape.certsrv.selftests.SelfTestClient;
 import com.netscape.certsrv.selftests.SelfTestResult;
@@ -32,7 +30,9 @@ import com.netscape.cmstools.cli.MainCLI;
 /**
  * @author Endi S. Dewata
  */
-public class SelfTestRunCLI extends CLI {
+public class SelfTestRunCLI extends CommandCLI {
+
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(SelfTestRunCLI.class);
 
     public SelfTestCLI selfTestCLI;
 
@@ -58,17 +58,13 @@ public class SelfTestRunCLI extends CLI {
         }
     }
 
-    public void execute(String[] args) throws Exception {
-        // Always check for "--help" prior to parsing
-        if (Arrays.asList(args).contains("--help")) {
-            printHelp();
-            return;
-        }
-
-        CommandLine cmd = parser.parse(options, args);
+    public void execute(CommandLine cmd) throws Exception {
 
         String[] cmdArgs = cmd.getArgs();
 
+        MainCLI mainCLI = (MainCLI) getRoot();
+        mainCLI.init();
+
         SelfTestClient selfTestClient = selfTestCLI.getSelfTestClient();
         SelfTestResults results;
 
