@@ -33,10 +33,12 @@ import com.netscape.cmstools.cli.SubsystemCLI;
  */
 public class SecurityDomainCLI extends CLI {
 
+    public MainCLI mainCLI;
     public SecurityDomainClient securityDomainClient;
 
-    public SecurityDomainCLI(CLI parent) {
-        super("securitydomain", "Security domain commands", parent);
+    public SecurityDomainCLI(MainCLI mainCLI) {
+        super("securitydomain", "Security domain commands", mainCLI);
+        this.mainCLI = mainCLI;
 
         addModule(new SecurityDomainShowCLI(this));
     }
@@ -80,9 +82,9 @@ public class SecurityDomainCLI extends CLI {
         System.out.println("  Domain: " + domain.getName());
         System.out.println();
 
-        for (SecurityDomainSubsystem subsystem : domain.getSubsystems()) {
+        for (SecurityDomainSubsystem subsystem : domain.getSubsystemArray()) {
 
-            SecurityDomainHost[] hosts = subsystem.getHosts();
+            SecurityDomainHost[] hosts = subsystem.getHostArray();
             if (hosts.length == 0) continue;
 
             System.out.println("  " + subsystem.getName() + " Subsystem:");
