@@ -24,16 +24,21 @@ import org.jboss.resteasy.plugins.providers.atom.Link;
 import com.netscape.certsrv.client.PKIClient;
 import com.netscape.certsrv.tps.cert.TPSCertClient;
 import com.netscape.certsrv.tps.cert.TPSCertData;
+import com.netscape.cmstools.tps.TPSCLI;
 
 /**
  * @author Endi S. Dewata
  */
 public class TPSCertCLI extends CLI {
 
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(TPSCertCLI.class);
+
+    public TPSCLI tpsCLI;
     public TPSCertClient certClient;
 
-    public TPSCertCLI(CLI parent) {
-        super("cert", "Certificate management commands", parent);
+    public TPSCertCLI(TPSCLI tpsCLI) {
+        super("cert", "Certificate management commands", tpsCLI);
+        this.tpsCLI = tpsCLI;
 
         addModule(new TPSCertFindCLI(this));
         addModule(new TPSCertShowCLI(this));
@@ -63,8 +68,6 @@ public class TPSCertCLI extends CLI {
         if (cert.getModifyTime() != null) System.out.println("  Modify Time: " + cert.getModifyTime());
 
         Link link = cert.getLink();
-        if (verbose && link != null) {
-            System.out.println("  Link: " + link.getHref());
-        }
+        logger.info("Link: " + (link == null ? null : link.getHref()));
     }
 }
