@@ -27,16 +27,21 @@ import org.jboss.resteasy.plugins.providers.atom.Link;
 import com.netscape.certsrv.client.PKIClient;
 import com.netscape.certsrv.tps.config.ConfigClient;
 import com.netscape.certsrv.tps.config.ConfigData;
+import com.netscape.cmstools.tps.TPSCLI;
 
 /**
  * @author Endi S. Dewata
  */
 public class ConfigCLI extends CLI {
 
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(ConfigCLI.class);
+
+    public TPSCLI tpsCLI;
     public ConfigClient configClient;
 
-    public ConfigCLI(CLI parent) {
-        super("config", "Configuration management commands", parent);
+    public ConfigCLI(TPSCLI tpsCLI) {
+        super("config", "Configuration management commands", tpsCLI);
+        this.tpsCLI = tpsCLI;
 
         addModule(new ConfigModifyCLI(this));
         addModule(new ConfigShowCLI(this));
@@ -66,8 +71,6 @@ public class ConfigCLI extends CLI {
         }
 
         Link link = configData.getLink();
-        if (verbose && link != null) {
-            System.out.println("  Link: " + link.getHref());
-        }
+        logger.info("Link: " + (link == null ? null : link.getHref()));
     }
 }
