@@ -22,11 +22,10 @@ import java.io.BufferedReader;
 import java.io.FileReader;
 import java.io.PrintWriter;
 import java.io.StringWriter;
-import java.util.Arrays;
 
 import org.apache.commons.cli.CommandLine;
 import org.apache.commons.cli.Option;
-import org.dogtagpki.cli.CLI;
+import org.dogtagpki.cli.CommandCLI;
 
 import com.netscape.certsrv.tps.connector.ConnectorClient;
 import com.netscape.certsrv.tps.connector.ConnectorData;
@@ -35,15 +34,15 @@ import com.netscape.cmstools.cli.MainCLI;
 /**
  * @author Endi S. Dewata
  */
-public class ConnectorAddCLI extends CLI {
+public class ConnectorAddCLI extends CommandCLI {
+
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(ConnectorAddCLI.class);
 
     public ConnectorCLI connectorCLI;
 
     public ConnectorAddCLI(ConnectorCLI connectorCLI) {
         super("add", "Add connector", connectorCLI);
         this.connectorCLI = connectorCLI;
-
-        createOptions();
     }
 
     public void printHelp() {
@@ -53,18 +52,10 @@ public class ConnectorAddCLI extends CLI {
     public void createOptions() {
         Option option = new Option(null, "input", true, "Input file containing connector properties.");
         option.setArgName("file");
-        option.setRequired(true);
         options.addOption(option);
     }
 
-    public void execute(String[] args) throws Exception {
-        // Always check for "--help" prior to parsing
-        if (Arrays.asList(args).contains("--help")) {
-            printHelp();
-            return;
-        }
-
-        CommandLine cmd = parser.parse(options, args);
+    public void execute(CommandLine cmd) throws Exception {
 
         String[] cmdArgs = cmd.getArgs();
 
@@ -74,6 +65,10 @@ public class ConnectorAddCLI extends CLI {
 
         String input = cmd.getOptionValue("input");
 
+        if (input == null) {
+            throw new Exception("Missing input file");
+        }
+
         ConnectorData connectorData;
 
         try (BufferedReader in = new BufferedReader(new FileReader(input));
@@ -88,6 +83,9 @@ public class ConnectorAddCLI extends CLI {
             connectorData = ConnectorData.valueOf(sw.toString());
         }
 
+        MainCLI mainCLI = (MainCLI) getRoot();
+        mainCLI.init();
+
         ConnectorClient connectorClient = connectorCLI.getConnectorClient();
         connectorData = connectorClient.addConnector(connectorData);
 
