@@ -18,12 +18,11 @@
 
 package com.netscape.cmstools.tps.profile;
 
-import java.util.Arrays;
 import java.util.Collection;
 
 import org.apache.commons.cli.CommandLine;
 import org.apache.commons.cli.Option;
-import org.dogtagpki.cli.CLI;
+import org.dogtagpki.cli.CommandCLI;
 
 import com.netscape.certsrv.tps.profile.ProfileMappingClient;
 import com.netscape.certsrv.tps.profile.ProfileMappingCollection;
@@ -33,15 +32,15 @@ import com.netscape.cmstools.cli.MainCLI;
 /**
  * @author Endi S. Dewata
  */
-public class ProfileMappingFindCLI extends CLI {
+public class ProfileMappingFindCLI extends CommandCLI {
+
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(ProfileMappingFindCLI.class);
 
     public ProfileMappingCLI profileMappingCLI;
 
     public ProfileMappingFindCLI(ProfileMappingCLI profileMappingCLI) {
         super("find", "Find profile mappings", profileMappingCLI);
         this.profileMappingCLI = profileMappingCLI;
-
-        createOptions();
     }
 
     public void printHelp() {
@@ -58,14 +57,7 @@ public class ProfileMappingFindCLI extends CLI {
         options.addOption(option);
     }
 
-    public void execute(String[] args) throws Exception {
-        // Always check for "--help" prior to parsing
-        if (Arrays.asList(args).contains("--help")) {
-            printHelp();
-            return;
-        }
-
-        CommandLine cmd = parser.parse(options, args);
+    public void execute(CommandLine cmd) throws Exception {
 
         String[] cmdArgs = cmd.getArgs();
         String filter = cmdArgs.length > 0 ? cmdArgs[0] : null;
