@@ -20,11 +20,10 @@ package com.netscape.cmstools.user;
 
 import java.nio.file.Files;
 import java.nio.file.Paths;
-import java.util.Arrays;
 
 import org.apache.commons.cli.CommandLine;
 import org.apache.commons.cli.Option;
-import org.dogtagpki.cli.CLI;
+import org.dogtagpki.cli.CommandCLI;
 
 import com.netscape.certsrv.ca.CACertClient;
 import com.netscape.certsrv.ca.CAClient;
@@ -37,15 +36,15 @@ import com.netscape.cmstools.cli.MainCLI;
 /**
  * @author Endi S. Dewata
  */
-public class UserCertAddCLI extends CLI {
+public class UserCertAddCLI extends CommandCLI {
+
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(UserCertAddCLI.class);
 
     public UserCertCLI userCertCLI;
 
     public UserCertAddCLI(UserCertCLI userCertCLI) {
         super("add", "Add user certificate", userCertCLI);
         this.userCertCLI = userCertCLI;
-
-        createOptions();
     }
 
     public void printHelp() {
@@ -62,14 +61,7 @@ public class UserCertAddCLI extends CLI {
         options.addOption(option);
     }
 
-    public void execute(String[] args) throws Exception {
-        // Always check for "--help" prior to parsing
-        if (Arrays.asList(args).contains("--help")) {
-            printHelp();
-            return;
-        }
-
-        CommandLine cmd = parser.parse(options, args);
+    public void execute(CommandLine cmd) throws Exception {
 
         String[] cmdArgs = cmd.getArgs();
 
@@ -81,31 +73,29 @@ public class UserCertAddCLI extends CLI {
         String inputFile = cmd.getOptionValue("input");
         String serialNumber = cmd.getOptionValue("serial");
 
+        MainCLI mainCLI = (MainCLI) getRoot();
+        mainCLI.init();
+
         String encoded;
 
         if (inputFile != null && serialNumber != null) {
             throw new Exception("Conflicting options: --input and --serial.");
 
         } else if (inputFile != null) {
-            if (verbose) {
-                System.out.println("Reading certificate from " + inputFile + ".");
-            }
+            logger.info("Reading certificate from " + inputFile);
 
             encoded = new String(Files.readAllBytes(Paths.get(inputFile)));
-            if (verbose) {
-                System.out.println(encoded);
-            }
+            logger.info("Certificate:\n" + encoded);
 
         } else if (serialNumber != null) {
-            if (verbose) {
-                System.out.println("Downloading certificate " + serialNumber + ".");
-            }
+            logger.info("Downloading certificate " + serialNumber);
 
             CAClient caClient = MainCLI.createCAClient(parent.getClient());
             CACertClient certClient = new CACertClient(caClient);
 
             CertData certData = certClient.getCert(new CertId(serialNumber));
             encoded = certData.getEncoded();
+            logger.info("Certificate:\n" + encoded);
 
         } else {
             throw new Exception("Missing input file or serial number.");
@@ -114,9 +104,7 @@ public class UserCertAddCLI extends CLI {
         UserCertData userCertData = new UserCertData();
         userCertData.setEncoded(encoded);
 
-        if (verbose) {
-            System.out.println(userCertData);
-        }
+        logger.info("Request:\n" + userCertData);
 
         UserClient userClient = userCertCLI.getUserClient();
         userCertData = userClient.addUserCert(userID, userCertData);
