@@ -29,6 +29,8 @@ import com.netscape.certsrv.user.UserClient;
  */
 public class UserCertCLI extends CLI {
 
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(UserCertCLI.class);
+
     UserCLI parent;
 
     public UserCertCLI(UserCLI parent) {
@@ -63,9 +65,7 @@ public class UserCertCLI extends CLI {
         System.out.println("  Subject: " + userCertData.getSubjectDN());
 
         Link link = userCertData.getLink();
-        if (verbose && link != null) {
-            System.out.println("  Link: " + link.getHref());
-        }
+        logger.info("Link: " + (link == null ? null : link.getHref()));
 
         String prettyPrint = userCertData.getPrettyPrint();
         if (showPrettyPrint && prettyPrint != null) {
