@@ -18,10 +18,8 @@
 
 package com.netscape.cmstools.user;
 
-import java.util.Arrays;
-
 import org.apache.commons.cli.CommandLine;
-import org.dogtagpki.cli.CLI;
+import org.dogtagpki.cli.CommandCLI;
 
 import com.netscape.certsrv.user.UserClient;
 import com.netscape.cmstools.cli.MainCLI;
@@ -29,7 +27,9 @@ import com.netscape.cmstools.cli.MainCLI;
 /**
  * @author Endi S. Dewata
  */
-public class UserMembershipRemoveCLI extends CLI {
+public class UserMembershipRemoveCLI extends CommandCLI {
+
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(UserMembershipRemoveCLI.class);
 
     public UserMembershipCLI userMembershipCLI;
 
@@ -42,14 +42,7 @@ public class UserMembershipRemoveCLI extends CLI {
         formatter.printHelp(getFullName() + " <User ID> <Group ID> [OPTIONS...]", options);
     }
 
-    public void execute(String[] args) throws Exception {
-        // Always check for "--help" prior to parsing
-        if (Arrays.asList(args).contains("--help")) {
-            printHelp();
-            return;
-        }
-
-        CommandLine cmd = parser.parse(options, args);
+    public void execute(CommandLine cmd) throws Exception {
 
         String[] cmdArgs = cmd.getArgs();
 
@@ -57,8 +50,11 @@ public class UserMembershipRemoveCLI extends CLI {
             throw new Exception("Incorrect number of arguments specified.");
         }
 
-        String userID = args[0];
-        String groupID = args[1];
+        String userID = cmdArgs[0];
+        String groupID = cmdArgs[1];
+
+        MainCLI mainCLI = (MainCLI) getRoot();
+        mainCLI.init();
 
         UserClient userClient = userMembershipCLI.getUserClient();
         userClient.removeUserMembership(userID, groupID);
