@@ -18,10 +18,8 @@
 
 package com.netscape.cmstools.user;
 
-import java.util.Arrays;
-
 import org.apache.commons.cli.CommandLine;
-import org.dogtagpki.cli.CLI;
+import org.dogtagpki.cli.CommandCLI;
 
 import com.netscape.certsrv.user.UserClient;
 import com.netscape.certsrv.user.UserData;
@@ -30,7 +28,9 @@ import com.netscape.cmstools.cli.MainCLI;
 /**
  * @author Endi S. Dewata
  */
-public class UserShowCLI extends CLI {
+public class UserShowCLI extends CommandCLI {
+
+    public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(UserShowCLI.class);
 
     public UserCLI userCLI;
 
@@ -43,14 +43,7 @@ public class UserShowCLI extends CLI {
         formatter.printHelp(getFullName() + " <User ID> [OPTIONS...]", options);
     }
 
-    public void execute(String[] args) throws Exception {
-        // Always check for "--help" prior to parsing
-        if (Arrays.asList(args).contains("--help")) {
-            printHelp();
-            return;
-        }
-
-        CommandLine cmd = parser.parse(options, args);
+    public void execute(CommandLine cmd) throws Exception {
 
         String[] cmdArgs = cmd.getArgs();
 
@@ -58,7 +51,10 @@ public class UserShowCLI extends CLI {
             throw new Exception("No User ID specified.");
         }
 
-        String userId = args[0];
+        String userId = cmdArgs[0];
+
+        MainCLI mainCLI = (MainCLI) getRoot();
+        mainCLI.init();
 
         UserClient userClient = userCLI.getUserClient();
         UserData userData = userClient.getUser(userId);
