@@ -26,6 +26,7 @@ import java.security.cert.CertificateException;
 import java.util.Arrays;
 import java.util.Vector;
 
+import org.dogtagpki.server.authentication.AuthToken;
 import org.dogtagpki.server.kra.ProofOfArchival;
 import org.mozilla.jss.asn1.ASN1Util;
 import org.mozilla.jss.asn1.ASN1Value;
@@ -48,9 +49,7 @@ import org.mozilla.jss.pkix.crmf.CertRequest;
 import org.mozilla.jss.pkix.crmf.PKIArchiveOptions;
 import org.mozilla.jss.pkix.primitive.AVA;
 
-import com.netscape.certsrv.authentication.AuthToken;
 import com.netscape.certsrv.base.EBaseException;
-import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.base.MetaInfo;
 import com.netscape.certsrv.base.SessionContext;
 import com.netscape.certsrv.dbs.keydb.IKeyRecord;
@@ -61,7 +60,6 @@ import com.netscape.certsrv.kra.IKeyRecoveryAuthority;
 import com.netscape.certsrv.logging.AuditFormat;
 import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.logging.event.SecurityDataArchivalProcessedEvent;
-import com.netscape.certsrv.profile.IEnrollProfile;
 import com.netscape.certsrv.request.IRequest;
 import com.netscape.certsrv.request.IService;
 import com.netscape.certsrv.request.RequestId;
@@ -73,6 +71,7 @@ import com.netscape.cms.logging.SignedAuditLogger;
 import com.netscape.cms.servlet.key.KeyRecordParser;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.apps.CMSEngine;
+import com.netscape.cmscore.apps.EngineConfig;
 import com.netscape.cmscore.crmf.CRMFParser;
 import com.netscape.cmscore.crmf.PKIArchiveOptionsContainer;
 import com.netscape.cmscore.dbs.KeyRecord;
@@ -146,11 +145,13 @@ public class EnrollmentService implements IService {
             throws EBaseException {
 
         CMSEngine engine = CMS.getCMSEngine();
-        IConfigStore config = null;
+        JssSubsystem jssSubsystem = engine.getJSSSubsystem();
+
+        EngineConfig config = null;
         Boolean allowEncDecrypt_archival = false;
 
         try {
-            config = engine.getConfigStore();
+            config = engine.getConfig();
             allowEncDecrypt_archival = config.getBoolean("kra.allowEncDecrypt.archival", false);
         } catch (Exception e) {
             throw new EBaseException(CMS.getUserMessage("CMS_BASE_CERT_ERROR", e.toString()));
@@ -172,11 +173,11 @@ public class EnrollmentService implements IService {
         // updateRequest() to delay actual write to ldap
         request.setExtData("delayLDAPCommit", "true");
 
-        String transportCert = request.getExtDataInString(IEnrollProfile.REQUEST_TRANSPORT_CERT);
+        String transportCert = request.getExtDataInString(IRequest.REQUEST_TRANSPORT_CERT);
         if (transportCert != null && transportCert.length() > 0) {
             //logger.debug("EnrollmentService: serviceRequest: transportCert=" + transportCert);
             logger.debug("EnrollmentService: serviceRequest: transportCert is in request");
-            request.deleteExtData(IEnrollProfile.REQUEST_TRANSPORT_CERT);
+            request.deleteExtData(IRequest.REQUEST_TRANSPORT_CERT);
         } else {
             logger.warn("EnrollmentService: serviceRequest: Missing transport certificate");
         }
@@ -188,7 +189,8 @@ public class EnrollmentService implements IService {
         String agentId = (String) sContext.get(SessionContext.USER_ID);
         AuthToken authToken = (AuthToken) sContext.get(SessionContext.AUTH_TOKEN);
 
-        mKRA.log(ILogger.LL_INFO, "KRA services enrollment request");
+        logger.info("KRA services enrollment request");
+
         // unwrap user key with transport
         byte unwrapped[] = null;
         byte tmp_unwrapped[] = null;
@@ -219,7 +221,7 @@ public class EnrollmentService implements IService {
         } else {
             // profile-based request
             PKIArchiveOptions options = toPKIArchiveOptions(
-            request.getExtDataInByteArray(IEnrollProfile.REQUEST_ARCHIVE_OPTIONS));
+            request.getExtDataInByteArray(IRequest.REQUEST_ARCHIVE_OPTIONS));
 
             aOpts = new PKIArchiveOptionsContainer[1];
             aOpts[0] = new PKIArchiveOptionsContainer(options,
@@ -239,7 +241,8 @@ public class EnrollmentService implements IService {
                 if (statsSub != null) {
                     statsSub.startTiming("decrypt_user_key");
                 }
-                mKRA.log(ILogger.LL_INFO, "KRA decrypts external private");
+
+                logger.info("KRA decrypts external private");
                 logger.debug("EnrollmentService::about to decryptExternalPrivate");
 
                 try {
@@ -250,7 +253,7 @@ public class EnrollmentService implements IService {
                             opts.getEncValue(),
                             tCert);
                 } catch (Exception e) {
-                    mKRA.log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_KRA_UNWRAP_USER_KEY"));
+                    logger.error(CMS.getLogMessage("CMSCORE_KRA_UNWRAP_USER_KEY"), e);
 
                     signedAuditLogger.log(SecurityDataArchivalProcessedEvent.createFailureEvent(
                             auditSubjectID,
@@ -277,7 +280,6 @@ public class EnrollmentService implements IService {
                 }
 
                 unwrapped = Arrays.copyOfRange(tmp_unwrapped, first, tmp_unwrapped.length);
-                JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                 jssSubsystem.obscureBytes(tmp_unwrapped);
             } /*else {  allowEncDecrypt_archival != true
                  this is done below with unwrap()
@@ -290,7 +292,7 @@ public class EnrollmentService implements IService {
 
             if (publicKeyData == null) {
                 String message = CMS.getLogMessage("CMSCORE_KRA_PUBLIC_NOT_FOUND");
-                mKRA.log(ILogger.LL_FAILURE, message);
+                logger.error(message);
 
                 signedAuditLogger.log(SecurityDataArchivalProcessedEvent.createFailureEvent(
                         auditSubjectID,
@@ -332,8 +334,7 @@ public class EnrollmentService implements IService {
                             pubkey,
                             tCert);
                 } catch (Exception e) {
-                    mKRA.log(ILogger.LL_DEBUG, e.getMessage());
-                    mKRA.log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_KRA_WRAP_USER_KEY"));
+                    logger.error(CMS.getLogMessage("CMSCORE_KRA_WRAP_USER_KEY"), e);
 
                     signedAuditLogger.log(SecurityDataArchivalProcessedEvent.createFailureEvent(
                             auditSubjectID,
@@ -362,9 +363,7 @@ public class EnrollmentService implements IService {
                 } catch (Exception e) {
                     logger.error("EnrollmentService: " + e.getMessage(), e);
 
-                    JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                     jssSubsystem.obscureBytes(unwrapped);
-                    mKRA.log(ILogger.LL_FAILURE, e.toString());
 
                     signedAuditLogger.log(SecurityDataArchivalProcessedEvent.createFailureEvent(
                         auditSubjectID,
@@ -392,7 +391,7 @@ public class EnrollmentService implements IService {
 
             if (owner == null) {
                 String message = CMS.getLogMessage("CMSCORE_KRA_OWNER_NAME_NOT_FOUND");
-                mKRA.log(ILogger.LL_FAILURE, message);
+                logger.error(message);
 
                 signedAuditLogger.log(SecurityDataArchivalProcessedEvent.createFailureEvent(
                         auditSubjectID,
@@ -413,7 +412,7 @@ public class EnrollmentService implements IService {
             //                       encKey OCTET_STRING,
             //                    }
             //
-            mKRA.log(ILogger.LL_INFO, "KRA encrypts internal private");
+            logger.info("KRA encrypts internal private");
             if (statsSub != null) {
                 statsSub.startTiming("encrypt_user_key");
             }
@@ -429,8 +428,7 @@ public class EnrollmentService implements IService {
                 }
 
             } catch (Exception e) {
-                mKRA.log(ILogger.LL_DEBUG, e.getMessage());
-                mKRA.log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_KRA_WRAP_USER_KEY"));
+                logger.error(CMS.getLogMessage("CMSCORE_KRA_WRAP_USER_KEY"), e);
 
                 signedAuditLogger.log(SecurityDataArchivalProcessedEvent.createFailureEvent(
                         auditSubjectID,
@@ -446,7 +444,6 @@ public class EnrollmentService implements IService {
                         CMS.getUserMessage("CMS_KRA_INVALID_PRIVATE_KEY") + ": " + e, e);
 
             } finally {
-                JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                 jssSubsystem.obscureBytes(unwrapped);
             }
 
@@ -515,7 +512,7 @@ public class EnrollmentService implements IService {
             // if record already has a serial number, yell out.
             if (rec.getSerialNumber() != null) {
                 String message = CMS.getLogMessage("CMSCORE_KRA_INVALID_SERIAL_NUMBER", rec.getSerialNumber().toString());
-                mKRA.log(ILogger.LL_FAILURE, message);
+                logger.error(message);
 
                 signedAuditLogger.log(SecurityDataArchivalProcessedEvent.createFailureEvent(
                         auditSubjectID,
@@ -539,7 +536,7 @@ public class EnrollmentService implements IService {
             try {
                 rec.setWrappingParams(params, allowEncDecrypt_archival);
             } catch (Exception e) {
-                mKRA.log(ILogger.LL_FAILURE, "Failed to store wrapping parameters");
+                logger.error("Failed to store wrapping parameters", e);
                 // TODO(alee) Set correct audit message here
                 signedAuditLogger.log(SecurityDataArchivalProcessedEvent.createFailureEvent(
                         auditSubjectID,
@@ -559,7 +556,7 @@ public class EnrollmentService implements IService {
 
             if (serialNo == null) {
                 String message = CMS.getLogMessage("CMSCORE_KRA_GET_NEXT_SERIAL");
-                mKRA.log(ILogger.LL_FAILURE, message);
+                logger.error(message);
 
                 signedAuditLogger.log(SecurityDataArchivalProcessedEvent.createFailureEvent(
                         auditSubjectID,
@@ -581,7 +578,8 @@ public class EnrollmentService implements IService {
                 request.setExtData(ATTR_KEY_RECORD + i, serialNo);
             }
 
-            mKRA.log(ILogger.LL_INFO, "KRA adding key record " + serialNo);
+            logger.info("KRA adding key record " + serialNo);
+
             if (statsSub != null) {
                 statsSub.startTiming("store_key");
             }
@@ -593,7 +591,7 @@ public class EnrollmentService implements IService {
             logger.debug("EnrollmentService: key record 0x" + serialNo.toString(16)
                         + " (" + owner + ") archived");
 
-            mKRA.log(ILogger.LL_INFO, "key record 0x" +
+            logger.info("key record 0x" +
                     serialNo.toString(16)
                     + " (" + owner + ") archived");
 
@@ -653,21 +651,21 @@ public class EnrollmentService implements IService {
         request.setExtData(IRequest.RESULT, IRequest.RES_SUCCESS);
 
         /* zero out the fields */
-        request.setExtData(IEnrollProfile.CTX_CERT_REQUEST, "");
-        request.setExtData(IEnrollProfile.REQUEST_ARCHIVE_OPTIONS, "");
+        request.setExtData(IRequest.CTX_CERT_REQUEST, "");
+        request.setExtData(IRequest.REQUEST_ARCHIVE_OPTIONS, "");
         request.setExtData(ATTR_PROOF_OF_ARCHIVAL, "");
-        request.setExtData(IEnrollProfile.REQUEST_KEY, "");
+        request.setExtData(IRequest.REQUEST_KEY, "");
         /* delete the fields */
-        request.deleteExtData(IEnrollProfile.CTX_CERT_REQUEST);
-        request.deleteExtData(IEnrollProfile.REQUEST_ARCHIVE_OPTIONS);
+        request.deleteExtData(IRequest.CTX_CERT_REQUEST);
+        request.deleteExtData(IRequest.REQUEST_ARCHIVE_OPTIONS);
         request.deleteExtData(ATTR_PROOF_OF_ARCHIVAL);
-        request.deleteExtData(IEnrollProfile.REQUEST_KEY);
+        request.deleteExtData(IRequest.REQUEST_KEY);
 
         // now that fields are cleared, we can really write to ldap
         request.setExtData("delayLDAPCommit", "false");
 
         // update request
-        mKRA.log(ILogger.LL_INFO, "KRA updating request");
+        logger.info("KRA updating request");
         mKRA.getRequestQueue().updateRequest(request);
 
         if (statsSub != null) {
@@ -813,7 +811,7 @@ public class EnrollmentService implements IService {
         String profileId = request.getExtDataInString(IRequest.PROFILE_ID);
 
         if (profileId != null && !profileId.equals("")) {
-            byte[] certKeyData = request.getExtDataInByteArray(IEnrollProfile.REQUEST_KEY);
+            byte[] certKeyData = request.getExtDataInByteArray(IRequest.REQUEST_KEY);
             if (certKeyData != null) {
                 try {
                     CertificateX509Key x509key = new CertificateX509Key(
@@ -835,31 +833,34 @@ public class EnrollmentService implements IService {
         if (certInfo == null) {
             throw new EBaseException(CMS.getLogMessage("CMS_BASE_CERT_NOT_FOUND"));
         }
+
         try {
             pX509Key = (CertificateX509Key)
                     certInfo[i].get(X509CertInfo.KEY);
+
         } catch (IOException e) {
-            mKRA.log(ILogger.LL_FAILURE,
-                    CMS.getLogMessage("CMSCORE_KRA_GET_PUBLIC_KEY", e.toString()));
+            logger.error(CMS.getLogMessage("CMSCORE_KRA_GET_PUBLIC_KEY", e.toString()), e);
             throw new EBaseException(CMS.getUserMessage("CMS_BASE_INVALID_ATTRIBUTE",
-                    "[" + X509CertInfo.KEY + "]" + e.toString()));
+                    "[" + X509CertInfo.KEY + "]" + e.toString()), e);
+
         } catch (CertificateException e) {
-            mKRA.log(ILogger.LL_FAILURE,
-                    CMS.getLogMessage("CMSCORE_KRA_GET_PUBLIC_KEY", e.toString()));
+            logger.error(CMS.getLogMessage("CMSCORE_KRA_GET_PUBLIC_KEY", e.toString()), e);
             throw new EBaseException(CMS.getUserMessage("CMS_BASE_INVALID_ATTRIBUTE",
-                    "[" + X509CertInfo.KEY + "]" + e.toString()));
+                    "[" + X509CertInfo.KEY + "]" + e.toString()), e);
         }
+
         X509Key pKey = null;
 
         try {
             pKey = (X509Key) pX509Key.get(
                         CertificateX509Key.KEY);
+
         } catch (IOException e) {
-            mKRA.log(ILogger.LL_FAILURE,
-                    CMS.getLogMessage("CMSCORE_KRA_GET_PUBLIC_KEY", e.toString()));
+            logger.error(CMS.getLogMessage("CMSCORE_KRA_GET_PUBLIC_KEY", e.toString()), e);
             throw new EBaseException(CMS.getUserMessage("CMS_BASE_INVALID_ATTRIBUTE", "["
-                    + CertificateX509Key.KEY + "]" + e.toString()));
+                    + CertificateX509Key.KEY + "]" + e.toString()), e);
         }
+
         return pKey;
     }
 
@@ -877,7 +878,7 @@ public class EnrollmentService implements IService {
 
         if (profileId != null && !profileId.equals("")) {
             CertificateSubjectName sub = request.getExtDataInCertSubjectName(
-                    IEnrollProfile.REQUEST_SUBJECT_NAME);
+                    IRequest.REQUEST_SUBJECT_NAME);
             if (sub != null) {
                 return sub.toString();
             }
@@ -893,17 +894,18 @@ public class EnrollmentService implements IService {
         try {
             pSub = (CertificateSubjectName)
                     certInfo[0].get(X509CertInfo.SUBJECT);
+
         } catch (IOException e) {
-            mKRA.log(ILogger.LL_FAILURE,
-                    CMS.getLogMessage("CMSCORE_KRA_GET_OWNER_NAME", e.toString()));
+            logger.error(CMS.getLogMessage("CMSCORE_KRA_GET_OWNER_NAME", e.toString()), e);
             throw new EBaseException(CMS.getUserMessage("CMS_BASE_INVALID_ATTRIBUTE", "["
-                    + X509CertInfo.SUBJECT + "]" + e.toString()));
+                    + X509CertInfo.SUBJECT + "]" + e.toString()), e);
+
         } catch (CertificateException e) {
-            mKRA.log(ILogger.LL_FAILURE,
-                    CMS.getLogMessage("CMSCORE_KRA_GET_OWNER_NAME", e.toString()));
+            logger.error(CMS.getLogMessage("CMSCORE_KRA_GET_OWNER_NAME", e.toString()), e);
             throw new EBaseException(CMS.getUserMessage("CMS_BASE_INVALID_ATTRIBUTE", "["
-                    + X509CertInfo.SUBJECT + "]" + e.toString()));
+                    + X509CertInfo.SUBJECT + "]" + e.toString()), e);
         }
+
         String owner = pSub.toString();
 
         return owner;
