@@ -34,6 +34,9 @@ import java.util.Vector;
 
 import org.dogtagpki.legacy.kra.KRAPolicy;
 import org.dogtagpki.legacy.policy.IPolicyProcessor;
+import org.dogtagpki.server.kra.KRAConfig;
+import org.dogtagpki.server.kra.KRAEngine;
+import org.dogtagpki.server.kra.KRAEngineConfig;
 import org.mozilla.jss.NoSuchTokenException;
 import org.mozilla.jss.crypto.CryptoToken;
 import org.mozilla.jss.crypto.KeyPairAlgorithm;
@@ -52,9 +55,7 @@ import com.netscape.certsrv.authority.IAuthority;
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.EPropertyNotFound;
 import com.netscape.certsrv.base.IConfigStore;
-import com.netscape.certsrv.base.ISubsystem;
 import com.netscape.certsrv.base.SessionContext;
-import com.netscape.certsrv.dbs.IDBSubsystem;
 import com.netscape.certsrv.dbs.keydb.IKeyRepository;
 import com.netscape.certsrv.dbs.keydb.KeyId;
 import com.netscape.certsrv.dbs.replicadb.IReplicaIDRepository;
@@ -67,7 +68,6 @@ import com.netscape.certsrv.logging.event.SecurityDataArchivalProcessedEvent;
 import com.netscape.certsrv.logging.event.SecurityDataArchivalRequestEvent;
 import com.netscape.certsrv.logging.event.SecurityDataRecoveryEvent;
 import com.netscape.certsrv.logging.event.SecurityDataRecoveryProcessedEvent;
-import com.netscape.certsrv.request.ARequestNotifier;
 import com.netscape.certsrv.request.IPolicy;
 import com.netscape.certsrv.request.IRequest;
 import com.netscape.certsrv.request.IRequestListener;
@@ -84,10 +84,13 @@ import com.netscape.cms.logging.Logger;
 import com.netscape.cms.logging.SignedAuditLogger;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.apps.CMSEngine;
+import com.netscape.cmscore.apps.EngineConfig;
 import com.netscape.cmscore.dbs.DBSubsystem;
+import com.netscape.cmscore.dbs.IDBSubsystem;
 import com.netscape.cmscore.dbs.KeyRecord;
 import com.netscape.cmscore.dbs.KeyRepository;
 import com.netscape.cmscore.dbs.ReplicaIDRepository;
+import com.netscape.cmscore.request.ARequestNotifier;
 import com.netscape.cmscore.request.RequestSubsystem;
 import com.netscape.cmscore.usrgrp.UGSubsystem;
 import com.netscape.cmsutil.crypto.CryptoUtil;
@@ -105,7 +108,6 @@ import com.netscape.cmsutil.crypto.CryptoUtil;
 public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecoveryAuthority {
 
     public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(KeyRecoveryAuthority.class);
-    private static Logger systemLogger = Logger.getLogger(ILogger.EV_SYSTEM, ILogger.S_KRA);
     private static Logger signedAuditLogger = SignedAuditLogger.getLogger();
 
     public final static String OFFICIAL_NAME = "Data Recovery Manager";
@@ -123,7 +125,7 @@ public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecove
     private static final String PROP_REPLICAID_DN = "dbs.replicadn";
 
     protected boolean mInitialized = false;
-    protected IConfigStore mConfig = null;
+    protected KRAConfig mConfig;
     protected KRAPolicy mPolicy = null;
     protected X500Name mName = null;
     protected boolean mQueueRequests = false;
@@ -137,7 +139,6 @@ public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecove
     protected ReplicaIDRepository mReplicaRepot = null;
     protected IRequestNotifier mNotify = null;
     protected IRequestNotifier mPNotify = null;
-    protected ISubsystem mOwner = null;
     protected int mRecoveryIDCounter = 0;
     protected Hashtable<String, Hashtable<String, Object>> mRecoveryParams =
             new Hashtable<String, Hashtable<String, Object>>();
@@ -203,11 +204,9 @@ public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecove
         }
         logger.debug("KeyRecoveryAuthority Entropy bits = " + mEntropyBitsPerKeyPair);
         if (mEntropyBitsPerKeyPair == 0) {
-            //log(ILogger.LL_INFO,
-            //CMS.getLogMessage("CMSCORE_KRA_ENTROPY_COLLECTION_DISABLED"));
+            //logger.info(CMS.getLogMessage("CMSCORE_KRA_ENTROPY_COLLECTION_DISABLED"));
         } else {
-            //log(ILogger.LL_INFO,
-            //CMS.getLogMessage("CMSCORE_KRA_ENTROPY_COLLECTION_ENABLED"));
+            //logger.info(CMS.getLogMessage("CMSCORE_KRA_ENTROPY_COLLECTION_ENABLED"));
             logger.debug("KeyRecoveryAuthority about to add Entropy");
             addEntropy(false);
             logger.debug("KeyRecoveryAuthority back from add Entropy");
@@ -228,8 +227,7 @@ public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecove
         } catch (Exception e) {
             logger.warn("KeyRecoveryAuthority: " + e.getMessage(), e);
             if (logflag) {
-                log(ILogger.LL_INFO,
-                        CMS.getLogMessage("CMSCORE_KRA_ENTROPY_ERROR",
+                logger.warn(CMS.getLogMessage("CMSCORE_KRA_ENTROPY_ERROR",
                                 e.getMessage()));
             }
         }
@@ -242,8 +240,7 @@ public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecove
             logger.debug("KeyRecoveryAuthority returning - warning - entropy took too long (ms=" +
                     duration + ")");
             if (logflag) {
-                log(ILogger.LL_INFO,
-                        CMS.getLogMessage("CMSCORE_KRA_ENTROPY_BLOCKED_WARNING",
+                logger.warn(CMS.getLogMessage("CMSCORE_KRA_ENTROPY_BLOCKED_WARNING",
                                 "" + (int) duration));
             }
         }
@@ -255,20 +252,22 @@ public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecove
      * necessary components. This subsystem is started by
      * KRASubsystem.
      * <P>
-     *
-     * @param owner owner of this subsystem
      * @param config configuration store for this subsystem
+     *
      * @exception EBaseException failed to start subsystem
      */
-    public void init(ISubsystem owner, IConfigStore config)
+    public void init(IConfigStore config)
             throws EBaseException {
+
         logger.debug("KeyRecoveryAuthority init() begins");
+
         if (mInitialized)
             return;
 
-        CMSEngine engine = CMS.getCMSEngine();
-        mConfig = config;
-        mOwner = owner;
+        KRAEngine engine = KRAEngine.getInstance();
+        KRAEngineConfig engineConfig = engine.getConfig();
+
+        mConfig = engineConfig.getKRAConfig();
 
         // initialize policy processor
         mPolicy = new KRAPolicy();
@@ -286,7 +285,7 @@ public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecove
         // read transport key from internal database
         mTransportKeyUnit = new TransportKeyUnit();
         try {
-            mTransportKeyUnit.init(this, mConfig.getSubStore(
+            mTransportKeyUnit.init(mConfig.getSubStore(
                     PROP_TRANSPORT_KEY));
         } catch (EBaseException e) {
             logger.warn("KeyRecoveryAuthority: transport unit exception " + e.getMessage(), e);
@@ -314,8 +313,9 @@ public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecove
         // read transport key from storage key
         mStorageKeyUnit = new StorageKeyUnit();
         try {
-            mStorageKeyUnit.init(this,
-                    mConfig.getSubStore(PROP_STORAGE_KEY));
+            mStorageKeyUnit.init(
+                    mConfig.getSubStore(PROP_STORAGE_KEY),
+                    mConfig.getBoolean("keySplitting", false));
         } catch (EBaseException e) {
             logger.error("KeyRecoveryAuthority: storage unit exception " + e.getMessage(), e);
             throw e;
@@ -356,7 +356,7 @@ public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecove
         initEntropy(mConfig);
         logger.debug("KeyRecoveryAuthority: completed init of entropy");
 
-        systemLogger.log(ILogger.LL_INFO, mName.toString() + " is started");
+        logger.info(mName.toString() + " is started");
 
         // setup the KRA request queue
         IService service = new KRAService(this);
@@ -464,7 +464,7 @@ public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecove
             mKeyDB.shutdown();
         }
 
-        systemLogger.log(ILogger.LL_INFO, mName.toString() + " is stopped");
+        logger.info(mName + " is stopped");
 
         mInitialized = false;
     }
@@ -475,7 +475,7 @@ public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecove
      *
      * @return configuration store
      */
-    public IConfigStore getConfigStore() {
+    public KRAConfig getConfigStore() {
         return mConfig;
     }
 
@@ -687,7 +687,7 @@ public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecove
         // see if we have the uid already
         if (!mConfig.getBoolean("keySplitting")) {
             // check if the uid is in the specified group
-            UGSubsystem ug = (UGSubsystem) engine.getSubsystem(UGSubsystem.ID);
+            UGSubsystem ug = engine.getUGSubsystem();
             if (!ug.isMemberOf(uid, mConfig.getString("recoveryAgentGroup"))) {
                 // invalid group
                 throw new EBaseException(CMS.getUserMessage("CMS_KRA_CREDENTIALS_NOT_EXIST"));
@@ -914,7 +914,7 @@ public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecove
         IRequest r = null;
 
         // check if the uid is in the specified group
-        UGSubsystem ug = (UGSubsystem) engine.getSubsystem(UGSubsystem.ID);
+        UGSubsystem ug = engine.getUGSubsystem();
         if (!ug.isMemberOf(agentID, mConfig.getString("recoveryAgentGroup"))) {
             // invalid group
             throw new EBaseException(CMS.getUserMessage("CMS_KRA_CREDENTIALS_NOT_EXIST"));
@@ -1263,8 +1263,7 @@ public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecove
             r.setExtData(RecoveryService.ATTR_ENCRYPTION_CERTS,
                     certChainOut.toByteArray());
         } catch (IOException e) {
-            log(ILogger.LL_FAILURE,
-                    "Error encoding certificate chain");
+            logger.warn("Error encoding certificate chain", e);
         }
 
         r.setExtData(RecoveryService.ATTR_SIGNING_CERT, signingCert);
@@ -1276,8 +1275,7 @@ public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecove
             r.setExtData(RecoveryService.ATTR_OWNER_NAME,
                     ownerNameOut.toByteArray());
         } catch (IOException e) {
-            log(ILogger.LL_FAILURE,
-                    "Error encoding X500Name for owner name");
+            logger.warn("Error encoding X500Name for owner name", e);
         }
 
         queue.processRequest(r);
@@ -1404,7 +1402,6 @@ public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecove
      * @param msg message to log
      */
     public void log(int level, String msg) {
-        systemLogger.log(level, msg);
     }
 
     /**
@@ -1441,22 +1438,20 @@ public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecove
                     mReqInQListener = (IRequestListener) Class.forName(requestInQListenerClassName).newInstance();
                     mReqInQListener.init(this, nc);
                 } catch (Exception e1) {
-                    log(ILogger.LL_FAILURE,
-                            CMS.getLogMessage("CMSCORE_KRA_REGISTER_LISTENER", requestInQListenerClassName));
+                    logger.warn(CMS.getLogMessage("CMSCORE_KRA_REGISTER_LISTENER", requestInQListenerClassName), e1);
                 }
             } else {
-                log(ILogger.LL_INFO,
-                        "No KRA notification Module configuration found");
+                logger.warn("No KRA notification Module configuration found");
             }
+
         } catch (EPropertyNotFound e) {
-            log(ILogger.LL_FAILURE,
-                    CMS.getLogMessage("CMSCORE_KRA_NOTIFY_ERROR", e.toString()));
+            logger.warn(CMS.getLogMessage("CMSCORE_KRA_NOTIFY_ERROR", e.toString()), e);
+
         } catch (EListenersException e) {
-            log(ILogger.LL_FAILURE,
-                    CMS.getLogMessage("CMSCORE_KRA_NOTIFY_ERROR", e.toString()));
+            logger.warn(CMS.getLogMessage("CMSCORE_KRA_NOTIFY_ERROR", e.toString()), e);
+
         } catch (EBaseException e) {
-            log(ILogger.LL_FAILURE,
-                    CMS.getLogMessage("CMSCORE_KRA_NOTIFY_ERROR", e.toString()));
+            logger.warn(CMS.getLogMessage("CMSCORE_KRA_NOTIFY_ERROR", e.toString()), e);
         }
     }
 
@@ -1474,15 +1469,13 @@ public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecove
             if (raname != null) {
                 radn = new X500Name(raname);
             }
+
         } catch (IOException e) {
-            mLogger.log(ILogger.EV_SYSTEM, ILogger.S_KRA,
-                ILogger.LL_FAILURE,
-                CMS.getLogMessage("CMSCORE_KRA_INVALID_RA_NAME", raname, e.toString()));
+            logger.warn(CMS.getLogMessage("CMSCORE_KRA_INVALID_RA_NAME", raname, e.toString()), e);
+
         } catch (EBaseException e) {
             // ignore - set to null.
-            mLogger.log(ILogger.EV_SYSTEM, ILogger.S_KRA,
-                ILogger.LL_FAILURE,
-                CMS.getLogMessage("CMSCORE_KRA_INVALID_RA_SETUP", e.toString()));
+            logger.warn(CMS.getLogMessage("CMSCORE_KRA_INVALID_RA_SETUP", e.toString()), e);
         }
         return new X500Name[] { radn };
     }
@@ -1770,7 +1763,7 @@ public class KeyRecoveryAuthority implements IAuthority, IKeyService, IKeyRecove
               extractable == true
         */
         KeyPairGenerator kpGen = token.getKeyPairGenerator(kpAlg);
-        IConfigStore config = engine.getConfigStore();
+        EngineConfig config = engine.getConfig();
         IConfigStore kgConfig = config.getSubStore("kra.keygen");
         boolean tp = false;
         boolean sp = false;
