@@ -28,6 +28,7 @@ import java.security.cert.CertificateEncodingException;
 import java.security.cert.X509Certificate;
 import java.util.Hashtable;
 
+import org.dogtagpki.server.authentication.AuthToken;
 import org.mozilla.jss.CryptoManager;
 import org.mozilla.jss.asn1.ANY;
 import org.mozilla.jss.asn1.ASN1Util;
@@ -52,24 +53,22 @@ import org.mozilla.jss.pkcs12.PasswordConverter;
 import org.mozilla.jss.pkcs12.SafeBag;
 import org.mozilla.jss.pkix.primitive.EncryptedPrivateKeyInfo;
 import org.mozilla.jss.pkix.primitive.PrivateKeyInfo;
+import org.mozilla.jss.util.Password;
 
-import com.netscape.certsrv.authentication.AuthToken;
 import com.netscape.certsrv.base.EBaseException;
-import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.base.SessionContext;
 import com.netscape.certsrv.dbs.keydb.IKeyRepository;
 import com.netscape.certsrv.kra.EKRAException;
 import com.netscape.certsrv.kra.IKeyRecoveryAuthority;
 import com.netscape.certsrv.logging.AuditFormat;
-import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.request.IRequest;
 import com.netscape.certsrv.request.IService;
 import com.netscape.certsrv.security.Credential;
 import com.netscape.certsrv.security.IStorageKeyUnit;
 import com.netscape.certsrv.util.IStatsSubsystem;
-import com.netscape.cms.logging.Logger;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.apps.CMSEngine;
+import com.netscape.cmscore.apps.EngineConfig;
 import com.netscape.cmscore.dbs.KeyRecord;
 import com.netscape.cmscore.security.JssSubsystem;
 import com.netscape.cmsutil.crypto.CryptoUtil;
@@ -108,8 +107,6 @@ public class RecoveryService implements IService {
     public static final String ATTR_USER_CERT = "cert";
     public static final String ATTR_DELIVERY = "delivery";
 
-    Logger transactionLogger = Logger.getLogger(ILogger.EV_AUDIT, ILogger.S_KRA);
-
     private IKeyRecoveryAuthority mKRA = null;
     private IKeyRepository mStorage = null;
     private IStorageKeyUnit mStorageUnit = null;
@@ -136,15 +133,17 @@ public class RecoveryService implements IService {
     public boolean serviceRequest(IRequest request) throws EBaseException {
 
         CryptoManager cm = null;
-        IConfigStore config = null;
+        EngineConfig config = null;
         String tokName = "";
         CryptoToken ct = null;
         Boolean allowEncDecrypt_recovery = false;
 
         CMSEngine engine = CMS.getCMSEngine();
+        JssSubsystem jssSubsystem = engine.getJSSSubsystem();
+
         try {
             cm = CryptoManager.getInstance();
-            config = engine.getConfigStore();
+            config = engine.getConfig();
             tokName = config.getString("kra.storageUnit.hardware", CryptoUtil.INTERNAL_TOKEN_NAME);
             logger.debug("RecoveryService: serviceRequest: token: " + tokName);
             ct = CryptoUtil.getCryptoToken(tokName);
@@ -163,8 +162,7 @@ public class RecoveryService implements IService {
             statsSub.startTiming("recovery", true /* main action */);
         }
 
-        logger.debug("KRA services recovery request");
-        mKRA.log(ILogger.LL_INFO, "KRA services recovery request");
+        logger.info("KRA services recovery request");
 
         // byte publicKey[] = (byte[])request.get(ATTR_PUBLIC_KEY_DATA);
         // X500Name owner = (X500Name)request.get(ATTR_OWNER_NAME);
@@ -180,7 +178,8 @@ public class RecoveryService implements IService {
         // retrieve based on serial no
         BigInteger serialno = request.getExtDataInBigInteger(ATTR_SERIALNO);
 
-        mKRA.log(ILogger.LL_INFO, "KRA reading key record");
+        logger.info("KRA reading key record");
+
         if (statsSub != null) {
             statsSub.startTiming("get_key");
         }
@@ -199,13 +198,13 @@ public class RecoveryService implements IService {
         byte inputPubData[] = x509cert.getPublicKey().getEncoded();
 
         if (inputPubData.length != pubData.length) {
-            mKRA.log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_KRA_PUBLIC_KEY_LEN"));
+            logger.error(CMS.getLogMessage("CMSCORE_KRA_PUBLIC_KEY_LEN"));
             throw new EKRAException(
                     CMS.getUserMessage("CMS_KRA_PUBLIC_KEY_NOT_MATCHED"));
         }
         for (int i = 0; i < pubData.length; i++) {
             if (pubData[i] != inputPubData[i]) {
-                mKRA.log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_KRA_PUBLIC_KEY_LEN"));
+                logger.error(CMS.getLogMessage("CMSCORE_KRA_PUBLIC_KEY_LEN"));
                 throw new EKRAException(
                         CMS.getUserMessage("CMS_KRA_PUBLIC_KEY_NOT_MATCHED"));
             }
@@ -252,10 +251,8 @@ public class RecoveryService implements IService {
                 }
                 // verifyKeyPair() is RSA-centric
                 if (verifyKeyPair(pubData, privateKeyData) == false) {
-                    JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                     jssSubsystem.obscureBytes(privateKeyData);
-                    mKRA.log(ILogger.LL_FAILURE,
-                            CMS.getLogMessage("CMSCORE_KRA_PUBLIC_NOT_FOUND"));
+                    logger.error(CMS.getLogMessage("CMSCORE_KRA_PUBLIC_NOT_FOUND"));
                     throw new EKRAException(
                             CMS.getUserMessage("CMS_KRA_INVALID_PUBLIC_KEY"));
                 }
@@ -277,8 +274,6 @@ public class RecoveryService implements IService {
             } catch (EBaseException e) {
                 throw e;
             } finally {
-                //We don't need this data any more
-                JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                 jssSubsystem.obscureBytes(privateKeyData);
             }
 
@@ -287,7 +282,7 @@ public class RecoveryService implements IService {
             }
         } else {
 
-            if (engine.getConfigStore().getBoolean("kra.keySplitting")) {
+            if (engine.getConfig().getBoolean("kra.keySplitting")) {
                 Credential creds[] = (Credential[])
                         params.get(ATTR_AGENT_CREDENTIALS);
                 mKRA.getStorageKeyUnit().login(creds);
@@ -310,13 +305,12 @@ public class RecoveryService implements IService {
                 statsSub.endTiming("unwrap_key");
             }
 
-            if (engine.getConfigStore().getBoolean("kra.keySplitting")) {
+            if (engine.getConfig().getBoolean("kra.keySplitting")) {
                 mKRA.getStorageKeyUnit().logout();
             }
         }
-        mKRA.log(ILogger.LL_INFO, "key " +
-                serialno.toString() +
-                " recovered");
+
+        logger.info("key " + serialno + " recovered");
 
         // for audit log
         String authMgr = AuditFormat.NOAUTH;
@@ -411,7 +405,7 @@ public class RecoveryService implements IService {
 
         CMSEngine engine = CMS.getCMSEngine();
         try {
-            if (engine.getConfigStore().getBoolean("kra.keySplitting")) {
+            if (engine.getConfig().getBoolean("kra.keySplitting")) {
                 Credential creds[] = (Credential[])
                         request.get(ATTR_AGENT_CREDENTIALS);
 
@@ -434,7 +428,7 @@ public class RecoveryService implements IService {
                         true /* temporary */,
                         keyRecord.getWrappingParams(mKRA.getStorageKeyUnit().getOldWrappingParams()));
             } catch (Exception e) {
-                mKRA.log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_KRA_PRIVATE_KEY_NOT_FOUND"));
+                logger.error(CMS.getLogMessage("CMSCORE_KRA_PRIVATE_KEY_NOT_FOUND"), e);
                 throw new EKRAException(CMS.getUserMessage("CMS_KRA_RECOVERY_FAILED_1",
                         "private key unwrapping failure"), e);
             }
@@ -463,7 +457,12 @@ public class RecoveryService implements IService {
         logger.debug("RecoverService: createPFX() allowEncDecrypt_recovery=false");
 
         CMSEngine engine = CMS.getCMSEngine();
-        org.mozilla.jss.util.Password pass = null;
+        JssSubsystem jssSubsystem = engine.getJSSSubsystem();
+
+        String pwd = (String) params.get(ATTR_TRANSPORT_PWD);
+        char[] pwdChar = pwd.toCharArray();
+        Password pass = new Password(pwdChar);
+
         try {
             // create p12
             X509Certificate x509cert =
@@ -471,11 +470,9 @@ public class RecoveryService implements IService {
             if (x509cert == null) {
                 throw new EKRAException(CMS.getUserMessage("CMS_KRA_PKCS12_FAILED_1","Missing Certificate"));
             }
-            String pwd = (String) params.get(ATTR_TRANSPORT_PWD);
 
-            // add certificate
-            mKRA.log(ILogger.LL_INFO, "KRA adds certificate to P12");
-            logger.debug("RecoverService: createPFX() adds certificate to P12");
+            logger.info("KRA adds certificate to P12");
+
             SEQUENCE encSafeContents = new SEQUENCE();
             ASN1Value cert = new OCTET_STRING(x509cert.getEncoded());
             String nickname = request.getExtDataInString(ATTR_NICKNAME);
@@ -493,27 +490,16 @@ public class RecoveryService implements IService {
 
             encSafeContents.addElement(certBag);
 
-            // add key
-            mKRA.log(ILogger.LL_INFO, "KRA adds key to P12");
-            logger.debug("RecoverService: createPFX() adds key to P12");
-            char[] pwdChar = pwd.toCharArray();
-            pass = new
-                    org.mozilla.jss.util.Password(
-                            pwdChar);
-            {
-                JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
-                jssSubsystem.obscureChars(pwdChar);
-            }
+            logger.info("KRA adds key to P12");
 
             SEQUENCE safeContents = new SEQUENCE();
             PasswordConverter passConverter = new
                     PasswordConverter();
 
-            boolean legacyP12 = engine.getConfigStore().getBoolean("kra.legacyPKCS12", true);
+            boolean legacyP12 = engine.getConfig().getBoolean("kra.legacyPKCS12", true);
 
             ASN1Value key;
             if (legacyP12) {
-                JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                 SecureRandom ran = jssSubsystem.getRandomNumberGenerator();
                 byte[] salt = new byte[20];
                 ran.nextBytes(salt);
@@ -593,14 +579,14 @@ public class RecoveryService implements IService {
             logger.debug("RecoverService: createPFX() completed.");
 
         } catch (Exception e) {
-            mKRA.log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_KRA_CONSTRUCT_P12", e.toString()));
+            logger.error(CMS.getLogMessage("CMSCORE_KRA_CONSTRUCT_P12", e.toString()), e);
             logger.error("RecoverService: createPFX() exception caught:" + e, e);
             throw new EKRAException(CMS.getUserMessage("CMS_KRA_PKCS12_FAILED_1", e.toString()));
 
         } finally {
-            if(pass != null) {
-                pass.clear();
-            }
+            pass.clear();
+
+            jssSubsystem.obscureChars(pwdChar);
         }
 
         // update request
@@ -614,26 +600,27 @@ public class RecoveryService implements IService {
     public synchronized byte[] recoverKey(Hashtable<String, Object> request, KeyRecord keyRecord)
             throws EBaseException {
         CMSEngine engine = CMS.getCMSEngine();
-        if (engine.getConfigStore().getBoolean("kra.keySplitting")) {
+        if (engine.getConfig().getBoolean("kra.keySplitting")) {
             Credential creds[] = (Credential[])
                     request.get(ATTR_AGENT_CREDENTIALS);
 
             mStorageUnit.login(creds);
         }
-        mKRA.log(ILogger.LL_INFO, "KRA decrypts internal private");
+
+        logger.info("KRA decrypts internal private");
 
         try {
              byte[] privateKeyData = mStorageUnit.decryptInternalPrivate(
                      keyRecord.getPrivateKeyData(),
                      keyRecord.getWrappingParams(mKRA.getStorageKeyUnit().getOldWrappingParams()));
 
-             if (engine.getConfigStore().getBoolean("kra.keySplitting")) {
+             if (engine.getConfig().getBoolean("kra.keySplitting")) {
                  mStorageUnit.logout();
              }
 
              return privateKeyData;
         } catch (Exception e) {
-            mKRA.log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_KRA_PRIVATE_KEY_NOT_FOUND"));
+            logger.error(CMS.getLogMessage("CMSCORE_KRA_PRIVATE_KEY_NOT_FOUND"), e);
             throw new EKRAException(CMS.getUserMessage("CMS_KRA_RECOVERY_FAILED_1", "no private key"));
         }
     }
@@ -652,7 +639,12 @@ public class RecoveryService implements IService {
         logger.debug("RecoverService: createPFX() allowEncDecrypt_recovery=true");
 
         CMSEngine engine = CMS.getCMSEngine();
-        org.mozilla.jss.util.Password pass = null;
+        JssSubsystem jssSubsystem = engine.getJSSSubsystem();
+
+        String pwd = (String) params.get(ATTR_TRANSPORT_PWD);
+        char[] pwdChars = pwd.toCharArray();
+        Password pass = new Password(pwdChars);
+
         try {
             // create p12
             X509Certificate x509cert =
@@ -660,10 +652,9 @@ public class RecoveryService implements IService {
             if (x509cert == null) {
                 throw new EKRAException(CMS.getUserMessage("CMS_KRA_PKCS12_FAILED_1","Missing Certificate"));
             }
-            String pwd = (String) params.get(ATTR_TRANSPORT_PWD);
 
-            // add certificate
-            mKRA.log(ILogger.LL_INFO, "KRA adds certificate to P12");
+            logger.info("KRA adds certificate to P12");
+
             SEQUENCE encSafeContents = new SEQUENCE();
             ASN1Value cert = new OCTET_STRING(x509cert.getEncoded());
             String nickname = request.getExtDataInString(ATTR_NICKNAME);
@@ -682,14 +673,7 @@ public class RecoveryService implements IService {
             encSafeContents.addElement(certBag);
 
             // add key
-            mKRA.log(ILogger.LL_INFO, "KRA adds key to P12");
-            char[] pwdChars = pwd.toCharArray();
-            pass = new org.mozilla.jss.util.Password(
-                    pwdChars);
-
-            JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
-            jssSubsystem.obscureChars(pwdChars);
-
+            logger.info("KRA adds key to P12");
 
             SEQUENCE safeContents = new SEQUENCE();
             PrivateKeyInfo pki = (PrivateKeyInfo)
@@ -697,7 +681,7 @@ public class RecoveryService implements IService {
                             priData);
             EncryptedPrivateKeyInfo epki = null;
 
-            boolean legacyP12 = engine.getConfigStore().getBoolean("kra.legacyPKCS12", true);
+            boolean legacyP12 = engine.getConfig().getBoolean("kra.legacyPKCS12", true);
 
             if (legacyP12) {
                 /* legacy mode may be required e.g. when token/HSM
@@ -757,12 +741,15 @@ public class RecoveryService implements IService {
 
             // put final PKCS12 into volatile request
             params.put(ATTR_PKCS12, fos.toByteArray());
+
         } catch (Exception e) {
-            mKRA.log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_KRA_CONSTRUCT_P12", e.toString()));
+            logger.error(CMS.getLogMessage("CMSCORE_KRA_CONSTRUCT_P12", e.toString()), e);
             throw new EKRAException(CMS.getUserMessage("CMS_KRA_PKCS12_FAILED_1", e.toString()));
+
         } finally {
-            if(pass != null)
-                pass.clear();
+            pass.clear();
+
+            jssSubsystem.obscureChars(pwdChars);
         }
 
         // update request
@@ -783,13 +770,13 @@ public class RecoveryService implements IService {
 
             md.update(certDer);
             return md.digest();
+
         } catch (CertificateEncodingException e) {
-            mKRA.log(ILogger.LL_FAILURE,
-                    CMS.getLogMessage("CMSCORE_KRA_CREAT_KEY_ID", e.toString()));
+            logger.error(CMS.getLogMessage("CMSCORE_KRA_CREAT_KEY_ID", e.toString()), e);
             throw new EKRAException(CMS.getUserMessage("CMS_KRA_KEYID_FAILED_1", e.toString()));
+
         } catch (NoSuchAlgorithmException e) {
-            mKRA.log(ILogger.LL_FAILURE,
-                    CMS.getLogMessage("CMSCORE_KRA_CREAT_KEY_ID", e.toString()));
+            logger.error(CMS.getLogMessage("CMSCORE_KRA_CREAT_KEY_ID", e.toString()), e);
             throw new EKRAException(CMS.getUserMessage("CMS_KRA_KEYID_FAILED_1", e.toString()));
         }
     }
@@ -818,9 +805,9 @@ public class RecoveryService implements IService {
             localKeyAttr.addElement(localKeySet);
             attrs.addElement(localKeyAttr);
             return attrs;
+
         } catch (CharConversionException e) {
-            mKRA.log(ILogger.LL_FAILURE,
-                    CMS.getLogMessage("CMSCORE_KRA_CREAT_KEY_BAG", e.toString()));
+            logger.error(CMS.getLogMessage("CMSCORE_KRA_CREAT_KEY_BAG", e.toString()), e);
             throw new EKRAException(CMS.getUserMessage("CMS_KRA_KEYBAG_FAILED_1", e.toString()));
         }
     }
