@@ -35,16 +35,13 @@ import org.mozilla.jss.pkix.primitive.PBEParameter;
 import org.mozilla.jss.util.Password;
 
 import com.netscape.certsrv.base.EBaseException;
-import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.dbs.keydb.IKeyRecord;
 import com.netscape.certsrv.dbs.keydb.IKeyRepository;
 import com.netscape.certsrv.dbs.keydb.KeyId;
 import com.netscape.certsrv.key.KeyRequestResource;
 import com.netscape.certsrv.kra.EKRAException;
 import com.netscape.certsrv.kra.IKeyRecoveryAuthority;
-import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.logging.event.SecurityDataArchivalProcessedEvent;
-import com.netscape.certsrv.profile.IEnrollProfile;
 import com.netscape.certsrv.request.IRequest;
 import com.netscape.certsrv.request.RequestId;
 import com.netscape.certsrv.security.IStorageKeyUnit;
@@ -53,6 +50,7 @@ import com.netscape.cms.logging.Logger;
 import com.netscape.cms.logging.SignedAuditLogger;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.apps.CMSEngine;
+import com.netscape.cmscore.apps.EngineConfig;
 import com.netscape.cmscore.dbs.KeyRecord;
 import com.netscape.cmscore.security.JssSubsystem;
 import com.netscape.cmsutil.crypto.CryptoUtil;
@@ -87,13 +85,13 @@ public class SecurityDataProcessor {
         String clientKeyId = request.getExtDataInString(IRequest.SECURITY_DATA_CLIENT_KEY_ID);
 
         // one way to get data - unexploded pkiArchiveOptions
-        String pkiArchiveOptions = request.getExtDataInString(IEnrollProfile.REQUEST_ARCHIVE_OPTIONS);
+        String pkiArchiveOptions = request.getExtDataInString(IRequest.REQUEST_ARCHIVE_OPTIONS);
 
         // another way - exploded pkiArchiveOptions
-        String transWrappedSessionKey = request.getExtDataInString(IEnrollProfile.REQUEST_SESSION_KEY);
-        String wrappedSecurityData = request.getExtDataInString(IEnrollProfile.REQUEST_SECURITY_DATA);
-        String algParams = request.getExtDataInString(IEnrollProfile.REQUEST_ALGORITHM_PARAMS);
-        String algStr = request.getExtDataInString(IEnrollProfile.REQUEST_ALGORITHM_OID);
+        String transWrappedSessionKey = request.getExtDataInString(IRequest.REQUEST_SESSION_KEY);
+        String wrappedSecurityData = request.getExtDataInString(IRequest.REQUEST_SECURITY_DATA);
+        String algParams = request.getExtDataInString(IRequest.REQUEST_ALGORITHM_PARAMS);
+        String algStr = request.getExtDataInString(IRequest.REQUEST_ALGORITHM_OID);
 
         // parameters if the secret is a symmetric key
         String dataType = request.getExtDataInString(IRequest.SECURITY_DATA_TYPE);
@@ -107,10 +105,12 @@ public class SecurityDataProcessor {
         logger.debug("SecurityDataProcessor.archive wrappedSecurityData: " + wrappedSecurityData);
 
         CMSEngine engine = CMS.getCMSEngine();
-        IConfigStore config = null;
+        JssSubsystem jssSubsystem = engine.getJSSSubsystem();
+
+        EngineConfig config = null;
 
         try {
-            config = engine.getConfigStore();
+            config = engine.getConfig();
             allowEncDecrypt_archival = config.getBoolean("kra.allowEncDecrypt.archival", false);
         } catch (Exception e) {
             throw new EBaseException(CMS.getUserMessage("CMS_BASE_CERT_ERROR", e.toString()));
@@ -177,7 +177,7 @@ public class SecurityDataProcessor {
             // Symmetric Key
             keyType = KeyRequestResource.SYMMETRIC_KEY_TYPE;
 
-            if (allowEncDecrypt_archival == true) {
+            if (allowEncDecrypt_archival) {
                 try {
                     tmp_unwrapped = transportUnit.decryptExternalPrivate(
                             wrappedSessionKey,
@@ -187,7 +187,7 @@ public class SecurityDataProcessor {
                             null);
 
                 } catch (Exception e) {
-                    throw new EBaseException("Can't decrypt symm key using allEncDecrypt_archival : true .");
+                    throw new EBaseException("Unable to decrypt symmetric key with kra.allowEncDecrypt.archival=true: " + e.getMessage(), e);
                 }
 
                 /* making sure leading 0's are removed */
@@ -197,7 +197,6 @@ public class SecurityDataProcessor {
                 }
 
                 unwrapped = Arrays.copyOfRange(tmp_unwrapped, first, tmp_unwrapped.length);
-                JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                 jssSubsystem.obscureBytes(tmp_unwrapped);
 
             } else {
@@ -210,7 +209,7 @@ public class SecurityDataProcessor {
                             KeyRequestService.SYMKEY_TYPES.get(algorithm),
                             strength);
                 } catch (Exception e) {
-                    throw new EBaseException("Can't decrypt symmetric key.", e);
+                    throw new EBaseException("Unable to decrypt symmetric key: " + e.getMessage(), e);
                 }
             }
 
@@ -224,7 +223,7 @@ public class SecurityDataProcessor {
                         secdata,
                         null);
             } catch (Exception e) {
-                throw new EBaseException("Can't decrypt passphrase.", e);
+                throw new EBaseException("Unable to decrypt passphrase: " + e.getMessage(), e);
             }
 
         }
@@ -272,8 +271,6 @@ public class SecurityDataProcessor {
 
             throw new EBaseException(CMS.getUserMessage("CMS_KRA_INVALID_PRIVATE_KEY"));
         } finally {
-            // clean up some data
-            JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
             jssSubsystem.obscureBytes(securityData);
             jssSubsystem.obscureBytes(unwrapped);
         }
@@ -309,8 +306,7 @@ public class SecurityDataProcessor {
         BigInteger serialNo = keyRepository.getNextSerialNumber();
 
         if (serialNo == null) {
-            kra.log(ILogger.LL_FAILURE,
-                    CMS.getLogMessage("CMSCORE_KRA_GET_NEXT_SERIAL"));
+            logger.error(CMS.getLogMessage("CMSCORE_KRA_GET_NEXT_SERIAL"));
 
             signedAuditLogger.log(SecurityDataArchivalProcessedEvent.createFailureEvent(
                     auditSubjectID,
@@ -340,8 +336,7 @@ public class SecurityDataProcessor {
         try {
             rec.setWrappingParams(params, doEncrypt);
         } catch (Exception e) {
-            kra.log(ILogger.LL_FAILURE,
-                    "Failed to store wrapping parameters: " + e);
+            logger.error("Unable to store wrapping parameters: " + e.getMessage(), e);
 
             signedAuditLogger.log(SecurityDataArchivalProcessedEvent.createFailureEvent(
                     auditSubjectID,
@@ -378,10 +373,12 @@ public class SecurityDataProcessor {
         logger.debug("SecurityDataService.recover(): start");
 
         CMSEngine engine = CMS.getCMSEngine();
-        IConfigStore config = null;
+        JssSubsystem jssSubsystem = engine.getJSSSubsystem();
+
+        EngineConfig config = null;
 
         try {
-            config = engine.getConfigStore();
+            config = engine.getConfig();
             allowEncDecrypt_recovery = config.getBoolean("kra.allowEncDecrypt.recovery", false);
         } catch (Exception e) {
             throw new EBaseException(CMS.getUserMessage("CMS_BASE_CERT_ERROR", e.toString()));
@@ -495,12 +492,11 @@ public class SecurityDataProcessor {
                     payloadWrapName,
                     transportUnit.getOldWrappingParams().getPayloadWrapAlgorithm());
         } catch (Exception e1) {
-            JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
             jssSubsystem.obscureBytes(unwrappedSecData);
             throw new EBaseException("Failed to generate IV when wrapping secret", e1);
         }
-        String ivStr = iv != null? Utils.base64encode(iv, true): null;
-        String ivStr_wrap = iv_wrap != null ? Utils.base64encode(iv_wrap, true): null;
+        String ivStr = iv != null? Utils.base64encode(iv, false): null;
+        String ivStr_wrap = iv_wrap != null ? Utils.base64encode(iv_wrap, false): null;
 
         WrappingParams wrapParams = null;
         if (payloadEncryptOID == null) {
@@ -517,7 +513,6 @@ public class SecurityDataProcessor {
                     iv != null? new IVParameterSpec(iv): null,
                     iv_wrap != null? new IVParameterSpec(iv_wrap): null);
             } catch (Exception e) {
-                JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                 jssSubsystem.obscureBytes(unwrappedSecData);
                 throw new EBaseException("Cannot generate wrapping params: " + e, e);
             }
@@ -544,7 +539,6 @@ public class SecurityDataProcessor {
 
                 char[] passChars = CryptoUtil.bytesToChars(unwrappedPass);
                 pass = new Password(passChars);
-                JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                 jssSubsystem.obscureChars(passChars);
 
 
@@ -576,8 +570,6 @@ public class SecurityDataProcessor {
                 params.put(IRequest.SECURITY_DATA_PASS_WRAPPED_DATA, pbeWrappedData);
 
             } catch (Exception e) {
-                JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
-                jssSubsystem.obscureBytes(unwrappedSecData);
                 throw new EBaseException("Cannot unwrap passphrase: " + e, e);
 
             } finally {
@@ -585,7 +577,6 @@ public class SecurityDataProcessor {
                     pass.clear();
                 }
 
-                JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                 jssSubsystem.obscureBytes(unwrappedPass);
 
             }
@@ -618,7 +609,6 @@ public class SecurityDataProcessor {
                     }
 
                 } catch (Exception e) {
-                    JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                     jssSubsystem.obscureBytes(unwrappedSecData);
                     throw new EBaseException("Cannot wrap symmetric key: " + e, e);
                 }
@@ -636,7 +626,6 @@ public class SecurityDataProcessor {
                             wrapParams.getPayloadEncryptionAlgorithm(),
                             wrapParams.getPayloadEncryptionIV());
                 } catch (Exception e) {
-                    JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                     jssSubsystem.obscureBytes(unwrappedSecData);
                     throw new EBaseException("Cannot encrypt passphrase: " + e, e);
                 }
@@ -668,13 +657,12 @@ public class SecurityDataProcessor {
                     }
 
                 } catch (Exception e) {
-                    JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                     jssSubsystem.obscureBytes(unwrappedSecData);
                     throw new EBaseException("Cannot wrap private key: " + e, e);
                 }
             }
 
-            String wrappedKeyData = Utils.base64encode(key_data, true);
+            String wrappedKeyData = Utils.base64encode(key_data, false);
             params.put(IRequest.SECURITY_DATA_SESS_WRAPPED_DATA, wrappedKeyData);
         }
 
@@ -699,7 +687,6 @@ public class SecurityDataProcessor {
 
 
         //If we made it this far, all is good, and clear out the unwrappedSecData before returning.
-        JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
         jssSubsystem.obscureBytes(unwrappedSecData);
 
         params.put(IRequest.SECURITY_DATA_TYPE, dataType);
@@ -736,7 +723,8 @@ public class SecurityDataProcessor {
         byte[] bytes = new byte[numBytes];
 
         CMSEngine engine = CMS.getCMSEngine();
-        JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
+        JssSubsystem jssSubsystem = engine.getJSSSubsystem();
+
         SecureRandom random = jssSubsystem.getRandomNumberGenerator();
         random.nextBytes(bytes);
 
@@ -771,7 +759,8 @@ public class SecurityDataProcessor {
         byte[] bytes = new byte[numBytes];
 
         CMSEngine engine = CMS.getCMSEngine();
-        JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
+        JssSubsystem jssSubsystem = engine.getJSSSubsystem();
+
         SecureRandom random = jssSubsystem.getRandomNumberGenerator();
         random.nextBytes(bytes);
 
@@ -901,7 +890,7 @@ public class SecurityDataProcessor {
             ByteArrayOutputStream oStream = new ByteArrayOutputStream();
             cInfo.encode(oStream);
             encoded = oStream.toByteArray();
-            retData = Utils.base64encode(encoded, true);
+            retData = Utils.base64encode(encoded, false);
 
         } catch (Exception e) {
             throw new EBaseException("Can't create a PBE wrapped EncryptedContentInfo! " + e.toString());
