@@ -61,12 +61,9 @@ import org.mozilla.jss.util.Password;
 
 import com.netscape.certsrv.base.EBaseException;
 import com.netscape.certsrv.base.IConfigStore;
-import com.netscape.certsrv.base.ISubsystem;
 import com.netscape.certsrv.kra.EKRAException;
 import com.netscape.certsrv.kra.IJoinShares;
-import com.netscape.certsrv.kra.IKeyRecoveryAuthority;
 import com.netscape.certsrv.kra.IShare;
-import com.netscape.certsrv.logging.ILogger;
 import com.netscape.certsrv.security.Credential;
 import com.netscape.certsrv.security.IStorageKeyUnit;
 import com.netscape.cms.servlet.key.KeyRecordParser;
@@ -83,8 +80,7 @@ import com.netscape.cmsutil.crypto.CryptoUtil;
  * @author thomask
  * @version $Revision$, $Date$
  */
-public class StorageKeyUnit extends EncryptionUnit implements
-        ISubsystem, IStorageKeyUnit {
+public class StorageKeyUnit extends EncryptionUnit implements IStorageKeyUnit {
 
     public static org.slf4j.Logger logger = org.slf4j.LoggerFactory.getLogger(StorageKeyUnit.class);
     private IConfigStore mConfig = null;
@@ -93,7 +89,6 @@ public class StorageKeyUnit extends EncryptionUnit implements
     // private RSAPrivateKey mPrivateKey = null;
 
     private IConfigStore mStorageConfig = null;
-    private IKeyRecoveryAuthority mKRA = null;
     private String mTokenFile = null;
     private X509Certificate mCert = null;
     private CryptoManager mManager = null;
@@ -231,20 +226,18 @@ public class StorageKeyUnit extends EncryptionUnit implements
     /**
      * Initializes this subsystem.
      */
-    public void init(ISubsystem owner, IConfigStore config)
+    public void init(IConfigStore config, boolean keySplitting)
             throws EBaseException {
 
         CMSEngine engine = CMS.getCMSEngine();
-        mKRA = (IKeyRecoveryAuthority) owner;
         mConfig = config;
-
-        mKeySplitting = owner.getConfigStore().getBoolean("keySplitting", false);
+        mKeySplitting = keySplitting;
 
         try {
             mManager = CryptoManager.getInstance();
             mToken = getToken();
         } catch (NotInitializedException e) {
-            mKRA.log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_KRA_STORAGE_INIT", e.toString()));
+            logger.error(CMS.getLogMessage("CMSCORE_KRA_STORAGE_INIT", e.toString()), e);
             throw new EBaseException(CMS.getUserMessage("CMS_BASE_CERT_ERROR", e.toString()));
         }
 
@@ -271,9 +264,9 @@ public class StorageKeyUnit extends EncryptionUnit implements
                     // pick up cert by nickName
 
                 } catch (IOException e) {
-                    mKRA.log(ILogger.LL_INFO,
-                            CMS.getLogMessage("CMSCORE_KRA_STORAGE_READ_CERT", e.toString()));
+                    logger.error(CMS.getLogMessage("CMSCORE_KRA_STORAGE_READ_CERT", e.toString()), e);
                     throw new EBaseException(CMS.getUserMessage("CMS_BASE_CERT_ERROR", e.toString()));
+
                 } finally {
                     try {
                         if (fi != null)
@@ -291,19 +284,20 @@ public class StorageKeyUnit extends EncryptionUnit implements
                             mCert = certs[i];
                         }
                     }
+
                     if (mCert == null) {
-                        mKRA.log(ILogger.LL_FAILURE,
-                                "Storage Cert could not be initialized. No cert in token matched kra-cert file");
+                        logger.error("Storage Cert could not be initialized. No cert in token matched kra-cert file");
                         throw new EBaseException(CMS.getUserMessage("CMS_BASE_CERT_ERROR", "mCert == null"));
                     } else {
-                        mKRA.log(ILogger.LL_INFO, "Using Storage Cert " + mCert.getSubjectDN());
+                        logger.info("Using Storage Cert " + mCert.getSubjectDN());
                     }
+
                 } catch (CertificateEncodingException e) {
-                    mKRA.log(ILogger.LL_FAILURE, "Error encoding cert ");
+                    logger.error("Error encoding cert: " + e.getMessage(), e);
                     throw new EBaseException(CMS.getUserMessage("CMS_BASE_CERT_ERROR", e.toString()));
+
                 } catch (TokenException e) {
-                    mKRA.log(ILogger.LL_FAILURE,
-                            CMS.getLogMessage("CMSCORE_KRA_STORAGE_READ_CERT", e.toString()));
+                    logger.error(CMS.getLogMessage("CMSCORE_KRA_STORAGE_READ_CERT", e.toString()), e);
                     throw new EBaseException(CMS.getUserMessage("CMS_BASE_CERT_ERROR", e.toString()));
                 }
             }
@@ -331,26 +325,26 @@ public class StorageKeyUnit extends EncryptionUnit implements
                     mCert = mManager.findCertByNickname(
                             config.getString(PROP_NICKNAME));
                 }
+
             } catch (IOException e) {
-                mKRA.log(ILogger.LL_FAILURE,
-                        CMS.getLogMessage("CMSCORE_KRA_STORAGE_READ_CERT", e.toString()));
-                throw new EBaseException(CMS.getUserMessage("CMS_BASE_CERT_ERROR", e.toString()));
+                logger.error(CMS.getLogMessage("CMSCORE_KRA_STORAGE_READ_CERT", e.toString()), e);
+                throw new EBaseException(CMS.getUserMessage("CMS_BASE_CERT_ERROR", e.toString()), e);
+
             } catch (TokenException e) {
-                mKRA.log(ILogger.LL_FAILURE,
-                        CMS.getLogMessage("CMSCORE_KRA_STORAGE_READ_CERT", e.toString()));
-                throw new EBaseException(CMS.getUserMessage("CMS_BASE_CERT_ERROR", e.toString()));
+                logger.error(CMS.getLogMessage("CMSCORE_KRA_STORAGE_READ_CERT", e.toString()), e);
+                throw new EBaseException(CMS.getUserMessage("CMS_BASE_CERT_ERROR", e.toString()), e);
+
             } catch (ObjectNotFoundException e) {
-                mKRA.log(ILogger.LL_FAILURE,
-                        CMS.getLogMessage("CMSCORE_KRA_STORAGE_READ_CERT", e.toString()));
+                logger.error(CMS.getLogMessage("CMSCORE_KRA_STORAGE_READ_CERT", e.toString()), e);
                 // XXX - this import wont work
                 try {
                     mCert = mManager.importCertPackage(certData,
                                 "kraStorageCert");
                 } catch (Exception ex) {
-                    mKRA.log(ILogger.LL_FAILURE,
-                            CMS.getLogMessage("CMSCORE_KRA_STORAGE_IMPORT_CERT", e.toString()));
+                    logger.error(CMS.getLogMessage("CMSCORE_KRA_STORAGE_IMPORT_CERT", e.toString()), ex);
                     throw new EBaseException(CMS.getUserMessage("CMS_BASE_CERT_ERROR", ex.toString()));
                 }
+
             } finally {
                 if (fi != null) {
                     try {
@@ -373,9 +367,9 @@ public class StorageKeyUnit extends EncryptionUnit implements
                     fi.read(mPrivateKeyData);
 
                 } catch (IOException e) {
-                    mKRA.log(ILogger.LL_FAILURE,
-                            CMS.getLogMessage("CMSCORE_KRA_STORAGE_READ_PRIVATE", e.toString()));
+                    logger.error(CMS.getLogMessage("CMSCORE_KRA_STORAGE_READ_PRIVATE", e.toString()), e);
                     throw new EBaseException(CMS.getUserMessage("CMS_BASE_INVALID_KEY_1", e.toString()));
+
                 } finally {
                     if (fi != null) {
                         try {
@@ -396,11 +390,8 @@ public class StorageKeyUnit extends EncryptionUnit implements
                 // read m, n and no of identifier
                 mStorageConfig = engine.createFileConfigStore(mTokenFile);
             } catch (EBaseException e) {
-                mKRA.log(ILogger.LL_FAILURE,
-                        CMS.getLogMessage("CMSCORE_KRA_STORAGE_READ_MN",
-                                e.toString()));
-                throw new EBaseException(CMS.getUserMessage("CMS_BASE_INVALID_OPERATION"));
-
+                logger.error(CMS.getLogMessage("CMSCORE_KRA_STORAGE_READ_MN", e.toString()), e);
+                throw new EBaseException(CMS.getUserMessage("CMS_BASE_INVALID_OPERATION"), e);
             }
         }
 
@@ -412,9 +403,8 @@ public class StorageKeyUnit extends EncryptionUnit implements
                 logger.debug("mCert = " + mCert);
             }
         } catch (Exception e) {
-            mKRA.log(ILogger.LL_FAILURE,
-                    CMS.getLogMessage("CMSCORE_KRA_STORAGE_READ_CERT", e.toString()));
-            throw new EBaseException(CMS.getUserMessage("CMS_BASE_CERT_ERROR", e.toString()));
+            logger.error(CMS.getLogMessage("CMSCORE_KRA_STORAGE_READ_CERT", e.toString()), e);
+            throw new EBaseException(CMS.getUserMessage("CMS_BASE_CERT_ERROR", e.toString()), e);
         }
 
     }
@@ -452,19 +442,15 @@ public class StorageKeyUnit extends EncryptionUnit implements
      */
     public static SymmetricKey buildSymmetricKey(CryptoToken token,
             String pin) throws EBaseException {
+        Password pass = new Password(pin.toCharArray());
         try {
-
-            Password pass = new Password(pin.toCharArray());
-            KeyGenerator kg = null;
-
-            kg = token.getKeyGenerator(
+            KeyGenerator kg = token.getKeyGenerator(
                         PBEAlgorithm.PBE_SHA1_DES3_CBC);
             byte salt[] = { 0x01, 0x01, 0x01, 0x01,
                     0x01, 0x01, 0x01, 0x01 };
             PBEKeyGenParams kgp = new PBEKeyGenParams(pass,
                     salt, 5);
 
-            pass.clear();
             kg.initialize(kgp);
             return kg.generate();
         } catch (TokenException e) {
@@ -483,6 +469,8 @@ public class StorageKeyUnit extends EncryptionUnit implements
             throw new EBaseException(CMS.getUserMessage("CMS_BASE_INVALID_KEY_1",
                         "buildSymmetricKey:" +
                                 e.toString()));
+        } finally {
+            pass.clear();
         }
     }
 
@@ -555,8 +543,9 @@ public class StorageKeyUnit extends EncryptionUnit implements
      */
     public void login(String pin) throws EBaseException {
         if (mConfig.getString(PROP_HARDWARE, null) != null) {
+            Password password = new Password(pin.toCharArray());
             try {
-                getToken().login(new Password(pin.toCharArray()));
+                getToken().login(password);
                 PrivateKey pk[] = getToken().getCryptoStore().getPrivateKeys();
 
                 for (int i = 0; i < pk.length; i++) {
@@ -566,7 +555,9 @@ public class StorageKeyUnit extends EncryptionUnit implements
                     }
                 }
             } catch (Exception e) {
-                mKRA.log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_KRA_STORAGE_LOGIN", e.toString()));
+                logger.warn(CMS.getLogMessage("CMSCORE_KRA_STORAGE_LOGIN", e.toString()), e);
+            } finally {
+                password.clear();
             }
 
         } else {
@@ -576,7 +567,7 @@ public class StorageKeyUnit extends EncryptionUnit implements
                 mPrivateKey = unwrapStorageKey(mToken, sk,
                             mPrivateKeyData, getPublicKey());
             } catch (Exception e) {
-                mKRA.log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_KRA_STORAGE_LOGIN", e.toString()));
+                logger.warn(CMS.getLogMessage("CMSCORE_KRA_STORAGE_LOGIN", e.toString()), e);
             }
             if (mPrivateKey == null) {
                 mPrivateKey = getPrivateKey();
@@ -605,7 +596,7 @@ public class StorageKeyUnit extends EncryptionUnit implements
                 }
             }
         } catch (Exception e) {
-            mKRA.log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_KRA_STORAGE_LOGOUT", e.toString()));
+            logger.warn(CMS.getLogMessage("CMSCORE_KRA_STORAGE_LOGOUT", e.toString()), e);
 
         }
         mPrivateKey = null;
@@ -639,6 +630,7 @@ public class StorageKeyUnit extends EncryptionUnit implements
             String newpwd) throws EBaseException {
 
         CMSEngine engine = CMS.getCMSEngine();
+        JssSubsystem jssSubsystem = engine.getJSSSubsystem();
 
         // locate the id(s)
         byte share[]=null;
@@ -656,12 +648,10 @@ public class StorageKeyUnit extends EncryptionUnit implements
                             encryptShareWithInternalStorage(
                                     share, newpwd));
                     mStorageConfig.commit(false);
-                    JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                     jssSubsystem.obscureBytes(share);
                     return true;
                 }
             } catch (Exception e) {
-                JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                 jssSubsystem.obscureBytes(share);
                 break;
             }
@@ -735,8 +725,7 @@ public class StorageKeyUnit extends EncryptionUnit implements
             mStorageConfig.commit(false);
             return true;
         } catch (EBaseException e) {
-            mKRA.log(ILogger.LL_FAILURE,
-                    CMS.getLogMessage("CMSCORE_KRA_STORAGE_CHANGE_MN", e.toString()));
+            logger.warn(CMS.getLogMessage("CMSCORE_KRA_STORAGE_CHANGE_MN", e.toString()), e);
         }
         return false;
     }
@@ -900,6 +889,7 @@ public class StorageKeyUnit extends EncryptionUnit implements
     public void checkPassword(String userid, String pwd) throws EBaseException {
 
         CMSEngine engine = CMS.getCMSEngine();
+        JssSubsystem jssSubsystem = engine.getJSSSubsystem();
 
         for (int i = 0;; i++) {
             String uid = null;
@@ -918,7 +908,6 @@ public class StorageKeyUnit extends EncryptionUnit implements
                 if (data == null) {
                     throw new EBaseException(CMS.getUserMessage("CMS_AUTHENTICATION_INVALID_CREDENTIAL"));
                 } else {
-                    JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                     jssSubsystem.obscureBytes(data);
                 }
                 return;
@@ -999,6 +988,7 @@ public class StorageKeyUnit extends EncryptionUnit implements
             throws EBaseException {
 
         CMSEngine engine = CMS.getCMSEngine();
+        JssSubsystem jssSubsystem = engine.getJSSSubsystem();
 
         // sort the credential according to the order in
         // configuration file
@@ -1025,7 +1015,6 @@ public class StorageKeyUnit extends EncryptionUnit implements
                     }
 
                     v.put(Integer.toString(i), pwd);
-                    JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
                     jssSubsystem.obscureBytes(pwd);
                     break;
                 }
@@ -1070,15 +1059,13 @@ public class StorageKeyUnit extends EncryptionUnit implements
             byte secret[] = j.recoverSecret();
             String pwd = new String(secret);
 
-            JssSubsystem jssSubsystem = (JssSubsystem) engine.getSubsystem(JssSubsystem.ID);
             jssSubsystem.obscureBytes(secret);
 
             return pwd;
         } catch (Exception ee) {
-            mKRA.log(ILogger.LL_FAILURE,
-                    CMS.getLogMessage("CMSCORE_KRA_STORAGE_RECONSTRUCT", e.toString()));
+            logger.error(CMS.getLogMessage("CMSCORE_KRA_STORAGE_RECONSTRUCT", e.toString()), ee);
             throw new EBaseException(CMS.getUserMessage("CMS_KRA_INVALID_PASSWORD",
-                        ee.toString()));
+                        ee.toString()), ee);
         }
     }
 
