@@ -112,11 +112,17 @@ public class KeyRequestService extends SubsystemService implements KeyRequestRes
         return createOKResponse(info);
     }
 
-    public Response archiveKey(KeyArchivalRequest data) {
+    public Response archiveKey(KeyArchivalRequest data) throws Exception {
         // auth and authz
         // Catch this before internal server processing has to deal with it
 
-        if (data == null || data.getClientKeyId() == null || data.getDataType() == null) {
+        if (data == null) {
+            throw new BadRequestException("Missing key archival request");
+        }
+
+        logger.info("Request:\n" + data.toJSON());
+
+        if (data.getClientKeyId() == null || data.getDataType() == null) {
             throw new BadRequestException("Invalid key archival request.");
         }
 
@@ -159,6 +165,8 @@ public class KeyRequestService extends SubsystemService implements KeyRequestRes
                     response.getRequestInfo().getRequestId(),
                     data.getClientKeyId()));
 
+            logger.info("Response:\n" + response.toJSON());
+
             return createCreatedResponse(response, new URI(response.getRequestInfo().getRequestURL()));
 
         } catch (EAuthzAccessDenied e) {
@@ -292,6 +300,14 @@ public class KeyRequestService extends SubsystemService implements KeyRequestRes
     @Override
     public Response listRequests(String requestState, String requestType, String clientKeyID,
             RequestId start, Integer pageSize, Integer maxResults, Integer maxTime, String realm) {
+
+        logger.info("KeyRequestService: Listing key requests");
+
+        logger.debug("KeyRequestService: request state: " + requestState);
+        logger.debug("KeyRequestService: request type: " + requestType);
+        logger.debug("KeyRequestService: client key ID: " + clientKeyID);
+        logger.debug("KeyRequestService: realm: " + realm);
+
         if (realm != null) {
             try {
                 authz.checkRealm(realm, getAuthToken(), null, "certServer.kra.requests", "list");
@@ -300,13 +316,14 @@ public class KeyRequestService extends SubsystemService implements KeyRequestRes
             } catch (EAuthzUnknownRealm e) {
                 throw new BadRequestException("Invalid realm", e);
             } catch (EBaseException e) {
-                logger.error("listRequests: unable to authorize realm: " + e.getMessage(), e);
+                logger.error("KeyRequestService: Unable to authorize realm: " + e.getMessage(), e);
                 throw new PKIException(e.toString(), e);
             }
         }
+
         // get ldap filter
         String filter = createSearchFilter(requestState, requestType, clientKeyID, realm);
-        logger.debug("listRequests: filter is " + filter);
+        logger.debug("KeyRequestService: filter: " + filter);
 
         start = start == null ? new RequestId(KeyRequestService.DEFAULT_START) : start;
         pageSize = pageSize == null ? DEFAULT_PAGESIZE : pageSize;
@@ -318,9 +335,10 @@ public class KeyRequestService extends SubsystemService implements KeyRequestRes
         try {
             requests = reqDAO.listRequests(filter, start, pageSize, maxResults, maxTime, uriInfo);
         } catch (EBaseException e) {
-            logger.error("listRequests: error in obtaining request results: " + e.getMessage(), e);
+            logger.error("KeyRequestService: Unable to obtain request results: " + e.getMessage(), e);
             throw new PKIException(e.toString(), e);
         }
+
         return createOKResponse(requests);
     }
 
@@ -398,14 +416,16 @@ public class KeyRequestService extends SubsystemService implements KeyRequestRes
     }
 
     @Override
-    public Response submitRequest(MultivaluedMap<String, String> form) {
+    public Response submitRequest(MultivaluedMap<String, String> form) throws Exception {
         ResourceMessage data = new ResourceMessage(form);
         return submitRequest(data);
     }
 
     @Override
-    public Response submitRequest(ResourceMessage data) {
+    public Response submitRequest(ResourceMessage data) throws Exception {
+
         Object request = null;
+
         try {
             Class<?> requestClazz = Class.forName(data.getClassName());
             request = requestClazz.getDeclaredConstructor(ResourceMessage.class).newInstance(data);
@@ -416,12 +436,16 @@ public class KeyRequestService extends SubsystemService implements KeyRequestRes
 
         if (request instanceof KeyArchivalRequest) {
             return archiveKey(new KeyArchivalRequest(data));
+
         } else if (request instanceof KeyRecoveryRequest) {
             return recoverKey(new KeyRecoveryRequest(data));
+
         } else if (request instanceof SymKeyGenerationRequest) {
             return generateSymKey(new SymKeyGenerationRequest(data));
+
         } else if (request instanceof AsymKeyGenerationRequest) {
             return generateAsymKey(new AsymKeyGenerationRequest(data));
+
         } else {
             throw new BadRequestException("Invalid request class.");
         }
