@@ -64,10 +64,10 @@ typedef struct RNGContextStr RNGContext;
 #include <secoidt.h>
 #include <nss.h>
 
-extern int equals(char *s, char *t);
+extern int equals(const char *s, const char *t);
 extern SECStatus PK11_HashBuf(SECOidTag hashAlg,
                               unsigned char *out,
-                              unsigned char *in,
+                              const unsigned char *in,
                               int32 len);
 extern SECStatus PK11_GenerateRandom(unsigned char *data,
                                      int len);
@@ -75,8 +75,8 @@ extern SECStatus PK11_GenerateRandom(unsigned char *data,
 /* use NSS's new generic hash api */
 #define USE_NSS_GEN_HASH
 
-void exitError(char *errstring);
-void exitLDAPError(char *errstring);
+void exitError(const char *errstring);
+void exitLDAPError(const char *errstring);
 void doLDAPBind();
 void doLDAPSearch(LDAPMessage **result);
 void doLDAPUnbind();
@@ -109,7 +109,7 @@ RNGContext *rngc = NULL;
 #define strcasecmp stricmp
 #endif
 
-void exitError(char *errstring) {
+void exitError(const char *errstring) {
     char *errbuf;
   
     errbuf = malloc(strlen(errstring)+strlen(programName)+10);
@@ -120,7 +120,7 @@ void exitError(char *errstring) {
 }
 
 
-void exitLDAPError(char *errstring) {
+void exitLDAPError(const char *errstring) {
     char *ldaperr;
     char newerror[500];
     int err;
@@ -996,19 +996,19 @@ void processSearchResults(LDAPMessage *r) {
 /* this function uses i_minlength and i_maxlength to determine the
    size of the password to generate */
 
-static char *UCalpha = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
+static const char *UCalpha = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
 
 
-static char *LCalpha = "abcdefghijklmnopqrstuvwxyz";
-static char *numbers = "0123456789";
-static char *punc = "!#$%&*+,-./:;<=>?@[]^{|}";
+static const char *LCalpha = "abcdefghijklmnopqrstuvwxyz";
+static const char *numbers = "0123456789";
+static const char *punc = "!#$%&*+,-./:;<=>?@[]^{|}";
 
 static char *charpool = NULL;  /* carpool, geddit? */
 static int charpoolsize;
 
-static char *RNG_ALPHA = "RNG-alpha";
-static char *RNG_PRINTABLEASCII = "RNG-printableascii";
-static char *RNG_ALPHANUM = "RNG-alphanum";
+static const char *RNG_ALPHA = "RNG-alpha";
+static const char *RNG_PRINTABLEASCII = "RNG-printableascii";
+static const char *RNG_ALPHANUM = "RNG-alphanum";
 
 
 /* build the pool of characters we can use for the password */
