@@ -151,7 +151,7 @@ Usage(const char *progName)
 
 
 static void
-errWarn(char * funcString)
+errWarn(const char * funcString)
 {
     PRErrorCode  perr      = PR_GetError();
 
@@ -159,7 +159,7 @@ errWarn(char * funcString)
 }
 
 static void
-errExit(char * funcString)
+errExit(const char * funcString)
 {
     errWarn(funcString);
     exit(1);
