@@ -28,6 +28,9 @@ import java.util.Date;
 import java.util.Enumeration;
 import java.util.Hashtable;
 
+import org.dogtagpki.server.ocsp.OCSPConfig;
+import org.dogtagpki.server.ocsp.OCSPEngine;
+import org.dogtagpki.server.ocsp.OCSPEngineConfig;
 import org.mozilla.jss.CryptoManager;
 import org.mozilla.jss.NotInitializedException;
 import org.mozilla.jss.asn1.ASN1Util;
@@ -89,7 +92,7 @@ public class OCSPAuthority implements IOCSPAuthority, IOCSPService, ISubsystem,
 
     private Hashtable<String, IOCSPStore> mStores = new Hashtable<String, IOCSPStore>();
     private String mId = "ocsp";
-    private IConfigStore mConfig = null;
+    private OCSPConfig mConfig;
     private SigningUnit mSigningUnit;
     private CertificateChain mCertChain = null;
     private X509CertImpl mCert = null;
@@ -104,9 +107,6 @@ public class OCSPAuthority implements IOCSPAuthority, IOCSPService, ISubsystem,
     public long mSignTime = 0;
     public long mLookupTime = 0;
 
-    protected Logger systemLogger = Logger.getLogger(ILogger.EV_SYSTEM, ILogger.S_OCSP);
-    protected Logger transactionLogger = Logger.getLogger(ILogger.EV_AUDIT, ILogger.S_OCSP);
-
     /**
      * Retrieves the name of this subsystem.
      */
@@ -125,15 +125,18 @@ public class OCSPAuthority implements IOCSPAuthority, IOCSPService, ISubsystem,
      * Initializes this subsystem with the given configuration
      * store.
      * <P>
-     *
-     * @param owner owner of this subsystem
      * @param config configuration store
+     *
      * @exception EBaseException failed to initialize
      */
-    public void init(ISubsystem owner, IConfigStore config)
+    public void init(IConfigStore config)
             throws EBaseException {
+
+        OCSPEngine engine = OCSPEngine.getInstance();
+        OCSPEngineConfig engineConfig = engine.getConfig();
+
         try {
-            mConfig = config;
+            mConfig = engineConfig.getOCSPConfig();
 
             initSigUnit();
 
@@ -159,12 +162,15 @@ public class OCSPAuthority implements IOCSPAuthority, IOCSPService, ISubsystem,
                         mDefStore = store;
                     }
                 }
+
             } catch (ClassNotFoundException e) {
-                log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_OCSP_SIGNING_UNIT", e.toString()));
+                logger.warn(CMS.getLogMessage("CMSCORE_OCSP_SIGNING_UNIT", e.toString()), e);
+
             } catch (InstantiationException e) {
-                log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_OCSP_SIGNING_UNIT", e.toString()));
+                logger.warn(CMS.getLogMessage("CMSCORE_OCSP_SIGNING_UNIT", e.toString()), e);
+
             } catch (IllegalAccessException e) {
-                log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_OCSP_SIGNING_UNIT", e.toString()));
+                logger.warn(CMS.getLogMessage("CMSCORE_OCSP_SIGNING_UNIT", e.toString()), e);
             }
 
         } catch (EBaseException e) {
@@ -196,7 +202,7 @@ public class OCSPAuthority implements IOCSPAuthority, IOCSPService, ISubsystem,
         try {
             return mConfig.getString(PROP_STORE + "." + id + ".class", null);
         } catch (EBaseException e) {
-            log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_OCSP_CLASSPATH", id, e.toString()));
+            logger.warn(CMS.getLogMessage("CMSCORE_OCSP_CLASSPATH", id, e.toString()), e);
             return null;
         }
     }
@@ -252,7 +258,7 @@ public class OCSPAuthority implements IOCSPAuthority, IOCSPService, ISubsystem,
         try {
             caPubKey = (X509Key) mCert.get(X509CertImpl.PUBLIC_KEY);
         } catch (CertificateParsingException e) {
-            log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_OCSP_RETRIEVE_KEY", e.toString()));
+            logger.warn(CMS.getLogMessage("CMSCORE_OCSP_RETRIEVE_KEY", e.toString()), e);
         }
         if (caPubKey == null) {
             return null; // something seriously wrong.
@@ -313,16 +319,13 @@ public class OCSPAuthority implements IOCSPAuthority, IOCSPService, ISubsystem,
             logger.debug("in init - got CA name " + mName);
 
         } catch (NotInitializedException e) {
-            log(ILogger.LL_FAILURE,
-                    CMS.getLogMessage("CMSCORE_OCSP_SIGNING", e.toString()));
+            logger.warn(CMS.getLogMessage("CMSCORE_OCSP_SIGNING", e.toString()), e);
+
         } catch (CertificateException e) {
-            logger.warn("OCSPAuthority: " + e.getMessage(), e);
-            log(ILogger.LL_FAILURE,
-                    CMS.getLogMessage("CMSCORE_OCSP_CHAIN", e.toString()));
+            logger.warn(CMS.getLogMessage("CMSCORE_OCSP_CHAIN", e.toString()), e);
+
         } catch (TokenException e) {
-            logger.warn("OCSPAuthority: " + e.getMessage(), e);
-            log(ILogger.LL_FAILURE,
-                    CMS.getLogMessage("CMSCORE_OCSP_CHAIN", e.toString()));
+            logger.warn(CMS.getLogMessage("CMSCORE_OCSP_CHAIN", e.toString()), e);
         }
     }
 
@@ -375,7 +378,7 @@ public class OCSPAuthority implements IOCSPAuthority, IOCSPService, ISubsystem,
      *
      * @return configuration store of this subsystem
      */
-    public IConfigStore getConfigStore() {
+    public OCSPConfig getConfigStore() {
         return mConfig;
     }
 
@@ -383,18 +386,7 @@ public class OCSPAuthority implements IOCSPAuthority, IOCSPService, ISubsystem,
         return mSigningUnit.getDefaultAlgorithm();
     }
 
-    /**
-     * logs a message in the CA area.
-     *
-     * @param level the debug level.
-     * @param msg the message to debug.
-     */
-    public void audit(int level, String msg) {
-        transactionLogger.log(level, msg);
-    }
-
     public void log(int level, String msg) {
-        systemLogger.log(level, msg);
     }
 
     public void setDefaultAlgorithm(String algorithm)
@@ -447,7 +439,7 @@ public class OCSPAuthority implements IOCSPAuthority, IOCSPService, ISubsystem,
             return response;
 
         } catch (Exception e) {
-            log(ILogger.LL_FAILURE, CMS.getLogMessage("CMSCORE_OCSP_SIGN_RESPONSE", e.toString()));
+            logger.error(CMS.getLogMessage("CMSCORE_OCSP_SIGN_RESPONSE", e.toString()), e);
             throw new EBaseException(e);
         }
 
@@ -520,7 +512,7 @@ public class OCSPAuthority implements IOCSPAuthority, IOCSPService, ISubsystem,
      * throws EBaseException
      * {
      * try {
-     * log(ILogger.LL_INFO, "start OCSP request");
+     * logger.info("start OCSP request");
      * TBSRequest tbsReq = request.getTBSRequest();
      *
      * Vector singleResponses = new Vector();
@@ -551,10 +543,10 @@ public class OCSPAuthority implements IOCSPAuthority, IOCSPService, ISubsystem,
      * new ResponseBytes(ResponseBytes.OCSP_BASIC,
      * new OCTET_STRING(ASN1Util.encode(basicRes))));
      *
-     * log(ILogger.LL_INFO, "done OCSP request");
+     * logger.info("done OCSP request");
      * return response;
      * } catch (Exception e) {
-     * log(ILogger.LL_FAILURE, "request processing failure " + e);
+     * logger.warn("request processing failure: " + e.getMessage(), e);
      * return null;
      * }
      * }
