@@ -15,13 +15,12 @@ import org.dogtagpki.server.rest.PKIExceptionMapper;
 import org.dogtagpki.server.rest.SecurityDomainService;
 import org.dogtagpki.server.rest.SelfTestService;
 import org.dogtagpki.server.rest.SessionContextInterceptor;
-import org.dogtagpki.server.rest.SystemCertService;
 import org.dogtagpki.server.rest.UserService;
 
 import com.netscape.certsrv.base.EBaseException;
-import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.apps.CMSEngine;
+import com.netscape.cmscore.apps.EngineConfig;
 
 public class OCSPApplication extends Application {
 
@@ -43,7 +42,7 @@ public class OCSPApplication extends Application {
 
         // security domain
         CMSEngine engine = CMS.getCMSEngine();
-        IConfigStore cs = engine.getConfigStore();
+        EngineConfig cs = engine.getConfig();
         try {
             boolean standalone = cs.getBoolean("ocsp.standalone", false);
             if (standalone) {
@@ -61,9 +60,6 @@ public class OCSPApplication extends Application {
         classes.add(GroupService.class);
         classes.add(UserService.class);
 
-        // system certs
-        classes.add(SystemCertService.class);
-
         // exception mapper
         classes.add(PKIExceptionMapper.class);
 
