@@ -27,6 +27,7 @@ import sys
 
 import pki.cli
 import pki.server
+import pki.server.cli.acme
 import pki.server.cli.audit
 import pki.server.cli.banner
 import pki.server.cli.ca
@@ -49,8 +50,11 @@ import pki.server.cli.tks
 import pki.server.cli.tps
 import pki.server.cli.upgrade
 import pki.server.cli.webapp
+import pki.server.instance
 import pki.util
 
+logger = logging.getLogger(__name__)
+
 
 class PKIServerCLI(pki.cli.CLI):
 
@@ -82,6 +86,7 @@ class PKIServerCLI(pki.cli.CLI):
         self.add_module(pki.server.cli.ocsp.OCSPCLI())
         self.add_module(pki.server.cli.tks.TKSCLI())
         self.add_module(pki.server.cli.tps.TPSCLI())
+        self.add_module(pki.server.cli.acme.ACMECLI())
 
         self.add_module(pki.server.cli.banner.BannerCLI())
         self.add_module(pki.server.cli.db.DBCLI())
@@ -113,18 +118,15 @@ class PKIServerCLI(pki.cli.CLI):
                 'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
         for o, _ in opts:
             if o in ('-v', '--verbose'):
-                self.set_verbose(True)
                 logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--debug':
-                self.set_verbose(True)
-                self.set_debug(True)
                 logging.getLogger().setLevel(logging.DEBUG)
 
             elif o == '--help':
@@ -132,12 +134,11 @@ class PKIServerCLI(pki.cli.CLI):
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option %s', o)
                 self.print_help()
                 sys.exit(1)
 
-        if self.verbose:
-            print('Command: %s' % ' '.join(args))
+        logger.info('Command: %s', ' '.join(args))
 
         super(PKIServerCLI, self).execute(args)
 
@@ -312,6 +313,7 @@ class CreateCLI(pki.cli.CLI):
     def print_help(self):
         print('Usage: pki-server create [OPTIONS] [<instance ID>]')
         print()
+        print('      --with-maven-deps         Install Maven dependencies.')
         print('      --force                   Force creation.')
         print('  -v, --verbose                 Run in verbose mode.')
         print('      --debug                   Run in debug mode.')
@@ -322,19 +324,23 @@ class CreateCLI(pki.cli.CLI):
 
         try:
             opts, args = getopt.gnu_getopt(argv, 'v', [
-                'force',
+                'with-maven-deps', 'force',
                 'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: %s' % e)
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
         instance_name = 'pki-tomcat'
+        with_maven_deps = False
         force = False
 
         for o, _ in opts:
-            if o == '--force':
+            if o == '--with-maven-deps':
+                with_maven_deps = True
+
+            elif o == '--force':
                 force = True
 
             elif o in ('-v', '--verbose'):
@@ -348,22 +354,23 @@ class CreateCLI(pki.cli.CLI):
                 sys.exit()
 
             else:
-                print('ERROR: Unknown option: %s' % o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
         if len(args) > 0:
             instance_name = args[0]
 
-        instance = pki.server.PKIServerFactory.create(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
         if not force and instance.is_valid():
-            print('ERROR: Instance already exists: %s' % instance_name)
+            logger.error('Instance already exists: %s', instance_name)
             sys.exit(1)
 
         logging.info('Creating instance: %s', instance_name)
 
-        instance.create(force)
+        instance.with_maven_deps = with_maven_deps
+        instance.create(force=force)
 
 
 class RemoveCLI(pki.cli.CLI):
@@ -388,7 +395,7 @@ class RemoveCLI(pki.cli.CLI):
                 'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: %s' % e)
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -410,23 +417,23 @@ class RemoveCLI(pki.cli.CLI):
                 sys.exit()
 
             else:
-                print('ERROR: Unknown option: %s' % o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
         if len(args) > 0:
             instance_name = args[0]
 
-        instance = pki.server.PKIServerFactory.create(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
         if not force and not instance.is_valid():
-            print('ERROR: Invalid instance: %s' % instance_name)
+            logger.error('Invalid instance: %s', instance_name)
             sys.exit(1)
 
         logging.info('Removing instance: %s', instance_name)
 
         instance.stop()
-        instance.remove(force)
+        instance.remove(force=force)
 
 
 class StatusCLI(pki.cli.CLI):
@@ -449,7 +456,7 @@ class StatusCLI(pki.cli.CLI):
                 'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: %s' % e)
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -467,17 +474,17 @@ class StatusCLI(pki.cli.CLI):
                 sys.exit()
 
             else:
-                print('ERROR: Unknown option: %s' % o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
         if len(args) > 0:
             instance_name = args[0]
 
-        instance = pki.server.PKIServerFactory.create(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
         if not instance.is_valid():
-            print('ERROR: Invalid instance: %s' % instance_name)
+            logger.error('Invalid instance: %s', instance_name)
             sys.exit(1)
 
         instance.load()
@@ -505,7 +512,7 @@ class StartCLI(pki.cli.CLI):
                 'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: %s' % e)
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -523,17 +530,17 @@ class StartCLI(pki.cli.CLI):
                 sys.exit()
 
             else:
-                print('ERROR: Unknown option: %s' % o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
         if len(args) > 0:
             instance_name = args[0]
 
-        instance = pki.server.PKIServerFactory.create(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
         if not instance.is_valid():
-            print('ERROR: Invalid instance: %s' % instance_name)
+            logger.error('Invalid instance: %s', instance_name)
             sys.exit(1)
 
         if instance.is_active():
@@ -563,7 +570,7 @@ class StopCLI(pki.cli.CLI):
                 'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: %s' % e)
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -581,17 +588,17 @@ class StopCLI(pki.cli.CLI):
                 sys.exit()
 
             else:
-                print('ERROR: Unknown option: %s' % o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
         if len(args) > 0:
             instance_name = args[0]
 
-        instance = pki.server.PKIServerFactory.create(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
         if not instance.is_valid():
-            print('ERROR: Invalid instance: %s' % instance_name)
+            logger.error('Invalid instance: %s', instance_name)
             sys.exit(1)
 
         if not instance.is_active():
@@ -621,7 +628,7 @@ class RestartCLI(pki.cli.CLI):
                 'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: %s' % e)
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -639,17 +646,17 @@ class RestartCLI(pki.cli.CLI):
                 sys.exit()
 
             else:
-                print('ERROR: Unknown option: %s' % o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
         if len(args) > 0:
             instance_name = args[0]
 
-        instance = pki.server.PKIServerFactory.create(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
         if not instance.is_valid():
-            print('ERROR: Invalid instance: %s' % instance_name)
+            logger.error('Invalid instance: %s', instance_name)
             sys.exit(1)
 
         instance.restart()
@@ -664,7 +671,8 @@ class RunCLI(pki.cli.CLI):
         print('Usage: pki-server run [OPTIONS] [<instance ID>]')
         print()
         print('      --as-current-user         Run as current user.')
-        print('      --jdb                     Run with Java Debugger.')
+        print('      --gdb                     Run under the GNU Debugger.')
+        print('      --jdb                     Run under the Java Debugger.')
         print('  -v, --verbose                 Run in verbose mode.')
         print('      --debug                   Run in debug mode.')
         print('      --help                    Show help message.')
@@ -678,18 +686,22 @@ class RunCLI(pki.cli.CLI):
                 'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: %s' % e)
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
         instance_name = 'pki-tomcat'
         as_current_user = False
         jdb = False
+        gdb = False
 
         for o, _ in opts:
             if o == '--as-current-user':
                 as_current_user = True
 
+            elif o == '--gdb':
+                gdb = True
+
             elif o == '--jdb':
                 jdb = True
 
@@ -704,23 +716,23 @@ class RunCLI(pki.cli.CLI):
                 sys.exit()
 
             else:
-                print('ERROR: Unknown option: %s' % o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
         if len(args) > 0:
             instance_name = args[0]
 
-        instance = pki.server.PKIServerFactory.create(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
         if not instance.is_valid():
-            print('ERROR: Invalid instance: %s' % instance_name)
+            logger.error('Invalid instance: %s', instance_name)
             sys.exit(1)
 
         instance.load()
 
         try:
-            instance.run(jdb=jdb, as_current_user=as_current_user)
+            instance.run(gdb=gdb, jdb=jdb, as_current_user=as_current_user)
 
         except KeyboardInterrupt:
             logging.debug('Server stopped')
