@@ -22,6 +22,7 @@ from __future__ import absolute_import
 from __future__ import print_function
 
 import getopt
+import logging
 import os
 import shutil
 import subprocess
@@ -29,6 +30,9 @@ import sys
 import tempfile
 
 import pki.cli
+import pki.server.instance
+
+logger = logging.getLogger(__name__)
 
 
 class AuditCLI(pki.cli.CLI):
@@ -97,6 +101,8 @@ class AuditConfigShowCLI(pki.cli.CLI):
         print('Usage: pki-server %s-audit-config-show [OPTIONS]' % self.parent.parent.name)
         print()
         print('  -i, --instance <instance ID>       Instance ID (default: pki-tomcat).')
+        print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
         print('      --help                         Show help message.')
         print()
 
@@ -104,10 +110,10 @@ class AuditConfigShowCLI(pki.cli.CLI):
         try:
             opts, _ = getopt.gnu_getopt(argv, 'i:v', [
                 'instance=',
-                'verbose', 'help'])
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -117,18 +123,24 @@ class AuditConfigShowCLI(pki.cli.CLI):
             if o in ('-i', '--instance'):
                 instance_name = a
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
+            elif o in ('-v', '--verbose'):
+                logging.getLogger().setLevel(logging.INFO)
+
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
@@ -137,8 +149,8 @@ class AuditConfigShowCLI(pki.cli.CLI):
         subsystem = instance.get_subsystem(subsystem_name)
 
         if not subsystem:
-            print('ERROR: No %s subsystem in instance %s.'
-                  % (subsystem_name.upper(), instance_name))
+            logger.error('No %s subsystem in instance %s.',
+                         subsystem_name.upper(), instance_name)
             sys.exit(1)
 
         AuditCLI.print_audit_config(subsystem)
@@ -164,6 +176,8 @@ class AuditConfigModifyCLI(pki.cli.CLI):
         print('      --expirationTime <time>        Set expiration time (seconds).')
         print('      --logSigning <True|False>      Enable/disable log signing.')
         print('      --signingCert <nickname>       Set signing certificate.')
+        print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
         print('      --help                         Show help message.')
         print()
 
@@ -175,10 +189,10 @@ class AuditConfigModifyCLI(pki.cli.CLI):
                 'logFile=', 'bufferSize=', 'flushInterval=',
                 'maxFileSize=', 'rolloverInterval=', 'expirationTime=',
                 'logSigning=', 'signingCert=',
-                'verbose', 'help'])
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -238,18 +252,24 @@ class AuditConfigModifyCLI(pki.cli.CLI):
             elif o == '--signingCert':
                 signingCert = a
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
+            elif o in ('-v', '--verbose'):
+                logging.getLogger().setLevel(logging.INFO)
+
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
@@ -258,8 +278,8 @@ class AuditConfigModifyCLI(pki.cli.CLI):
         subsystem = instance.get_subsystem(subsystem_name)
 
         if not subsystem:
-            print('ERROR: No %s subsystem in instance %s.'
-                  % (subsystem_name.upper(), instance_name))
+            logger.error('No %s subsystem in instance %s.',
+                         subsystem_name.upper(), instance_name)
             sys.exit(1)
 
         name = 'log.instance.SignedAudit.%s'
@@ -315,10 +335,18 @@ class AuditEventFindCLI(pki.cli.CLI):
     def print_help(self):
         print('Usage: pki-server %s-audit-event-find [OPTIONS]' % self.parent.parent.name)
         print()
-        print('  -i, --instance <instance ID>       Instance ID (default: pki-tomcat).')
-        print('      --enabled <True|False>         Show enabled/disabled events only.')
-        print('  -v, --verbose                      Run in verbose mode.')
-        print('      --help                         Show help message.')
+        print('  -i, --instance <instance ID>       '
+              '  Instance ID (default: pki-tomcat).')
+        print('      --enabled <True|False>         '
+              '  Show events currently enabled/disabled only.')
+        print('      --enabledByDefault <True|False>'
+              '  Show events enabled/disabled by default only.')
+        print('  -v, --verbose                      '
+              '  Run in verbose mode.')
+        print('      --debug                        '
+              '  Run in debug mode.')
+        print('      --help                         '
+              '  Show help message.')
         print()
 
     def execute(self, argv):
@@ -326,16 +354,17 @@ class AuditEventFindCLI(pki.cli.CLI):
         try:
             opts, _ = getopt.gnu_getopt(argv, 'i:v', [
                 'instance=',
-                'enabled=',
-                'verbose', 'help'])
+                'enabled=', 'enabledByDefault=',
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
         instance_name = 'pki-tomcat'
         enabled = None
+        enabled_by_default = None
 
         for o, a in opts:
             if o in ('-i', '--instance'):
@@ -344,21 +373,27 @@ class AuditEventFindCLI(pki.cli.CLI):
             elif o == '--enabled':
                 enabled = a == 'True'
 
+            elif o == '--enabledByDefault':
+                enabled_by_default = a == 'True'
+
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
@@ -366,11 +401,11 @@ class AuditEventFindCLI(pki.cli.CLI):
         subsystem_name = self.parent.parent.name
         subsystem = instance.get_subsystem(subsystem_name)
         if not subsystem:
-            print('ERROR: No %s subsystem in instance %s.'
-                  % (subsystem_name.upper(), instance_name))
+            logger.error('No %s subsystem in instance %s.',
+                         subsystem_name.upper(), instance_name)
             sys.exit(1)
 
-        events = subsystem.find_audit_event_configs(enabled)
+        events = subsystem.find_audit_event_configs(enabled, enabled_by_default)
 
         self.print_message('%s entries matched' % len(events))
 
@@ -400,6 +435,7 @@ class AuditEventShowCLI(pki.cli.CLI):
         print()
         print('  -i, --instance <instance ID>       Instance ID (default: pki-tomcat).')
         print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
         print('      --help                         Show help message.')
         print()
 
@@ -408,10 +444,10 @@ class AuditEventShowCLI(pki.cli.CLI):
         try:
             opts, args = getopt.gnu_getopt(argv, 'i:v', [
                 'instance=',
-                'verbose', 'help'])
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -421,15 +457,18 @@ class AuditEventShowCLI(pki.cli.CLI):
             if o in ('-i', '--instance'):
                 instance_name = a
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
@@ -441,9 +480,9 @@ class AuditEventShowCLI(pki.cli.CLI):
 
         event_name = args[0]
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
@@ -452,8 +491,8 @@ class AuditEventShowCLI(pki.cli.CLI):
         subsystem = instance.get_subsystem(subsystem_name)
 
         if not subsystem:
-            print('ERROR: No %s subsystem in instance %s.'
-                  % (subsystem_name.upper(), instance_name))
+            logger.error('No %s subsystem in instance %s.',
+                         subsystem_name.upper(), instance_name)
             sys.exit(1)
 
         event = subsystem.get_audit_event_config(event_name)
@@ -474,6 +513,7 @@ class AuditEventEnableCLI(pki.cli.CLI):
         print()
         print('  -i, --instance <instance ID>       Instance ID (default: pki-tomcat).')
         print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
         print('      --help                         Show help message.')
         print()
 
@@ -481,10 +521,11 @@ class AuditEventEnableCLI(pki.cli.CLI):
 
         try:
             opts, args = getopt.gnu_getopt(argv, 'i:v', [
-                'instance=', 'verbose', 'help'])
+                'instance=',
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -494,15 +535,18 @@ class AuditEventEnableCLI(pki.cli.CLI):
             if o in ('-i', '--instance'):
                 instance_name = a
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
@@ -512,9 +556,9 @@ class AuditEventEnableCLI(pki.cli.CLI):
             raise getopt.GetoptError("Too many arguments specified.")
         event_name = args[0]
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
@@ -522,8 +566,8 @@ class AuditEventEnableCLI(pki.cli.CLI):
         subsystem_name = self.parent.parent.name
         subsystem = instance.get_subsystem(subsystem_name)
         if not subsystem:
-            print('ERROR: No %s subsystem in instance %s.'
-                  % (subsystem_name.upper(), instance_name))
+            logger.error('No %s subsystem in instance %s.',
+                         subsystem_name.upper(), instance_name)
             sys.exit(1)
 
         enabled = subsystem.enable_audit_event(event_name)
@@ -559,18 +603,19 @@ class AuditEventUpdateCLI(pki.cli.CLI):
         print('  -i, --instance <instance ID>       Instance ID (default: pki-tomcat).')
         print('  -f, --filter <event filter>        Event Filter (Ex: (Outcome=Failure)).')
         print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
         print('      --help                         Show help message.')
         print()
 
     def execute(self, argv):
 
         try:
-            opts, args = getopt.gnu_getopt(argv, 'i:f:v',
-                                           ['instance=', 'filter=', 'verbose',
-                                            'help'])
+            opts, args = getopt.gnu_getopt(argv, 'i:f:v', [
+                'instance=', 'filter=',
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -584,15 +629,18 @@ class AuditEventUpdateCLI(pki.cli.CLI):
             elif o in ('-f', '--filter'):
                 event_filter = a
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
@@ -603,9 +651,9 @@ class AuditEventUpdateCLI(pki.cli.CLI):
 
         event_name = args[0]
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
@@ -613,8 +661,8 @@ class AuditEventUpdateCLI(pki.cli.CLI):
         subsystem_name = self.parent.parent.name
         subsystem = instance.get_subsystem(subsystem_name)
         if not subsystem:
-            print('ERROR: No %s subsystem in instance %s.'
-                  % (subsystem_name.upper(), instance_name))
+            logger.error('No %s subsystem in instance %s.',
+                         subsystem_name.upper(), instance_name)
             sys.exit(1)
 
         subsystem.update_audit_event_filter(event_name, event_filter)
@@ -638,6 +686,7 @@ class AuditEventDisableCLI(pki.cli.CLI):
         print()
         print('  -i, --instance <instance ID>       Instance ID (default: pki-tomcat).')
         print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
         print('      --help                         Show help message.')
         print()
 
@@ -645,10 +694,11 @@ class AuditEventDisableCLI(pki.cli.CLI):
 
         try:
             opts, args = getopt.gnu_getopt(argv, 'i:v', [
-                'instance=', 'verbose', 'help'])
+                'instance=',
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -658,15 +708,18 @@ class AuditEventDisableCLI(pki.cli.CLI):
             if o in ('-i', '--instance'):
                 instance_name = a
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
@@ -677,9 +730,9 @@ class AuditEventDisableCLI(pki.cli.CLI):
 
         event_name = args[0]
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
@@ -687,8 +740,8 @@ class AuditEventDisableCLI(pki.cli.CLI):
         subsystem_name = self.parent.parent.name
         subsystem = instance.get_subsystem(subsystem_name)
         if not subsystem:
-            print('ERROR: No %s subsystem in instance %s.'
-                  % (subsystem_name.upper(), instance_name))
+            logger.error('No %s subsystem in instance %s.',
+                         subsystem_name.upper(), instance_name)
             sys.exit(1)
 
         disable = subsystem.disable_audit_event(event_name)
@@ -722,6 +775,7 @@ class AuditFileFindCLI(pki.cli.CLI):
         print()
         print('  -i, --instance <instance ID>       Instance ID (default: pki-tomcat).')
         print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
         print('      --help                         Show help message.')
         print()
 
@@ -730,10 +784,10 @@ class AuditFileFindCLI(pki.cli.CLI):
         try:
             opts, _ = getopt.gnu_getopt(argv, 'i:v', [
                 'instance=',
-                'verbose', 'help'])
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -743,21 +797,24 @@ class AuditFileFindCLI(pki.cli.CLI):
             if o in ('-i', '--instance'):
                 instance_name = a
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
@@ -765,8 +822,8 @@ class AuditFileFindCLI(pki.cli.CLI):
         subsystem_name = self.parent.parent.name
         subsystem = instance.get_subsystem(subsystem_name)
         if not subsystem:
-            print('ERROR: No %s subsystem in instance %s.'
-                  % (subsystem_name.upper(), instance_name))
+            logger.error('No %s subsystem in instance %s.',
+                         subsystem_name.upper(), instance_name)
             sys.exit(1)
 
         log_files = subsystem.get_audit_log_files()
@@ -796,6 +853,7 @@ class AuditFileVerifyCLI(pki.cli.CLI):
         print()
         print('  -i, --instance <instance ID>       Instance ID (default: pki-tomcat).')
         print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
         print('      --help                         Show help message.')
         print()
 
@@ -804,10 +862,10 @@ class AuditFileVerifyCLI(pki.cli.CLI):
         try:
             opts, _ = getopt.gnu_getopt(argv, 'i:v', [
                 'instance=',
-                'verbose', 'help'])
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -817,21 +875,24 @@ class AuditFileVerifyCLI(pki.cli.CLI):
             if o in ('-i', '--instance'):
                 instance_name = a
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
@@ -839,8 +900,8 @@ class AuditFileVerifyCLI(pki.cli.CLI):
         subsystem_name = self.parent.parent.name
         subsystem = instance.get_subsystem(subsystem_name)
         if not subsystem:
-            print('ERROR: No %s subsystem in instance %s.'
-                  % (subsystem_name.upper(), instance_name))
+            logger.error('No %s subsystem in instance %s.',
+                         subsystem_name.upper(), instance_name)
             sys.exit(1)
 
         log_dir = subsystem.get_audit_log_dir()
@@ -858,7 +919,7 @@ class AuditFileVerifyCLI(pki.cli.CLI):
 
             cmd = ['AuditVerify']
 
-            if self.verbose:
+            if logger.isEnabledFor(logging.INFO):
                 cmd.append('-v')
 
             cmd.extend([
@@ -866,7 +927,7 @@ class AuditFileVerifyCLI(pki.cli.CLI):
                 '-n', signing_cert['nickname'],
                 '-a', file_list])
 
-            if self.verbose:
+            if logger.isEnabledFor(logging.INFO):
                 print('Command: %s' % ' '.join(cmd))
 
             subprocess.call(cmd)
