@@ -25,6 +25,7 @@ import logging
 import sys
 
 import pki.cli
+import pki.server.instance
 
 
 class SubsystemConfigCLI(pki.cli.CLI):
@@ -81,7 +82,7 @@ class SubsystemConfigFindCLI(pki.cli.CLI):
                 self.print_help()
                 sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
         if not instance.is_valid():
             logging.error('Invalid instance: %s', instance_name)
             sys.exit(1)
@@ -149,7 +150,7 @@ class SubsystemConfigShowCLI(pki.cli.CLI):
 
         name = args[0]
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
         if not instance.is_valid():
             logging.error('Invalid instance: %s', instance_name)
             sys.exit(1)
@@ -228,7 +229,7 @@ class SubsystemConfigSetCLI(pki.cli.CLI):
         name = args[0]
         value = args[1]
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
         if not instance.is_valid():
             logging.error('Invalid instance: %s', instance_name)
             sys.exit(1)
@@ -296,7 +297,7 @@ class SubsystemConfigUnsetCLI(pki.cli.CLI):
 
         name = args[0]
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
         if not instance.is_valid():
             logging.error('Invalid instance: %s', instance_name)
             sys.exit(1)
