@@ -21,53 +21,55 @@
 from __future__ import absolute_import
 from __future__ import print_function
 import getopt
-import ldap
 import logging
-import nss.nss as nss
 import subprocess
 import sys
 import getpass
 
 import pki.cli
+import pki.server.instance
+
+logger = logging.getLogger(__name__)
 
 
 class DBCLI(pki.cli.CLI):
 
     def __init__(self):
         super(DBCLI, self).__init__(
-            'db', 'DB management commands')
+            'db', 'Database management commands')
 
-        self.add_module(DBUpgrade())
-        self.add_module(DBSchemaUpgrade())
+        self.add_module(DBUpgradeCLI())
+        self.add_module(DBSchemaUpgradeCLI())
 
 
-class DBSchemaUpgrade(pki.cli.CLI):
+class DBSchemaUpgradeCLI(pki.cli.CLI):
 
     SCHEMA_PATH = '/usr/share/pki/server/conf/schema.ldif'
 
     def __init__(self):
-        super(DBSchemaUpgrade, self).__init__(
+        super(DBSchemaUpgradeCLI, self).__init__(
             'schema-upgrade', 'Upgrade PKI database schema')
 
-    def usage(self):
+    def print_help(self):
         print('Usage: pki-server db-schema-upgrade [OPTIONS]')
         print()
         print('  -i, --instance <instance ID>       Instance ID (default: pki-tomcat).')
         print('  -D, --bind-dn <Bind DN>            Connect DN (default: cn=Directory Manager).')
         print('  -w, --bind-password <password>     Password to connect to DB.')
         print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
         print('      --help                         Show help message.')
         print()
 
     def execute(self, argv):
         try:
-            opts, _ = getopt.gnu_getopt(
-                argv, 'i:D:w:v', ['instance=', 'bind-dn=', 'bind-password=',
-                                  'verbose', 'help'])
+            opts, _ = getopt.gnu_getopt(argv, 'i:D:w:v', [
+                'instance=', 'bind-dn=', 'bind-password=',
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
-            self.usage()
+            logger.error(e)
+            self.print_help()
             sys.exit(1)
 
         instance_name = 'pki-tomcat'
@@ -85,25 +87,28 @@ class DBSchemaUpgrade(pki.cli.CLI):
                 bind_password = a
 
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
+
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
 
             elif o == '--help':
-                self.usage()
+                self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
-                self.usage()
+                logger.error('Invalid option: %s', o)
+                self.print_help()
                 sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
         if not instance.is_valid():
-            print("ERROR: Invalid instance %s." % instance_name)
+            logger.error('Invalid instance: %s', instance_name)
             sys.exit(1)
         instance.load()
 
         if not instance.subsystems:
-            print("ERROR: No subsystem in instance %s." % instance_name)
+            logger.error('No subsystem in instance %s', instance_name)
             sys.exit(1)
 
         if not bind_password:
@@ -113,12 +118,15 @@ class DBSchemaUpgrade(pki.cli.CLI):
             self.update_schema(instance.subsystems[0], bind_dn, bind_password)
 
         except subprocess.CalledProcessError as e:
-            print("ERROR: " + e.output)
-            sys.exit(e.returncode)
+            logger.error('Unable to update schema: %s', e)
+            raise e
 
         self.print_message('Upgrade complete')
 
     def update_schema(self, subsystem, bind_dn, bind_password):
+
+        logger.info('Updating schema with %s', self.SCHEMA_PATH)
+
         # TODO(alee) re-implement this using open_database
         host = subsystem.config['internaldb.ldapconn.host']
         port = subsystem.config['internaldb.ldapconn.port']
@@ -138,101 +146,81 @@ class DBSchemaUpgrade(pki.cli.CLI):
         subprocess.check_output(cmd, stderr=subprocess.STDOUT)
 
 
-class DBUpgrade(pki.cli.CLI):
-    def __init__(self):
-        super(DBUpgrade, self).__init__(
-            'upgrade', 'Upgrade PKI server database')
+class DBUpgradeCLI(pki.cli.CLI):
 
-    def usage(self):
+    def __init__(self):
+        super(DBUpgradeCLI, self).__init__('upgrade', 'Upgrade PKI server database')
+
+    def print_help(self):
         print('Usage: pki-server db-upgrade [OPTIONS]')
         print()
         print('  -i, --instance <instance ID>       Instance ID (default: pki-tomcat).')
+        print('      --as-current-user              Run as current user.')
         print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
         print('      --help                         Show help message.')
         print()
 
     def execute(self, argv):
         try:
-            opts, _ = getopt.gnu_getopt(
-                argv, 'i:v', ['instance=', 'verbose', 'help'])
+            opts, _ = getopt.gnu_getopt(argv, 'i:v', [
+                'instance=',
+                'as-current-user',
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
-            self.usage()
+            logger.error(e)
+            self.print_help()
             sys.exit(1)
 
         instance_name = 'pki-tomcat'
+        as_current_user = False
+        verbose = False
+        debug = False
 
         for o, a in opts:
             if o in ('-i', '--instance'):
                 instance_name = a
 
+            elif o == '--as-current-user':
+                as_current_user = True
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
+                verbose = True
+
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+                debug = True
 
             elif o == '--help':
-                self.usage()
+                self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
-                self.usage()
+                logger.error('Invalid option: %s', o)
+                self.print_help()
                 sys.exit(1)
 
-        nss.nss_init_nodb()
+        instance = pki.server.instance.PKIInstance(instance_name)
 
-        instance = pki.server.PKIInstance(instance_name)
         if not instance.is_valid():
-            print("ERROR: Invalid instance %s." % instance_name)
+            logger.error('Invalid instance: %s', instance_name)
             sys.exit(1)
+
         instance.load()
 
-        subsystem = instance.get_subsystem('ca')
-        if not subsystem:
-            print('ERROR: No CA subsystem in instance %s.' % instance_name)
-            sys.exit(1)
+        # upgrade all subsystems
+        for subsystem in instance.subsystems:
 
-        base_dn = subsystem.config['internaldb.basedn']
-        conn = subsystem.open_database()
+            cmd = [subsystem.name + '-db-upgrade']
 
-        try:
-            repo_dn = 'ou=certificateRepository,ou=ca,%s' % base_dn
-            if self.verbose:
-                print('Searching certificates records with missing issuerName in %s' % repo_dn)
+            if verbose:
+                cmd.append('--verbose')
+            elif debug:
+                cmd.append('--debug')
 
-            entries = conn.ldap.search_s(
-                repo_dn,
-                ldap.SCOPE_ONELEVEL,
-                '(&(objectclass=certificaterecord)(|(!(issuername=*))(issuername=)))',
-                None)
-
-            for entry in entries:
-                self.add_issuer_name(conn, entry)
-
-        finally:
-            conn.close()
-
-        self.print_message('Upgrade complete')
-
-    def add_issuer_name(self, conn, entry):
-        dn, attrs = entry
-
-        if self.verbose:
-            print('Fixing certificate record %s' % dn)
-
-        attr_cert = attrs.get('userCertificate;binary')
-        if not attr_cert:
-            return  # shouldn't happen, but nothing we can do if it does
-
-        cert = nss.Certificate(bytearray(attr_cert[0]))
-        issuer_name = str(cert.issuer)
-
-        try:
-            conn.ldap.modify_s(dn, [(ldap.MOD_REPLACE, 'issuerName', issuer_name)])
-        except ldap.LDAPError as e:
-            print(
-                'Failed to add issuerName to certificate {}: {}'
-                .format(attrs.get('cn', ['<unknown>'])[0], e))
+            subsystem.run(cmd, as_current_user=as_current_user)
 
 
 class SubsystemDBCLI(pki.cli.CLI):
@@ -245,6 +233,9 @@ class SubsystemDBCLI(pki.cli.CLI):
         self.parent = parent
         self.add_module(SubsystemDBConfigCLI(self))
         self.add_module(SubsystemDBInfoCLI(self))
+        self.add_module(SubsystemDBEmptyCLI(self))
+        self.add_module(SubsystemDBRemoveCLI(self))
+        self.add_module(SubsystemDBUpgradeCLI(self))
 
     @staticmethod
     def print_config(subsystem):
@@ -315,6 +306,8 @@ class SubsystemDBConfigShowCLI(pki.cli.CLI):
         print('Usage: pki-server %s-db-config-show [OPTIONS]' % self.parent.parent.parent.name)
         print()
         print('  -i, --instance <instance ID>       Instance ID (default: pki-tomcat).')
+        print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
         print('      --help                         Show help message.')
         print()
 
@@ -322,10 +315,10 @@ class SubsystemDBConfigShowCLI(pki.cli.CLI):
         try:
             opts, _ = getopt.gnu_getopt(argv, 'i:v', [
                 'instance=',
-                'verbose', 'help'])
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -335,18 +328,24 @@ class SubsystemDBConfigShowCLI(pki.cli.CLI):
             if o in ('-i', '--instance'):
                 instance_name = a
 
+            elif o in ('-v', '--verbose'):
+                logging.getLogger().setLevel(logging.INFO)
+
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Invalid option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance: %s', instance_name)
             sys.exit(1)
 
         instance.load()
@@ -355,8 +354,8 @@ class SubsystemDBConfigShowCLI(pki.cli.CLI):
         subsystem = instance.get_subsystem(subsystem_name)
 
         if not subsystem:
-            print('ERROR: No %s subsystem in instance %s.'
-                  % (subsystem_name.upper(), instance_name))
+            logger.error('No %s subsystem in instance %s.',
+                         subsystem_name.upper(), instance_name)
             sys.exit(1)
 
         SubsystemDBCLI.print_config(subsystem)
@@ -388,6 +387,8 @@ class SubsystemDBConfigModifyCLI(pki.cli.CLI):
         print('      --multiSuffix <True|False>     Set multiple suffix.')
         print('      --maxConns <max connections>   Set maximum connections.')
         print('      --minConns <min connections>   Set minimum connections.')
+        print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
         print('      --help                         Show help message.')
         print()
 
@@ -400,10 +401,10 @@ class SubsystemDBConfigModifyCLI(pki.cli.CLI):
                 'nickname=',
                 'database=', 'baseDN=', 'multiSuffix=',
                 'maxConns=', 'minConns=',
-                'verbose', 'help'])
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -473,18 +474,24 @@ class SubsystemDBConfigModifyCLI(pki.cli.CLI):
                     raise ValueError('Invalid input: %s accepts a number' % o)
                 minConns = a
 
+            elif o in ('-v', '--verbose'):
+                logging.getLogger().setLevel(logging.INFO)
+
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Invalid option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance: %s', instance_name)
             sys.exit(1)
 
         instance.load()
@@ -493,8 +500,8 @@ class SubsystemDBConfigModifyCLI(pki.cli.CLI):
         subsystem = instance.get_subsystem(subsystem_name)
 
         if not subsystem:
-            print('ERROR: No %s subsystem in instance %s.'
-                  % (subsystem_name.upper(), instance_name))
+            logger.error('No %s subsystem in instance %s',
+                         subsystem_name.upper(), instance_name)
             sys.exit(1)
 
         name = 'internaldb.%s'
@@ -573,7 +580,7 @@ class SubsystemDBInfoCLI(pki.cli.CLI):
                 'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: %s' % e)
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -603,13 +610,13 @@ class SubsystemDBInfoCLI(pki.cli.CLI):
                 sys.exit()
 
             else:
-                print('ERROR: unknown option %s' % o)
+                logger.error('Invalid option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance: %s', instance_name)
             sys.exit(1)
 
         instance.load()
@@ -617,8 +624,249 @@ class SubsystemDBInfoCLI(pki.cli.CLI):
         subsystem = instance.get_subsystem(subsystem_name)
 
         if not subsystem:
-            print('ERROR: No %s subsystem in instance %s.'
-                  % (subsystem_name.upper(), instance_name))
+            logger.error('No %s subsystem in instance %s',
+                         subsystem_name.upper(), instance_name)
+            sys.exit(1)
+
+        subsystem.run(cmd, as_current_user=as_current_user)
+
+
+class SubsystemDBEmptyCLI(pki.cli.CLI):
+
+    def __init__(self, parent):
+        super(SubsystemDBEmptyCLI, self).__init__(
+            'empty',
+            'Empty %s database' % parent.parent.name.upper())
+
+        self.parent = parent
+
+    def print_help(self):
+        print('Usage: pki-server %s-db-empty [OPTIONS]' % self.parent.parent.name)
+        print()
+        print('  -i, --instance <instance ID>       Instance ID (default: pki-tomcat).')
+        print('      --force                        Force database removal.')
+        print('      --as-current-user              Run as current user.')
+        print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
+        print('      --help                         Show help message.')
+        print()
+
+    def execute(self, argv):
+        try:
+            opts, _ = getopt.gnu_getopt(argv, 'i:v', [
+                'instance=',
+                'force', 'as-current-user',
+                'verbose', 'debug', 'help'])
+
+        except getopt.GetoptError as e:
+            logger.error(e)
+            self.print_help()
+            sys.exit(1)
+
+        instance_name = 'pki-tomcat'
+        subsystem_name = self.parent.parent.name
+        force = False
+        as_current_user = False
+
+        for o, a in opts:
+            if o in ('-i', '--instance'):
+                instance_name = a
+
+            elif o == '--force':
+                force = True
+
+            elif o == '--as-current-user':
+                as_current_user = True
+
+            elif o in ('-v', '--verbose'):
+                logging.getLogger().setLevel(logging.INFO)
+
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
+            elif o == '--help':
+                self.print_help()
+                sys.exit()
+
+            else:
+                logger.error('Invalid option: %s', o)
+                self.print_help()
+                sys.exit(1)
+
+        instance = pki.server.instance.PKIInstance(instance_name)
+        if not instance.is_valid():
+            logger.error('Invalid instance: %s', instance_name)
+            sys.exit(1)
+
+        instance.load()
+
+        subsystem = instance.get_subsystem(subsystem_name)
+
+        if not subsystem:
+            logger.error('No %s subsystem in instance %s',
+                         subsystem_name.upper(), instance_name)
+            sys.exit(1)
+
+        subsystem.empty_database(
+            force=force,
+            as_current_user=as_current_user)
+
+
+class SubsystemDBRemoveCLI(pki.cli.CLI):
+
+    def __init__(self, parent):
+        super(SubsystemDBRemoveCLI, self).__init__(
+            'remove',
+            'Remove %s database' % parent.parent.name.upper())
+
+        self.parent = parent
+
+    def print_help(self):
+        print('Usage: pki-server %s-db-remove [OPTIONS]' % self.parent.parent.name)
+        print()
+        print('  -i, --instance <instance ID>       Instance ID (default: pki-tomcat).')
+        print('      --force                        Force database removal.')
+        print('      --as-current-user              Run as current user.')
+        print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
+        print('      --help                         Show help message.')
+        print()
+
+    def execute(self, argv):
+        try:
+            opts, _ = getopt.gnu_getopt(argv, 'i:v', [
+                'instance=',
+                'force', 'as-current-user',
+                'verbose', 'debug', 'help'])
+
+        except getopt.GetoptError as e:
+            logger.error(e)
+            self.print_help()
+            sys.exit(1)
+
+        instance_name = 'pki-tomcat'
+        subsystem_name = self.parent.parent.name
+        force = False
+        as_current_user = False
+
+        for o, a in opts:
+            if o in ('-i', '--instance'):
+                instance_name = a
+
+            elif o == '--force':
+                force = True
+
+            elif o == '--as-current-user':
+                as_current_user = True
+
+            elif o in ('-v', '--verbose'):
+                logging.getLogger().setLevel(logging.INFO)
+
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
+            elif o == '--help':
+                self.print_help()
+                sys.exit()
+
+            else:
+                logger.error('Invalid option: %s', o)
+                self.print_help()
+                sys.exit(1)
+
+        instance = pki.server.instance.PKIInstance(instance_name)
+        if not instance.is_valid():
+            logger.error('Invalid instance: %s', instance_name)
+            sys.exit(1)
+
+        instance.load()
+
+        subsystem = instance.get_subsystem(subsystem_name)
+
+        if not subsystem:
+            logger.error('No %s subsystem in instance %s',
+                         subsystem_name.upper(), instance_name)
+            sys.exit(1)
+
+        subsystem.remove_database(
+            force=force,
+            as_current_user=as_current_user)
+
+
+class SubsystemDBUpgradeCLI(pki.cli.CLI):
+
+    def __init__(self, parent):
+        super(SubsystemDBUpgradeCLI, self).__init__(
+            'upgrade',
+            'Upgrade %s database' % parent.parent.name.upper())
+
+        self.parent = parent
+
+    def print_help(self):
+        print('Usage: pki-server %s-db-upgrade [OPTIONS]' % self.parent.parent.name)
+        print()
+        print('  -i, --instance <instance ID>       Instance ID (default: pki-tomcat).')
+        print('      --as-current-user              Run as current user.')
+        print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
+        print('      --help                         Show help message.')
+        print()
+
+    def execute(self, argv):
+        try:
+            opts, _ = getopt.gnu_getopt(argv, 'i:v', [
+                'instance=',
+                'as-current-user',
+                'verbose', 'debug', 'help'])
+
+        except getopt.GetoptError as e:
+            logging.error(e)
+            self.print_help()
+            sys.exit(1)
+
+        instance_name = 'pki-tomcat'
+        subsystem_name = self.parent.parent.name
+        as_current_user = False
+
+        cmd = [subsystem_name + '-db-upgrade']
+
+        for o, a in opts:
+            if o in ('-i', '--instance'):
+                instance_name = a
+
+            elif o == '--as-current-user':
+                as_current_user = True
+
+            elif o in ('-v', '--verbose'):
+                logging.getLogger().setLevel(logging.INFO)
+                cmd.append('--verbose')
+
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+                cmd.append('--debug')
+
+            elif o == '--help':
+                self.print_help()
+                sys.exit()
+
+            else:
+                logging.error('Invalid option: %s', o)
+                self.print_help()
+                sys.exit(1)
+
+        instance = pki.server.instance.PKIInstance(instance_name)
+
+        if not instance.is_valid():
+            logging.error('Invalid instance: %s', instance_name)
+            sys.exit(1)
+
+        instance.load()
+
+        subsystem = instance.get_subsystem(subsystem_name)
+
+        if not subsystem:
+            logging.error('No %s subsystem in instance %s.',
+                          subsystem_name.upper(), instance_name)
             sys.exit(1)
 
         subsystem.run(cmd, as_current_user=as_current_user)
