@@ -28,6 +28,7 @@ import pki.cli
 import pki.nssdb
 import pki.server
 import pki.server.cli.nuxwdog
+import pki.server.instance
 
 
 class HTTPCLI(pki.cli.CLI):
@@ -205,7 +206,7 @@ class HTTPConnectorAddCLI(pki.cli.CLI):
 
         name = args[0]
 
-        instance = pki.server.PKIServerFactory.create(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
         if not instance.is_valid():
             print('ERROR: invalid instance: %s' % instance_name)
@@ -295,7 +296,7 @@ class HTTPConnectorDeleteCLI(pki.cli.CLI):
 
         name = args[0]
 
-        instance = pki.server.PKIServerFactory.create(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
         if not instance.is_valid():
             print('ERROR: Invalid instance: %s' % instance_name)
@@ -355,7 +356,7 @@ class HTTPConnectorFindCLI(pki.cli.CLI):
                 self.print_help()
                 sys.exit(1)
 
-        instance = pki.server.PKIServerFactory.create(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
         if not instance.is_valid():
             print('ERROR: Invalid instance: %s' % instance_name)
@@ -433,7 +434,7 @@ class HTTPConnectorShowCLI(pki.cli.CLI):
 
         name = args[0]
 
-        instance = pki.server.PKIServerFactory.create(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
         if not instance.is_valid():
             print('ERROR: Invalid instance: %s' % instance_name)
@@ -566,7 +567,7 @@ class HTTPConnectorModCLI(pki.cli.CLI):
 
         name = args[0]
 
-        instance = pki.server.PKIServerFactory.create(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
         if not instance.is_valid():
             print('ERROR: invalid instance: %s' % instance_name)
@@ -733,7 +734,7 @@ class SSLHostAddCLI(pki.cli.CLI):
 
         hostname = args[1]
 
-        instance = pki.server.PKIServerFactory.create(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
         if not instance.is_valid():
             print('ERROR: invalid instance: %s' % instance_name)
@@ -818,7 +819,7 @@ class SSLHostDeleteCLI(pki.cli.CLI):
 
         hostname = args[1]
 
-        instance = pki.server.PKIServerFactory.create(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
         if not instance.is_valid():
             print('ERROR: Invalid instance: %s' % instance_name)
@@ -885,7 +886,7 @@ class SSLHostFindCLI(pki.cli.CLI):
 
         connector_name = args[0]
 
-        instance = pki.server.PKIServerFactory.create(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
         if not instance.is_valid():
             print('ERROR: Invalid instance: %s' % instance_name)
@@ -1041,7 +1042,7 @@ class SSLCertAddCLI(pki.cli.CLI):
         else:
             certType = args[0]
 
-        instance = pki.server.PKIServerFactory.create(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
         if not instance.is_valid():
             print('ERROR: invalid instance: %s' % instance_name)
@@ -1138,7 +1139,7 @@ class SSLCertDeleteCLI(pki.cli.CLI):
         else:
             certType = args[0]
 
-        instance = pki.server.PKIServerFactory.create(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
         if not instance.is_valid():
             print('ERROR: Invalid instance: %s' % instance_name)
@@ -1214,7 +1215,7 @@ class SSLCertFindLI(pki.cli.CLI):
                 self.print_help()
                 sys.exit(1)
 
-        instance = pki.server.PKIServerFactory.create(instance_name)
+        instance = pki.server.instance.PKIServerFactory.create(instance_name)
 
         if not instance.is_valid():
             print('ERROR: Invalid instance: %s' % instance_name)
