@@ -20,8 +20,10 @@
 
 from __future__ import absolute_import
 from __future__ import print_function
+
 import getopt
 import getpass
+import logging
 import os
 import sys
 
@@ -29,8 +31,11 @@ import pki.cli
 import pki.nssdb
 import pki.server
 import pki.server.cli.nuxwdog
+import pki.server.instance
 import pki.util
 
+logger = logging.getLogger(__name__)
+
 
 class InstanceCLI(pki.cli.CLI):
 
@@ -98,7 +103,7 @@ class InstanceCertExportCLI(pki.cli.CLI):
                 'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -112,7 +117,6 @@ class InstanceCertExportCLI(pki.cli.CLI):
         include_trust_flags = True
         include_key = True
         include_chain = True
-        debug = False
 
         for o, a in opts:
             if o in ('-i', '--instance'):
@@ -139,30 +143,30 @@ class InstanceCertExportCLI(pki.cli.CLI):
             elif o == '--no-chain':
                 include_chain = False
 
-            elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
-
             elif o == '--debug':
-                debug = True
+                logging.getLogger().setLevel(logging.DEBUG)
+
+            elif o in ('-v', '--verbose'):
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
         if not pkcs12_file:
-            print('ERROR: missing output file')
+            logger.error('missing output file')
             self.print_help()
             sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
 
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
@@ -180,8 +184,7 @@ class InstanceCertExportCLI(pki.cli.CLI):
                 append=append,
                 include_trust_flags=include_trust_flags,
                 include_key=include_key,
-                include_chain=include_chain,
-                debug=debug)
+                include_chain=include_chain)
         finally:
             nssdb.close()
 
@@ -194,31 +197,35 @@ class InstanceFindCLI(pki.cli.CLI):
     def print_help(self):
         print('Usage: pki-server instance-find [OPTIONS]')
         print()
-        print('  -v, --verbose                Run in verbose mode.')
-        print('      --help                   Show help message.')
+        print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
+        print('      --help                         Show help message.')
         print()
 
     def execute(self, argv):
 
         try:
             opts, _ = getopt.gnu_getopt(argv, 'i:v', [
-                'verbose', 'help'])
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
         for o, _ in opts:
-            if o in ('-v', '--verbose'):
-                self.set_verbose(True)
+            if o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
+            elif o in ('-v', '--verbose'):
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
@@ -240,7 +247,7 @@ class InstanceFindCLI(pki.cli.CLI):
             else:
                 print()
 
-            instance = pki.server.PKIInstance(instance_name)
+            instance = pki.server.instance.PKIInstance(instance_name)
             instance.load()
 
             InstanceCLI.print_instance(instance)
@@ -254,45 +261,49 @@ class InstanceShowCLI(pki.cli.CLI):
     def print_help(self):
         print('Usage: pki-server instance-show [OPTIONS] <instance ID>')
         print()
-        print('  -v, --verbose                Run in verbose mode.')
-        print('      --help                   Show help message.')
+        print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
+        print('      --help                         Show help message.')
         print()
 
     def execute(self, argv):
 
         try:
             opts, args = getopt.gnu_getopt(argv, 'i:v', [
-                'verbose', 'help'])
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
         for o, _ in opts:
-            if o in ('-v', '--verbose'):
-                self.set_verbose(True)
+            if o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
+            elif o in ('-v', '--verbose'):
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
         if len(args) != 1:
-            print('ERROR: missing instance ID')
+            logger.error('Missing instance ID')
             self.print_help()
             sys.exit(1)
 
         instance_name = args[0]
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
 
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
@@ -308,45 +319,49 @@ class InstanceStartCLI(pki.cli.CLI):
     def print_help(self):
         print('Usage: pki-server instance-start [OPTIONS] <instance ID>')
         print()
-        print('  -v, --verbose                Run in verbose mode.')
-        print('      --help                   Show help message.')
+        print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
+        print('      --help                         Show help message.')
         print()
 
     def execute(self, argv):
 
         try:
             opts, args = getopt.gnu_getopt(argv, 'i:v', [
-                'verbose', 'help'])
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
         for o, _ in opts:
-            if o in ('-v', '--verbose'):
-                self.set_verbose(True)
+            if o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
+            elif o in ('-v', '--verbose'):
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
         if len(args) != 1:
-            print('ERROR: missing instance ID')
+            logger.error('Missing instance ID')
             self.print_help()
             sys.exit(1)
 
         instance_name = args[0]
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
 
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         if instance.is_active():
@@ -367,45 +382,49 @@ class InstanceStopCLI(pki.cli.CLI):
     def print_help(self):
         print('Usage: pki-server instance-stop [OPTIONS] <instance ID>')
         print()
-        print('  -v, --verbose                Run in verbose mode.')
-        print('      --help                   Show help message.')
+        print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
+        print('      --help                         Show help message.')
         print()
 
     def execute(self, argv):
 
         try:
             opts, args = getopt.gnu_getopt(argv, 'i:v', [
-                'verbose', 'help'])
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
         for o, _ in opts:
-            if o in ('-v', '--verbose'):
-                self.set_verbose(True)
+            if o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
+            elif o in ('-v', '--verbose'):
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
         if len(args) != 1:
-            print('ERROR: missing instance ID')
+            logger.error('Missing instance ID')
             self.print_help()
             sys.exit(1)
 
         instance_name = args[0]
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
 
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         if not instance.is_active():
@@ -436,10 +455,11 @@ class InstanceMigrateCLI(pki.cli.CLI):
 
         try:
             opts, args = getopt.gnu_getopt(argv, 'i:v', [
-                'tomcat=', 'verbose', 'debug', 'help'])
+                'tomcat=',
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -449,24 +469,23 @@ class InstanceMigrateCLI(pki.cli.CLI):
             if o == '--tomcat':
                 tomcat_version = pki.util.Version(a)
 
-            elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
-
             elif o == '--debug':
-                self.set_verbose(True)
-                self.set_debug(True)
+                logging.getLogger().setLevel(logging.DEBUG)
+
+            elif o in ('-v', '--verbose'):
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
         if len(args) != 1:
-            print('ERROR: missing instance ID')
+            logger.error('Missing instance ID')
             self.print_help()
             sys.exit(1)
 
@@ -475,17 +494,14 @@ class InstanceMigrateCLI(pki.cli.CLI):
         if not tomcat_version:
             tomcat_version = pki.server.Tomcat.get_version()
 
-        if self.verbose:
-            print('Migrating to Tomcat %s' % tomcat_version)
+        logger.info('Migrating to Tomcat %s', tomcat_version)
 
         module = self.get_top_module().find_module('migrate')
-        module.set_verbose(self.verbose)
-        module.set_debug(self.debug)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
 
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
@@ -507,33 +523,39 @@ class InstanceNuxwdogEnableCLI(pki.cli.CLI):
     def print_help(self):
         print('Usage: pki-server instance-nuxwdog-enable [OPTIONS] <instance ID>')
         print()
-        print('  -v, --verbose                Run in verbose mode.')
-        print('      --help                   Show help message.')
+        print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
+        print('      --help                         Show help message.')
         print()
 
     def execute(self, argv):
         try:
             opts, args = getopt.gnu_getopt(argv, 'i:v', [
-                'verbose', 'help'])
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
         for o, _ in opts:
-            if o in ('-v', '--verbose'):
-                self.set_verbose(True)
+            if o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
+            elif o in ('-v', '--verbose'):
+                logging.getLogger().setLevel(logging.INFO)
+
             elif o == '--help':
                 self.print_help()
                 sys.exit()
+
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
         if len(args) != 1:
-            print('ERROR: missing instance ID')
+            logger.error('Missing instance ID')
             self.print_help()
             sys.exit(1)
 
@@ -541,12 +563,11 @@ class InstanceNuxwdogEnableCLI(pki.cli.CLI):
 
         module = self.get_top_module().find_module('nuxwdog-enable')
         module = pki.server.cli.nuxwdog.NuxwdogEnableCLI()
-        module.set_verbose(self.verbose)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
 
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
@@ -566,45 +587,50 @@ class InstanceNuxwdogDisableCLI(pki.cli.CLI):
     def print_help(self):
         print('Usage: pki-server instance-nuxwdog-disable [OPTIONS] <instance ID>')
         print()
-        print('  -v, --verbose                Run in verbose mode.')
-        print('      --help                   Show help message.')
+        print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
+        print('      --help                         Show help message.')
         print()
 
     def execute(self, argv):
         try:
             opts, args = getopt.gnu_getopt(argv, 'i:v', [
-                'verbose', 'help'])
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
         for o, _ in opts:
-            if o in ('-v', '--verbose'):
-                self.set_verbose(True)
+            if o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
+            elif o in ('-v', '--verbose'):
+                logging.getLogger().setLevel(logging.INFO)
+
             elif o == '--help':
                 self.print_help()
                 sys.exit()
+
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
         if len(args) != 1:
-            print('ERROR: missing instance ID')
+            logger.error('Missing instance ID')
             self.print_help()
             sys.exit(1)
 
         instance_name = args[0]
 
         module = self.get_top_module().find_module('nuxwdog-disable')
-        module.set_verbose(self.verbose)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
 
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
@@ -632,6 +658,7 @@ class InstanceExternalCertAddCLI(pki.cli.CLI):
         print('      --nickname <nickname>          Nickname to be used.')
         print('      --token <token_name>           Token (default: internal).')
         print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
         print('      --help                         Show help message.')
         print()
 
@@ -640,10 +667,10 @@ class InstanceExternalCertAddCLI(pki.cli.CLI):
             opts, _ = getopt.gnu_getopt(argv, 'i:v', [
                 'instance=',
                 'cert-file=', 'trust-args=', 'nickname=', 'token=',
-                'verbose', 'help'])
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -669,39 +696,41 @@ class InstanceExternalCertAddCLI(pki.cli.CLI):
             elif o == '--token':
                 token = a
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
         if not cert_file:
-            print('ERROR: missing input file containing certificate')
+            logger.error('Missing input file containing certificate')
             self.print_help()
             sys.exit(1)
 
         if not nickname:
-            print('ERROR: missing nickname')
+            logger.error('Missing nickname')
             self.print_help()
             sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
 
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
 
         if instance.external_cert_exists(nickname, token):
-            print('ERROR: Certificate already imported for instance %s.' %
-                  instance_name)
+            logger.error('Certificate already imported for instance %s.', instance_name)
             sys.exit(1)
 
         nicks = self.import_certs(
@@ -742,6 +771,7 @@ class InstanceExternalCertDeleteCLI(pki.cli.CLI):
         print('      --nickname <nickname>          Nickname to be used.')
         print('      --token <token_name>           Token (default: internal).')
         print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
         print('      --help                         Show help message.')
         print()
 
@@ -749,10 +779,10 @@ class InstanceExternalCertDeleteCLI(pki.cli.CLI):
         try:
             opts, _ = getopt.gnu_getopt(argv, 'i:v', [
                 'instance=', 'nickname=', 'token=',
-                'verbose', 'help'])
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -770,27 +800,30 @@ class InstanceExternalCertDeleteCLI(pki.cli.CLI):
             elif o == '--token':
                 token = a
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
         if not nickname:
-            print('ERROR: missing nickname')
+            logger.error('Missing nickname')
             self.print_help()
             sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
 
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
