@@ -20,11 +20,13 @@
 
 from __future__ import absolute_import
 from __future__ import print_function
+
 import getopt
 import io
 import ldap
 import ldap.modlist
 import ldif
+import logging
 import os
 import shutil
 import sys
@@ -35,7 +37,9 @@ import pki.cli
 import pki.server.cli.audit
 import pki.server.cli.config
 import pki.server.cli.db
+import pki.server.instance
 
+logger = logging.getLogger(__name__)
 
 KRA_VLVS = ['allKeys', 'kraAll',
             'kraArchival', 'kraRecovery',
@@ -52,11 +56,10 @@ class KRACLI(pki.cli.CLI):
         super(KRACLI, self).__init__(
             'kra', 'KRA management commands')
 
-        self.add_module(KRACloneCLI())
-        self.add_module(KRADBCLI())
         self.add_module(pki.server.cli.audit.AuditCLI(self))
+        self.add_module(KRACloneCLI())
         self.add_module(pki.server.cli.config.SubsystemConfigCLI(self))
-        self.add_module(pki.server.cli.db.SubsystemDBCLI(self))
+        self.add_module(KRADBCLI(self))
 
 
 class KRACloneCLI(pki.cli.CLI):
@@ -82,6 +85,7 @@ class KRAClonePrepareCLI(pki.cli.CLI):
         print('      --pkcs12-password <password>   Password for the PKCS #12 file.')
         print('      --pkcs12-password-file <path>  File containing the PKCS #12 password.')
         print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
         print('      --help                         Show help message.')
         print()
 
@@ -90,10 +94,10 @@ class KRAClonePrepareCLI(pki.cli.CLI):
         try:
             opts, _ = getopt.gnu_getopt(argv, 'i:v', [
                 'instance=', 'pkcs12-file=', 'pkcs12-password=', 'pkcs12-password-file=',
-                'verbose', 'help'])
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -115,37 +119,40 @@ class KRAClonePrepareCLI(pki.cli.CLI):
                 with io.open(a, 'rb') as f:
                     pkcs12_password = f.read()
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
         if not pkcs12_file:
-            print('ERROR: Missing PKCS #12 file')
+            logger.error('Missing PKCS #12 file')
             self.print_help()
             sys.exit(1)
 
         if not pkcs12_password:
-            print('ERROR: Missing PKCS #12 password')
+            logger.error('Missing PKCS #12 password')
             self.print_help()
             sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
         instance.load()
 
         subsystem = instance.get_subsystem('kra')
         if not subsystem:
-            print('ERROR: No KRA subsystem in instance %s.' % instance_name)
+            logger.error('No KRA subsystem in instance %s.', instance_name)
             sys.exit(1)
 
         tmpdir = tempfile.mkdtemp()
@@ -172,10 +179,16 @@ class KRAClonePrepareCLI(pki.cli.CLI):
 
 class KRADBCLI(pki.cli.CLI):
 
-    def __init__(self):
+    def __init__(self, parent):
         super(KRADBCLI, self).__init__(
             'db', 'KRA database management commands')
 
+        self.parent = parent
+        self.add_module(pki.server.cli.db.SubsystemDBConfigCLI(self))
+        self.add_module(pki.server.cli.db.SubsystemDBInfoCLI(self))
+        self.add_module(pki.server.cli.db.SubsystemDBEmptyCLI(self))
+        self.add_module(pki.server.cli.db.SubsystemDBRemoveCLI(self))
+        self.add_module(pki.server.cli.db.SubsystemDBUpgradeCLI(self))
         self.add_module(KRADBVLVCLI())
 
 
@@ -204,6 +217,7 @@ class KRADBVLVFindCLI(pki.cli.CLI):
         print('  -D, --bind-dn <Bind DN>            Connect DN (default: cn=Directory Manager).')
         print('  -w, --bind-password <password>     Password to connect to database.')
         print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
         print('      --help                         Show help message.')
         print()
 
@@ -213,11 +227,11 @@ class KRADBVLVFindCLI(pki.cli.CLI):
                 argv,
                 'i:D:w:x:g:v',
                 ['instance=', 'bind-dn=', 'bind-password=', 'generate-ldif=',
-                 'verbose', 'help']
+                 'verbose', 'debug', 'help']
             )
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -235,27 +249,30 @@ class KRADBVLVFindCLI(pki.cli.CLI):
             elif o in ('-w', '--bind-password'):
                 bind_password = a
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
         instance.load()
 
         subsystem = instance.get_subsystem('kra')
         if not subsystem:
-            print('ERROR: No KRA subsystem in instance %s.' % instance_name)
+            logger.error('No KRA subsystem in instance %s.', instance_name)
             sys.exit(1)
 
         self.find_vlv(subsystem, bind_dn, bind_password)
@@ -269,8 +286,7 @@ class KRADBVLVFindCLI(pki.cli.CLI):
             database = subsystem.config['internaldb.database']
             base_dn = 'cn=' + database + ',cn=ldbm database, cn=plugins, cn=config'
 
-            if self.verbose:
-                print('Searching %s' % base_dn)
+            logger.info('Searching %s', base_dn)
 
             entries = conn.ldap.search_s(
                 base_dn,
@@ -314,8 +330,9 @@ class KRADBVLVAddCLI(pki.cli.CLI):
         print('  -i, --instance <instance ID>       Instance ID (default: pki-tomcat).')
         print('  -D, --bind-dn <Bind DN>            Connect DN (default: cn=Directory Manager).')
         print('  -w, --bind-password <password>     Password to connect to database.')
-        print('  -v, --verbose                      Run in verbose mode.')
         print('  -g, --generate-ldif <outfile>      Generate LDIF of required changes.')
+        print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
         print('      --help                         Show help message.')
         print()
 
@@ -325,11 +342,11 @@ class KRADBVLVAddCLI(pki.cli.CLI):
                 argv,
                 'i:D:w:x:g:v',
                 ['instance=', 'bind-dn=', 'bind-password=', 'generate-ldif=',
-                 'verbose', 'help']
+                 'verbose', 'debug', 'help']
             )
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -350,27 +367,30 @@ class KRADBVLVAddCLI(pki.cli.CLI):
             elif o in ('-g', '--generate-ldif'):
                 self.out_file = a
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
         instance.load()
 
         subsystem = instance.get_subsystem('kra')
         if not subsystem:
-            print('ERROR: No KRA subsystem in instance %s.' % instance_name)
+            logger.error('No KRA subsystem in instance %s.', instance_name)
             sys.exit(1)
 
         if self.out_file:
@@ -384,7 +404,7 @@ class KRADBVLVAddCLI(pki.cli.CLI):
             print('KRA VLVs added to the database for ' + instance_name)
 
         except ldap.LDAPError as e:
-            print("ERROR: {}".format(e))
+            logger.error(e)
             sys.exit(1)
 
     def add_vlv(self, subsystem, bind_dn, bind_password):
@@ -422,6 +442,7 @@ class KRADBVLVDeleteCLI(pki.cli.CLI):
         print('  -w, --bind-password <password>     Password to connect to database.')
         print('  -g, --generate-ldif <outfile>      Generate LDIF of required changes.')
         print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
         print('      --help                         Show help message.')
         print()
 
@@ -431,11 +452,11 @@ class KRADBVLVDeleteCLI(pki.cli.CLI):
                 argv,
                 'i:D:w:x:g:v',
                 ['instance=', 'bind-dn=', 'bind-password=', 'generate-ldif=',
-                 'verbose', 'help']
+                 'verbose', 'debug', 'help']
             )
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -456,22 +477,25 @@ class KRADBVLVDeleteCLI(pki.cli.CLI):
             elif o in ('-g', '--generate-ldif'):
                 self.out_file = a
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
 
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
@@ -479,7 +503,7 @@ class KRADBVLVDeleteCLI(pki.cli.CLI):
         subsystem = instance.get_subsystem('kra')
 
         if not subsystem:
-            print('ERROR: No KRA subsystem in instance %s.' % instance_name)
+            logger.error('No KRA subsystem in instance %s.', instance_name)
             sys.exit(1)
 
         self.delete_vlv(subsystem, bind_dn, bind_password)
@@ -544,6 +568,7 @@ class KRADBVLVReindexCLI(pki.cli.CLI):
         print('  -w, --bind-password <password>     Password to connect to database.')
         print('  -g, --generate-ldif <outfile>      Generate LDIF of required changes.')
         print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
         print('      --help                         Show help message.')
         print()
 
@@ -553,11 +578,11 @@ class KRADBVLVReindexCLI(pki.cli.CLI):
                 argv,
                 'i:D:w:x:g:v',
                 ['instance=', 'bind-dn=', 'bind-password=', 'generate-ldif=',
-                 'verbose', 'help']
+                 'verbose', 'debug', 'help']
             )
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -578,27 +603,30 @@ class KRADBVLVReindexCLI(pki.cli.CLI):
             elif o in ('-g', '--generate-ldif'):
                 self.out_file = a
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
         instance.load()
 
         subsystem = instance.get_subsystem('kra')
         if not subsystem:
-            print('ERROR: No KRA subsystem in instance %s.' % instance_name)
+            logger.error('No KRA subsystem in instance %s.', instance_name)
             sys.exit(1)
 
         if self.out_file:
@@ -626,8 +654,7 @@ class KRADBVLVReindexCLI(pki.cli.CLI):
 
             for dn, entry in parser.all_records:
 
-                if self.verbose:
-                    print('Adding %s' % dn)
+                logger.info('Adding %s', dn)
 
                 add_modlist = ldap.modlist.addModlist(entry)
                 conn.ldap.add_s(dn, add_modlist)
@@ -636,8 +663,7 @@ class KRADBVLVReindexCLI(pki.cli.CLI):
                     time.sleep(1)
 
                     try:
-                        if self.verbose:
-                            print('Checking %s' % dn)
+                        logger.info('Checking %s', dn)
 
                         conn.ldap.search_s(dn, ldap.SCOPE_BASE)
                     except ldap.NO_SUCH_OBJECT:
