@@ -22,8 +22,10 @@
 
 from __future__ import absolute_import
 from __future__ import print_function
+
 import getopt
 import getpass
+import logging
 import os
 import subprocess
 import sys
@@ -32,6 +34,9 @@ import tempfile
 import pki.cli
 import pki.nssdb
 import pki.server
+import pki.server.instance
+
+logger = logging.getLogger(__name__)
 
 
 class SubsystemCLI(pki.cli.CLI):
@@ -64,6 +69,7 @@ class SubsystemFindCLI(pki.cli.CLI):
         print()
         print('  -i, --instance <instance ID>    Instance ID (default: pki-tomcat).')
         print('  -v, --verbose                   Run in verbose mode.')
+        print('      --debug                     Run in debug mode.')
         print('      --help                      Show help message.')
         print()
 
@@ -72,10 +78,10 @@ class SubsystemFindCLI(pki.cli.CLI):
         try:
             opts, _ = getopt.gnu_getopt(argv, 'i:v', [
                 'instance=',
-                'verbose', 'help'])
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.usage()
             sys.exit(1)
 
@@ -85,22 +91,25 @@ class SubsystemFindCLI(pki.cli.CLI):
             if o in ('-i', '--instance'):
                 instance_name = a
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.usage()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.usage()
                 sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
 
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
@@ -127,6 +136,7 @@ class SubsystemShowCLI(pki.cli.CLI):
         print()
         print('  -i, --instance <instance ID>    Instance ID (default: pki-tomcat).')
         print('  -v, --verbose                   Run in verbose mode.')
+        print('      --debug                     Run in debug mode.')
         print('      --help                      Show help message.')
         print()
 
@@ -135,10 +145,10 @@ class SubsystemShowCLI(pki.cli.CLI):
         try:
             opts, args = getopt.gnu_getopt(argv, 'i:v', [
                 'instance=',
-                'verbose', 'help'])
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.usage()
             sys.exit(1)
 
@@ -148,37 +158,40 @@ class SubsystemShowCLI(pki.cli.CLI):
             if o in ('-i', '--instance'):
                 instance_name = a
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.usage()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.usage()
                 sys.exit(1)
 
         if len(args) != 1:
-            print('ERROR: missing subsystem ID')
+            logger.error('Missing subsystem ID')
             self.usage()
             sys.exit(1)
 
         subsystem_name = args[0]
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
 
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
 
         subsystem = instance.get_subsystem(subsystem_name)
         if not subsystem:
-            print('ERROR: No %s subsystem in instance '
-                  '%s.' % (subsystem_name, instance_name))
+            logger.error('ERROR: No %s subsystem in instance %s.',
+                         subsystem_name, instance_name)
             sys.exit(1)
 
         SubsystemCLI.print_subsystem(subsystem)
@@ -193,8 +206,10 @@ class SubsystemEnableCLI(pki.cli.CLI):
         print('Usage: pki-server subsystem-enable [OPTIONS] <subsystem ID>')
         print()
         print('  -i, --instance <instance ID>    Instance ID (default: pki-tomcat).')
-        print('  -v, --verbose                   Run in verbose mode.')
+        print('      --all                       Enable all subsystems.')
         print('      --silent                    Run in silent mode.')
+        print('  -v, --verbose                   Run in verbose mode.')
+        print('      --debug                     Run in debug mode.')
         print('      --help                      Show help message.')
         print()
 
@@ -202,11 +217,11 @@ class SubsystemEnableCLI(pki.cli.CLI):
 
         try:
             opts, args = getopt.gnu_getopt(argv, 'i:v', [
-                'instance=', 'all',
-                'verbose', 'silent', 'help'])
+                'instance=', 'all', 'silent',
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.usage()
             sys.exit(1)
 
@@ -221,25 +236,28 @@ class SubsystemEnableCLI(pki.cli.CLI):
             elif o == '--all':
                 all_subsystems = True
 
-            elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
-
             elif o == '--silent':
                 silent = True
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
+            elif o in ('-v', '--verbose'):
+                logging.getLogger().setLevel(logging.INFO)
+
             elif o == '--help':
                 self.usage()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.usage()
                 sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
 
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
@@ -255,7 +273,7 @@ class SubsystemEnableCLI(pki.cli.CLI):
             return
 
         if len(args) != 1:
-            print('ERROR: missing subsystem ID')
+            logger.error('Missing subsystem ID')
             self.usage()
             sys.exit(1)
 
@@ -263,8 +281,8 @@ class SubsystemEnableCLI(pki.cli.CLI):
 
         subsystem = instance.get_subsystem(subsystem_name)
         if not subsystem:
-            print('ERROR: No %s subsystem in instance '
-                  '%s.' % (subsystem_name, instance_name))
+            logger.error('No %s subsystem in instance %s.',
+                         subsystem_name, instance_name)
             sys.exit(1)
 
         if subsystem.is_enabled():
@@ -291,7 +309,9 @@ class SubsystemDisableCLI(pki.cli.CLI):
         print('Usage: pki-server subsystem-disable [OPTIONS] <subsystem ID>')
         print()
         print('  -i, --instance <instance ID>    Instance ID (default: pki-tomcat).')
+        print('      --all                       Disable all subsystems.')
         print('  -v, --verbose                   Run in verbose mode.')
+        print('      --debug                     Run in debug mode.')
         print('      --help                      Show help message.')
         print()
 
@@ -300,10 +320,10 @@ class SubsystemDisableCLI(pki.cli.CLI):
         try:
             opts, args = getopt.gnu_getopt(argv, 'i:v', [
                 'instance=', 'all',
-                'verbose', 'help'])
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.usage()
             sys.exit(1)
 
@@ -317,22 +337,25 @@ class SubsystemDisableCLI(pki.cli.CLI):
             elif o == '--all':
                 all_subsystems = True
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.usage()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.usage()
                 sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
 
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
@@ -347,7 +370,7 @@ class SubsystemDisableCLI(pki.cli.CLI):
             return
 
         if len(args) != 1:
-            print('ERROR: missing subsystem ID')
+            logger.error('Missing subsystem ID')
             self.usage()
             sys.exit(1)
 
@@ -355,8 +378,8 @@ class SubsystemDisableCLI(pki.cli.CLI):
 
         subsystem = instance.get_subsystem(subsystem_name)
         if not subsystem:
-            print('ERROR: No %s subsystem in instance '
-                  '%s.' % (subsystem_name, instance_name))
+            logger.error('No %s subsystem in instance %s.',
+                         subsystem_name, instance_name)
             sys.exit(1)
 
         if not subsystem.is_enabled():
@@ -410,6 +433,7 @@ class SubsystemCertFindCLI(pki.cli.CLI):
         print('  -i, --instance <instance ID>    Instance ID (default: pki-tomcat).')
         print('      --show-all                  Show all attributes.')
         print('  -v, --verbose                   Run in verbose mode.')
+        print('      --debug                     Run in debug mode.')
         print('      --help                      Show help message.')
         print()
 
@@ -418,10 +442,10 @@ class SubsystemCertFindCLI(pki.cli.CLI):
         try:
             opts, args = getopt.gnu_getopt(argv, 'i:v', [
                 'instance=', 'show-all',
-                'verbose', 'help'])
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -435,37 +459,40 @@ class SubsystemCertFindCLI(pki.cli.CLI):
             elif o == '--show-all':
                 show_all = True
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
         if len(args) != 1:
-            print('ERROR: missing subsystem ID')
+            logger.error('Missing subsystem ID')
             self.print_help()
             sys.exit(1)
 
         subsystem_name = args[0]
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
 
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
 
         subsystem = instance.get_subsystem(subsystem_name)
         if not subsystem:
-            print('ERROR: No %s subsystem in instance '
-                  '%s.' % (subsystem_name, instance_name))
+            logger.error('No %s subsystem in instance %s.',
+                         subsystem_name, instance_name)
             sys.exit(1)
 
         certs = subsystem.get_cert_infos()
@@ -499,6 +526,7 @@ class SubsystemCertShowCLI(pki.cli.CLI):
         print('  -i, --instance <instance ID>    Instance ID (default: pki-tomcat).')
         print('      --show-all                  Show all attributes.')
         print('  -v, --verbose                   Run in verbose mode.')
+        print('      --debug                     Run in debug mode.')
         print('      --help                      Show help message.')
         print()
 
@@ -507,10 +535,10 @@ class SubsystemCertShowCLI(pki.cli.CLI):
         try:
             opts, args = getopt.gnu_getopt(argv, 'i:v', [
                 'instance=', 'show-all',
-                'verbose', 'help'])
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.usage()
             sys.exit(1)
 
@@ -524,43 +552,46 @@ class SubsystemCertShowCLI(pki.cli.CLI):
             elif o == '--show-all':
                 show_all = True
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.usage()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.usage()
                 sys.exit(1)
 
         if len(args) < 1:
-            print('ERROR: missing subsystem ID')
+            logger.error('Missing subsystem ID')
             self.usage()
             sys.exit(1)
 
         if len(args) < 2:
-            print('ERROR: missing cert ID')
+            logger.error('Missing cert ID')
             self.usage()
             sys.exit(1)
 
         subsystem_name = args[0]
         cert_id = args[1]
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
 
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
 
         subsystem = instance.get_subsystem(subsystem_name)
         if not subsystem:
-            print('ERROR: No %s subsystem in instance '
-                  '%s.' % (subsystem_name, instance_name))
+            logger.error('ERROR: No %s subsystem in instance %s.',
+                         subsystem_name, instance_name)
             sys.exit(1)
         cert = subsystem.get_subsystem_cert(cert_id)
         self.print_message('"{}" subsystem "{}" certificate'.format(subsystem_name, cert_id))
@@ -605,7 +636,7 @@ class SubsystemCertExportCLI(pki.cli.CLI):
                 'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -619,7 +650,6 @@ class SubsystemCertExportCLI(pki.cli.CLI):
         include_trust_flags = True
         include_key = True
         include_chain = True
-        debug = False
 
         for o, a in opts:
             if o in ('-i', '--instance'):
@@ -652,45 +682,45 @@ class SubsystemCertExportCLI(pki.cli.CLI):
             elif o == '--no-chain':
                 include_chain = False
 
-            elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
-
             elif o == '--debug':
-                debug = True
+                logging.getLogger().setLevel(logging.DEBUG)
+
+            elif o in ('-v', '--verbose'):
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
         if len(args) < 1:
-            print('ERROR: missing subsystem ID')
+            logger.error('Missing subsystem ID')
             self.print_help()
             sys.exit(1)
 
         subsystem_name = args[0]
 
         if not (cert_file or csr_file or pkcs12_file):
-            print('ERROR: missing output file')
+            logger.error('Missing output file')
             self.print_help()
             sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
 
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
 
         subsystem = instance.get_subsystem(subsystem_name)
         if not subsystem:
-            print('ERROR: No %s subsystem in instance '
-                  '%s.' % (subsystem_name, instance_name))
+            logger.error('No %s subsystem in instance %s.',
+                         subsystem_name, instance_name)
             sys.exit(1)
         subsystem_cert = None
 
@@ -699,14 +729,14 @@ class SubsystemCertExportCLI(pki.cli.CLI):
             subsystem_cert = subsystem.get_subsystem_cert(cert_id)
 
         if (cert_file or csr_file) and not subsystem_cert:
-            print('ERROR: missing cert ID')
+            logger.error('Missing cert ID')
             self.print_help()
             sys.exit(1)
 
         if cert_file:
             cert_data = subsystem_cert.get('data', None)
             if cert_data is None:
-                print("ERROR: Unable to find certificate data for %s" % cert_id)
+                logger.error("Unable to find certificate data for %s", cert_id)
                 sys.exit(1)
 
             cert_data = pki.nssdb.convert_cert(cert_data, 'base64', 'pem')
@@ -716,7 +746,7 @@ class SubsystemCertExportCLI(pki.cli.CLI):
         if csr_file:
             cert_request = subsystem_cert.get('request', None)
             if cert_request is None:
-                print("ERROR: Unable to find certificate request for %s" % cert_id)
+                logger.error('Unable to find certificate request for %s', cert_id)
                 sys.exit(1)
 
             csr_data = pki.nssdb.convert_csr(cert_request, 'base64', 'pem')
@@ -748,8 +778,7 @@ class SubsystemCertExportCLI(pki.cli.CLI):
                     append=append,
                     include_trust_flags=include_trust_flags,
                     include_key=include_key,
-                    include_chain=include_chain,
-                    debug=debug)
+                    include_chain=include_chain)
 
             finally:
                 nssdb.close()
@@ -765,9 +794,10 @@ class SubsystemCertUpdateCLI(pki.cli.CLI):
         print('Usage: pki-server subsystem-cert-update [OPTIONS] <subsystem ID> <cert ID>')
         print()
         print('  -i, --instance <instance ID>    Instance ID (default: pki-tomcat).')
-        print('  -v, --verbose                   Run in verbose mode.')
-        print('      --help                      Show help message.')
         print('      --cert <certificate>        New certificate to be added')
+        print('  -v, --verbose                   Run in verbose mode.')
+        print('      --debug                     Run in debug mode.')
+        print('      --help                      Show help message.')
         print()
 
     def execute(self, argv):
@@ -775,11 +805,11 @@ class SubsystemCertUpdateCLI(pki.cli.CLI):
         try:
             opts, args = getopt.gnu_getopt(argv, 'i:v', [
                 'instance=',
-                'verbose', 'help',
-                'cert='])
+                'cert=',
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.usage()
             sys.exit(1)
 
@@ -790,8 +820,11 @@ class SubsystemCertUpdateCLI(pki.cli.CLI):
             if o in ('-i', '--instance'):
                 instance_name = a
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.usage()
@@ -801,48 +834,47 @@ class SubsystemCertUpdateCLI(pki.cli.CLI):
                 cert_file = a
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.usage()
                 sys.exit(1)
 
         if len(args) < 1:
-            print('ERROR: missing subsystem ID')
+            logger.error('Missing subsystem ID')
             self.usage()
             sys.exit(1)
 
         if len(args) < 2:
-            print('ERROR: missing cert ID')
+            logger.error('Missing cert ID')
             self.usage()
             sys.exit(1)
 
         subsystem_name = args[0]
         cert_id = args[1]
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
 
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
 
         subsystem = instance.get_subsystem(subsystem_name)
         if not subsystem:
-            print('ERROR: No %s subsystem in instance '
-                  '%s.' % (subsystem_name, instance_name))
+            logger.error('No %s subsystem in instance %s.',
+                         subsystem_name, instance_name)
             sys.exit(1)
         subsystem_cert = subsystem.get_subsystem_cert(cert_id)
 
-        if self.verbose:
-            print('Retrieving certificate %s from %s' %
-                  (subsystem_cert['nickname'], subsystem_cert['token']))
+        logger.info('Retrieving certificate %s from %s',
+                    subsystem_cert['nickname'], subsystem_cert['token'])
 
         token = subsystem_cert['token']
         nssdb = instance.open_nssdb(token)
 
         if cert_file:
             if not os.path.isfile(cert_file):
-                print('ERROR: %s certificate does not exist.' % cert_file)
+                logger.error('%s certificate does not exist.', cert_file)
                 self.usage()
                 sys.exit(1)
 
@@ -851,12 +883,11 @@ class SubsystemCertUpdateCLI(pki.cli.CLI):
                 output_format='base64')
 
             if data:
-                if self.verbose:
-                    print('Removing old %s certificate from database.'
-                          % subsystem_cert['nickname'])
+                logger.info('Removing old %s certificate from database.',
+                            subsystem_cert['nickname'])
                 nssdb.remove_cert(nickname=subsystem_cert['nickname'])
-            if self.verbose:
-                print('Adding new %s certificate into database.' % subsystem_cert['nickname'])
+
+            logger.info('Adding new %s certificate into database.', subsystem_cert['nickname'])
             nssdb.add_cert(
                 nickname=subsystem_cert['nickname'],
                 cert_file=cert_file)
@@ -872,13 +903,12 @@ class SubsystemCertUpdateCLI(pki.cli.CLI):
         lines = [data[i:i + 64] for i in range(0, len(data), 64)]
         data = '\r\n'.join(lines) + '\r\n'
 
-        if self.verbose:
-            print('Retrieving certificate request from CA database')
+        logger.info('Retrieving certificate request from CA database')
 
         # TODO: add support for remote CA
         ca = instance.get_subsystem('ca')
         if not ca:
-            print('ERROR: No CA subsystem in instance %s.' % instance_name)
+            logger.error('No CA subsystem in instance %s.', instance_name)
             sys.exit(1)
 
         results = ca.find_cert_requests(cert=data)
@@ -897,7 +927,7 @@ class SubsystemCertUpdateCLI(pki.cli.CLI):
             subsystem_cert['request'] = request
 
         else:
-            print('WARNING: Certificate request not found')
+            logger.warning('Certificate request not found')
 
         # store cert data and request in CS.cfg
         subsystem.update_subsystem_cert(subsystem_cert)
@@ -917,6 +947,7 @@ class SubsystemCertValidateCLI(pki.cli.CLI):
         print()
         print('  -i, --instance <instance ID>    Instance ID (default: pki-tomcat).')
         print('  -v, --verbose                   Run in verbose mode.')
+        print('      --debug                     Run in debug mode.')
         print('      --help                      Show help message.')
         print()
 
@@ -925,10 +956,10 @@ class SubsystemCertValidateCLI(pki.cli.CLI):
         try:
             opts, args = getopt.gnu_getopt(argv, 'i:v', [
                 'instance=',
-                'verbose', 'help'])
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.usage()
             sys.exit(1)
 
@@ -938,20 +969,23 @@ class SubsystemCertValidateCLI(pki.cli.CLI):
             if o in ('-i', '--instance'):
                 instance_name = a
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.usage()
                 sys.exit()
 
             else:
-                self.print_message('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.usage()
                 sys.exit(1)
 
         if len(args) < 1:
-            print('ERROR: missing subsystem ID')
+            logger.error('Missing subsystem ID')
             self.usage()
             sys.exit(1)
 
@@ -962,18 +996,18 @@ class SubsystemCertValidateCLI(pki.cli.CLI):
         else:
             cert_id = None
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
 
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
 
         subsystem = instance.get_subsystem(subsystem_name)
         if not subsystem:
-            print('ERROR: No %s subsystem in instance '
-                  '%s.' % (subsystem_name, instance_name))
+            logger.error('No %s subsystem in instance %s.',
+                         subsystem_name, instance_name)
             sys.exit(1)
 
         if cert_id is not None:
@@ -1002,8 +1036,7 @@ class SubsystemCertValidateCLI(pki.cli.CLI):
 
     def validate_certificate(self, instance, cert):
 
-        if self.verbose:
-            print(cert)
+        logger.info(cert)
 
         print('  Cert ID: %s' % cert['id'])
 
@@ -1062,8 +1095,7 @@ class SubsystemCertValidateCLI(pki.cli.CLI):
                 '--certusage', usage
             ])
 
-            if self.verbose:
-                print('Command: %s' % ' '.join(cmd))
+            logger.info('Command: %s', ' '.join(cmd))
 
             subprocess.check_output(cmd, stderr=subprocess.STDOUT)
             print('  Status: VALID')
