@@ -20,8 +20,10 @@
 
 from __future__ import absolute_import
 from __future__ import print_function
+
 import getopt
 import io
+import logging
 import os
 import shutil
 import sys
@@ -31,6 +33,9 @@ import pki.cli
 import pki.server.cli.audit
 import pki.server.cli.config
 import pki.server.cli.db
+import pki.server.instance
+
+logger = logging.getLogger(__name__)
 
 
 class TKSCLI(pki.cli.CLI):
@@ -39,8 +44,8 @@ class TKSCLI(pki.cli.CLI):
         super(TKSCLI, self).__init__(
             'tks', 'TKS management commands')
 
-        self.add_module(TKSCloneCLI())
         self.add_module(pki.server.cli.audit.AuditCLI(self))
+        self.add_module(TKSCloneCLI())
         self.add_module(pki.server.cli.config.SubsystemConfigCLI(self))
         self.add_module(pki.server.cli.db.SubsystemDBCLI(self))
 
@@ -68,6 +73,7 @@ class TKSClonePrepareCLI(pki.cli.CLI):
         print('      --pkcs12-password <password>   Password for the PKCS #12 file.')
         print('      --pkcs12-password-file <path>  File containing the PKCS #12 password.')
         print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
         print('      --help                         Show help message.')
         print()
 
@@ -76,7 +82,7 @@ class TKSClonePrepareCLI(pki.cli.CLI):
         try:
             opts, _ = getopt.gnu_getopt(argv, 'i:v', [
                 'instance=', 'pkcs12-file=', 'pkcs12-password=', 'pkcs12-password-file=',
-                'verbose', 'help'])
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
             print('ERROR: ' + str(e))
@@ -101,38 +107,41 @@ class TKSClonePrepareCLI(pki.cli.CLI):
                 with io.open(a, 'rb') as f:
                     pkcs12_password = f.read()
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
         if not pkcs12_file:
-            print('ERROR: Missing PKCS #12 file')
+            logger.error('Missing PKCS #12 file')
             self.print_help()
             sys.exit(1)
 
         if not pkcs12_password:
-            print('ERROR: Missing PKCS #12 password')
+            logger.error('Missing PKCS #12 password')
             self.print_help()
             sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
 
         instance.load()
 
         subsystem = instance.get_subsystem('tks')
         if not subsystem:
-            print("ERROR: No TKS subsystem in instance %s." % instance_name)
+            logger.error('No TKS subsystem in instance %s.', instance_name)
             sys.exit(1)
 
         tmpdir = tempfile.mkdtemp()
@@ -144,8 +153,6 @@ class TKSClonePrepareCLI(pki.cli.CLI):
 
             subsystem.export_system_cert(
                 'subsystem', pkcs12_file, pkcs12_password_file)
-            subsystem.export_system_cert(
-                'signing', pkcs12_file, pkcs12_password_file, append=True)
             subsystem.export_system_cert(
                 'audit_signing', pkcs12_file, pkcs12_password_file, append=True)
             instance.export_external_certs(
