@@ -20,11 +20,13 @@
 
 from __future__ import absolute_import
 from __future__ import print_function
+
 import getopt
 import io
 import ldap
 import ldap.modlist
 import ldif
+import logging
 import os
 import shutil
 import sys
@@ -35,7 +37,9 @@ import pki.cli
 import pki.server.cli.audit
 import pki.server.cli.config
 import pki.server.cli.db
+import pki.server.instance
 
+logger = logging.getLogger(__name__)
 
 TPS_VLV_PATH = '/usr/share/pki/tps/conf/vlv.ldif'
 TPS_VLV_TASKS_PATH = '/usr/share/pki/tps/conf/vlvtasks.ldif'
@@ -76,6 +80,7 @@ class TPSClonePrepareCLI(pki.cli.CLI):
         print('      --pkcs12-password <password>   Password for the PKCS #12 file.')
         print('      --pkcs12-password-file <path>  File containing the PKCS #12 password.')
         print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
         print('      --help                         Show help message.')
         print()
 
@@ -84,10 +89,10 @@ class TPSClonePrepareCLI(pki.cli.CLI):
         try:
             opts, _ = getopt.gnu_getopt(argv, 'i:v', [
                 'instance=', 'pkcs12-file=', 'pkcs12-password=', 'pkcs12-password-file=',
-                'verbose', 'help'])
+                'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -109,37 +114,40 @@ class TPSClonePrepareCLI(pki.cli.CLI):
                 with io.open(a, 'rb') as f:
                     pkcs12_password = f.read()
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
         if not pkcs12_file:
-            print('ERROR: Missing PKCS #12 file')
+            logger.error('Missing PKCS #12 file')
             self.print_help()
             sys.exit(1)
 
         if not pkcs12_password:
-            print('ERROR: Missing PKCS #12 password')
+            logger.error('Missing PKCS #12 password')
             self.print_help()
             sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
         instance.load()
 
         subsystem = instance.get_subsystem('tps')
         if not subsystem:
-            print("ERROR: No TPS subsystem in instance %s." % instance_name)
+            logger.error('No TPS subsystem in instance %s.', instance_name)
             sys.exit(1)
 
         tmpdir = tempfile.mkdtemp()
@@ -169,6 +177,9 @@ class TPSDBCLI(pki.cli.CLI):
         self.parent = parent
         self.add_module(pki.server.cli.db.SubsystemDBConfigCLI(self))
         self.add_module(pki.server.cli.db.SubsystemDBInfoCLI(self))
+        self.add_module(pki.server.cli.db.SubsystemDBEmptyCLI(self))
+        self.add_module(pki.server.cli.db.SubsystemDBRemoveCLI(self))
+        self.add_module(pki.server.cli.db.SubsystemDBUpgradeCLI(self))
         self.add_module(TPSDBVLVCLI())
 
 
@@ -197,6 +208,7 @@ class TPSDBVLVFindCLI(pki.cli.CLI):
         print('  -D, --bind-dn <Bind DN>            Connect DN (default: cn=Directory Manager).')
         print('  -w, --bind-password <password>     Password to connect to database.')
         print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
         print('      --help                         Show help message.')
         print()
 
@@ -206,11 +218,10 @@ class TPSDBVLVFindCLI(pki.cli.CLI):
                 argv,
                 'i:D:w:x:g:v',
                 ['instance=', 'bind-dn=', 'bind-password=', 'generate-ldif=',
-                 'verbose', 'help']
-            )
+                 'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -228,27 +239,30 @@ class TPSDBVLVFindCLI(pki.cli.CLI):
             elif o in ('-w', '--bind-password'):
                 bind_password = a
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
         instance.load()
 
         subsystem = instance.get_subsystem('tps')
         if not subsystem:
-            print("ERROR: No TPS subsystem in instance %s." % instance_name)
+            logger.error('No TPS subsystem in instance %s.', instance_name)
             sys.exit(1)
 
         self.find_vlv(subsystem, bind_dn, bind_password)
@@ -262,8 +276,7 @@ class TPSDBVLVFindCLI(pki.cli.CLI):
             database = subsystem.config['internaldb.database']
             base_dn = 'cn=' + database + ',cn=ldbm database, cn=plugins, cn=config'
 
-            if self.verbose:
-                print('Searching %s' % base_dn)
+            logger.info('Searching %s', base_dn)
 
             entries = conn.ldap.search_s(
                 base_dn,
@@ -308,6 +321,7 @@ class TPSDBVLVAddCLI(pki.cli.CLI):
         print('  -w, --bind-password <password>     Password to connect to database.')
         print('  -g, --generate-ldif <outfile>      Generate LDIF of required changes.')
         print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
         print('      --help                         Show help message.')
         print()
 
@@ -317,11 +331,10 @@ class TPSDBVLVAddCLI(pki.cli.CLI):
                 argv,
                 'i:D:w:x:g:v',
                 ['instance=', 'bind-dn=', 'bind-password=', 'generate-ldif=',
-                 'verbose', 'help']
-            )
+                 'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -343,27 +356,30 @@ class TPSDBVLVAddCLI(pki.cli.CLI):
             elif o in ('-g', '--generate-ldif'):
                 out_file = a
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
         instance.load()
 
         subsystem = instance.get_subsystem('tps')
         if not subsystem:
-            print("ERROR: No TPS subsystem in instance %s." % instance_name)
+            logger.error('No TPS subsystem in instance %s.', instance_name)
             sys.exit(1)
 
         if out_file:
@@ -392,8 +408,7 @@ class TPSDBVLVAddCLI(pki.cli.CLI):
 
                 for dn, entry in parser.all_records:
 
-                    if self.verbose:
-                        print('Adding %s' % dn)
+                    logger.info('Adding %s', dn)
 
                     add_modlist = ldap.modlist.addModlist(entry)
                     conn.ldap.add_s(dn, add_modlist)
@@ -421,6 +436,7 @@ class TPSDBVLVDeleteCLI(pki.cli.CLI):
         print('  -w, --bind-password <password>     Password to connect to DB.')
         print('  -g, --generate-ldif <outfile>      Generate LDIF of required changes.')
         print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
         print('      --help                         Show help message.')
         print()
 
@@ -430,11 +446,10 @@ class TPSDBVLVDeleteCLI(pki.cli.CLI):
                 argv,
                 'i:D:w:x:g:v',
                 ['instance=', 'bind-dn=', 'bind-password=', 'generate-ldif=',
-                 'verbose', 'help']
-            )
+                 'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -456,27 +471,30 @@ class TPSDBVLVDeleteCLI(pki.cli.CLI):
             elif o in ('-g', '--generate-ldif'):
                 out_file = a
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
         instance.load()
 
         subsystem = instance.get_subsystem('tps')
         if not subsystem:
-            print("ERROR: No TPS subsystem in instance %s." % instance_name)
+            logger.error('No TPS subsystem in instance %s.', instance_name)
             sys.exit(1)
 
         if out_file:
@@ -516,8 +534,7 @@ class TPSDBVLVDeleteCLI(pki.cli.CLI):
             database = subsystem.config['internaldb.database']
             base_dn = 'cn=' + database + ',cn=ldbm database, cn=plugins, cn=config'
 
-            if self.verbose:
-                print('Searching %s' % base_dn)
+            logger.info('Searching %s', base_dn)
 
             entries = conn.ldap.search_s(
                 base_dn,
@@ -531,8 +548,7 @@ class TPSDBVLVDeleteCLI(pki.cli.CLI):
             for entry in reversed(entries):
                 dn = entry[0]
 
-                if self.verbose:
-                    print('Deleting %s' % dn)
+                logger.info('Deleting %s', dn)
 
                 conn.ldap.delete_s(dn)
 
@@ -556,6 +572,7 @@ class TPSDBVLVReindexCLI(pki.cli.CLI):
         print('  -w, --bind-password <password>     Password to connect to database.')
         print('  -g, --generate-ldif <outfile>      Generate LDIF of required changes.')
         print('  -v, --verbose                      Run in verbose mode.')
+        print('      --debug                        Run in debug mode.')
         print('      --help                         Show help message.')
         print()
 
@@ -565,11 +582,10 @@ class TPSDBVLVReindexCLI(pki.cli.CLI):
                 argv,
                 'i:D:w:x:g:v',
                 ['instance=', 'bind-dn=', 'bind-password=', 'generate-ldif=',
-                 'verbose', 'help']
-            )
+                 'verbose', 'debug', 'help'])
 
         except getopt.GetoptError as e:
-            print('ERROR: ' + str(e))
+            logger.error(e)
             self.print_help()
             sys.exit(1)
 
@@ -591,27 +607,30 @@ class TPSDBVLVReindexCLI(pki.cli.CLI):
             elif o in ('-g', '--generate-ldif'):
                 out_file = a
 
+            elif o == '--debug':
+                logging.getLogger().setLevel(logging.DEBUG)
+
             elif o in ('-v', '--verbose'):
-                self.set_verbose(True)
+                logging.getLogger().setLevel(logging.INFO)
 
             elif o == '--help':
                 self.print_help()
                 sys.exit()
 
             else:
-                print('ERROR: unknown option ' + o)
+                logger.error('Unknown option: %s', o)
                 self.print_help()
                 sys.exit(1)
 
-        instance = pki.server.PKIInstance(instance_name)
+        instance = pki.server.instance.PKIInstance(instance_name)
         if not instance.is_valid():
-            print('ERROR: Invalid instance %s.' % instance_name)
+            logger.error('Invalid instance %s.', instance_name)
             sys.exit(1)
         instance.load()
 
         subsystem = instance.get_subsystem('tps')
         if not subsystem:
-            print("ERROR: No TPS subsystem in instance %s." % instance_name)
+            logger.error('No TPS subsystem in instance %s.', instance_name)
             sys.exit(1)
 
         if out_file:
@@ -638,8 +657,7 @@ class TPSDBVLVReindexCLI(pki.cli.CLI):
 
             for dn, entry in parser.all_records:
 
-                if self.verbose:
-                    print('Adding %s' % dn)
+                logger.info('Adding %s', dn)
 
                 add_modlist = ldap.modlist.addModlist(entry)
                 conn.ldap.add_s(dn, add_modlist)
@@ -648,8 +666,7 @@ class TPSDBVLVReindexCLI(pki.cli.CLI):
                     time.sleep(1)
 
                     try:
-                        if self.verbose:
-                            print('Checking %s' % dn)
+                        logger.info('Checking %s', dn)
 
                         conn.ldap.search_s(dn, ldap.SCOPE_BASE)
                     except ldap.NO_SUCH_OBJECT:
