@@ -27,7 +27,6 @@ import ldap
 import logging
 import os
 import random
-import requests.exceptions
 import string
 import xml.etree.ElementTree as ET
 
@@ -185,8 +184,6 @@ class PKIConfigParser:
             help='display verbose information (details below)')
 
         self.indent = 0
-        self.ds_connection = None
-        self.sd_connection = None
         self.authdb_connection = None
 
         # Master and Slot dictionaries
@@ -204,15 +201,12 @@ class PKIConfigParser:
         # Process 'Optional' command-line options
         #    '-v'
         if args.pki_verbosity == 1:
-            config.pki_console_log_level = logging.INFO
+            config.pki_log_level = logging.INFO
         elif args.pki_verbosity >= 2:
-            config.pki_console_log_level = logging.DEBUG
+            config.pki_log_level = logging.DEBUG
         else:
             # Set default log levels
-            config.pki_console_log_level = logging.WARNING
-
-        # Debug log is always at DEBUG level
-        config.pki_log_level = logging.DEBUG
+            config.pki_log_level = logging.WARNING
 
         return args
 
@@ -326,17 +320,6 @@ class PKIConfigParser:
                     values[name] = value
         return values
 
-    def set_property(self, section, key, value):
-        if section != "DEFAULT" and not self.deployer.main_config.has_section(section):
-            self.deployer.main_config.add_section(section)
-        self.deployer.main_config.set(section, key, value)
-        self.deployer.flatten_master_dict()
-
-        if section != "DEFAULT" and not self.deployer.user_config.has_section(
-                section):
-            self.deployer.user_config.add_section(section)
-        self.deployer.user_config.set(section, key, value)
-
     def print_text(self, message):
         print(' ' * self.indent + message)
 
@@ -379,7 +362,7 @@ class PKIConfigParser:
 
         value = value.replace("%", "%%")
         if section:
-            self.set_property(section, key, value)
+            self.deployer.set_property(key, value, section=section)
 
         return value
 
@@ -407,7 +390,7 @@ class PKIConfigParser:
 
         password = password.replace("%", "%%")
         if section:
-            self.set_property(section, key, password)
+            self.deployer.set_property(key, password, section=section)
 
         return password
 
@@ -522,100 +505,6 @@ class PKIConfigParser:
 
             print('WARNING: %s' % message)
 
-    def ds_connect(self):
-
-        hostname = self.mdict['pki_ds_hostname']
-
-        if config.str2bool(self.mdict['pki_ds_secure_connection']):
-            protocol = 'ldaps'
-            port = self.mdict['pki_ds_ldaps_port']
-            # ldap.set_option(ldap.OPT_DEBUG_LEVEL, 255)
-            ldap.set_option(ldap.OPT_X_TLS_DEMAND, True)
-            ldap.set_option(ldap.OPT_X_TLS, ldap.OPT_X_TLS_DEMAND)
-            ldap.set_option(ldap.OPT_X_TLS_CACERTFILE,
-                            self.mdict['pki_ds_secure_connection_ca_pem_file'])
-            ldap.set_option(ldap.OPT_X_TLS_REQUIRE_CERT, ldap.OPT_X_TLS_DEMAND)
-        else:
-            protocol = 'ldap'
-            port = self.mdict['pki_ds_ldap_port']
-
-        self.ds_connection = ldap.initialize(
-            protocol + '://' + hostname + ':' + port)
-
-    def ds_bind(self):
-        self.ds_connection.simple_bind_s(
-            self.mdict['pki_ds_bind_dn'],
-            self.mdict['pki_ds_password'])
-
-    def ds_search(self, key=None):
-        if key is None:
-            key = ''
-        return self.ds_connection.search_s(key, ldap.SCOPE_BASE)
-
-    def ds_close(self):
-        self.ds_connection.unbind_s()
-
-    def ds_verify_configuration(self):
-
-        try:
-            self.ds_connect()
-            self.ds_bind()
-            self.ds_search()
-        finally:
-            self.ds_close()
-
-    def ds_base_dn_exists(self):
-        base_dn_exists = True
-        try:
-            self.ds_connect()
-            self.ds_bind()
-            self.ds_search()
-            try:
-                results = self.ds_search(self.mdict['pki_ds_base_dn'])
-
-                if results is None or len(results) == 0:
-                    base_dn_exists = False
-
-            except ldap.NO_SUCH_OBJECT:
-                base_dn_exists = False
-        finally:
-            self.ds_close()
-        return base_dn_exists
-
-    def sd_connect(self):
-        self.sd_connection = pki.client.PKIConnection(
-            protocol='https',
-            hostname=self.mdict['pki_security_domain_hostname'],
-            port=self.mdict['pki_security_domain_https_port'],
-            subsystem='ca',
-            trust_env=False)
-
-    def sd_get_info(self):
-        sd = pki.system.SecurityDomainClient(self.sd_connection)
-        try:
-            info = sd.get_security_domain_info()
-        except requests.exceptions.HTTPError as e:
-            logger.warning('Unable to get security domain info: %s', e)
-            logger.info('Trying older interface.')
-            info = sd.get_old_security_domain_info()
-        return info
-
-    def sd_authenticate(self):
-        self.sd_connection.authenticate(
-            self.mdict['pki_security_domain_user'],
-            self.mdict['pki_security_domain_password'])
-
-        account = pki.account.AccountClient(self.sd_connection)
-        try:
-            account.login()
-            account.logout()
-        except requests.exceptions.HTTPError as e:
-            code = e.response.status_code
-            if code == 404 or code == 501:
-                logger.warning('Unable to authenticate against security domain: %s', e)
-            else:
-                raise
-
     def authdb_connect(self):
 
         hostname = self.mdict['pki_authdb_hostname']
@@ -650,9 +539,8 @@ class PKIConfigParser:
             protocol=parse.scheme,
             hostname=parse.hostname,
             port=str(parse.port),
-            subsystem=system_type,
             trust_env=False)
-        client = pki.system.SystemStatusClient(conn)
+        client = pki.system.SystemStatusClient(conn, subsystem=system_type)
         response = client.get_status()
         root = ET.fromstring(response)
         return root.findtext("Status")
