@@ -26,6 +26,7 @@ import logging
 import os
 import shutil
 import tempfile
+import urllib.parse
 
 # PKI Deployment Imports
 from .. import pkiconfig as config
@@ -34,6 +35,7 @@ from .. import pkiscriptlet
 import pki.encoder
 import pki.nssdb
 import pki.server
+import pki.server.instance
 import pki.system
 import pki.util
 
@@ -545,7 +547,7 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
         if PKISPAWN_STARTUP_TIMEOUT_SECONDS <= 0:
             PKISPAWN_STARTUP_TIMEOUT_SECONDS = 60
 
-        instance = pki.server.PKIInstance(deployer.mdict['pki_instance_name'])
+        instance = pki.server.instance.PKIInstance(deployer.mdict['pki_instance_name'])
         instance.load()
 
         subsystem = instance.get_subsystem(deployer.mdict['pki_subsystem'].lower())
@@ -567,21 +569,6 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
         if config.str2bool(deployer.mdict['pki_share_db']):
             subsystem.config['preop.internaldb.dbuser'] = deployer.mdict['pki_share_dbuser_dn']
 
-        if config.str2bool(deployer.mdict['pki_ds_create_new_db']):
-            subsystem.config['preop.database.createNewDB'] = 'true'
-        else:
-            subsystem.config['preop.database.createNewDB'] = 'false'
-
-        if config.str2bool(deployer.mdict['pki_ds_remove_data']):
-            subsystem.config['preop.database.removeData'] = 'true'
-        else:
-            subsystem.config['preop.database.removeData'] = 'false'
-
-        # configure cloning
-        subsystem.config['preop.database.setupReplication'] = \
-            deployer.mdict['pki_clone_setup_replication']
-        subsystem.config['preop.database.reindexData'] = deployer.mdict['pki_clone_reindex_data']
-
         ocsp_uri = deployer.mdict.get('pki_default_ocsp_uri')
         if ocsp_uri:
             subsystem.config['ca.defaultOcspUri'] = ocsp_uri
@@ -663,6 +650,159 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
 
         create_temp_sslserver_cert = self.create_temp_sslserver_cert(deployer, instance)
 
+        server_config = instance.get_server_config()
+        unsecurePort = server_config.get_unsecure_port()
+        securePort = server_config.get_secure_port()
+
+        if deployer.mdict['pki_security_domain_type'] == 'existing':
+
+            logger.info('Joining existing domain')
+
+            deployer.join_domain()
+
+            subsystem.config['securitydomain.name'] = deployer.domain_info.id
+            subsystem.config['securitydomain.select'] = 'existing'
+
+            # hostname and ports point to security domain
+            subsystem.config['securitydomain.host'] = deployer.sd_host.Hostname
+            subsystem.config['securitydomain.httpport'] = deployer.sd_host.Port
+            subsystem.config['securitydomain.httpseeport'] = deployer.sd_host.SecurePort
+            subsystem.config['securitydomain.httpsadminport'] = deployer.sd_host.SecureAdminPort
+            subsystem.config['securitydomain.httpsagentport'] = deployer.sd_host.SecureAgentPort
+
+        elif config.str2bool(deployer.mdict['pki_subordinate']) and \
+                config.str2bool(deployer.mdict['pki_subordinate_create_new_security_domain']):
+
+            logger.info('Creating new security subdomain')
+
+            deployer.join_domain()
+
+            sd_name = deployer.mdict['pki_subordinate_security_domain_name']
+            subsystem.config['securitydomain.name'] = sd_name
+            subsystem.config['securitydomain.select'] = 'new'
+
+            # hostname and ports point to current host
+            subsystem.config['securitydomain.host'] = deployer.mdict['pki_hostname']
+            subsystem.config['securitydomain.httpport'] = unsecurePort
+            subsystem.config['securitydomain.httpsagentport'] = securePort
+            subsystem.config['securitydomain.httpseeport'] = securePort
+            subsystem.config['securitydomain.httpsadminport'] = securePort
+
+        else:
+
+            logger.info('Creating new security domain')
+
+            sd_name = deployer.mdict['pki_security_domain_name']
+            subsystem.config['securitydomain.name'] = sd_name
+            subsystem.config['securitydomain.select'] = 'new'
+
+            # hostname and ports point to current host
+            subsystem.config['securitydomain.host'] = deployer.mdict['pki_hostname']
+            subsystem.config['securitydomain.httpport'] = unsecurePort
+            subsystem.config['securitydomain.httpsagentport'] = securePort
+            subsystem.config['securitydomain.httpseeport'] = securePort
+            subsystem.config['securitydomain.httpsadminport'] = securePort
+
+        subsystem.config['service.securityDomainPort'] = securePort
+        subsystem.config['securitydomain.store'] = 'ldap'
+
+        hierarchy = subsystem.config.get('hierarchy.select')
+        if not (subsystem.type == 'CA' and hierarchy == 'Root'):
+
+            issuing_ca = deployer.mdict['pki_issuing_ca']
+
+            if issuing_ca == 'External CA':
+
+                logger.info('Using external CA')
+
+                subsystem.config['preop.ca.type'] = 'otherca'
+                subsystem.config['preop.ca.pkcs7'] = ''
+                subsystem.config['preop.ca.certchain.size'] = '0'
+
+                if subsystem.type == 'CA':
+                    subsystem.config['preop.cert.signing.type'] = 'remote'
+
+            else:
+
+                logger.info('Using CA at %s', issuing_ca)
+
+                url = urllib.parse.urlparse(issuing_ca)
+
+                subsystem.config['preop.ca.url'] = issuing_ca
+                subsystem.config['preop.ca.type'] = 'sdca'
+                subsystem.config['preop.ca.hostname'] = url.hostname
+                subsystem.config['preop.ca.httpsport'] = str(url.port)
+                subsystem.config['preop.ca.httpsadminport'] = str(url.port)
+
+                if subsystem.type == 'CA':
+                    subsystem.config['preop.cert.signing.type'] = 'remote'
+                    subsystem.config['preop.cert.signing.profile'] = 'caInstallCACert'
+
+        subsystem.save()
+
+        if config.str2bool(deployer.mdict['pki_ds_remove_data']):
+
+            if config.str2bool(deployer.mdict['pki_ds_create_new_db']):
+                logger.info('Removing existing database')
+                subsystem.remove_database(force=True)
+
+            elif not config.str2bool(deployer.mdict['pki_clone']) or \
+                    config.str2bool(deployer.mdict['pki_clone_setup_replication']):
+                logger.info('Emptying existing database')
+                subsystem.empty_database(force=True)
+
+            else:
+                logger.info('Reusing replicated database')
+
+        logger.info('Initializing database')
+
+        # In most cases, we want to replicate the schema and therefore not add it here.
+        # We provide this option though in case the clone already has schema
+        # and we want to replicate back to the master.
+
+        # On the other hand, if we are not setting up replication,
+        # then we are assuming that replication is already taken care of,
+        # and schema has already been replicated.
+
+        setup_schema = not config.str2bool(deployer.mdict['pki_clone']) or \
+            not config.str2bool(deployer.mdict['pki_clone_setup_replication']) or \
+            not config.str2bool(deployer.mdict['pki_clone_replicate_schema'])
+
+        create_database = config.str2bool(deployer.mdict['pki_ds_create_new_db'])
+
+        # When cloning a subsystem without setting up the replication agreements,
+        # the database is a subtree of an existing tree and is already replicated,
+        # so there is no need to set up the base entry.
+
+        create_base = config.str2bool(deployer.mdict['pki_ds_create_new_db']) or \
+            not config.str2bool(deployer.mdict['pki_clone']) or \
+            config.str2bool(deployer.mdict['pki_clone_setup_replication'])
+
+        create_containers = not config.str2bool(deployer.mdict['pki_clone'])
+
+        # If the database is already replicated but not yet indexed, rebuild the indexes.
+
+        rebuild_indexes = config.str2bool(deployer.mdict['pki_clone']) and \
+            not config.str2bool(deployer.mdict['pki_clone_setup_replication']) and \
+            config.str2bool(deployer.mdict['pki_clone_reindex_data'])
+
+        setup_db_manager = not config.str2bool(deployer.mdict['pki_clone']) or \
+            not config.str2bool(deployer.mdict['pki_clone_setup_replication'])
+
+        # If setting up replication, set up VLV indexes after replication.
+
+        setup_vlv_indexes = not config.str2bool(deployer.mdict['pki_clone']) or \
+            not config.str2bool(deployer.mdict['pki_clone_setup_replication'])
+
+        subsystem.init_database(
+            setup_schema=setup_schema,
+            create_database=create_database,
+            create_base=create_base,
+            create_containers=create_containers,
+            rebuild_indexes=rebuild_indexes,
+            setup_db_manager=setup_db_manager,
+            setup_vlv_indexes=setup_vlv_indexes)
+
         # Start/Restart this Tomcat PKI Process
         # Optionally prepare to enable a java debugger
         # (e. g. - 'eclipse'):
@@ -704,28 +844,39 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
             protocol='https',
             hostname=deployer.mdict['pki_hostname'],
             port=deployer.mdict['pki_https_port'],
-            subsystem=deployer.mdict['pki_subsystem_type'],
             trust_env=False)
 
-        client = pki.system.SystemConfigClient(connection)
+        client = pki.system.SystemConfigClient(
+            connection,
+            subsystem=deployer.mdict['pki_subsystem_type'])
 
         logger.info('Configuring %s subsystem', subsystem.type)
+
         request = deployer.config_client.create_config_request()
         client.configure(request)
 
+        if clone:
+
+            logger.info('Setting up clone')
+
+            clone_setup_request = deployer.config_client.create_clone_setup_request(subsystem)
+            clone_setup_request.domainInfo = deployer.domain_info
+            clone_setup_request.installToken = deployer.install_token
+            client.setupClone(clone_setup_request)
+
         logger.info('Setting up database')
 
         database_setup_request = deployer.config_client.create_database_setup_request()
         client.setupDatabase(database_setup_request)
 
         sslserver = subsystem.get_subsystem_cert('sslserver')
-        cert_setup_request = deployer.config_client.create_certificate_setup_request()
 
         for tag in subsystem.config['preop.cert.list'].split(','):
 
             logger.info('Setting up %s certificate', tag)
 
-            cert_setup_request.tag = tag
+            cert_setup_request = deployer.config_client.create_certificate_setup_request(tag)
+            cert_setup_request.installToken = deployer.install_token
             cert = client.setupCert(cert_setup_request)
 
             if not cert:
@@ -737,12 +888,14 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
             if tag == 'sslserver':
                 sslserver['data'] = cert['cert']
                 sslserver['request'] = cert['request']
+                sslserver['token'] = cert['token']
 
         if not clone:
 
             logger.info('Setting up admin user')
 
             admin_setup_request = deployer.config_client.create_admin_setup_request()
+            admin_setup_request.installToken = deployer.install_token
             admin_setup_response = client.setupAdmin(admin_setup_request)
 
             if external or standalone \
@@ -759,12 +912,12 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
                     deployer.mdict['pki_subsystem'].lower() + '_backup_keys.p12'
 
             logger.info('Backing up keys into %s', deployer.mdict['pki_backup_file'])
-
-            key_backup_request = deployer.config_client.create_key_backup_request()
-            client.backupKeys(key_backup_request)
+            deployer.backup_keys(instance, subsystem)
 
         logger.info('Setting up security domain')
         sd_setup_request = deployer.config_client.create_security_domain_setup_request()
+        sd_setup_request.domainInfo = deployer.domain_info
+        sd_setup_request.installToken = deployer.install_token
         client.setupSecurityDomain(sd_setup_request)
 
         if not config.str2bool(deployer.mdict['pki_share_db']):
@@ -774,8 +927,14 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
 
         logger.info('Finalizing %s configuration', subsystem.type)
         finalize_config_request = deployer.config_client.create_finalize_config_request()
+        finalize_config_request.domainInfo = deployer.domain_info
+        finalize_config_request.installToken = deployer.install_token
         client.finalizeConfiguration(finalize_config_request)
 
+        if subsystem.type == 'TPS':
+            logger.info('Setting up shared secret')
+            deployer.setup_shared_secret(instance, subsystem)
+
         logger.info('%s configuration complete', subsystem.type)
 
         # Create an empty file that designates the fact that although
@@ -804,7 +963,11 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
             if not (standalone or external and subsystem.name in ['kra', 'ocsp']):
 
                 nickname = sslserver['nickname']
-                token = sslserver['token']
+                token = pki.nssdb.normalize_token(sslserver['token'])
+
+                if not token:
+                    token = deployer.mdict['pki_token_name']
+
                 instance.set_sslserver_cert_nickname(nickname, token)
 
                 self.import_perm_sslserver_cert(deployer, instance, sslserver)
