@@ -24,10 +24,10 @@ import logging
 import os
 
 import pki
+import pki.server.instance
 
 # PKI Deployment Imports
 from .. import pkiconfig as config
-from .. import pkimessages as log
 from .. import pkiscriptlet
 
 logger = logging.getLogger('instance')
@@ -42,27 +42,94 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
             logger.info('Skipping instance creation')
             return
 
+        logger.info('Preparing %s instance', deployer.mdict['pki_instance_name'])
+
+        instance = pki.server.instance.PKIInstance(deployer.mdict['pki_instance_name'])
+        instance.load()
+
+        instance_conf_path = deployer.mdict['pki_instance_configuration_path']
+
+        logger.info('Creating %s', instance_conf_path)
+        instance.makedirs(instance_conf_path, force=True)
+
+        logger.info('Creating password config %s', deployer.mdict['pki_shared_password_conf'])
+
+        # Configuring internal token password
+
+        internal_token = deployer.mdict['pki_self_signed_token']
+        if not pki.nssdb.normalize_token(internal_token):
+            internal_token = pki.nssdb.INTERNAL_TOKEN_NAME
+
+        # If instance already exists and has password, reuse the password
+        if internal_token in instance.passwords:
+            logger.info('Reusing server NSS database password')
+            deployer.mdict['pki_server_database_password'] = instance.passwords.get(internal_token)
+
+        # Otherwise, use user-provided password if specified
+        elif deployer.mdict['pki_server_database_password']:
+            logger.info('Using specified server NSS database password')
+
+        # Otherwise, use user-provided pin if specified
+        elif deployer.mdict['pki_pin']:
+            logger.info('Using specified PIN as server NSS database password')
+            deployer.mdict['pki_server_database_password'] = deployer.mdict['pki_pin']
+
+        # Otherwise, generate a random password
+        else:
+            logger.info('Generating random server NSS database password')
+            deployer.mdict['pki_server_database_password'] = pki.generate_password()
+
+        instance.passwords[internal_token] = deployer.mdict['pki_server_database_password']
+
+        # Configuring HSM password
+
+        if config.str2bool(deployer.mdict['pki_hsm_enable']):
+            hsm_token = deployer.mdict['pki_token_name']
+            instance.passwords['hardware-%s' % hsm_token] = deployer.mdict['pki_token_password']
+
+        # Configuring internal database password
+
+        if 'internaldb' in instance.passwords:
+            logger.info('Reusing internal database password')
+            deployer.mdict['pki_ds_password'] = instance.passwords.get('internaldb')
+
+        else:
+            logger.info('Using specified internal database password')
+
+        instance.passwords['internaldb'] = deployer.mdict['pki_ds_password']
+
+        # Configuring replication manager password
+        # Bug #430745 Create separate password for replication manager
+        # Use user-provided password if specified
+
+        if 'replicationdb' in instance.passwords:
+            logger.info('Reusing replication manager password')
+
+        elif deployer.mdict['pki_replication_password']:
+            logger.info('Using specified replication manager password')
+            instance.passwords['replicationdb'] = deployer.mdict['pki_replication_password']
+
+        else:
+            logger.info('Generating random replication manager password')
+            instance.passwords['replicationdb'] = pki.generate_password()
+
+        instance.store_passwords()
+
         # if this is not the first subsystem, skip
         if len(deployer.instance.tomcat_instance_subsystems()) != 1:
             logger.info('Installing %s instance', deployer.mdict['pki_instance_name'])
             return
 
-        logger.info('Creating new %s instance', deployer.mdict['pki_instance_name'])
-
-        instance = pki.server.PKIInstance(deployer.mdict['pki_instance_name'])
-        instance.load()
-
         # establish instance logs
         deployer.directory.create(deployer.mdict['pki_instance_log_path'])
 
-        logger.info('Creating %s', deployer.mdict['pki_instance_configuration_path'])
-        # copy /usr/share/pki/server/conf tree into
-        # /var/lib/pki/<instance>/conf
-        # except common ldif files and theme deployment descriptor
-        deployer.directory.copy(
-            deployer.mdict['pki_source_server_path'],
-            deployer.mdict['pki_instance_configuration_path'],
-            ignore_cb=file_ignore_callback_src_server)
+        shared_conf_path = deployer.mdict['pki_source_server_path']
+
+        # Copy /usr/share/pki/server/conf/tomcat.conf to
+        # /var/lib/pki/<instance>/conf/tomcat.conf.
+        deployer.file.copy_with_slot_substitution(
+            os.path.join(shared_conf_path, 'tomcat.conf'),
+            os.path.join(instance_conf_path, 'tomcat.conf'))
 
         logger.info('Creating %s', deployer.mdict['pki_target_server_xml'])
         # Copy /usr/share/pki/server/conf/server.xml
@@ -74,45 +141,29 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
 
         # Link /etc/pki/<instance>/catalina.properties
         # to /usr/share/pki/server/conf/catalina.properties.
-        deployer.symlink.create(
-            os.path.join(deployer.mdict['pki_source_server_path'],
-                         "catalina.properties"),
-            os.path.join(deployer.mdict['pki_instance_configuration_path'],
-                         "catalina.properties"))
+        instance.symlink(
+            os.path.join(shared_conf_path, 'catalina.properties'),
+            os.path.join(instance_conf_path, 'catalina.properties'),
+            force=True)
 
         # Link /etc/pki/<instance>/ciphers.info
         # to /usr/share/pki/server/conf/ciphers.info.
-        deployer.symlink.create(
-            os.path.join(deployer.mdict['pki_source_server_path'],
-                         "ciphers.info"),
-            os.path.join(deployer.mdict['pki_instance_configuration_path'],
-                         "ciphers.info"))
+        instance.symlink(
+            os.path.join(shared_conf_path, 'ciphers.info'),
+            os.path.join(instance_conf_path, 'ciphers.info'),
+            force=True)
 
         # Link /etc/pki/<instance>/context.xml
         # to /usr/share/tomcat/conf/context.xml.
-        deployer.symlink.create(
-            os.path.join(deployer.mdict['CATALINA_HOME'],
-                         "conf",
-                         "context.xml"),
-            os.path.join(deployer.mdict['pki_instance_configuration_path'],
-                         "context.xml"))
+        context_xml = os.path.join(pki.server.Tomcat.CONF_DIR, 'context.xml')
+        instance.symlink(context_xml, instance.context_xml, force=True)
 
         # Link /etc/pki/<instance>/logging.properties
         # to /usr/share/pki/server/conf/logging.properties.
-        deployer.symlink.create(
-            os.path.join(deployer.mdict['pki_source_server_path'],
-                         "logging.properties"),
-            os.path.join(deployer.mdict['pki_instance_configuration_path'],
-                         "logging.properties"))
-
-        # Link /etc/pki/<instance>/web.xml
-        # to /usr/share/tomcat/conf/web.xml.
-        deployer.symlink.create(
-            os.path.join(deployer.mdict['CATALINA_HOME'],
-                         "conf",
-                         "web.xml"),
-            os.path.join(deployer.mdict['pki_instance_configuration_path'],
-                         "web.xml"))
+        instance.symlink(
+            os.path.join(shared_conf_path, 'logging.properties'),
+            os.path.join(instance_conf_path, 'logging.properties'),
+            force=True)
 
         logger.info('Creating %s', deployer.mdict['pki_target_tomcat_conf_instance_id'])
         # create /etc/sysconfig/<instance>
@@ -128,11 +179,24 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
             deployer.mdict['pki_target_tomcat_conf'],
             overwrite_flag=True)
 
+        # Link /etc/pki/<instance>/web.xml
+        # to /usr/share/tomcat/conf/web.xml.
+        web_xml = os.path.join(pki.server.Tomcat.CONF_DIR, 'web.xml')
+        instance.symlink(web_xml, instance.web_xml, force=True)
+
+        catalina_dir = os.path.join(instance_conf_path, 'Catalina')
+        logger.info('Creating %s', catalina_dir)
+        instance.makedirs(catalina_dir, force=True)
+
+        localhost_dir = os.path.join(catalina_dir, 'localhost')
+        logger.info('Creating %s', localhost_dir)
+        instance.makedirs(localhost_dir, force=True)
+
         logger.info('Deploying ROOT web application')
         instance.deploy_webapp(
             "ROOT",
             os.path.join(
-                deployer.mdict['pki_source_server_path'],
+                shared_conf_path,
                 "Catalina",
                 "localhost",
                 "ROOT.xml"))
@@ -143,22 +207,13 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
         instance.deploy_webapp(
             "pki",
             os.path.join(
-                deployer.mdict['pki_source_server_path'],
+                shared_conf_path,
                 "Catalina",
                 "localhost",
                 "pki.xml"))
 
-        logger.info('Creating %s', deployer.mdict['pki_instance_lib'])
-        # Link /var/lib/pki/<instance>/lib to /usr/share/pki/server/lib
-        deployer.symlink.create(
-            '/usr/share/pki/server/lib',
-            deployer.mdict['pki_instance_lib'])
-
-        logger.info('Creating %s', deployer.mdict['pki_tomcat_common_path'])
-        # Link /var/lib/pki/<instance>/common to /usr/share/pki/server/common
-        deployer.symlink.create(
-            '/usr/share/pki/server/common',
-            deployer.mdict['pki_tomcat_common_path'])
+        instance.with_maven_deps = deployer.with_maven_deps
+        instance.create_libs(force=True)
 
         deployer.directory.create(deployer.mdict['pki_tomcat_tmpdir_path'])
 
@@ -194,14 +249,8 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
         deployer.systemd.write_overrides()
         deployer.systemd.daemon_reload()
 
-        # establish shared NSS security databases for this instance
-        deployer.directory.create(deployer.mdict['pki_server_database_path'])
-        # establish instance convenience symbolic links
         deployer.symlink.create(
-            deployer.mdict['pki_server_database_path'],
-            deployer.mdict['pki_instance_database_link'])
-        deployer.symlink.create(
-            deployer.mdict['pki_instance_configuration_path'],
+            instance_conf_path,
             deployer.mdict['pki_instance_conf_link'])
         deployer.symlink.create(
             deployer.mdict['pki_instance_log_path'],
@@ -220,12 +269,12 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
 
     def destroy(self, deployer):
 
-        logger.info('Removing %s instance', deployer.mdict['pki_instance_name'])
-
         # if this is not the last subsystem, skip
-        if len(deployer.instance.tomcat_instance_subsystems()) != 0:
+        if len(deployer.instance.tomcat_instance_subsystems()) > 0:
             return
 
+        logger.info('Removing %s instance', deployer.mdict['pki_instance_name'])
+
         # remove Tomcat instance systemd service link
         deployer.symlink.delete(deployer.systemd.systemd_link)
 
@@ -243,8 +292,6 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
         if deployer.mdict['pki_remove_logs']:
             deployer.directory.delete(deployer.mdict['pki_instance_log_path'])
 
-        # remove shared NSS security database path for this instance
-        deployer.directory.delete(deployer.mdict['pki_server_database_path'])
         # remove Tomcat instance configuration
         deployer.directory.delete(
             deployer.mdict['pki_instance_configuration_path'])
@@ -254,22 +301,3 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
         # remove Tomcat instance registry
         deployer.directory.delete(
             deployer.mdict['pki_instance_registry_path'])
-
-
-# Callback only when the /usr/share/pki/server/conf directory
-# Is getting copied to the etc tree.
-# Don't copy the shared ldif files:
-# schema.ldif, manager.ldif, database.ldif
-def file_ignore_callback_src_server(src, names):
-    logger.debug(log.FILE_EXCLUDE_CALLBACK_2, src, names)
-
-    return {
-        'catalina.properties',
-        'ciphers.info',
-        'schema.ldif',
-        'database.ldif',
-        'manager.ldif',
-        'pki.xml',
-        'logging.properties',
-        'serverCertNick.conf'
-    }
