@@ -26,6 +26,7 @@ import re
 import pki.encoder
 import pki.nssdb
 import pki.server
+import pki.server.instance
 import pki.system
 import pki.util
 
@@ -455,7 +456,7 @@ class PkiScriptlet(pkiscriptlet.AbstractBasePkiScriptlet):
 
         logger.info('Generating system keys')
 
-        instance = pki.server.PKIInstance(deployer.mdict['pki_instance_name'])
+        instance = pki.server.instance.PKIInstance(deployer.mdict['pki_instance_name'])
         instance.load()
 
         subsystem = instance.get_subsystem(
