@@ -20,13 +20,15 @@
 
 from __future__ import absolute_import
 from __future__ import print_function
+
 import logging
 import subprocess
 import sys
-import traceback
 
 import pki.server.cli
 
+logger = logging.getLogger(__name__)
+
 
 if __name__ == '__main__':
 
@@ -37,19 +39,29 @@ if __name__ == '__main__':
     try:
         cli.execute(sys.argv)
 
-    except KeyboardInterrupt:
-        if logging.getLogger().isEnabledFor(logging.INFO):
-            traceback.print_exc()
+    except KeyboardInterrupt as e:
+
+        if logger.isEnabledFor(logging.INFO):
+            logging.exception(e)
+
         sys.exit(1)
 
     except subprocess.CalledProcessError as e:
-        if logging.getLogger().isEnabledFor(logging.INFO):
-            traceback.print_exc()
-        logging.error('Command: %s', ' '.join(e.cmd))
+
+        if logger.isEnabledFor(logging.DEBUG):
+            logging.exception('Command: %s', ' '.join(e.cmd))
+
+        else:
+            logging.error('Command: %s', ' '.join(e.cmd))
+
         sys.exit(e.returncode)
 
     except Exception as e:  # pylint: disable=broad-except
-        if logging.getLogger().isEnabledFor(logging.INFO):
-            traceback.print_exc()
-        logging.error(e)
+
+        if logger.isEnabledFor(logging.DEBUG):
+            logging.exception(e)
+
+        else:
+            logging.error(e)
+
         sys.exit(1)
