@@ -64,6 +64,37 @@ def interrupt_handler(event, frame):
     sys.exit(1)
 
 
+def verify_ds_configuration():
+    try:
+        deployer.ds_init()
+        deployer.ds_connect()
+        deployer.ds_bind()
+        deployer.ds_search()
+    finally:
+        deployer.ds_close()
+
+
+def base_dn_exists():
+    try:
+        deployer.ds_connect()
+        deployer.ds_bind()
+        deployer.ds_search()
+
+        try:
+            results = deployer.ds_search(deployer.mdict['pki_ds_base_dn'])
+
+            if results is None or len(results) == 0:
+                return False
+
+        except ldap.NO_SUCH_OBJECT:
+            return False
+
+    finally:
+        deployer.ds_close()
+
+    return True
+
+
 # PKI Deployment Functions
 def main(argv):
     """main entry point"""
@@ -109,6 +140,12 @@ def main(argv):
         action='store_true',
         help='enforce strict hostname/FQDN checks')
 
+    parser.optional.add_argument(
+        '--with-maven-deps',
+        dest='with_maven_deps',
+        action='store_true',
+        help='Install Maven dependencies')
+
     args = parser.process_command_line_arguments()
 
     config.default_deployment_cfg = \
@@ -196,14 +233,9 @@ def main(argv):
                 'Password', deployer.subsystem_name, 'pki_admin_password',
                 verifyMessage='Verify password')
 
-            parser.set_property(deployer.subsystem_name, 'pki_backup_password',
-                                admin_password)
-            parser.set_property(deployer.subsystem_name,
-                                'pki_client_database_password',
-                                admin_password)
-            parser.set_property(deployer.subsystem_name,
-                                'pki_client_pkcs12_password',
-                                admin_password)
+            deployer.set_property('pki_backup_password', admin_password)
+            deployer.set_property('pki_client_database_password', admin_password)
+            deployer.set_property('pki_client_pkcs12_password', admin_password)
 
             if parser.mdict['pki_import_admin_cert'] == 'True':
                 import_cert = 'Y'
@@ -216,16 +248,12 @@ def main(argv):
                 sign='?', case_sensitive=False).lower()
 
             if import_cert == 'y' or import_cert == 'yes':
-                parser.set_property(deployer.subsystem_name,
-                                    'pki_import_admin_cert',
-                                    'True')
+                deployer.set_property('pki_import_admin_cert', 'True')
                 parser.read_text('Import certificate from',
                                  deployer.subsystem_name,
                                  'pki_admin_cert_file')
             else:
-                parser.set_property(deployer.subsystem_name,
-                                    'pki_import_admin_cert',
-                                    'False')
+                deployer.set_property('pki_import_admin_cert', 'False')
 
                 parser.read_text('Export certificate to',
                                  deployer.subsystem_name,
@@ -247,21 +275,15 @@ def main(argv):
             #     sys.exit(0)
 
             # TBD:  Interactive HSM installation
-            # parser.set_property(deployer.subsystem_name,
-            #                     'pki_hsm_enable',
-            #                     'True')
+            # deployer.set_property('pki_hsm_enable', 'True')
             # modulename = parser.read_text(
             #     'HSM Module Name (e. g. - nethsm)', allow_empty=False)
-            # parser.set_property(deployer.subsystem_name,
-            #                     'pki_hsm_modulename',
-            #                     modulename)
+            # deployer.set_property('pki_hsm_modulename', modulename)
             # libfile = parser.read_text(
             #     'HSM Lib File ' +
             #     '(e. g. - /opt/nfast/toolkits/pkcs11/libcknfast.so)',
             #     allow_empty=False)
-            # parser.set_property(deployer.subsystem_name,
-            #                     'pki_hsm_libfile',
-            #                     libfile)
+            # deployer.set_property('pki_hsm_libfile', libfile)
             print()
 
             print("Directory Server:")
@@ -287,9 +309,7 @@ def main(argv):
 
                 if secure == 'y' or secure == 'yes':
                     # Set secure DS connection to true
-                    parser.set_property(deployer.subsystem_name,
-                                        'pki_ds_secure_connection',
-                                        'True')
+                    deployer.set_property('pki_ds_secure_connection', 'True')
                     # Prompt for secure 'ldaps' port
                     parser.read_text('Secure LDAPS Port',
                                      deployer.subsystem_name,
@@ -299,9 +319,7 @@ def main(argv):
                     pem_file = parser.read_text(
                         'Directory Server CA certificate pem file',
                         allow_empty=False)
-                    parser.set_property(deployer.subsystem_name,
-                                        'pki_ds_secure_connection_ca_pem_file',
-                                        pem_file)
+                    deployer.set_property('pki_ds_secure_connection_ca_pem_file', pem_file)
                 else:
                     parser.read_text('LDAP Port',
                                      deployer.subsystem_name,
@@ -315,17 +333,21 @@ def main(argv):
                                      'pki_ds_password')
 
                 try:
-                    parser.ds_verify_configuration()
+                    verify_ds_configuration()
 
                 except ldap.LDAPError as e:
                     parser.print_text('ERROR: ' + e.args[0]['desc'])
+
+                    # Force deployer to re-initialize the DS connection string
+                    # next time, as we're in interactive mode here.
+                    deployer.ds_url = None
                     continue
 
                 parser.read_text('Base DN',
                                  deployer.subsystem_name,
                                  'pki_ds_base_dn')
                 try:
-                    if not parser.ds_base_dn_exists():
+                    if not base_dn_exists():
                         break
 
                 except ldap.LDAPError as e:
@@ -364,12 +386,10 @@ def main(argv):
                                      'pki_security_domain_https_port')
 
                     try:
-                        parser.sd_connect()
-                        info = parser.sd_get_info()
-                        parser.print_text('Name: ' + info.name)
-                        parser.set_property(deployer.subsystem_name,
-                                            'pki_security_domain_name',
-                                            info.name)
+                        deployer.sd_connect()
+                        info = deployer.get_domain_info()
+                        parser.print_text('Name: ' + info.id)
+                        deployer.set_property('pki_security_domain_name', info.id)
                         break
                     except pki.RETRYABLE_EXCEPTIONS as e:
                         parser.print_text('ERROR: ' + str(e))
@@ -383,7 +403,8 @@ def main(argv):
                                          'pki_security_domain_password')
 
                     try:
-                        parser.sd_authenticate()
+                        deployer.sd_login()
+                        deployer.sd_logout()
                         break
                     except requests.exceptions.HTTPError as e:
                         parser.print_text('ERROR: ' + str(e))
@@ -424,9 +445,7 @@ def main(argv):
                         sign='?', case_sensitive=False).lower()
 
                     if keygen == 'y' or keygen == 'yes':
-                        parser.set_property(deployer.subsystem_name,
-                                            'pki_enable_server_side_keygen',
-                                            'True')
+                        deployer.set_property('pki_enable_server_side_keygen', 'True')
 
                         parser.read_text('KRA URL',
                                          deployer.subsystem_name,
@@ -440,9 +459,7 @@ def main(argv):
                         except pki.RETRYABLE_EXCEPTIONS as e:
                             parser.print_text('ERROR: ' + str(e))
                     else:
-                        parser.set_property(deployer.subsystem_name,
-                                            'pki_enable_server_side_keygen',
-                                            'False')
+                        deployer.set_property('pki_enable_server_side_keygen', 'False')
                         break
 
                 print()
@@ -457,9 +474,7 @@ def main(argv):
                                      deployer.subsystem_name,
                                      'pki_authdb_port')
                     basedn = parser.read_text('Base DN', allow_empty=False)
-                    parser.set_property(deployer.subsystem_name,
-                                        'pki_authdb_basedn',
-                                        basedn)
+                    deployer.set_property('pki_authdb_basedn', basedn)
 
                     try:
                         parser.authdb_connect()
@@ -508,20 +523,19 @@ def main(argv):
 
     # --skip-configuration
     if args.skip_configuration:
-        parser.set_property(deployer.subsystem_name,
-                            'pki_skip_configuration', 'True')
+        deployer.set_property('pki_skip_configuration', 'True')
 
     # --skip-installation
     if args.skip_installation:
-        parser.set_property(deployer.subsystem_name,
-                            'pki_skip_installation', 'True')
+        deployer.set_property('pki_skip_installation', 'True')
 
     create_master_dictionary(parser)
+    deployer.init()
 
     if not interactive and \
             not config.str2bool(parser.mdict['pki_skip_configuration']):
-        check_ds(parser)
-        check_security_domain(parser)
+        check_ds()
+        check_security_domain()
 
     if args.precheck:
         print('pre-checks completed successfully.')
@@ -532,7 +546,9 @@ def main(argv):
 
     # Process the various "scriptlets" to create the specified PKI subsystem.
     pki_subsystem_scriptlets = parser.mdict['spawn_scriplets'].split()
-    deployer.init(parser)
+
+    logger.debug('Installing Maven dependencies: %s', args.with_maven_deps)
+    deployer.with_maven_deps = args.with_maven_deps
 
     try:
         for scriptlet_name in pki_subsystem_scriptlets:
@@ -675,7 +691,6 @@ def start_logging():
     pkilogging.enable_pki_logger(config.pki_log_dir,
                                  config.pki_log_name,
                                  config.pki_log_level,
-                                 config.pki_console_log_level,
                                  "pkispawn")
 
 
@@ -694,60 +709,56 @@ def create_master_dictionary(parser):
     logger.debug(pkilogging.log_format(parser.mdict))
 
 
-def check_security_domain(parser):
-    if parser.mdict['pki_security_domain_type'] != "new":
-        try:
-            # Verify existence of Security Domain Password
-            if 'pki_security_domain_password' not in parser.mdict or \
-                    not len(parser.mdict['pki_security_domain_password']):
-                logger.error(
-                    log.PKIHELPER_UNDEFINED_CONFIGURATION_FILE_ENTRY_2,
-                    "pki_security_domain_password",
-                    parser.mdict['pki_user_deployment_cfg'])
-                sys.exit(1)
+def check_security_domain():
 
-            if not config.str2bool(parser.mdict['pki_skip_sd_verify']):
-                parser.sd_connect()
-                info = parser.sd_get_info()
-                parser.set_property(deployer.subsystem_name,
-                                    'pki_security_domain_name',
-                                    info.name)
-                parser.sd_authenticate()
+    # If the subsystem being installed is joining an existing security domain,
+    # or it is a subordinate CA (either joining the security domain or creating
+    # a new one), connect to and authenticate against the security domain.
 
-        except requests.exceptions.RequestException as e:
-            print(('ERROR:  Unable to access security domain: ' + str(e)))
-            sys.exit(1)
+    if deployer.mdict['pki_security_domain_type'] == 'existing' \
+            or config.str2bool(deployer.mdict['pki_subordinate']):
+
+        if 'pki_security_domain_password' not in deployer.mdict or \
+                not len(deployer.mdict['pki_security_domain_password']):
+            raise Exception('Missing security domain password')
+
+        deployer.sd_connect()
+
+        info = deployer.get_domain_info()
+        deployer.set_property('pki_security_domain_name', info.id)
+
+        logger.info('Logging into security domain %s', info.id)
+
+        deployer.sd_login()
 
 
-def check_ds(parser):
+def check_ds():
     try:
         # Verify existence of Directory Server Password
-        if 'pki_ds_password' not in parser.mdict or \
-                not len(parser.mdict['pki_ds_password']):
+        if 'pki_ds_password' not in deployer.mdict or \
+                not len(deployer.mdict['pki_ds_password']):
             logger.error(
                 log.PKIHELPER_UNDEFINED_CONFIGURATION_FILE_ENTRY_2,
                 "pki_ds_password",
-                parser.mdict['pki_user_deployment_cfg'])
+                deployer.mdict['pki_user_deployment_cfg'])
             sys.exit(1)
 
-        if not config.str2bool(parser.mdict['pki_skip_ds_verify']):
-            parser.ds_verify_configuration()
+        if not config.str2bool(deployer.mdict['pki_skip_ds_verify']):
+            verify_ds_configuration()
 
-            if parser.ds_base_dn_exists() and not \
-                    config.str2bool(parser.mdict['pki_ds_remove_data']):
+            if base_dn_exists() and not \
+                    config.str2bool(deployer.mdict['pki_ds_remove_data']):
                 print('ERROR:  Base DN already exists.')
                 sys.exit(1)
 
-    except ldap.LDAPError as e:
-        server = parser.protocol + '://' + parser.hostname + ':' + parser.port
-        print('ERROR:  Unable to access directory server (' + server + '): ' +
-              e.args[0]['desc'])
-        sys.exit(1)
+    except ldap.LDAPError:
+        logger.error('Unable to access LDAP server: %s', deployer.ds_url)
+        raise
 
 
 def set_port(parser, tag, prompt, existing_data):
     if tag in existing_data:
-        parser.set_property(deployer.subsystem_name, tag, existing_data[tag])
+        deployer.set_property(tag, existing_data[tag])
     else:
         parser.read_text(prompt, deployer.subsystem_name, tag)
 
