@@ -388,11 +388,10 @@ class PKISubsystem(object):
             protocol=protocol,
             hostname=socket.getfqdn(),
             port=port,
-            subsystem=self.name,
             accept='application/xml',
             trust_env=False)
 
-        client = pki.system.SystemStatusClient(connection)
+        client = pki.system.SystemStatusClient(connection, subsystem=self.name)
         response = client.get_status(timeout=timeout)
 
         root = ET.fromstring(response)
@@ -860,6 +859,78 @@ class PKISubsystem(object):
         """
         self.config.update(new_config)
 
+    def init_database(
+            self,
+            setup_schema=False,
+            create_database=False,
+            create_base=False,
+            create_containers=False,
+            rebuild_indexes=False,
+            setup_db_manager=False,
+            setup_vlv_indexes=False,
+            as_current_user=False):
+
+        cmd = [self.name + '-db-init']
+
+        if setup_schema:
+            cmd.append('--setup-schema')
+
+        if create_database:
+            cmd.append('--create-database')
+
+        if create_base:
+            cmd.append('--create-base')
+
+        if create_containers:
+            cmd.append('--create-containers')
+
+        if rebuild_indexes:
+            cmd.append('--rebuild-indexes')
+
+        if setup_db_manager:
+            cmd.append('--setup-db-manager')
+
+        if setup_vlv_indexes:
+            cmd.append('--setup-vlv-indexes')
+
+        if logger.isEnabledFor(logging.DEBUG):
+            cmd.append('--debug')
+
+        elif logger.isEnabledFor(logging.INFO):
+            cmd.append('--verbose')
+
+        self.run(cmd, as_current_user=as_current_user)
+
+    def empty_database(self, force=False, as_current_user=False):
+
+        cmd = [self.name + '-db-empty']
+
+        if force:
+            cmd.append('--force')
+
+        if logger.isEnabledFor(logging.DEBUG):
+            cmd.append('--debug')
+
+        elif logger.isEnabledFor(logging.INFO):
+            cmd.append('--verbose')
+
+        self.run(cmd, as_current_user=as_current_user)
+
+    def remove_database(self, force=False, as_current_user=False):
+
+        cmd = [self.name + '-db-remove']
+
+        if force:
+            cmd.append('--force')
+
+        if logger.isEnabledFor(logging.DEBUG):
+            cmd.append('--debug')
+
+        elif logger.isEnabledFor(logging.INFO):
+            cmd.append('--verbose')
+
+        self.run(cmd, as_current_user=as_current_user)
+
     def run(self, args, as_current_user=False):
 
         java_home = self.instance.config['JAVA_HOME']
@@ -903,10 +974,10 @@ class PKISubsystem(object):
 
         cmd.extend(args)
 
-        logger.info('Command: %s', ' '.join(cmd))
+        logger.debug('Command: %s', ' '.join(cmd))
 
         try:
-            subprocess.check_call(cmd)
+            subprocess.run(cmd, check=True)
 
         except KeyboardInterrupt:
             logger.debug('Server stopped')
@@ -917,6 +988,25 @@ class CASubsystem(PKISubsystem):
     def __init__(self, instance):
         super(CASubsystem, self).__init__(instance, 'ca')
 
+    def load_profile_registry(self):
+
+        registry = {}
+        registry_conf = os.path.join(self.conf_dir, 'registry.cfg')
+        pki.util.load_properties(registry_conf, registry)
+
+        return registry
+
+    def get_profile_configs(self):
+
+        profiles_dir = os.path.join(self.base_dir, 'profiles')
+
+        profile_configs = []
+        for root, _, files in os.walk(profiles_dir):
+            for filename in files:
+                profile_configs.append(os.path.join(root, filename))
+
+        return profile_configs
+
     def find_cert_requests(self, cert=None):
 
         base_dn = self.config['internaldb.basedn']
