@@ -22,15 +22,12 @@ from __future__ import absolute_import
 from __future__ import print_function
 import logging
 import os
-import traceback
 
 import pki
 import pki.upgrade
 import pki.util
 import pki.server
-import pki.server.subsystem
-
-from pki.upgrade import verbose
+import pki.server.instance
 
 UPGRADE_DIR = pki.SHARE_DIR + '/server/upgrade'
 BACKUP_DIR = pki.LOG_DIR + '/server/upgrade'
@@ -38,6 +35,8 @@ BACKUP_DIR = pki.LOG_DIR + '/server/upgrade'
 INSTANCE_TRACKER = '%s/tomcat.conf'
 SUBSYSTEM_TRACKER = '%s/CS.cfg'
 
+logger = logging.getLogger(__name__)
+
 
 class PKIServerUpgradeScriptlet(pki.upgrade.PKIUpgradeScriptlet):
 
@@ -80,23 +79,21 @@ class PKIServerUpgradeScriptlet(pki.upgrade.PKIUpgradeScriptlet):
                 continue
 
             if not self.can_upgrade_server(instance):
-                if verbose:
-                    print('Skipping ' + str(instance) + ' instance.')
+                logger.info('Skipping %s instance', instance)
                 continue
 
             try:
-                if verbose:
-                    print('Upgrading ' + str(instance) + ' instance.')
+                logger.info('Upgrading %s instance', instance)
 
                 self.upgrade_instance(instance)
                 self.update_server_tracker(instance)
 
             except Exception as e:
 
-                if verbose:
-                    traceback.print_exc()
+                if logger.isEnabledFor(logging.INFO):
+                    logger.exception(e)
                 else:
-                    print('ERROR: %s' % e)
+                    logger.error(e)
 
                 message = 'Failed upgrading ' + str(instance) + ' instance.'
                 if self.upgrader.silent:
@@ -119,22 +116,20 @@ class PKIServerUpgradeScriptlet(pki.upgrade.PKIUpgradeScriptlet):
             logging.info('Upgrading %s subsystem', subsystem.name)
 
             if not self.can_upgrade_server(instance, subsystem):
-                if verbose:
-                    print('Skipping ' + str(subsystem) + ' subsystem.')
+                logger.info('Skipping %s subsystem', subsystem)
                 continue
 
             try:
-                if verbose:
-                    print('Upgrading ' + str(subsystem) + ' subsystem.')
+                logger.info('Upgrading %s subsystem', subsystem)
                 self.upgrade_subsystem(instance, subsystem)
                 self.update_server_tracker(instance, subsystem)
 
             except Exception as e:
 
-                if verbose:
-                    traceback.print_exc()
+                if logger.isEnabledFor(logging.INFO):
+                    logger.exception(e)
                 else:
-                    print('ERROR: %s' % e)
+                    logger.error(e)
 
                 message = 'Failed upgrading ' + str(subsystem) + ' subsystem.'
                 if self.upgrader.silent:
@@ -182,7 +177,7 @@ class PKIServerUpgrader(pki.upgrade.PKIUpgrader):
 
     def instances(self):
         if self.instanceName and self.instance_version:
-            instance = pki.server.PKIInstance(
+            instance = pki.server.instance.PKIInstance(
                 self.instanceName,
                 self.instance_version)
             instance.validate()
@@ -196,7 +191,7 @@ class PKIServerUpgrader(pki.upgrade.PKIUpgrader):
                 for instanceName in os.listdir(pki.server.PKIServer.BASE_DIR):
                     if not self.instanceName or \
                             self.instanceName == instanceName:
-                        instance = pki.server.PKIInstance(instanceName)
+                        instance = pki.server.instance.PKIInstance(instanceName)
                         instance.validate()
                         instance.load()
                         instance_list.append(instance)
@@ -208,7 +203,7 @@ class PKIServerUpgrader(pki.upgrade.PKIUpgrader):
                             os.path.join(pki.server.PKIServer.REGISTRY_DIR, s)):
                         if not self.instanceName or \
                                 self.instanceName == instanceName:
-                            instance = pki.server.PKIInstance(instanceName, version=9)
+                            instance = pki.server.instance.PKIInstance(instanceName, version=9)
                             instance.validate()
                             instance.load()
                             instance_list.append(instance)
@@ -219,7 +214,7 @@ class PKIServerUpgrader(pki.upgrade.PKIUpgrader):
 
     def subsystems(self, instance):
         if self.subsystemName:
-            subsystem = pki.server.subsystem.PKISubsystem(instance, self.subsystemName)
+            subsystem = instance.get_subsystem(self.subsystemName)
             subsystem.validate()
             subsystem.load()
             return [subsystem]
@@ -232,9 +227,7 @@ class PKIServerUpgrader(pki.upgrade.PKIUpgrader):
                 instance.name)
             for subsystemName in os.listdir(registry_dir):
                 if subsystemName in pki.server.SUBSYSTEM_TYPES:
-                    subsystem = pki.server.subsystem.PKISubsystem(
-                        instance,
-                        subsystemName)
+                    subsystem = instance.get_subsystem(subsystemName)
                     subsystem.validate()
                     subsystem.load()
                     subsystem_list.append(subsystem)
@@ -245,9 +238,7 @@ class PKIServerUpgrader(pki.upgrade.PKIUpgrader):
                     subsystemName,
                     instance.name)
                 if os.path.exists(registry_dir):
-                    subsystem = pki.server.subsystem.PKISubsystem(
-                        instance,
-                        subsystemName)
+                    subsystem = instance.get_subsystem(subsystemName)
                     subsystem.validate()
                     subsystem.load()
                     subsystem_list.append(subsystem)
