@@ -85,13 +85,13 @@ public class ProxyRealm implements Realm {
     }
 
     @Override
-    public Principal authenticate(X509Certificate certs[]) {
+    public Principal authenticate(X509Certificate[] certs) {
         if (realm == null) {
             throw new ServiceUnavailableException("Subsystem unavailable");
         }
         logger.info("Authenticating certificate chain:");
         for (X509Certificate cert : certs) {
-            logger.info(" - " + cert.getSubjectDN());
+            logger.info("- " + cert.getSubjectDN());
         }
         return realm.authenticate(certs);
     }
@@ -203,20 +203,4 @@ public class ProxyRealm implements Realm {
         }
         realm.setCredentialHandler(handler);
     }
-
-    @Override
-    public String[] getRoles(Principal principal) {
-        if (realm == null) {
-            throw new ServiceUnavailableException("Subsystem unavailable");
-        }
-        return realm.getRoles(principal);
-    }
-
-    @Override
-    public boolean isAvailable() {
-        if (realm == null) {
-            throw new ServiceUnavailableException("Subsystem unavailable");
-        }
-        return realm.isAvailable();
-    }
 }
