@@ -1,9 +1,7 @@
 package org.dogtagpki.server.tks.rest;
 
-import java.io.CharConversionException;
 import java.net.URI;
 import java.security.InvalidKeyException;
-import java.security.NoSuchAlgorithmException;
 import java.security.Principal;
 import java.security.cert.X509Certificate;
 import java.util.Arrays;
@@ -17,18 +15,13 @@ import javax.ws.rs.core.Response;
 import org.apache.commons.lang.ArrayUtils;
 import org.apache.commons.lang.StringUtils;
 import org.jboss.resteasy.plugins.providers.atom.Link;
-import org.mozilla.jss.CryptoManager;
 import org.mozilla.jss.NotInitializedException;
-import org.mozilla.jss.crypto.CryptoToken;
-import org.mozilla.jss.crypto.KeyGenAlgorithm;
-import org.mozilla.jss.crypto.KeyGenerator;
 import org.mozilla.jss.crypto.SymmetricKey;
 import org.mozilla.jss.crypto.TokenException;
 import org.mozilla.jss.netscape.security.util.Utils;
 
 import com.netscape.certsrv.base.BadRequestException;
 import com.netscape.certsrv.base.EBaseException;
-import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.base.PKIException;
 import com.netscape.certsrv.base.ResourceNotFoundException;
 import com.netscape.certsrv.base.UnauthorizedException;
@@ -41,6 +34,7 @@ import com.netscape.certsrv.usrgrp.IUser;
 import com.netscape.cms.servlet.base.PKIService;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.apps.CMSEngine;
+import com.netscape.cmscore.apps.EngineConfig;
 import com.netscape.cmscore.usrgrp.UGSubsystem;
 import com.netscape.cmsutil.crypto.CryptoUtil;
 
@@ -51,12 +45,15 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
     private static final String TPS_LIST = "tps.list";
 
     CMSEngine engine = CMS.getCMSEngine();
-    IConfigStore cs = engine.getConfigStore();
+    EngineConfig cs = engine.getConfig();
 
-    public UGSubsystem userGroupManager = (UGSubsystem) engine.getSubsystem(UGSubsystem.ID);
+    public UGSubsystem userGroupManager = engine.getUGSubsystem();
 
     @Override
     public Response findConnectors(String host, String port, Integer start, Integer size) {
+
+        logger.info("TPSConnectorService: Finding TPS connectors for " + host + ":" + port);
+
         try {
             start = start == null ? 0 : start;
             size = size == null ? DEFAULT_SIZE : size;
@@ -131,6 +128,8 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
 
     public TPSConnectorData getConnectorData(String id) {
 
+        logger.info("TPSConnectorService: Getting TPS connector " + id);
+
         if (id == null)
             throw new BadRequestException("TPS connector ID is null.");
 
@@ -149,6 +148,8 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
     @Override
     public Response createConnector(String tpsHost, String tpsPort) {
 
+        logger.info("TPSConnectorService: Creating TPS connector for " + tpsHost + ":" + tpsPort);
+
         if (tpsHost == null)
             throw new BadRequestException("TPS connector host is null.");
         if (tpsPort == null)
@@ -185,6 +186,9 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
 
     @Override
     public Response modifyConnector(String id, TPSConnectorData data) {
+
+        logger.info("TPSConnectorService: Modifying TPS connector " + id);
+
         try {
             if (id == null) {
                 throw new BadRequestException("Invalid connector ID");
@@ -239,6 +243,9 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
 
     @Override
     public Response deleteConnector(String id) {
+
+        logger.info("TPSConnectorService: Deleting TPS connector " + id);
+
         try {
             if (StringUtils.isEmpty(id))
                 throw new BadRequestException("Attempt to delete TPS connection with null or empty id");
@@ -262,6 +269,8 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
     @Override
     public Response deleteConnector(String host, String port) {
 
+        logger.info("TPSConnectorService: Deleting TPS connector for " + host + ":" + port);
+
         if (host == null)
             throw new BadRequestException("TPS connector host is null.");
         if (port == null)
@@ -282,7 +291,7 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
     @Override
     public Response createSharedSecret(String id) {
 
-        logger.debug("TPSConnectorService.createSharedSecret.id: " + id);
+        logger.info("TPSConnectorService: Creating shared secret for " + id);
 
         if (id == null)
             throw new BadRequestException("TPS connector ID is null.");
@@ -314,7 +323,7 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
             cs.commit(true);
 
             //Create des3 session sym key to wrap the shared secret.
-            SymmetricKey tempKey = createDes3SessionKeyOnInternal();
+            SymmetricKey tempKey = CryptoUtil.createDes3SessionKeyOnInternal();
 
             if (tempKey == null) {
                 return createNoContentResponse();
@@ -326,8 +335,8 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
             byte[] wrappedSharedSecret = listWrappedKeys.get(1);
 
             KeyData keyData = new KeyData();
-            keyData.setWrappedPrivateData(Utils.base64encode(wrappedSessionKey, true));
-            keyData.setAdditionalWrappedPrivateData(Utils.base64encode(wrappedSharedSecret, true));
+            keyData.setWrappedPrivateData(Utils.base64encodeSingleLine(wrappedSessionKey));
+            keyData.setAdditionalWrappedPrivateData(Utils.base64encodeSingleLine(wrappedSharedSecret));
 
             return createOKResponse(keyData);
 
@@ -358,6 +367,8 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
     @Override
     public Response replaceSharedSecret(String id) {
 
+        logger.info("TPSConnectorService: Replacing shared secret for " + id);
+
         if (id == null)
             throw new BadRequestException("TPS connector ID is null.");
 
@@ -382,7 +393,7 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
             CryptoUtil.createSharedSecret(nickname);
 
             //Create des3 session sym key to wrap the shared secret.
-            SymmetricKey tempKey = createDes3SessionKeyOnInternal();
+            SymmetricKey tempKey = CryptoUtil.createDes3SessionKeyOnInternal();
 
             if (tempKey == null) {
                 return createNoContentResponse();
@@ -394,8 +405,8 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
             byte[] wrappedSharedSecret = listWrappedKeys.get(1);
 
             KeyData keyData = new KeyData();
-            keyData.setWrappedPrivateData(Utils.base64encode(wrappedSessionKey, true));
-            keyData.setAdditionalWrappedPrivateData(Utils.base64encode(wrappedSharedSecret, true));
+            keyData.setWrappedPrivateData(Utils.base64encodeSingleLine(wrappedSessionKey));
+            keyData.setAdditionalWrappedPrivateData(Utils.base64encodeSingleLine(wrappedSharedSecret));
 
             return createOKResponse(keyData);
 
@@ -408,6 +419,8 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
     @Override
     public Response deleteSharedSecret(String id) {
 
+        logger.info("TPSConnectorService: Deleting shared secret for " + id);
+
         if (id == null)
             throw new BadRequestException("TPS connector ID is null.");
 
@@ -443,10 +456,11 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
     @Override
     public Response getSharedSecret(String id) {
 
+        logger.info("TPSConnectorService: Getting shared secret for " + id);
+
         if (id == null)
             throw new BadRequestException("TPS connector ID is null.");
 
-        logger.debug("TPSConnectorServlet.getSharedSecret: id : " + id);
         try {
             if (!connectorExists(id)) {
                 throw new ResourceNotFoundException("TPS connection does not exist");
@@ -465,7 +479,7 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
             X509Certificate[] certs = user.getX509Certificates();
 
             //Create des3 session sym key to wrap the shared secrt.
-            SymmetricKey tempKey = createDes3SessionKeyOnInternal();
+            SymmetricKey tempKey = CryptoUtil.createDes3SessionKeyOnInternal();
 
             if (tempKey == null) {
                 return createNoContentResponse();
@@ -476,8 +490,8 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
             byte[] wrappedSharedSecret = listWrappedKeys.get(1);
 
             KeyData keyData = new KeyData();
-            keyData.setWrappedPrivateData(Utils.base64encode(wrappedSessionKey, true));
-            keyData.setAdditionalWrappedPrivateData(Utils.base64encode(wrappedSharedSecret, true));
+            keyData.setWrappedPrivateData(Utils.base64encodeSingleLine(wrappedSessionKey));
+            keyData.setAdditionalWrappedPrivateData(Utils.base64encodeSingleLine(wrappedSharedSecret));
 
             return createOKResponse(keyData);
 
@@ -528,30 +542,4 @@ public class TPSConnectorService extends PKIService implements TPSConnectorResou
             index++;
         return Integer.toString(index);
     }
-
-    private SymmetricKey createDes3SessionKeyOnInternal() throws EBaseException {
-
-        SymmetricKey tempKey = null;
-        try {
-            CryptoManager cm = CryptoManager.getInstance();
-            CryptoToken token = cm.getInternalKeyStorageToken();
-            KeyGenerator kg = token.getKeyGenerator(KeyGenAlgorithm.DES3);
-
-            SymmetricKey.Usage usages[] = new SymmetricKey.Usage[4];
-            usages[0] = SymmetricKey.Usage.WRAP;
-            usages[1] = SymmetricKey.Usage.UNWRAP;
-            usages[2] = SymmetricKey.Usage.ENCRYPT;
-            usages[3] = SymmetricKey.Usage.DECRYPT;
-
-            kg.setKeyUsages(usages);
-            kg.temporaryKeys(true);
-            tempKey = kg.generate();
-        } catch (NoSuchAlgorithmException | TokenException | IllegalStateException | CharConversionException
-                | NotInitializedException e) {
-            logger.error("TPSConnectorService: Unable to generate temporary session key: " + e.getMessage(), e);
-            throw new EBaseException("Unable to generate temporary session key: " + e.getMessage(), e);
-        }
-
-        return tempKey;
-    }
 }
