@@ -23,6 +23,7 @@ import java.util.Collection;
 import java.util.Date;
 import java.util.HashMap;
 import java.util.Iterator;
+import java.util.LinkedHashMap;
 import java.util.Map;
 
 import org.dogtagpki.server.tps.cms.CARemoteRequestHandler;
@@ -33,16 +34,15 @@ import org.dogtagpki.server.tps.dbs.TokenCertStatus;
 import org.dogtagpki.server.tps.dbs.TokenRecord;
 import org.dogtagpki.server.tps.main.ExternalRegCertToRecover;
 import org.dogtagpki.tps.main.TPSException;
-import org.dogtagpki.tps.msg.EndOpMsg.TPSStatus;
 import org.mozilla.jss.netscape.security.x509.RevocationReason;
 import org.mozilla.jss.netscape.security.x509.X509CertImpl;
 
 import com.netscape.certsrv.base.EBaseException;
-import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.dbs.EDBRecordNotFoundException;
 import com.netscape.certsrv.tps.token.TokenStatus;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.apps.CMSEngine;
+import com.netscape.cmscore.apps.EngineConfig;
 
 /*
  * TPSTokendb class offers a collection of tokendb management convenience routines
@@ -96,7 +96,7 @@ public class TPSTokendb {
                     (tokenRecord != null)? tokenRecord.getUserID():null,
                     (tokenRecord != null)? tokenRecord.getType():null);
         } catch (Exception e) {
-            msg = msg + ";" + " tokendb activity logging failure: " + e;
+            logger.warn(msg + ";" + " tokendb activity logging failure: " + e.getMessage(), e);
         }
     }
 
@@ -114,8 +114,9 @@ public class TPSTokendb {
                     msg,
                     uid,
                     (tokenRecord != null)? tokenRecord.getType():null);
+
         } catch (Exception e) {
-            msg = msg + ";" + " tokendb activity logging failure: " + e;
+            logger.warn(msg + ";" + " tokendb activity logging failure: " + e.getMessage(), e);
         }
     }
 
@@ -143,17 +144,22 @@ public class TPSTokendb {
      */
     public ArrayList<TokenRecord> tdbFindTokenRecordsByUID(String uid)
             throws Exception {
+
+        // search for tokens with (userID=<UID>) filter which will be
+        // translated into (tokenUserID=<UID>) LDAP filter as defined
+        // in TokenRecord
+        Map<String, String> attributes = new LinkedHashMap<>();
+        attributes.put("userID", uid);
+
+        Iterator<TokenRecord> records = tps.tokenDatabase.findRecords(null, attributes).iterator();
+
         ArrayList<TokenRecord> tokenRecords = new ArrayList<TokenRecord>();
-        String filter = uid;
-        Iterator<TokenRecord> records = null;
-        records = tps.tokenDatabase.findRecords(filter).iterator();
+        while (records.hasNext()) {
+            TokenRecord tokenRecord = records.next();
+            tokenRecords.add(tokenRecord);
+        }
 
-       while (records.hasNext()) {
-           TokenRecord tokenRecord = records.next();
-           tokenRecords.add(tokenRecord);
-       }
-
-       return tokenRecords;
+        return tokenRecords;
     }
 
     public void tdbHasActiveToken(String userid)
@@ -211,7 +217,7 @@ public class TPSTokendb {
         } catch (EDBRecordNotFoundException e) {
             String logMsg = method + e.getMessage();
             logger.error(logMsg, e);
-            throw new TPSException(logMsg, TPSStatus.STATUS_ERROR_CONTACT_ADMIN);
+            throw new TPSException(logMsg);
         }
         // token found; modify
         logger.debug(method + " token entry found; Modifying with status: " + tokenRecord.getTokenStatus());
@@ -255,7 +261,7 @@ public class TPSTokendb {
         } catch (Exception e) {
             logger.error(method + e.getMessage(), e);
             // TODO: what if it throws in the middle of the cert list -- some cert records already updated?
-            throw new TPSException(e.getMessage());
+            throw new TPSException(e.getMessage(), e);
         }
     }
 
@@ -301,7 +307,7 @@ public class TPSTokendb {
             records = tps.certDatabase.findRecords(null, attributes).iterator();
         } catch (Exception e) {
             logger.error(method + e.getMessage(), e);
-            throw new TPSException(e.getMessage());
+            throw new TPSException(e.getMessage(), e);
         }
 
         while (records.hasNext()) {
@@ -534,11 +540,10 @@ public class TPSTokendb {
             try {
                 tokenRecord = tdbGetTokenEntry(cert.getTokenID());
             } catch (Exception e) {
-                throw new TPSException("error getting token entry for: " +
-                        cert.getTokenID() + e.toString());
+                throw new TPSException("error getting token entry for: " + cert.getTokenID() + ": " + e.getMessage(), e);
             }
-            if ((tokenRecord.getTokenStatus() == TokenStatus.ACTIVE) ||
-                    (tokenRecord.getTokenStatus() == TokenStatus.SUSPENDED)) {
+
+            if (tokenRecord.getTokenStatus() == TokenStatus.ACTIVE) {
                 logger.warn(method + "token " + cert.getTokenID() + " contains the cert and has status: "
                         + tokenRecord.getTokenStatus() + "... returning false");
                 return false;
@@ -563,7 +568,7 @@ public class TPSTokendb {
         CMSEngine engine = CMS.getCMSEngine();
         try {
 
-            IConfigStore configStore = engine.getConfigStore();
+            EngineConfig configStore = engine.getConfig();
 
             // get conn ID
             String config = "op.enroll." + cert.getType() + ".keyGen." + cert.getKeyType() + ".ca.conn";
@@ -628,7 +633,7 @@ public class TPSTokendb {
 
         CMSEngine engine = CMS.getCMSEngine();
         try {
-            IConfigStore configStore = engine.getConfigStore();
+            EngineConfig configStore = engine.getConfig();
 
             // get conn ID
             String config = "op.enroll." + cert.getType() + ".keyGen." + cert.getKeyType() + ".ca.conn";
@@ -662,14 +667,14 @@ public class TPSTokendb {
             logMsg = "certificate unrevoked: " + cert.getSerialNumber();
             logger.debug(method + ": " + logMsg);
 
-            tdbActivity(ActivityDatabase.OP_CERT_UNREVOCATION, tokenRecord,
+            tdbActivity(ActivityDatabase.OP_CERT_RESTORATION, tokenRecord,
                     ipAddress, logMsg, "success", remoteUser);
 
         } catch (Exception e) {
             logMsg = "certificate not unrevoked: " + cert.getSerialNumber() + " : " + e.getMessage();
             logger.warn(method + ": " + logMsg, e);
 
-            tdbActivity(ActivityDatabase.OP_CERT_UNREVOCATION, tokenRecord,
+            tdbActivity(ActivityDatabase.OP_CERT_RESTORATION, tokenRecord,
                     ipAddress, e.getMessage(), "failure", remoteUser);
 
             // continue unrevoking the next certificate
@@ -682,15 +687,28 @@ public class TPSTokendb {
         String method = "TPSTokendb.checkShouldRevoke:";
         String msg = "";
         CMSEngine engine = CMS.getCMSEngine();
-        IConfigStore configStore = engine.getConfigStore();
+        EngineConfig configStore = engine.getConfig();
 
         if (cert == null) {
             throw new TPSException("Missing token certificate");
         }
         if (cert.getStatus().equalsIgnoreCase(TokenCertStatus.REVOKED.toString())) {
-            throw new TPSException(
-                    method + "certificate " + cert.getSerialNumber() +
-                            " already revoked.");
+            String existingTokenReason = tokenRecord.getReason();
+            if( (existingTokenReason != null && existingTokenReason.equals(tokenReason)) ||
+                (existingTokenReason == null && tokenReason == null) )
+            {
+                throw new TPSException(
+                        method + "certificate " + cert.getSerialNumber() +
+                                " already revoked and reason has not changed.");
+            }
+            else {
+                logger.debug(method + "Cert " + cert.getSerialNumber() +
+                        " already revoked, but reason has changed, so revoking again.");
+                logger.debug(method + "Previous reason was: " +
+                        ((existingTokenReason == null) ? "(null)" : existingTokenReason));
+                logger.debug(method + "New reason is: " +
+                        ((tokenReason == null) ? "(null)" : tokenReason));
+            }
         }
         logger.debug(method + "begins: ");
 
