@@ -52,11 +52,14 @@ import org.dogtagpki.tps.main.Util;
 import org.dogtagpki.tps.msg.EndOpMsg.TPSStatus;
 import org.mozilla.jss.pkcs11.PK11SymKey;
 import org.mozilla.jss.pkcs11.PKCS11Constants;
+import org.mozilla.jss.crypto.IllegalBlockSizeException;
+
+import java.security.InvalidAlgorithmParameterException;
 
 import com.netscape.certsrv.base.EBaseException;
-import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.apps.CMSEngine;
+import com.netscape.cmscore.apps.EngineConfig;
 
 public class SecureChannel {
 
@@ -150,8 +153,8 @@ public class SecureChannel {
 
         logger.debug("SecureChannel.SecureChannel: For SCP03. :  ");
 
-        if (keyCheck != null)
-            logger.debug("keyCheck: " + keyCheck.toHexString());
+        //if (keyCheck != null)
+        //    logger.debug("keyCheck: " + keyCheck.toHexString());
 
         this.platProtInfo = platformInfo;
         this.processor = processor;
@@ -329,7 +332,7 @@ public class SecureChannel {
         }
 
         CMSEngine engine = CMS.getCMSEngine();
-        IConfigStore configStore = engine.getConfigStore();
+        EngineConfig configStore = engine.getConfig();
 
         final String keyCapabilities = "keyCapabilities";
 
@@ -419,16 +422,16 @@ public class SecureChannel {
             TPSBuffer context = new TPSBuffer(hostChallenge);
             context.add(cardChallenge);
             try {
-                calculatedCardCryptogram = Util.compute_AES_CMAC_Cryptogram(macSessionKey, context, Util.CARD_CRYPTO_KDF_CONSTANT_SCP03);
+                calculatedCardCryptogram = SecureChannelProtocol.compute_AES_CMAC_Cryptogram(macSessionKey, context, SecureChannelProtocol.CARD_CRYPTO_KDF_CONSTANT_SCP03);
             } catch (EBaseException e) {
                 throw new TPSException(method + "Failed to calculate card cryptogram!", TPSStatus.STATUS_ERROR_SECURE_CHANNEL);
             }
 
-            if(cardCryptogram != null)
-                logger.debug(method + " actual card cryptogram " + cardCryptogram.toHexString());
+            //if(cardCryptogram != null)
+            //    logger.debug(method + " actual card cryptogram " + cardCryptogram.toHexString());
 
-            if(calculatedCardCryptogram != null)
-                logger.debug(method + " calculated card cryptogram " + calculatedCardCryptogram.toHexString());
+            //if(calculatedCardCryptogram != null)
+            //    logger.debug(method + " calculated card cryptogram " + calculatedCardCryptogram.toHexString());
 
             ExternalAuthenticateAPDUGP211 externalAuth = new ExternalAuthenticateAPDUGP211(hostCryptogram,
                     /* secLevel */secLevelGP211);
@@ -533,7 +536,8 @@ public class SecureChannel {
                 apdu.secureMessage(encSessionKey, (byte) 1);
                 //logger.debug("SecureChannel.computeAPDU: After encryption data value: " + apdu.getData().toHexString());
             } catch (EBaseException e) {
-                throw new TPSException("SecureChannel.computeAPDU: Can't encrypt outgoing data! " + e);
+                throw new TPSException("SecureChannel.computeAPDU: Can't encrypt outgoing data! " + e,
+                    TPSStatus.STATUS_ERROR_SECURE_CHANNEL);
             }
 
             logger.debug("SecureChannel.computeAPDU: Successfully encrypted apdu data.");
@@ -560,7 +564,8 @@ public class SecureChannel {
                 //logger.debug("SecureChannel.computeAPDU_SCP03: After encryption data value: "
                 //        + apdu.getData().toHexString());
             } catch (EBaseException e) {
-                throw new TPSException("SecureChannel.computeAPDU_SCP03: Can't encrypt outgoing data! " + e);
+                throw new TPSException("SecureChannel.computeAPDU_SCP03: Can't encrypt outgoing data! " + e,
+                    TPSStatus.STATUS_ERROR_SECURE_CHANNEL);
             }
 
             logger.debug("SecureChannel.computeAPDU_SCP03: Successfully encrypted apdu data.");
@@ -612,7 +617,8 @@ public class SecureChannel {
                 //logger.debug("SecureChannel.computeAPDU_SCP02: After encryption data value: "
                 //        + apdu.getData().toHexString());
             } catch (EBaseException e) {
-                throw new TPSException("SecureChannel.computeAPDU_SCP02: Can't encrypt outgoing data! " + e);
+                throw new TPSException("SecureChannel.computeAPDU_SCP02: Can't encrypt outgoing data! " + e,
+                    TPSStatus.STATUS_ERROR_SECURE_CHANNEL);
             }
 
             logger.debug("SecureChannel.computeAPDU_SCP02: Successfully encrypted apdu data.");
@@ -645,7 +651,7 @@ public class SecureChannel {
                 //logger.debug("SecureChannel.computeAPDUMacSCP03: final data To MAC: " + dataToMac.toHexString() + " incoming icv: "
                 //        + icv.toHexString());
 
-                newMac = Util.computeAES_CMAC(macSessionKey, dataToMac);
+                newMac = SecureChannelProtocol.computeAES_CMAC(macSessionKey, dataToMac);
 
 
         } catch (EBaseException e) {
@@ -743,7 +749,8 @@ public class SecureChannel {
     public void deleteFileX(TPSBuffer aid) throws TPSException, IOException {
         logger.debug("SecureChannel.deleteFileX: entering...");
         if (aid == null) {
-            throw new TPSException("SecureChannel.deleteFileX: no input aid!");
+            throw new TPSException("SecureChannel.deleteFileX: no input aid!",
+                    TPSStatus.STATUS_ERROR_UPGRADE_APPLET);
         }
 
         if (isGP211()) {
@@ -775,7 +782,7 @@ public class SecureChannel {
 
         if (packageAID == null || sdAID == null || fileLength <= 0) {
             throw new TPSException("SecureChannel.insallLoad bad input parameters!",
-                    TPSStatus.STATUS_ERROR_SECURE_CHANNEL);
+                    TPSStatus.STATUS_ERROR_UPGRADE_APPLET);
         }
 
         TPSBuffer emptySDAID = new TPSBuffer();
@@ -808,7 +815,7 @@ public class SecureChannel {
 
         if (packageAID == null || sdAID == null || fileLength <= 0) {
             throw new TPSException("SecureChannel.insallLoadGP211 bad input parameters!",
-                    TPSStatus.STATUS_ERROR_SECURE_CHANNEL);
+                    TPSStatus.STATUS_ERROR_UPGRADE_APPLET);
         }
 
         InstallLoadGP211APDU install = new InstallLoadGP211APDU(packageAID, sdAID,
@@ -940,7 +947,7 @@ public class SecureChannel {
         if (!response.checkResult()) {
             throw new TPSException(
                     "SecureChannel.loadFileSegment. Failed to perform loadFileSegmentInstallLoad operation.",
-                    TPSStatus.STATUS_ERROR_SECURE_CHANNEL);
+                    TPSStatus.STATUS_ERROR_UPGRADE_APPLET);
         }
 
         logger.debug("SecureChannel.loadFileSegment: ends");
@@ -958,7 +965,7 @@ public class SecureChannel {
 
         if (netkeyPAIDBuff == null || netkeyAIDBuff == null || channelInstanceSize < 0 || channelAppletMemSize < 0) {
             throw new TPSException("SecureChannel.installApplet. Invalid input parameters!",
-                    TPSStatus.STATUS_ERROR_SECURE_CHANNEL);
+                    TPSStatus.STATUS_ERROR_UPGRADE_APPLET);
 
         }
 
@@ -984,7 +991,7 @@ public class SecureChannel {
 
         if (!response.checkResult()) {
             throw new TPSException("SecureChannel.installApplett. Failed installApplet operation.",
-                    TPSStatus.STATUS_ERROR_SECURE_CHANNEL);
+                    TPSStatus.STATUS_ERROR_UPGRADE_APPLET);
         }
 
     }
@@ -1087,7 +1094,8 @@ public class SecureChannel {
         logger.debug("SecureChannel.writeObject: entering ...");
 
         if (objectID == null || objectData == null) {
-            throw new TPSException("SecureChannel.writeObject: invalid input data.");
+            throw new TPSException("SecureChannel.writeObject: invalid input data.",
+                    TPSStatus.STATUS_ERROR_CANNOT_PERFORM_OPERATION);
         }
 
         final int MAX_WRITE_SIZE = 0xd0;
@@ -1118,7 +1126,7 @@ public class SecureChannel {
                 //Throw this return code because this happens during enrollment and we don't have
                 // a more specific error code.
                 throw new TPSException("SecureChannel.writeObject. Failed in middle of writeObject.",
-                        TPSStatus.STATUS_ERROR_MAC_ENROLL_PDU);
+                        TPSStatus.STATUS_ERROR_CANNOT_PERFORM_OPERATION);
             }
 
             offset += blockSize;
@@ -1138,7 +1146,7 @@ public class SecureChannel {
 
         if (objectID == null || len == 0) {
             throw new TPSException("SecureChannel.readObject: invalid input data.",
-                    TPSStatus.STATUS_ERROR_READ_OBJECT_PDU);
+                    TPSStatus.STATUS_ERROR_CANNOT_PERFORM_OPERATION);
         }
 
         final int MAX_READ_BUFFER_SIZE = 0xd0;
@@ -1168,7 +1176,7 @@ public class SecureChannel {
             if (!response.checkResult()) {
                 logger.error("SecureChannel.readObject: bad apdu return!");
                 throw new TPSException("SecureChannel.installApplett. Failed in middle of readObject.",
-                        TPSStatus.STATUS_ERROR_SECURE_CHANNEL);
+                        TPSStatus.STATUS_ERROR_CANNOT_PERFORM_OPERATION);
             }
 
             TPSBuffer resp = response.getResultDataNoCode();
@@ -1240,15 +1248,15 @@ public class SecureChannel {
 
         TPSBuffer result = new TPSBuffer();
 
-        logger.debug("SecureChannel.createPKCS11PriKeyAttrsBuffer: entering...");
+        //logger.debug("SecureChannel.createPKCS11PriKeyAttrsBuffer: entering...");
 
         if (id == null || label == null || keyid == null || modulus == null || keyTypePrefix == null) {
             throw new TPSException("SecureChannel.craetePKCS11PriKeyAttrsBuffer: invalid input data.",
                     TPSStatus.STATUS_ERROR_MAC_ENROLL_PDU);
         }
 
-        logger.debug("SecureChannel.createPKCS11PriKeyAttrsBuffer:  id: " + id + " label: " + label + " keyid: "
-                + keyid.toHexString());
+        //logger.debug("SecureChannel.createPKCS11PriKeyAttrsBuffer:  id: " + id + " label: " + label + " keyid: "
+        //        + keyid.toHexString());
 
         byte keytype[] = { 0, 0, 0, 0 };
         byte p11class[] = { 3, 0, 0, 0 };
@@ -1357,15 +1365,15 @@ public class SecureChannel {
     public TPSBuffer createPKCS11CertAttrsBuffer(TokenKeyType keyType, String id, String label, TPSBuffer keyid)
             throws TPSException {
 
-        logger.debug("SecureChannel.createPKCS11CertAttrsBuffer: entering... id: " + id);
+        //logger.debug("SecureChannel.createPKCS11CertAttrsBuffer: entering... id: " + id);
         if (keyType == null || id == null || label == null || keyid == null) {
             throw new TPSException("SecureChannel.createPKCS11CertAttrsBuffer. Bad input data.",
                     TPSStatus.STATUS_ERROR_MAC_ENROLL_PDU);
 
         }
 
-        logger.debug("SecureChannel.createPKCS11CertAttrsBuffer: ... id: " + id + " label: " + label + " keyid: "
-                + keyid.toHexString());
+        //logger.debug("SecureChannel.createPKCS11CertAttrsBuffer: ... id: " + id + " label: " + label + " keyid: "
+        //        + keyid.toHexString());
 
         byte[] type = { 0x0, 0x0, 0x0, 0x0 };
         byte[] p11class = { 0x1, 0x0, 0x0, 0x0 };
@@ -1373,8 +1381,8 @@ public class SecureChannel {
 
         TPSBuffer result = new TPSBuffer();
 
-        logger.debug("SecureChannel.createPKCS11CertAttrsBuffer: label: " + label + " label bytes: "
-                + (new TPSBuffer(label)).toHexString());
+        //logger.debug("SecureChannel.createPKCS11CertAttrsBuffer: label: " + label + " label bytes: "
+        //        + (new TPSBuffer(label)).toHexString());
 
         appendPKCS11Attribute(result, PKCS11Constants.CKA_LABEL, new TPSBuffer(label.getBytes()));
         appendPKCS11Attribute(result, PKCS11Constants.CKA_ID, keyid);
@@ -1494,7 +1502,7 @@ public class SecureChannel {
         if (!response.checkResult()) {
             logger.error(method + "result.checkResult() returns false; Throwing exception!");
             throw new TPSException("SecureChannel.setLifecycleState. Failed to set Lifecycle State!.",
-                    TPSStatus.STATUS_ERROR_MAC_ENROLL_PDU);
+                    TPSStatus.STATUS_ERROR_MAC_LIFECYCLE_PDU);
         }
 
         logger.debug(method + "ends");
@@ -1506,7 +1514,7 @@ public class SecureChannel {
 
         if (pin == null) {
             throw new TPSException("SecureChannel.createPin: invalid intput data.",
-                    TPSStatus.STATUS_ERROR_TOKEN_RESET_PIN_FAILED);
+                    TPSStatus.STATUS_ERROR_MAC_RESET_PIN_PDU);
         }
 
         TPSBuffer pinBuf = new TPSBuffer(pin.getBytes());
@@ -1557,8 +1565,8 @@ public class SecureChannel {
         byte keyVersion = curVersion;
 
         if (curVersion == (byte) 0xff) {
-            logger.debug("Setting keyVersion to 1");
-            keyVersion = 0x1;
+            logger.debug("Setting keyVersion to 0");
+            keyVersion = 0x0;
         }
 
         logger.debug("keyVersion now set to: " + keyVersion);
@@ -1575,7 +1583,7 @@ public class SecureChannel {
 
         int kill = 0;
         if (kill == 1) {
-            throw new TPSException("putKeys end of progress.");
+            throw new TPSException("putKeys end of progress.", TPSStatus.STATUS_ERROR_KEY_CHANGE_OVER);
         }
 
         APDUResponse response = processor.handleAPDURequest(putKey);
@@ -1609,7 +1617,7 @@ public class SecureChannel {
 
         if (data == null) {
             throw new TPSException("SecureChannel.importKeyEnc: Invalid input data!",
-                    TPSStatus.STATUS_ERROR_MAC_CERT_PDU);
+                    TPSStatus.STATUS_ERROR_MAC_ENROLL_PDU);
         }
 
         ImportKeyEncAPDU importKeyEnc = new ImportKeyEncAPDU((byte) pe1, (byte) pe2, data);
@@ -1620,7 +1628,7 @@ public class SecureChannel {
 
         if (!response.checkResult()) {
             throw new TPSException("SecureChannel.importKeyEnc: failed to import private key!",
-                    TPSStatus.STATUS_ERROR_MAC_CERT_PDU);
+                    TPSStatus.STATUS_ERROR_MAC_ENROLL_PDU);
         }
 
     }
