@@ -23,10 +23,11 @@ import org.dogtagpki.server.tps.TPSSubsystem;
 import org.dogtagpki.server.tps.config.ConnectorDatabase;
 import org.dogtagpki.server.tps.config.ConnectorRecord;
 
-import com.netscape.certsrv.base.IConfigStore;
 import com.netscape.certsrv.base.PKIException;
 import com.netscape.cmscore.apps.CMS;
 import com.netscape.cmscore.apps.CMSEngine;
+import com.netscape.cmscore.apps.EngineConfig;
+import com.netscape.cmscore.apps.PreOpConfig;
 
 /**
  * Utility class for TPS installation to be used both by the RESTful installer
@@ -48,10 +49,11 @@ public class TPSInstaller {
         CMSEngine engine = CMS.getCMSEngine();
         TPSSubsystem subsystem = (TPSSubsystem) engine.getSubsystem(TPSSubsystem.ID);
         ConnectorDatabase database = subsystem.getConnectorDatabase();
-        IConfigStore cs = engine.getConfigStore();
+        EngineConfig cs = engine.getConfig();
+        PreOpConfig preopConfig = cs.getPreOpConfig();
 
         // TODO: see if this is only needed by wizard-based installation
-        cs.putString("preop.cainfo.select", uri.toString());
+        preopConfig.putString("cainfo.select", uri.toString());
 
         try {
             database.addCAConnector(uri.getHost(), uri.getPort(), nickname);
@@ -67,10 +69,11 @@ public class TPSInstaller {
         CMSEngine engine = CMS.getCMSEngine();
         TPSSubsystem subsystem = (TPSSubsystem) engine.getSubsystem(TPSSubsystem.ID);
         ConnectorDatabase database = subsystem.getConnectorDatabase();
-        IConfigStore cs = engine.getConfigStore();
+        EngineConfig cs = engine.getConfig();
+        PreOpConfig preopConfig = cs.getPreOpConfig();
 
         // TODO: see if this is only needed by wizard-based installation
-        cs.putString("preop.tksinfo.select", uri.toString());
+        preopConfig.putString("tksinfo.select", uri.toString());
 
         try {
             database.addTKSConnector(uri.getHost(), uri.getPort(), nickname, false);
@@ -86,11 +89,12 @@ public class TPSInstaller {
         CMSEngine engine = CMS.getCMSEngine();
         TPSSubsystem subsystem = (TPSSubsystem) engine.getSubsystem(TPSSubsystem.ID);
         ConnectorDatabase database = subsystem.getConnectorDatabase();
-        IConfigStore cs = engine.getConfigStore();
+        EngineConfig cs = engine.getConfig();
+        PreOpConfig preopConfig = cs.getPreOpConfig();
 
         if (keygen) {
             // TODO: see if this is only needed by wizard-based installation
-            cs.putString("preop.krainfo.select", uri.toString());
+            preopConfig.putString("krainfo.select", uri.toString());
 
             // TODO: see if there are other profiles need to be configured
             cs.putString("op.enroll.userKey.keyGen.encryption.serverKeygen.enable", "true");
