@@ -1,9 +1,12 @@
 #common to all subsystems
+MASTER_HOSTNAME = 'pki1.example.com'
+CLONE_HOSTNAME = 'pki2.example.com'
+
+CLIENT_PKCS12_PASSWORD = 'SECret.123'
+CLIENT_DIR_PASSWORD = 'SECret.123'
+BACKUP_PASSWORD = 'SECret.123'
+CLIENT_DATABASE_PASSWORD = 'SECret.123'
 NSSDB = '/opt/pki/certdb'
-CLIENT_PKCS12_PASSWORD = 'Secret123'
-CLIENT_DIR_PASSWORD = 'Secret123'
-BACKUP_PASSWORD = 'Secret123'
-CLIENT_DATABASE_PASSWORD = 'Secret123'
 #CA Instance
 CA_HTTPS_PORT = '20443'
 CA_HTTP_PORT = '20080'
@@ -11,8 +14,8 @@ CA_AJP_PORT = '20009'
 CA_TOMCAT_PORT = '20005'
 CA_CLIENT_DIR = '/opt/topology-CA'
 CA_INSTANCE_NAME = 'topology-CA'
-SECURITY_DOMAIN_PASSWORD = 'Secret123'
-CA_PASSWORD = 'Secret123'
+SECURITY_DOMAIN_PASSWORD = 'SECret.123'
+CA_PASSWORD = 'SECret.123'
 CA_SECURITY_DOMAIN_NAME = 'topology_Foobarmaster.org'
 CA_ADMIN_USERNAME = 'caadmin'
 CA_ADMIN_NICK = 'PKI CA Administrator for Example.Org'
@@ -22,7 +25,7 @@ KRA_HTTPS_PORT = 21443
 KRA_HTTP_PORT = 21080
 KRA_AJP_PORT = 21009
 KRA_TOMCAT_PORT = 21005
-KRA_PASSWORD = 'Secret123'
+KRA_PASSWORD = 'SECret.123'
 KRA_CLIENT_DIR = '/opt/topology-KRA'
 KRA_ADMIN_NICK = 'PKI KRA Administrator for Example.Org'
 #OCSP Instance
@@ -31,7 +34,7 @@ OCSP_HTTPS_PORT = 22443
 OCSP_HTTP_PORT = 22080
 OCSP_AJP_PORT = 22009
 OCSP_TOMCAT_PORT = 22005
-OCSP_PASSWORD = 'Secret123'
+OCSP_PASSWORD = 'SECret.123'
 OCSP_CLIENT_DIR = '/opt/topology-OCSP'
 OCSP_ADMIN_NICK = 'PKI OCSP Administrator for Example.Org'
 #TKS Instance
@@ -40,7 +43,7 @@ TKS_HTTPS_PORT = 23443
 TKS_HTTP_PORT = 23080
 TKS_AJP_PORT = 23009
 TKS_TOMCAT_PORT = 23005
-TKS_PASSWORD = 'Secret123'
+TKS_PASSWORD = 'SECret.123'
 TKS_CLIENT_DIR = '/opt/topology-TKS'
 #TPS instance
 TPS_INSTANCE_NAME = 'topology-TPS'
@@ -48,6 +51,25 @@ TPS_HTTPS_PORT = '25443'
 TPS_HTTP_PORT = '25080'
 TPS_AJP_PORT = '25009'
 TPS_TOMCAT_PORT = '25005'
-TPS_PASSWORD = 'Secret123'
+TPS_PASSWORD = 'SECret.123'
 TPS_CLIENT_DIR = '/opt/topology-TPS'
 TPS_ADMIN_NICK = 'PKI TPS Administrator for Example.Org'
+#LDAP Details
+LDAP_PORT = 'ldapServerPort'
+LDAP_BIND_DN = 'cn=Directory Manager'
+LDAP_PASSWD = 'SECret.123'
+LDAP_BASE_DN = 'dc=example,dc=org'
+LDAP_KRA_PORT = 'ldapkraServerPort'
+LDAP_OCSP_PORT = 'ldapocspServerPort'
+LDAP_TKS_PORT = 'ldaptksServerPort'
+LDAP_TPS_PORT = 'ldaptpsServerPort'
+LDAP_USER = 'foobar'
+LDAP_USER_ENROLL = 'testuser'
+CUID = '40906145C76224192D2B'
+CUID_01 = '40906145C76224192D11'
+TPS_OPERATION = 'ra_enroll'
+#Details for tps-activity cli automation
+LDAP_USER1 = 'jdoe'
+TOKEN_FORMAT = 'ra_format'
+TOKEN_RESET_PIN = 'ra_reset_pin'
+TOKEN_CUID = '40000000000000000002'
