@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/bin/bash -ex
 #
 # Authors:
 #     Dinesh Prasanth M K <dmoluguw@redhat.com>
@@ -19,10 +19,9 @@
 # Copyright (C) 2018 Red Hat, Inc.
 # All rights reserved.
 #
-set -e
 
-# Enable IPA COPR repo
-dnf copr enable -y @freeipa/freeipa-4-7
+# Enable IPA's nightly COPR repo
+dnf copr enable -y @freeipa/freeipa-master-nightly
 
 # Install latest IPA from official fedora/updates repository
 dnf install -y freeipa-server freeipa-server-dns freeipa-server-trust-ad python3-ipatests --best --allowerasing
